@@ -1,4 +1,4 @@
-// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
+// Copyright (c) 2002-2004 Rob Kaper <cap@capsi.com>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -24,7 +24,6 @@
 #include <qptrlist.h>
 
 #include <kmainwindow.h>
-#include <kaction.h>
 
 #include "configdlg.h"
 #include "portfolioview.h"
@@ -35,6 +34,9 @@ class AtlantikNetwork;
 
 struct AtlantikConfig
 {
+	// General options;
+	bool chatTimestamps;
+
 	// Personalization options
 	QString playerName;
 
@@ -45,6 +47,10 @@ struct AtlantikConfig
 	bool quartzEffects;
 	bool animateTokens;
 
+	// Meta server options
+	bool connectOnStart;
+	bool hideDevelopmentServers;
+
 	// Portfolio colors
 	QColor activeColor, inactiveColor;
 };
@@ -58,6 +64,20 @@ class Player;
 class Estate;
 class Trade;
 
+class LogTextEdit : public QTextEdit
+{
+Q_OBJECT
+
+public:
+	LogTextEdit( QWidget *parent = 0, const char *name = 0 );
+	virtual ~LogTextEdit();
+
+	QPopupMenu *LogTextEdit::createPopupMenu( const QPoint & pos );
+
+private:
+	KAction *m_clear, *m_selectAll, *m_copy;
+};
+
 /**
  * Main Atlantik window.
  * Manages gameboard, portfolios and pretty much everything else.
@@ -109,7 +129,7 @@ public slots:
 	 void slotNetworkConnected();
 
 	/**
-	 * An error occured while setting up the network connection. Inform the
+	 * An error occurred while setting up the network connection. Inform the
 	 * user.
 	 *
 	 * @param errno See http://doc.trolltech.com/3.0/qsocket.html#Error-enum
@@ -122,6 +142,12 @@ public slots:
 	 */
 	void slotConfigure();
 
+	/**
+	 * Opens the KNotify dialog for configuration events.
+	 *
+	 */
+	void configureNotifications();
+
 	/**
 	 * Reads values from configuration dialog and stores them into
 	 * global configuration struct. If values have changed, appropriate
@@ -172,6 +198,7 @@ public slots:
 	void removeGUI(Trade *trade);
 
 	void playerChanged(Player *player);
+	void gainedTurn();
 
 signals:
 	void rollDice();
