@@ -1,4 +1,4 @@
-// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
+// Copyright (c) 2002-2004 Rob Kaper <cap@capsi.com>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -15,6 +15,10 @@
 // Boston, MA 02111-1307, USA.
 
 #include <qdom.h>
+#include <qptrlist.h>
+
+#include <kextendedsocket.h>
+#include <klatencytimer.h>
 
 #include "monopigator.moc"
 #include "main.h"
@@ -30,12 +34,13 @@ Monopigator::~Monopigator()
 {
 	if (m_job)
 		m_job -> kill();
+        delete m_downloadData;
+        m_downloadData=0L;
 }
 
 void Monopigator::loadData(const KURL &url)
 {
-	if (m_downloadData)
-		delete m_downloadData;
+    delete m_downloadData;
 	m_downloadData = new QBuffer();
 	m_downloadData->open(IO_WriteOnly);
 	m_downloadData->reset();
@@ -103,13 +108,36 @@ void Monopigator::processData(const QByteArray &data, bool okSoFar)
 	}
 }
 
-MonopigatorEntry::MonopigatorEntry(QListView *parent, QString host, QString version, QString users, QString port) : QListViewItem(parent, host, version, users, port)
+MonopigatorEntry::MonopigatorEntry(QListView *parent, QString host, QString latency, QString version, QString users, QString port) : QObject(), QListViewItem(parent, host, latency, version, users, port)
 {
+//	setEnabled(false);
+	parent->sort();
+
+	QPtrList<KAddressInfo> addresses = KExtendedSocket::lookup(host, port);
+	addresses.setAutoDelete(true);
+	m_latencyTimer = new KLatencyTimer(port.toInt(), this, "latencyTimer");
+
+	if ( addresses.count() )
+	{
+		m_latencyTimer->setHost(addresses.first()->address());
+
+		connect(m_latencyTimer, SIGNAL(answer(int)), this, SLOT(updateLatency(int)));
+		m_latencyTimer->start();
+	}
+}
+
+void MonopigatorEntry::updateLatency(int msec)
+{
+	setText(1, QString::number(msec));
+//	setEnabled(true);
+
+	listView()->sort();
 }
 
 int MonopigatorEntry::compare(QListViewItem *i, int col, bool ascending) const
 {
-	if (col == 2)
+	// Colums 1 and 3 are integers (latency and users)
+	if (col == 1 || col == 3)
 	{
 		int myVal = text(col).toInt(), iVal = i->text(col).toInt();
 		if (myVal == iVal)
