@@ -20,24 +20,38 @@
 #include <qradiobutton.h>
 
 #include <kdebug.h>
-
 #include <kdialog.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
+#include <kstandarddirs.h>
 
 #include <player.h>
- 
+
+#include "tokenwidget.h"
 #include "selectconfiguration_widget.moc"
 
 SelectConfiguration::SelectConfiguration(QWidget *parent, const char *name) : QWidget(parent, name)
 {
+	m_tokenWidget = 0;
+
 	m_mainLayout = new QVBoxLayout(this, KDialog::marginHint());
 	Q_CHECK_PTR(m_mainLayout);
 
 	// Game configuration.
 	m_configBox = new QVGroupBox(i18n("Game Configuration"), this, "configBox");
-	m_mainLayout->addWidget(m_configBox); 
+	m_mainLayout->addWidget(m_configBox);
+
+	// Player buttons.
+	QHBoxLayout *playerButtons = new QHBoxLayout(m_mainLayout, KDialog::spacingHint());
+	playerButtons->setMargin(0);
+
+	playerButtons->addItem(new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum));
+
+	m_tokenButton = new KPushButton(SmallIcon("personal"), i18n("Select Token..."), this);
+	playerButtons->addWidget(m_tokenButton);
+
+	connect(m_tokenButton, SIGNAL(clicked()), this, SLOT(slotTokenButtonClicked()));
 
 	// Vertical spacer.
 	m_mainLayout->addItem(new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding));
@@ -45,7 +59,6 @@ SelectConfiguration::SelectConfiguration(QWidget *parent, const char *name) : QW
 	// Server buttons.
 	QHBoxLayout *serverButtons = new QHBoxLayout(m_mainLayout, KDialog::spacingHint());
 	serverButtons->setMargin(0);
-	m_mainLayout->addItem(serverButtons);
 
 	m_backButton = new KPushButton(SmallIcon("back"), i18n("Leave Game"), this);
 	serverButtons->addWidget(m_backButton);
@@ -54,10 +67,10 @@ SelectConfiguration::SelectConfiguration(QWidget *parent, const char *name) : QW
 
 	serverButtons->addItem(new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum));
 
-	m_connectButton = new KPushButton(SmallIcon("forward"), i18n("Start Game"), this);
-	serverButtons->addWidget(m_connectButton);
+	m_startButton = new KPushButton(SmallIcon("forward"), i18n("Start Game"), this);
+	serverButtons->addWidget(m_startButton);
 
-	connect(m_connectButton, SIGNAL(clicked()), this, SIGNAL(startGame()));
+	connect(m_startButton, SIGNAL(clicked()), this, SIGNAL(startGame()));
 
     // Status indicator.
 	m_statusLabel = new QLabel(this);
@@ -75,6 +88,28 @@ void SelectConfiguration::initGame()
 	m_statusLabel->setText(i18n("Game started. Retrieving full game data..."));
 }
 
+void SelectConfiguration::slotTokenButtonClicked()
+{
+	if (m_tokenWidget)
+	{
+		m_tokenWidget->show();
+		return;
+	}
+
+	m_tokenWidget = new TokenWidget(0);
+	m_tokenWidget->show();
+
+	connect(m_tokenWidget, SIGNAL(iconSelected(const QString &)), this, SLOT(slotTokenSelected(const QString &)));
+}
+
+void SelectConfiguration::slotTokenSelected(const QString &name)
+{
+	emit iconSelected(name);
+	m_tokenWidget->close();
+//	m_tokenWidget->deleteLater(); // FIXME: crashes?
+	m_tokenWidget = 0;
+}
+
 void SelectConfiguration::gameOption(QString title, QString type, QString value, QString edit, QString command)
 {
 	// Find if option exists in GUI yet
@@ -97,7 +132,6 @@ void SelectConfiguration::gameOption(QString title, QString type, QString value,
 
 		connect(checkBox, SIGNAL(clicked()), this, SLOT(optionChanged()));
 	}
-
 	// TODO: create options other than type=bool
 
 	// TODO: Enable edit for master only
@@ -116,9 +150,10 @@ void SelectConfiguration::optionChanged()
 
 void SelectConfiguration::slotEndUpdate()
 {
+	m_statusLabel->setText(i18n("Retrieved configuration list."));
 }
 
 void SelectConfiguration::setCanStart(const bool &canStart)
 {
-	m_connectButton->setEnabled(canStart);
+	m_startButton->setEnabled(canStart);
 }
