@@ -29,6 +29,7 @@ class QCheckBox;
 class QListViewItem;
 
 class Player;
+class TokenWidget;
 
 class SelectConfiguration : public QWidget
 {
@@ -43,6 +44,8 @@ public:
 	int portToConnect();
 
 private slots:
+	void slotTokenButtonClicked();
+	void slotTokenSelected(const QString &name);
 	void gameOption(QString title, QString type, QString value, QString edit, QString command);
 	void optionChanged();
 	void slotEndUpdate();
@@ -54,16 +57,18 @@ signals:
 	void joinConfiguration(int configurationId);
 	void newConfiguration();
 	void buttonCommand(QString);
+	void iconSelected(const QString &);
 //	void statusChanged();
 
 private:
 	QVBoxLayout *m_mainLayout;
 	QLabel *m_statusLabel;
 	QVGroupBox *m_configBox, *m_messageBox;
-	KPushButton *m_backButton, *m_connectButton;
+	KPushButton *m_backButton, *m_startButton, *m_tokenButton;
 	QMap <QObject *, QString> m_optionCommandMap;
 	QMap <QString, QCheckBox *> m_checkBoxMap;
 	QMap <Player *, QListViewItem *> m_items;
+	TokenWidget *m_tokenWidget;
 };
 
 #endif
