@@ -1,4 +1,4 @@
-// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
+// Copyright (c) 2002-2004 Rob Kaper <cap@capsi.com>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,8 +14,12 @@
 // the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 // Boston, MA 02111-1307, USA.
 
-#include <qvbuttongroup.h>
+#include <qlayout.h>
 #include <qradiobutton.h>
+#include <qregexp.h>
+#include <qsizepolicy.h>
+#include <qvbuttongroup.h>
+#include <qhgroupbox.h>
 
 #include <kdialog.h>
 #include <kextendedsocket.h>
@@ -24,55 +28,67 @@
 
 #include "selectserver_widget.moc"
 
-SelectServer::SelectServer(QWidget *parent, const char *name) : QWidget(parent, name)
+SelectServer::SelectServer(bool useMonopigatorOnStart, bool hideDevelopmentServers, QWidget *parent, const char *name) : QWidget(parent, name)
 {
+	m_hideDevelopmentServers = hideDevelopmentServers;
+
 	m_mainLayout = new QVBoxLayout(this, KDialog::marginHint());
 	Q_CHECK_PTR(m_mainLayout);
 
-	QVButtonGroup *bgroup;
-//	bgroup = new QVButtonGroup(i18n("Start or select a monopd server"), this, "bgroup");
-	bgroup = new QVButtonGroup(i18n("Select monopd Server"), this, "bgroup");
+	// Custom server group
+	QHGroupBox *customGroup = new QHGroupBox(i18n("Enter Custom monopd Server"), this, "customGroup");
+	m_mainLayout->addWidget(customGroup);
+
+	QLabel *hostLabel = new QLabel(i18n("Hostname:"), customGroup);
+
+	m_hostEdit = new KLineEdit(customGroup);
+	m_hostEdit->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum));
+
+	QLabel *portLabel = new QLabel(i18n("Port:"), customGroup);
+
+	m_portEdit = new KLineEdit(QString::number(1234), customGroup);
+	m_portEdit->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum));
+
+	KPushButton *connectButton = new KPushButton( KGuiItem(i18n("Connect"), "network"), customGroup);
+	connect(connectButton, SIGNAL(clicked()), this, SLOT(customConnect()));
+
+	// Server list group
+	QVButtonGroup *bgroup = new QVButtonGroup(i18n("Select monopd Server"), this, "bgroup");
 	bgroup->setExclusive(true);
-	m_mainLayout->addWidget(bgroup); 
-
-	// Button for local games
-//	m_localGameButton = new QRadioButton(QString(i18n("Start a local server")), bgroup, "m_localGameButton");
-//	connect(m_localGameButton, SIGNAL(stateChanged(int)), this, SLOT(validateConnectButton())); 
-
-	// Button for on-line games
-//	m_onlineGameButton = new QRadioButton(QString(i18n("Select a server to play a game on-line")), bgroup, "m_onlineGameButton");
-//	m_localGameButton->setEnabled(true);
-//	connect(m_onlineGameButton, SIGNAL(stateChanged(int)), this, SLOT(validateConnectButton()));
+	m_mainLayout->addWidget(bgroup);
 
 	// List of servers
 	m_serverList = new KListView(bgroup, "m_serverList");
-	m_serverList->addColumn(QString(i18n("Host")));
-	m_serverList->addColumn(QString(i18n("Version")));
-	m_serverList->addColumn(QString(i18n("Users")));
+	m_serverList->addColumn(i18n("Host"));
+	m_serverList->addColumn(i18n("Latency"));
+	m_serverList->addColumn(i18n("Version"));
+	m_serverList->addColumn(i18n("Users"));
 	m_serverList->setAllColumnsShowFocus(true);
+	m_serverList->setSorting(1);
 //	m_mainLayout->addWidget(m_serverList);
 
 	connect(m_serverList, SIGNAL(clicked(QListViewItem *)), this, SLOT(validateConnectButton()));
-//	connect(m_serverList, SIGNAL(clicked(QListViewItem *)), this, SLOT(slotListClicked(QListViewItem *)));
 	connect(m_serverList, SIGNAL(doubleClicked(QListViewItem *)), this, SLOT(slotConnect()));
 	connect(m_serverList, SIGNAL(rightButtonClicked(QListViewItem *, const QPoint &, int)), this, SLOT(validateConnectButton()));
 	connect(m_serverList, SIGNAL(selectionChanged(QListViewItem *)), this, SLOT(validateConnectButton()));
 
- 	QHBoxLayout *buttonBox = new QHBoxLayout(m_mainLayout, KDialog::spacingHint());
+	QHBoxLayout *buttonBox = new QHBoxLayout(m_mainLayout, KDialog::spacingHint());
 	buttonBox->addItem(new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum));
 
-	m_refreshButton = new KPushButton(BarIcon("reload", KIcon::SizeSmall), i18n("Refresh"), this);
+	// Server List / Refresh
+	m_refreshButton = new KPushButton( KGuiItem(useMonopigatorOnStart ? i18n("Reload Server List") : i18n("Get Server List"), useMonopigatorOnStart ? "reload" : "network"), this);
 	buttonBox->addWidget(m_refreshButton);
 
 	connect(m_refreshButton, SIGNAL(clicked()), this, SLOT(slotRefresh()));
 
+	// Connect
 	m_connectButton = new KPushButton(BarIcon("forward", KIcon::SizeSmall), i18n("Connect"), this);
 	m_connectButton->setEnabled(false);
 	buttonBox->addWidget(m_connectButton);
 
 	connect(m_connectButton, SIGNAL(clicked()), this, SLOT(slotConnect()));
-	
-    // Status indicator
+
+//	Status indicator
 	status_label = new QLabel(this);
 	m_mainLayout->addWidget(status_label);
 
@@ -83,58 +99,37 @@ SelectServer::SelectServer(QWidget *parent, const char *name) : QWidget(parent,
 	connect(m_monopigator, SIGNAL(finished()), SLOT(monopigatorFinished()));
 	connect(m_monopigator, SIGNAL(timeout()), SLOT(monopigatorTimeout()));
 
-	// Until we have a good way to use start a local monopd server, disable this button
-//	m_localGameButton->setEnabled(false);
-
-	slotRefresh();
+	slotRefresh(useMonopigatorOnStart);
 }
 
 SelectServer::~SelectServer()
 {
 	delete m_monopigator;
-	delete m_localSocket;
+}
+
+void SelectServer::setHideDevelopmentServers(bool hideDevelopmentServers)
+{
+	m_hideDevelopmentServers = hideDevelopmentServers;
 }
 
 void SelectServer::initMonopigator()
 {
 	// Hardcoded, but there aren't any other Monopigator root servers at the moment
 	status_label->setText(i18n("Retrieving server list..."));
+	m_refreshButton->setGuiItem(KGuiItem(i18n("Reload Server List"), "reload"));
 	m_monopigator->loadData("http://gator.monopd.net/");
 }
 
-void SelectServer::checkLocalServer()
-{
-	m_localSocket = new KExtendedSocket(0, 0, KExtendedSocket::inputBufferedSocket);
-	connect(m_localSocket, SIGNAL(connectionSuccess()), this, SLOT(slotLocalConnected()));
-	connect(m_localSocket, SIGNAL(connectionFailed(int)), this, SLOT(slotLocalError()));
-	m_localSocket->setAddress("localhost", 1234);
-	m_localSocket->enableRead(true);
-	m_localSocket->startAsyncConnect();
-}
-
 void SelectServer::slotMonopigatorAdd(QString host, QString port, QString version, int users)
 {
-	MonopigatorEntry *item = new MonopigatorEntry(m_serverList, host, version, (users == -1) ? i18n("unknown") : QString::number(users), port);
+	if (m_hideDevelopmentServers && version.find( QRegExp("(CVS|-dev)") ) != -1 )
+		return;
+
+	MonopigatorEntry *item = new MonopigatorEntry(m_serverList, host, QString::number(9999), version, (users == -1) ? i18n("unknown") : QString::number(users), port);
 	item->setPixmap(0, BarIcon("atlantik", KIcon::SizeSmall));
 	validateConnectButton();
 }
 
-void SelectServer::slotLocalConnected()
-{
-	m_localServerAvailable = true;
-
-	MonopigatorEntry *item = new MonopigatorEntry(m_serverList, "localhost", i18n("unknown"), i18n("unknown"), QString::number(1234));
-	item->setPixmap(0, BarIcon("atlantik", KIcon::SizeSmall));
-	validateConnectButton();
-}
-
-void SelectServer::slotLocalError()
-{
-	m_localServerAvailable = false;
-
-	// TODO: fork server or offer option to do so
-}
-
 void SelectServer::monopigatorFinished()
 {
 	status_label->setText(i18n("Retrieved server list."));
@@ -143,57 +138,38 @@ void SelectServer::monopigatorFinished()
 
 void SelectServer::monopigatorTimeout()
 {
+	status_label->setText(i18n("Error while retrieving the server list."));
 	m_refreshButton->setEnabled(true);
 }
 
-void SelectServer::validateRadioButtons()
-{
-	return;
-	if (m_serverList->childCount() > 0)
-	{
-		if (!m_onlineGameButton->isEnabled())
-			m_onlineGameButton->setEnabled(true);
-	}
-	else
-	{
-		if (m_onlineGameButton->isEnabled())
-			m_onlineGameButton->setEnabled(false);
-		m_serverList->clearSelection();
-	}
-}
-
 void SelectServer::validateConnectButton()
 {
-	validateRadioButtons();
-
-//	if ( (m_localGameButton->isEnabled() && m_localGameButton->isChecked()) || (m_onlineGameButton->isEnabled() && m_onlineGameButton->isChecked() && m_serverList->selectedItem()) )
 	if (m_serverList->selectedItem())
 		m_connectButton->setEnabled(true);
 	else
 		m_connectButton->setEnabled(false);
 }
 
-void SelectServer::slotListClicked(QListViewItem *item)
+void SelectServer::slotRefresh(bool useMonopigator)
 {
-	// Simulate a user press
-	if(item && !m_onlineGameButton->isOn())
-		m_onlineGameButton->toggle();
-}
-
-void SelectServer::slotRefresh()
-{
-	m_localServerAvailable = false;
-
 	m_serverList->clear();
 	validateConnectButton();
 
-	checkLocalServer();
-	m_refreshButton->setEnabled(false);
-	initMonopigator();
+	if (useMonopigator)
+	{
+		m_refreshButton->setEnabled(false);
+		initMonopigator();
+	}
 }
 
 void SelectServer::slotConnect()
 {
 	if (QListViewItem *item = m_serverList->selectedItem())
-		emit serverConnect(item->text(0), item->text(3).toInt());
+		emit serverConnect(item->text(0), item->text(4).toInt());
+}
+
+void SelectServer::customConnect()
+{
+	if (!m_hostEdit->text().isEmpty() && !m_portEdit->text().isEmpty())
+		emit serverConnect(m_hostEdit->text(), m_portEdit->text().toInt());
 }
