@@ -22,6 +22,7 @@
 #include <qradiobutton.h>
 #include <qlabel.h>
 
+#include <klineedit.h>
 #include <klistview.h>
 #include <kpushbutton.h>
 
@@ -34,45 +35,40 @@ class SelectServer : public QWidget
 Q_OBJECT
 
 public:
-	SelectServer(QWidget *parent, const char *name=0);
+	SelectServer(bool useMonopigatorOnStart, bool hideDevelopmentServers, QWidget *parent, const char *name=0);
 	virtual ~SelectServer();
 
 	void initPage();
-		bool validateNext();
-		QString hostToConnect() const;
-		int portToConnect();
+	void setHideDevelopmentServers(bool hideDevelopmentServers);
+	bool validateNext();
+	QString hostToConnect() const;
+	int portToConnect();
 
-	public slots:
-		void validateRadioButtons();
-		void validateConnectButton();
+public slots:
+	void validateConnectButton();
 
-		void slotMonopigatorAdd(QString host, QString port, QString version, int users);
-		void slotListClicked(QListViewItem *);
+	void slotMonopigatorAdd(QString host, QString port, QString version, int users);
 
-	private slots:
-		void slotConnect();
-		void slotRefresh();
-		void slotLocalConnected();
-		void slotLocalError();
-		void monopigatorFinished();
-		void monopigatorTimeout();
+private slots:
+	void slotConnect();
+	void customConnect();
+	void slotRefresh(bool useMonopigator = true);
+	void monopigatorFinished();
+	void monopigatorTimeout();
 
-	signals:
-		void serverConnect(const QString host, int port);
-//		void statusChanged();
+signals:
+	void serverConnect(const QString host, int port);
 
 private:
-	void checkLocalServer();
 	void initMonopigator();
 
-		QVBoxLayout *m_mainLayout;
-		QLabel *status_label;
-		QRadioButton *m_localGameButton, *m_onlineGameButton;
-		KListView *m_serverList;
-		KPushButton *m_refreshButton, *m_connectButton;
-		Monopigator *m_monopigator;
-		KExtendedSocket *m_localSocket;
-		bool m_localServerAvailable;
+	QVBoxLayout *m_mainLayout;
+	QLabel *status_label;
+	KListView *m_serverList;
+	KLineEdit *m_hostEdit, *m_portEdit;
+	KPushButton *m_addServerButton, *m_refreshButton, *m_customConnect, *m_connectButton;
+	Monopigator *m_monopigator;
+	bool m_hideDevelopmentServers;
 };
 
 #endif
