@@ -14,6 +14,8 @@
 // the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 // Boston, MA 02111-1307, USA.
 
+#include <iostream>
+
 #include "atlantic_core.moc"
 
 #include "player.h"
@@ -123,7 +125,7 @@ Estate *AtlanticCore::findEstate(int estateId)
 {
 	Estate *estate = 0;
 	for (QPtrListIterator<Estate> it(m_estates); (estate = *it) ; ++it)
-		if (estate->estateId() == estateId)
+		if (estate->id() == estateId)
 			return estate;
 
 	return 0;
@@ -213,3 +215,30 @@ void AtlanticCore::delAuction(Auction *auction)
 	m_auctions.remove(auction);
 	delete auction;
 }
+
+void AtlanticCore::printDebug()
+{
+	Player *player = 0;
+	for (QPtrListIterator<Player> it(m_players); (player = *it) ; ++it)
+		if (player == m_playerSelf)
+			std::cout << "PS: " << player->name().latin1() << ", game " << QString::number(player->gameId()).latin1() << std::endl;
+		else
+			std::cout << " P: " << player->name().latin1() << ", game " << QString::number(player->gameId()).latin1() << std::endl;
+
+	Estate *estate = 0;
+	for (QPtrListIterator<Estate> it(m_estates); (estate = *it) ; ++it)
+		std::cout << " E: " << estate->name().latin1() << std::endl;
+
+	EstateGroup *estateGroup = 0;
+	for (QPtrListIterator<EstateGroup> it(m_estateGroups); (estateGroup = *it) ; ++it)
+		std::cout << "EG: " << estateGroup->name().latin1() << std::endl;
+
+	Auction *auction = 0;
+	for (QPtrListIterator<Auction> it(m_auctions); (auction = *it) ; ++it)
+		std::cout << "A: " << QString::number(auction->auctionId()).latin1() << std::endl;
+
+	Trade *trade = 0;
+	for (QPtrListIterator<Trade> it(m_trades); (trade = *it) ; ++it)
+		std::cout << "T: " << QString::number(trade->tradeId()).latin1() << std::endl;
+
+}
