@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Rob Kaper <cap@capsi.com>
+// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -29,7 +29,7 @@ Q_OBJECT
 
 public:
 	Estate(int estateId);
-	int estateId() const { return m_estateId; }
+	int id() { return m_id; }
 	void setName(QString name);
 	QString name() const;
 	void setEstateGroup(EstateGroup *estateGroup);
@@ -68,7 +68,7 @@ signals:
 
 protected:
 	bool m_changed;
-	int m_estateId;
+	int m_id;
 
 private:
 	QString m_name;
