@@ -24,8 +24,7 @@ class EstateGroup : public QObject
 Q_OBJECT
 
 public:
-	EstateGroup(int groupId);
-
+	EstateGroup(const int id);
 	int id() { return m_id; }
 	void setName(const QString name);
 	QString name() const { return m_name; }
