@@ -21,11 +21,12 @@
 Player::Player(int playerId) : QObject()
 {
 	m_id = playerId;
-	m_location = m_destination = 0;
-	m_money = 0;
 	m_gameId = -1;
 	m_name = "";
 	m_host = "";
+	m_image = "";
+	m_location = m_destination = 0;
+	m_money = 0;
 	m_changed = m_isSelf = false;
 	m_master = m_bankrupt = m_hasDebt = m_hasTurn = m_canRoll = m_canBuy = m_canAuction = m_canUseCard = m_inJail = false;
 }
@@ -90,6 +91,8 @@ void Player::setHasTurn(const bool hasTurn)
 	{
 		m_hasTurn = hasTurn;
 		m_changed = true;
+		if (m_hasTurn && m_isSelf)
+			emit gainedTurn();
 	}
 }
 
@@ -156,11 +159,20 @@ void Player::setHost(const QString &host)
 	}
 }
 
-void Player::setMoney(unsigned int _m)
+void Player::setImage(const QString &image)
 {
-	if (m_money != _m)
+	if (m_image != image)
 	{
-		m_money = _m;
+		m_image = image;
+		m_changed = true;
+	}
+}
+
+void Player::setMoney(unsigned int money)
+{
+	if (m_money != money)
+	{
+		m_money = money;
 		m_changed = true;
 	}
 }
