@@ -44,6 +44,12 @@ AtlantikNetwork::AtlantikNetwork(AtlanticCore *atlanticCore) : KExtendedSocket(0
 	m_playerId = -1;
 
 	QObject::connect(this, SIGNAL(readyRead()), this, SLOT(slotRead()));
+	QObject::connect(this, SIGNAL(lookupFinished(int)),
+	                 this, SLOT(slotLookupFinished(int)));
+	QObject::connect(this, SIGNAL(connectionSuccess()),
+	                 this, SLOT(slotConnectionSuccess()));
+	QObject::connect(this, SIGNAL(connectionFailed(int)),
+	                 this, SLOT(slotConnectionFailed(int)));
 }
 
 AtlantikNetwork::~AtlantikNetwork(void)
@@ -52,7 +58,8 @@ AtlantikNetwork::~AtlantikNetwork(void)
 }
 
 void AtlantikNetwork::rollDice()
-{	writeData(".r");
+{
+	writeData(".r");
 }
 
 void AtlantikNetwork::buyEstate()
@@ -70,129 +77,105 @@ void AtlantikNetwork::startGame()
 	writeData(".gs");
 }
 
+void AtlantikNetwork::reconnect(const QString &cookie)
+{
+	writeData(".R" + cookie);
+}
+
 void AtlantikNetwork::leaveGame()
 {
 	writeData(".gx");
 }
 
 void AtlantikNetwork::endTurn()
-{	writeData(".E");
+{
+	writeData(".E");
 }
 
 void AtlantikNetwork::setName(QString name)
 {
 	// Almost deprecated, will be replaced by libmonopdprotocol
-	QString msg(".n");
-	msg.append(name);
-	writeData(msg);
+	writeData(QString(".n%1").arg(name));
 }
 
 void AtlantikNetwork::tokenConfirmation(Estate *estate)
 {
-	QString msg(".t");
-	msg.append(QString::number(estate ? estate->estateId() : -1));
-	writeData(msg);
+	writeData(QString(".t%1").arg(estate ? estate->id() : -1));
 }
 
 void AtlantikNetwork::estateToggleMortgage(Estate *estate)
 {
-	QString msg(".em");
-	msg.append(QString::number(estate ? estate->estateId() : -1));
-	writeData(msg);
+	writeData(QString(".em%1").arg(estate ? estate->id() : -1));
 }
 
 void AtlantikNetwork::estateHouseBuy(Estate *estate)
 {
-	QString msg(".hb");
-	msg.append(QString::number(estate ? estate->estateId() : -1));
-	writeData(msg);
+	writeData(QString(".hb%1").arg(estate ? estate->id() : -1));
 }
 
 void AtlantikNetwork::estateHouseSell(Estate *estate)
 {
-	QString msg(".hs");
-	msg.append(QString::number(estate ? estate->estateId() : -1));
-	writeData(msg);
+	writeData(QString(".hs%1").arg(estate ? estate->id() : -1));
 }
 
 void AtlantikNetwork::cmdGamesList()
-{	writeData(".gl");
+{
+	writeData(".gl");
 }
 
 void AtlantikNetwork::getPlayerList()
-{	writeData(".gp");
+{
+	writeData(".gp");
 }
 
 void AtlantikNetwork::newGame(const QString &gameType)
 {
-	writeData(".gn" + gameType);
+	writeData(QString(".gn%1").arg(gameType));
 }
 
 void AtlantikNetwork::joinGame(int gameId)
 {
-	QString msg(".gj");
-	msg.append(QString::number(gameId));
-	writeData(msg);
+	writeData(QString(".gj%1").arg(gameId));
 }
 
 void AtlantikNetwork::cmdChat(QString msg)
-{	writeData(msg);
+{
+	writeData(msg);
 }
 
 void AtlantikNetwork::newTrade(Player *player)
 {
-	QString msg(".Tn");
-	msg.append(QString::number(player ? player->id() : -1));
-	writeData(msg);
+	writeData(QString(".Tn%1").arg(player ? player->id() : -1));
 }
 
 void AtlantikNetwork::tradeUpdateEstate(Trade *trade, Estate *estate, Player *player)
 {
-	QString msg(".Te");
-	msg.append(QString::number(trade ? trade->tradeId() : -1));
-	msg.append(":");
-	msg.append(QString::number(estate ? estate->estateId() : -1));
-	msg.append(":");
-	msg.append(QString::number(player ? player->id() : -1));
-	writeData(msg);
+	writeData(QString(".Te%1:%2:%3").arg(trade ? trade->tradeId() : -1).arg(estate ? estate->id() : -1).arg(player ? player->id() : -1));
 }
 
 void AtlantikNetwork::tradeUpdateMoney(Trade *trade, unsigned int money, Player *pFrom, Player *pTo)
 {
-	QString msg(".Tm");
-	msg.append(QString::number(trade ? trade->tradeId() : -1));
-	msg.append(":");
-	msg.append(QString::number(pFrom ? pFrom->id() : -1));
-	msg.append(":");
-	msg.append(QString::number(pTo ? pTo->id() : -1));
-	msg.append(":");
-	msg.append(QString::number(money));
-	writeData(msg);
+	writeData(QString(".Tm%1:%2:%3:%4").arg(trade ? trade->tradeId() : -1).arg(pFrom ? pFrom->id() : -1).arg(pTo ? pTo->id() : -1).arg(money));
 }
 
 void AtlantikNetwork::tradeReject(Trade *trade)
 {
-	QString msg(".Tr");
-	msg.append(QString::number(trade ? trade->tradeId() : -1));
-	writeData(msg);
+	writeData(QString(".Tr%1").arg(trade ? trade->tradeId() : -1));
 }
 
 void AtlantikNetwork::tradeAccept(Trade *trade)
 {
-	QString msg(".Ta");
-	msg.append(QString::number(trade ? trade->tradeId() : -1));
-	msg.append(":");
-	msg.append(QString::number(trade ? trade->revision() : -1));
-	writeData(msg);
+	writeData(QString(".Ta%1:%2").arg(trade ? trade->tradeId() : -1).arg(trade ? trade->revision() : -1));
 }
 
 void AtlantikNetwork::auctionBid(Auction *auction, int amount)
 {
-	QString msg(".ab");
-	msg.append(QString::number(auction ? auction->auctionId() : -1));
-	msg.append(":");
-	msg.append(QString::number(amount));
-	writeData(msg);
+	writeData(QString(".ab%1:%2").arg(auction ? auction->auctionId() : -1).arg(amount));
+}
+
+void AtlantikNetwork::setImage(const QString &name)
+{
+	writeData(QString(".pi%1").arg(name));
 }
 
 void AtlantikNetwork::jailPay()
@@ -212,15 +195,19 @@ void AtlantikNetwork::jailCard()
 
 void AtlantikNetwork::writeData(QString msg)
 {
+	kdDebug() << "sending [" << msg << "]" << endl;
 	msg.append("\n");
 	if (socketStatus() == KExtendedSocket::connected)
 		*m_textStream << msg;
 	else
-		kdDebug() << "could not send [" << msg << "]" << endl;
+		kdDebug() << "warning: socket not connected!" << endl;
 }
 
 void AtlantikNetwork::slotRead()
 {
+	if ( socketStatus() != KExtendedSocket::connected )
+		return;
+
 	if (canReadLine())
 	{
 		processMsg(m_textStream->readLine());
@@ -249,6 +236,7 @@ void AtlantikNetwork::processMsg(QString str)
 	}
 	QDomNode n = e.firstChild();
 	processNode(n);
+	m_atlanticCore->printDebug();
 }
 
 void AtlantikNetwork::processNode(QDomNode n)
@@ -281,7 +269,8 @@ void AtlantikNetwork::processNode(QDomNode n)
 				if (!a.isNull())
 				{
 					estateId = a.value().toInt();
-					Estate *estate = m_atlanticCore->findEstate(a.value().toInt());
+					Estate *estate;
+					estate = m_atlanticCore->findEstate(a.value().toInt());
 
 					emit displayDetails(e.attributeNode(QString("text")).value(), e.attributeNode(QString("cleartext")).value().toInt(), e.attributeNode(QString("clearbuttons")).value().toInt(), estate);
 
@@ -363,6 +352,8 @@ void AtlantikNetwork::processNode(QDomNode n)
 				{
 					gameId = a.value().toInt();
 
+					kdDebug() << "gameupdate for " << QString::number(gameId) << " with playerSelf in game " << QString::number(m_atlanticCore->playerSelf() ? m_atlanticCore->playerSelf()->gameId() : -2) << endl;
+
 					QString status = e.attributeNode(QString("status")).value();
 					if (status == "config")
 					{
@@ -426,6 +417,11 @@ void AtlantikNetwork::processNode(QDomNode n)
 					if (player && !a.isNull())
 						player->setHost(a.value());
 
+					// Update player image/token
+					a = e.attributeNode(QString("image"));
+					if (player && !a.isNull())
+						player->setImage(a.value());
+
 					// Update player money
 					a = e.attributeNode(QString("money"));
 					if (player && !a.isNull())
@@ -481,9 +477,10 @@ void AtlantikNetwork::processNode(QDomNode n)
 					{
 						m_playerLocationMap[player] = a.value().toInt();
 
-						Estate *estate = m_atlanticCore->findEstate(a.value().toInt());
 						bool directMove = false;
 
+						Estate *estate = m_atlanticCore->findEstate(a.value().toInt());
+
 						a = e.attributeNode(QString("directmove"));
 						if (!a.isNull())
 							directMove = a.value().toInt();
@@ -521,7 +518,6 @@ void AtlantikNetwork::processNode(QDomNode n)
 					{
 						// Create EstateGroup object
 						estateGroup = m_atlanticCore->newEstateGroup(a.value().toInt());
-
 						b_newEstateGroup = true;
 					}
 
@@ -567,7 +563,7 @@ void AtlantikNetwork::processNode(QDomNode n)
 						Player *player = 0;
 						QPtrList<Player> playerList = m_atlanticCore->players();
 						for (QPtrListIterator<Player> it(playerList); (player = *it) ; ++it)
-							if (m_playerLocationMap[player] == estate->estateId())
+							if (m_playerLocationMap[player] == estate->id())
 								player->setLocation(estate);
 					}
 
@@ -663,7 +659,7 @@ void AtlantikNetwork::processNode(QDomNode n)
 					if (type=="new")
 					{
 						// TODO: trade->setActor
-						// Player *player = m_playerMap[e.attributeNode(QString("actor")).value().toInt()];
+						// Player *player = m_atlanticCore->findPlayer(e.attributeNode(QString("actor")).value().toInt());
 						// if (trade && player)
 						// 	trade->setActor(player);
 
@@ -838,5 +834,21 @@ void AtlantikNetwork::serverConnect(const QString host, int port)
 {
 	setAddress(host, port);
 	enableRead(true);
+	emit msgInfo(i18n("Connecting to %1...").arg(host));
 	startAsyncConnect();
 }
+
+void AtlantikNetwork::slotLookupFinished(int count)
+{
+	emit msgInfo(i18n("Server host name lookup finished..."));
+}
+
+void AtlantikNetwork::slotConnectionSuccess()
+{
+	emit msgInfo(i18n("Connection established!"));
+}
+
+void AtlantikNetwork::slotConnectionFailed(int error)
+{
+	emit msgError(i18n("Connection failed! Error code: %1").arg(error));
+}
