@@ -49,6 +49,7 @@ private slots:
 	void endTurn();
 	void getPlayerList();
 	void newGame(const QString &gameType);
+	void reconnect(const QString &cookie);
 	void startGame();
 	void leaveGame();
 	void buyEstate();
@@ -66,6 +67,10 @@ private slots:
 	void tradeReject(Trade *trade);
 	void tradeAccept(Trade *trade);
 	void auctionBid(Auction *auction, int amount);
+	void setImage(const QString &name);
+	void slotLookupFinished(int count);
+	void slotConnectionSuccess();
+	void slotConnectionFailed(int error);
 
 public slots:
 	void serverConnect(const QString host, int port);
