@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Rob Kaper <cap@capsi.com>
+// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -27,6 +27,9 @@
 #include <klocale.h>
 #include <kpixmap.h>
 #include <kpushbutton.h>
+#include <kstdguiitem.h>
+
+#include <kdebug.h>
 
 #include <estate.h>
 #include <estategroup.h>
@@ -62,12 +65,10 @@ EstateDetails::EstateDetails(Estate *estate, QString text, QWidget *parent, cons
 
 	m_buttonBox = new QHBoxLayout(m_mainLayout, KDialog::spacingHint());
 	m_buttonBox->setMargin(0);
-	m_mainLayout->addItem(m_buttonBox);
 
 	m_buttonBox->addItem(new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum));
 
 	setEstate(estate);
-	setPaletteBackgroundColor(m_estate ? m_estate->bgColor() : Qt::white);
 }
 
 EstateDetails::~EstateDetails()
@@ -160,8 +161,8 @@ void EstateDetails::paintEvent(QPaintEvent *)
 				{
 					// Houses
 					painter.setBrush(greenHouse);
-					int h = titleHeight-4, w = titleWidth-4;
-					for ( unsigned int i=0 ; i < m_estate->houses() ; i++ )
+						int h = titleHeight-4, w = titleWidth-4;
+						for ( unsigned int i=0 ; i < m_estate->houses() ; i++ )
 						painter.drawRect(2+(i*(w+2)), 2, w, h);
 				}
 			}
@@ -224,7 +225,7 @@ void EstateDetails::addCloseButton()
 {
 	if (!m_closeButton)
 	{
-		m_closeButton = new KPushButton(i18n("Close"), this);
+		m_closeButton = new KPushButton(KStdGuiItem::close(), this);
 		m_buttonBox->addWidget(m_closeButton);
 		m_closeButton->show();
 		connect(m_closeButton, SIGNAL(pressed()), this, SIGNAL(buttonClose()));
@@ -237,6 +238,8 @@ void EstateDetails::setEstate(Estate *estate)
 	{
 		m_estate = estate;
 
+		setPaletteBackgroundColor(m_estate ? m_estate->bgColor() : Qt::white);
+
 		QString columnText = m_estate ? m_estate->name() : QString::null;
 		m_infoListView->setColumnText(0, columnText);
 
@@ -287,7 +290,7 @@ void EstateDetails::appendText(QString text)
 	else
 		infoText->setPixmap(0, QPixmap(SmallIcon("atlantik")));
 
-	m_infoListView->ensureVisible(0, m_infoListView->contentsHeight());
+    m_infoListView->ensureVisible(0, m_infoListView->contentsHeight());
 }
 
 void EstateDetails::clearButtons()
