@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Rob Kaper <cap@capsi.com>
+// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -17,10 +17,13 @@
 #include <qpainter.h>
 #include <qcursor.h>
 
+#include <kdebug.h>
 #include <kdialogbase.h>
+#include <kiconeffect.h>
 #include <kglobalsettings.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
+#include <kstandarddirs.h>
 
 #include <atlantic_core.h>
 #include <config.h>
@@ -35,6 +38,7 @@
 #define PE_SPACE	2
 #define PE_MARGINW	5
 #define PE_MARGINH	2
+#define ICONSIZE	48
 
 PortfolioView::PortfolioView(AtlanticCore *core, Player *player, QColor activeColor, QColor inactiveColor, QWidget *parent, const char *name) : QWidget(parent, name)
 {
@@ -44,12 +48,24 @@ PortfolioView::PortfolioView(AtlanticCore *core, Player *player, QColor activeCo
 	m_inactiveColor = inactiveColor;
 	m_lastPE = 0;
 
-	setBackgroundColor(Qt::white);
-
 	qpixmap = 0;
 	b_recreate = true;
-	
-	setMinimumHeight(35);
+
+	m_portfolioEstates.setAutoDelete(true);
+	setBackgroundColor(Qt::white);
+	setMinimumHeight(ICONSIZE);
+
+	// Init icon
+	m_image = 0;
+	m_imageName = "hamburger.png";
+	loadIcon();
+}
+
+PortfolioView::~PortfolioView()
+{
+	clearPortfolio();
+	delete m_image;
+	delete qpixmap;
 }
 
 Player *PortfolioView::player()
@@ -59,13 +75,15 @@ Player *PortfolioView::player()
 
 void PortfolioView::buildPortfolio()
 {
-	// TODO: clear current portfolioEstateMap
+	if ( m_portfolioEstates.count() )
+		clearPortfolio();
+
 	// Loop through estate groups in order
 	QPtrList<EstateGroup> estateGroups = m_atlanticCore->estateGroups();
 	PortfolioEstate *lastPE = 0, *firstPEprevGroup = 0;
 
 	int x = 100, y = 25, marginHint = 5, bottom;
-	bottom = 20 - PE_HEIGHT - marginHint;
+	bottom = ICONSIZE - PE_HEIGHT - marginHint;
 
 	EstateGroup *estateGroup;
 	for (QPtrListIterator<EstateGroup> it(estateGroups); *it; ++it)
@@ -84,7 +102,7 @@ void PortfolioView::buildPortfolio()
 				{
 					// Create PE
 					PortfolioEstate *portfolioEstate = new PortfolioEstate(estate, m_player, false, this, "portfolioestate");
-					portfolioEstateMap[estate->estateId()] = portfolioEstate;
+					m_portfolioEstates.append(portfolioEstate);
 
  					connect(portfolioEstate, SIGNAL(estateClicked(Estate *)), this, SIGNAL(estateClicked(Estate *)));
 					if (lastPE)
@@ -102,7 +120,7 @@ void PortfolioView::buildPortfolio()
 					}
 					else
 					{
-						x = marginHint;
+						x = ICONSIZE + marginHint;
 						y = 20 + marginHint;
 						if (y > bottom)
 							bottom = y;
@@ -125,6 +143,51 @@ void PortfolioView::buildPortfolio()
 		setMinimumHeight(minHeight);
 }
 
+void PortfolioView::clearPortfolio()
+{
+	m_portfolioEstates.clear();
+}
+
+void PortfolioView::loadIcon()
+{
+	if (m_imageName == m_player->image())
+		return;
+	m_imageName = m_player->image();
+
+	delete m_image;
+	m_image = 0;
+
+	if (!m_imageName.isEmpty())
+	{
+		QString filename = locate("data", "atlantik/themes/default/tokens/" + m_imageName);
+		if (KStandardDirs::exists(filename))
+			m_image = new QPixmap(filename);
+	}
+
+	if (!m_image)
+	{
+		return;
+
+/*
+		m_imageName = "hamburger.png";
+
+		QString filename = locate("data", "atlantik/themes/default/tokens/" + m_imageName);
+		if (KStandardDirs::exists(filename))
+			m_image = new QPixmap(filename);
+*/
+	}
+	else if (ICONSIZE > minimumHeight())
+		setMinimumHeight(ICONSIZE);
+
+	QWMatrix m;
+	m.scale(double(ICONSIZE) / m_image->width(), double(ICONSIZE) / m_image->height());
+	QPixmap *scaledPixmap = new QPixmap(ICONSIZE, ICONSIZE);
+	*scaledPixmap = m_image->xForm(m);
+
+	delete m_image;
+	m_image = scaledPixmap;
+}
+
 void PortfolioView::paintEvent(QPaintEvent *)
 {
 	if (b_recreate)
@@ -143,11 +206,20 @@ void PortfolioView::paintEvent(QPaintEvent *)
 		painter.setBrush(m_player->hasTurn() ? m_activeColor : Qt::black);
 		painter.drawRect(0, 0, width(), 20);
 
+		if (m_image)
+		{
+			painter.setPen(Qt::black);
+			painter.setBrush(Qt::white);
+			painter.drawRect(0, 0, ICONSIZE, ICONSIZE);
+
+			painter.drawPixmap(0, 0, *m_image);
+		}
+
 		painter.setPen(Qt::white);
 		painter.setFont(QFont(KGlobalSettings::generalFont().family(), KGlobalSettings::generalFont().pointSize(), QFont::Bold));
-		painter.drawText(KDialog::marginHint(), 15, m_player->name());
+		painter.drawText(ICONSIZE + KDialog::marginHint(), 15, m_player->name());
 
-		if (portfolioEstateMap.size())
+		if ( m_portfolioEstates.count() )
 			painter.drawText(width() - 50, 15, QString::number(m_player->money()));
 		else
 		{
@@ -155,7 +227,7 @@ void PortfolioView::paintEvent(QPaintEvent *)
 			painter.setBrush(Qt::white);
 
 			painter.setFont(QFont(KGlobalSettings::generalFont().family(), KGlobalSettings::generalFont().pointSize(), QFont::Normal));
-			painter.drawText(KDialog::marginHint(), 30, m_player->host());
+			painter.drawText(ICONSIZE + KDialog::marginHint(), 30, m_player->host());
 		}
 
 		b_recreate = false;
@@ -170,13 +242,15 @@ void PortfolioView::resizeEvent(QResizeEvent *)
 
 void PortfolioView::playerChanged()
 {
+	loadIcon();
+
 	b_recreate = true;
 	update();
 }
 
-void PortfolioView::mousePressEvent(QMouseEvent *e) 
+void PortfolioView::mousePressEvent(QMouseEvent *e)
 {
-	if (e->button()==RightButton && !m_player->isSelf() && portfolioEstateMap.size())
+	if (e->button()==RightButton && !m_player->isSelf() && m_portfolioEstates.count() )
 	{
 		KPopupMenu *rmbMenu = new KPopupMenu(this);
 		rmbMenu->insertTitle(m_player->name());
