@@ -19,7 +19,7 @@
 
 #include <qwidget.h>
 #include <qpixmap.h>
-#include <qmap.h>
+#include <qptrlist.h>
 
 #include "portfolioestate.h"
 
@@ -36,7 +36,10 @@ Q_OBJECT
 
 public:
 	PortfolioView(AtlanticCore *core, Player *_player, QColor activeColor, QColor inactiveColor, QWidget *parent, const char *name = 0);
+	~PortfolioView();
+
 	void buildPortfolio();
+	void clearPortfolio();
 
 	Player *player();
 
@@ -54,13 +57,16 @@ private slots:
 	void slotMenuAction(int item);
 
 private:
+	void loadIcon();
+
 	AtlanticCore *m_atlanticCore;
 	Player *m_player;
 	PortfolioEstate *m_lastPE;
 	QColor m_activeColor, m_inactiveColor;
-	QPixmap *qpixmap;
+	QPixmap *qpixmap, *m_image;
+	QString m_imageName;
 	bool b_recreate;
-	QMap<int, PortfolioEstate*> portfolioEstateMap;
+	QPtrList<PortfolioEstate> m_portfolioEstates;
 };
 
 #endif
