@@ -31,6 +31,7 @@ Q_OBJECT
 
 	public:
 		Token (Player *player, AtlantikBoard *parent, const char *name = 0);
+		~Token();
 		Player *player();
 		void setLocation(Estate *estate);
 		Estate *location() { return m_location; }
@@ -47,12 +48,15 @@ Q_OBJECT
 		void resizeEvent(QResizeEvent *);
 
 private:
+		void loadIcon();
+
 		Player *m_player;
 		Estate *m_location, *m_destination;
 		bool m_inJail;
 		AtlantikBoard *m_parentBoard;
 		bool b_recreate;
-		QPixmap *qpixmap;
+		QPixmap *qpixmap, *m_image;
+		QString m_imageName;
 };
 
 #endif
