@@ -5,12 +5,10 @@
  */
 #include <config.h>
 
-
-#include <kglobal.h>
 #include <kstandarddirs.h>
-#include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kapplication.h>
+#include <kaboutdata.h>
 
 #include "version.h"
 #include "toplevel.h"
@@ -19,14 +17,12 @@
 #include <arts/dispatcher.h>
 #endif
 
-#include <kaboutdata.h>
 
 static const char *description =
 	I18N_NOOP("KDE Space Game");
 
 int main( int argc, char *argv[] )
 {
-
     KAboutData aboutData( "kasteroids", I18N_NOOP("KAsteroids"),
         KASTEROIDS_VERSION, description, KAboutData::License_GPL,
         "(c) 1997, Martin R. Jones");
@@ -43,12 +39,13 @@ int main( int argc, char *argv[] )
     Arts::Dispatcher dispatcher;
 #endif
 
-    KAstTopLevel *mainWidget = new KAstTopLevel();
-    app.setMainWidget( mainWidget );
-    mainWidget->show();
-
-    app.exec();
-
-    return 0;
+    if( app.isRestored() )
+        RESTORE(KAstTopLevel)
+    else {
+        KAstTopLevel *w = new KAstTopLevel;
+        app.setMainWidget(w);
+        w->show();
+    }
+    return app.exec();
 }
 
