@@ -7,29 +7,30 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlcdnumber.h>
+#include <qspinbox.h>
+#include <qcheckbox.h>
 
 #include <kdebug.h>
 #include <kapplication.h>
 #include <kstandarddirs.h>
+#include <kglobalsettings.h>
 #include <kmessagebox.h>
-#include <kmainwindow.h>
-#include <kconfig.h>
 #include <klocale.h>
 #include <kkeydialog.h>
 #include <kaction.h>
-#include <kstdaction.h>
 #include <kstdgameaction.h>
 #include <kaudioplayer.h>
 #include <kscoredialog.h>
+#include <kconfigdialog.h>
 
+#include "settings.h"
 #include "toplevel.h"
 #include "ledmeter.h"
-#include "preferences.h"
-#include "version.h"
 
 #include "toplevel.moc"
 
 #include <X11/Xlib.h>
+#include <fixx11h.h>
 
 #define SB_SCORE	1
 #define SB_LEVEL	2
@@ -62,20 +63,6 @@ SLevel levels[MAX_LEVELS] =
     { 5, 1.0 }
 };
 
-const char *soundEvents[] =
-{
-    "ShipDestroyed",
-    "RockDestroyed",
-    0
-};
-
-const char *soundDefaults[] =
-{
-    "Explosion.wav",
-    "ploop.wav",
-    0
-};
-
 #ifdef KA_ENABLE_SOUND
 #include <arts/dispatcher.h>
 #include <arts/soundserver.h>
@@ -84,10 +71,8 @@ Arts::SimpleSoundServer *soundServer = 0;
 #endif
 
 
-KAstTopLevel::KAstTopLevel() : KMainWindow(0)
+KAstTopLevel::KAstTopLevel()
 {
-    setCaption("");
-
     QWidget *mainWin = new QWidget( this );
     mainWin->setFixedSize(640, 480);
 
@@ -102,7 +87,7 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
     QHBoxLayout *hbd = new QHBoxLayout;
     vb->addLayout( hb );
 
-    QFont labelFont( "helvetica", 24 );
+    QFont labelFont( KGlobalSettings::generalFont().family(), 24 );
     QColorGroup grp( darkGreen, black, QColor( 128, 128, 128 ),
 	    QColor( 64, 64, 64 ), black, darkGreen, black );
     QPalette pal( grp, grp, grp );
@@ -173,7 +158,7 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
 
     vb->addLayout( hbd );
 
-    QFont smallFont( "helvetica", 14 );
+    QFont smallFont( KGlobalSettings::generalFont().family(), 14 );
     hbd->addSpacing( 10 );
 
     QString sprites_prefix =
@@ -271,7 +256,7 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
                          Arts::Reference("global:Arts_SimpleSoundServer") );
 #endif
 
-    readSettings();
+    loadSettings();
     slotNewGame();
     installEventFilter(this);
 }
@@ -279,6 +264,8 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
 KAstTopLevel::~KAstTopLevel()
 {
     XAutoRepeatOn( qt_xdisplay() );
+    soundDict.setAutoDelete(true);
+    soundDict.clear();
 #ifdef KA_ENABLE_SOUND
     delete soundServer;
 #endif
@@ -290,7 +277,7 @@ void KAstTopLevel::initKAction()
     KStdGameAction::gameNew( this, SLOT( slotNewGame() ), actionCollection() );
     KStdGameAction::highscores( this, SLOT( slotShowHighscores() ), actionCollection() );
     KStdGameAction::pause( this, SLOT( slotPause() ), actionCollection() );
-    KStdGameAction::quit(this, SLOT( slotQuit() ), actionCollection());
+    KStdGameAction::quit(this, SLOT( close() ), actionCollection());
 
 // settings
     KStdAction::keyBindings(this, SLOT( slotKeyConfig() ), actionCollection());
@@ -301,38 +288,23 @@ void KAstTopLevel::initKAction()
     keycodes.insert(RotateLeft, new KAction(i18n("Rotate Left"), Qt::Key_Left, 0, 0, actionCollection(), "RotateLeft"));
     keycodes.insert(RotateRight, new KAction(i18n("Rotate Right"), Qt::Key_Right, 0, 0, actionCollection(), "RotateRight"));
     keycodes.insert(Shoot, new KAction(i18n("Shoot"), Qt::Key_Space, 0, 0, actionCollection(), "Shoot"));
-    keycodes.insert(Teleport, new KAction(i18n("Teleport"), Qt::Key_Z, 0, 0, actionCollection(), "Teleport"));
+//     keycodes.insert(Teleport, new KAction(i18n("Teleport"), Qt::Key_Z, 0, 0, actionCollection(), "Teleport"));
     keycodes.insert(Brake, new KAction(i18n("Brake"), Qt::Key_X, 0, 0, actionCollection(), "Brake"));
     keycodes.insert(Shield, new KAction(i18n("Shield"), Qt::Key_S, 0, 0, actionCollection(), "Shield"));
     launchAction = new KAction(i18n("Launch"), Qt::Key_L, this, SLOT(slotLaunch()), actionCollection(), "Launch");
-    
-    createGUI("kasteroidsui.rc");
+
+    createGUI();
 }
 
 
-void KAstTopLevel::readSettings()
+void KAstTopLevel::loadSettings()
 {
-    KConfig *config = kapp->config();
-    config->setGroup( "Sounds" );
+    soundDict.insert("ShipDestroyed", 
+                 new QString( locate("sounds", Settings::soundShipDestroyed())) );
+    soundDict.insert("RockDestroyed", 
+                 new QString( locate("sounds", Settings::soundRockDestroyed())) );
 
-    QString sound_prefix =
-        KGlobal::dirs()->findResourceDir("sounds", "Explosion.wav");
-    kdDebug() << "soundPrefix = " << sound_prefix << endl;
-
-    QString qs;
-
-    for ( int i = 0; soundEvents[i]; i++ )
-    {
-	qs = config->readEntry( soundEvents[i], soundDefaults[i] );
-        soundDict.insert( soundEvents[i], new QString( sound_prefix + qs ) );
-    }
-
-    sound = config->readBoolEntry( "PlaySounds", true );
-
-    config->setGroup( "Preferences" );
-
-    showHiscores = config->readBoolEntry( "showHiscores", false );
-    shipsRemain = config->readNumEntry( "numShips", 3 );
+    shipsRemain = Settings::numShips();
 }
 
 void KAstTopLevel::playSound( const char *snd )
@@ -340,6 +312,8 @@ void KAstTopLevel::playSound( const char *snd )
 // KAudioPlayer sometimes seem to be a little bit...slow
 // it takes a moment until the sound is played - maybe an arts problem
 // but it's a good temporary solution
+    if (!Settings::playSounds())
+        return;
 
     QString *filename = soundDict[ snd ];
     if (filename) {
@@ -348,28 +322,26 @@ void KAstTopLevel::playSound( const char *snd )
 
 return; // remove this and the above when the sound below is working correctly
 #ifdef KA_ENABLE_SOUND
-    if ( sound ) {
-        QString *filename = soundDict[ snd ];
-        if (filename) {
-            kdDebug() << "playing " << *filename << endl;
-            if(!soundServer->isNull()) soundServer->play(filename->latin1());
-        }
+    QString *filename = soundDict[ snd ];
+    if (filename) {
+        kdDebug()<< "playing " << *filename << endl;
+        if(!soundServer->isNull()) soundServer->play(filename->latin1());
     }
 #endif
 }
 
 bool KAstTopLevel::eventFilter( QObject* /* object */, QEvent *event )
 {
-    QKeyEvent *e = dynamic_cast<QKeyEvent*>(event);
-    if (event->type() == QEvent::AccelOverride)
-    {
-        if (processKeyPress(e)) return true;
-        else return false;
-    }
-    else if (event->type() == 7) // 7 == QEvent::KeyRelease
-    {
-        if (processKeyRelease(e)) return true;
-        else return false;
+	QKeyEvent *e = dynamic_cast<QKeyEvent*>(event);
+	if (event->type() == QEvent::AccelOverride)
+	{
+		if (processKeyPress(e)) return true;
+		else return false;
+	}
+	else if (event->type() == QEvent::KeyRelease)
+	{
+		if (processKeyRelease(e)) return true;
+		else return false;
 	}
 	return false;
 }
@@ -412,9 +384,9 @@ bool KAstTopLevel::processKeyPress( QKeyEvent *event )
             view->setShield( true );
             break;
 
-        case Teleport:
+/*        case Teleport:
             view->teleport( true );
-            break;
+            break;*/
 
         case Brake:
             view->brake( true );
@@ -466,32 +438,35 @@ bool KAstTopLevel::processKeyRelease( QKeyEvent *event )
             view->setShield( false );
             break;
 
-        case Teleport:
+/*        case Teleport:
             view->teleport( false );
-            break;
+            break;*/
 
         case Invalid:
         default:
             return false;
     }
+
     return true;
 }
 
 void KAstTopLevel::focusInEvent( QFocusEvent *e )
 {
+    view->pause( false );
     XAutoRepeatOff( qt_xdisplay() );
     KMainWindow::focusInEvent(e);
 }
 
 void KAstTopLevel::focusOutEvent( QFocusEvent *e )
 {
+    view->pause( true );
     XAutoRepeatOn( qt_xdisplay() );
     KMainWindow::focusOutEvent(e);
 }
 
 void KAstTopLevel::slotNewGame()
 {
-    readSettings();
+    loadSettings();
     score = 0;
     scoreLCD->display( 0 );
     level = 0;
@@ -504,15 +479,13 @@ void KAstTopLevel::slotNewGame()
                     .arg(launchAction->shortcut().seq(0).toString()),
                     yellow );
     waitShip = true;
-    isPaused = false;
     gameOver = false;
 }
 
-void KAstTopLevel::slotQuit()
+bool KAstTopLevel::queryExit()
 {
     XAutoRepeatOn( qt_xdisplay() );
-    kapp->quit();
-    delete this;
+    return true;
 }
 
 void KAstTopLevel::slotShipKilled()
@@ -537,10 +510,10 @@ void KAstTopLevel::slotShipKilled()
 	KScoreDialog d(KScoreDialog::Name | KScoreDialog::Level | KScoreDialog::Score, this);
         KScoreDialog::FieldInfo scoreInfo;
         scoreInfo[KScoreDialog::Level].setNum(level);
-        
-        if (d.addScore(score, scoreInfo) || showHiscores)
+
+        if (d.addScore(score, scoreInfo) || Settings::showHiscores())
         {
-           // Show highscore and ask for name.	
+           // Show highscore and ask for name.
            d.exec();
            slotGameOver();
         }
@@ -592,23 +565,46 @@ void KAstTopLevel::slotRocksRemoved()
 
 void KAstTopLevel::slotKeyConfig()
 {
-    view->pause( true );
     KKeyDialog::configure( actionCollection(), this );
     if ( waitShip ) view->showText( i18n( "Press %1 to launch." )
                     .arg(launchAction->shortcut().seq(0).toString()),
                     yellow, false );
-    
-    view->pause( false );
 }
 
 void KAstTopLevel::slotPref()
 {
-    view->pause( true );
-    PrefDialog *pref = new PrefDialog( this );
-    if ( pref->exec() )
-        readSettings();
-    delete pref;
-    view->pause( false );
+  if(KConfigDialog::showDialog("settings"))
+    return;
+
+  KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self(), KDialogBase::Swallow);
+
+  /* Make widget */
+  QWidget *w = new QWidget(0, "Settings");
+  QVBoxLayout *page = new QVBoxLayout( w, 11 );
+
+  QHBoxLayout *hb = new QHBoxLayout( page, 11 );
+  QLabel *label = new QLabel( i18n("Start new game with"), w );
+  QSpinBox* sb = new QSpinBox( 1, 5, 1, w, "kcfg_numShips" );
+  sb->setValue(3);
+  QLabel *lb = new QLabel( i18n(" ships."), w );
+  QSpacerItem* hspacer = new QSpacerItem( 16, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
+  hb->addWidget(label);
+  hb->addWidget(sb);
+  hb->addWidget(lb);
+  hb->addItem(hspacer);
+
+  QCheckBox *f1 = new QCheckBox(i18n("Show highscores on Game Over"), w, "kcfg_showHiscores");
+  QCheckBox *f2 = new QCheckBox(i18n("Player can destroy Powerups"), w, "kcfg_canDestroyPowerups");
+  f2->setChecked(true);
+  page->addWidget(f1);
+  page->addWidget(f2);
+  QSpacerItem* spacer = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Expanding );
+  page->addItem( spacer );
+  /* Done */
+
+  dialog->addPage(w, i18n("General"), "package_settings");
+  connect(dialog, SIGNAL(settingsChanged()), this, SLOT(loadSettings()));
+  dialog->show();
 }
 
 void KAstTopLevel::slotShowHighscores()
@@ -649,11 +645,9 @@ void KAstTopLevel::slotUpdateVitals()
 
 void KAstTopLevel::slotPause()
 {
-    view->pause( true );
     KMessageBox::information( this,
                               i18n("KAsteroids is paused"),
                               i18n("Paused") );
-    
     //Hack (montel@kde.org)
     //To create "pause" action we display a messagebox
     //and we "play" when we close this messagebox
@@ -661,8 +655,6 @@ void KAstTopLevel::slotPause()
     //so I force to unchecked it when we close messagebox.
     KToggleAction * act = (KToggleAction *)(sender());
     act->setChecked(false);
-
-    view->pause( false );
 }
 
 void KAstTopLevel::slotLaunch()
