@@ -7,11 +7,10 @@
 #include <stdlib.h>
 #include <math.h>
 #include <kapplication.h>
-#include <qkeycode.h>
 #include <kstandarddirs.h>
-#include <kglobal.h>
-#include <kconfig.h>
+#include <kglobalsettings.h>
 
+#include "settings.h"
 #include "view.h"
 #include "view.moc"
 
@@ -82,14 +81,13 @@ KAsteroidsView::KAsteroidsView( QWidget *parent, const char *name )
     field.setBackgroundPixmap( pm );
 
     textSprite = new QCanvasText( &field );
-    QFont font( "helvetica", 18 );
+    QFont font( KGlobalSettings::generalFont().family(), 18 );
     textSprite->setFont( font );
 
     shield = 0;
     shieldOn = false;
     refreshRate = REFRESH_DELAY;
 
-    readConfig();
     readSprites();
 
     shieldTimer = new QTimer( this );
@@ -98,18 +96,9 @@ KAsteroidsView::KAsteroidsView( QWidget *parent, const char *name )
 
     shipPower = MAX_POWER_LEVEL;
     vitalsChanged = true;
-}
-
-// - - -
-
-void KAsteroidsView::readConfig()
-{
-   KConfigBase *conf = kapp->config();
-   if ( conf )
-   {
-     conf->setGroup( "Preferences" );
-     can_destroy_powerups =  conf->readBoolEntry( "canDestroyPowerups", true );
-   }
+    mBrakeCount = 0;
+    mShootCount = 0;
+    mShieldCount = 0;
 }
 
 // - - -
@@ -136,8 +125,6 @@ void KAsteroidsView::reset()
     mFrameNum = 0;
     mPaused = false;
 
-    readConfig();
-
     ship->hide();
     shield->hide();
 
@@ -795,9 +782,9 @@ void KAsteroidsView::processPowerups()
         KPowerup *pup;
         QPtrListIterator<KPowerup> it( powerups );
 
-        for( ; it.current(); ++it )
+        for( ; (pup = it.current()); )
         {
-            pup = it.current();
+            ++it; // We have to increase here, because pup may get deleted.
             pup->growOlder();
 
             if( pup->expired() )
@@ -840,13 +827,15 @@ void KAsteroidsView::processPowerups()
 
                     powerups.removeRef( pup );
                     vitalsChanged = true;
+                    break;
                 }
 
                 if ( (*it)->rtti() == ID_MISSILE )
                 {
-                    if ( can_destroy_powerups )
+                    if ( Settings::canDestroyPowerups() )
                     {
                       powerups.removeRef( pup );
+                      break;
                     }
                 }
             }
