@@ -14,16 +14,16 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
   */
 
 
 #include "toplevel.h"
-#include "kapplication.h"
+
+#include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
-
 #include <kaboutdata.h>
 
 
@@ -54,9 +54,14 @@ int main(int argc, char **argv)
   QApplication::setColorSpec(QApplication::ManyColor);
   KApplication a;
   KGlobal::locale()->insertCatalogue("libkdegames");
-  AtomTopLevel *top = new AtomTopLevel("katomic");
-  a.setMainWidget(top);
-  top->show();
+
+  if ( a.isRestored() )
+        RESTORE(AtomTopLevel)
+  else {
+      AtomTopLevel *top = new AtomTopLevel;
+      top->show();
+      a.setMainWidget(top);
+  }
   return a.exec();
 }
 
