@@ -18,8 +18,6 @@ class KConfig;
  *
  * @short Basic class for AtomTopLevel
  * @author Andreas Wst
- * @version 0.00
- *
  */
 
 class AtomTopLevel : public KMainWindow
@@ -27,19 +25,11 @@ class AtomTopLevel : public KMainWindow
     Q_OBJECT
 
  public:
-	
-  // The constructor method for class KFortune
-  //
-  // @see AtomTopLevel
-  // @param parent Parent widget, used for QWidget
-  // @param name	Name for QWidget
-	 	
-  AtomTopLevel ( const char *name=0 );
-	
-  // The destrucor method for class KFortune
-	
+
+  AtomTopLevel();
+
   ~AtomTopLevel();
-		
+
  protected:
 
   // Creates the menubar and connects the menu-entries to the
@@ -57,15 +47,10 @@ class AtomTopLevel : public KMainWindow
 
   KConfig *config;
 
-  KAction *game_exit;
-
   GameWidget *main;
 
 public slots:
 
-  // Quit the application
-  void quitapp();
-
   // Shows a window for configuring the keybindings
   void configkeys();
 
