@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgfibs.cpp,v 1.15.2.1 2002/12/06 12:23:21 lunakl Exp $
+  $Id: kbgfibs.cpp,v 1.22 2003/07/01 00:31:37 mueller Exp $
 
 */
 
@@ -64,9 +64,8 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <iostream.h>
 #include <time.h>
-
+#include <iostream>
 #include "kbgboard.h"
 #include "kbgstatus.h"
 
@@ -659,6 +658,8 @@ bool KBgEngineFIBS::queryClose()
  */
 bool KBgEngineFIBS::queryExit()
 {
+	if( kapp->sessionSaving())
+	    return true;
 	if (connection->state() != QSocket::Idle)
 		disconnectFIBS();
 	return true;
@@ -891,7 +892,7 @@ void KBgEngineFIBS::hostFound()
 }
 
 /*
- * An error has occured. Reset and inform the user.
+ * An error has occurred. Reset and inform the user.
  */
 void KBgEngineFIBS::connError(int f)
 {
@@ -999,7 +1000,7 @@ void KBgEngineFIBS::newAccount()
 
 /*
  * Send a disconnection request to the server. The server will disconnect
- * and we will recieve a connectionClosed() signal.
+ * and we will receive a connectionClosed() signal.
  */
 void KBgEngineFIBS::disconnectFIBS()
 {
@@ -1138,7 +1139,7 @@ bool KBgEngineFIBS::queryConnection(const bool newlogin)
 	}
 
 	/*
-	 * Made it here, all paramters aquired
+	 * Made it here, all parameters acquired
 	 */
 	return true;
 }
@@ -1333,7 +1334,7 @@ void KBgEngineFIBS::handleServerData(QString &line)
 		/*
 		 * This is a serious problem - latin1() is fine since the line comes from FIBS.
 		 */
-		cerr << "PROBLEM in KBgEngineFIBS::handleServerData: " << line.latin1() << endl;
+		std::cerr << "PROBLEM in KBgEngineFIBS::handleServerData: " << line.latin1() << std::endl;
 	}
 }
 
@@ -2303,7 +2304,7 @@ KBgEngineFIBS::~KBgEngineFIBS()
 	delete optsMenu;
 
 	delete connection;
-	if (invitationDlg) delete invitationDlg;
+	delete invitationDlg;
 
 	delete playerlist;
 	delete chatWindow;
