@@ -16,9 +16,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgfibschat.cpp,v 1.19.2.1 2003/05/19 15:17:23 mueller Exp $
+  $Id: kbgfibschat.cpp,v 1.25 2003/07/26 23:09:34 mueller Exp $
 
 */
 
@@ -58,11 +58,9 @@
 #include "clip.h"
 #include "version.h"
 
-#include <iostream.h>
-
 
 /*
- * Private utility class that might become more generally usefull in
+ * Private utility class that might become more generally useful in
  * the future. Basically, it implements rich text QListBox items.
  */
 class KLBT : public QListBoxText
@@ -650,13 +648,13 @@ void KBgChat::handleData(const QString &msg)
             cMsg.replace(QRegExp("^You say to yourself: "),
                          i18n("<u>You say to yourself:</u> "));
         } else {
-            kdDebug(user == QString::null, 10500) << "KBgChat::handleData unhandled message: "
+            kdDebug(user.isNull(), 10500) << "KBgChat::handleData unhandled message: "
                                                   << cMsg.latin1() << endl;
             return;
         }
     }
 
-    if (cMsg != "")
+    if (!cMsg.isEmpty())
         addMessage(user, cMsg);
 }
 
@@ -683,7 +681,7 @@ void KBgChat::contextMenu(QListBoxItem *i, const QPoint &p)
     /*
      * Fill the context menu with actions
      */
-    if (d->mName[0] != QString::null) {
+    if (!d->mName[0].isNull()) {
 
         d->mAct[KBgChatPrivate::Talk]->setText(i18n("Talk to %1").arg(d->mName[0]));
         d->mAct[KBgChatPrivate::Talk]->plug(d->mChat);
@@ -707,7 +705,7 @@ void KBgChat::contextMenu(QListBoxItem *i, const QPoint &p)
     if (d->mGag.count() > 0)
         d->mAct[KBgChatPrivate::Cleargag]->plug(d->mChat);
 
-    if ((d->mGag.count() > 0) || (d->mName[0] != QString::null))
+    if ((d->mGag.count() > 0) || (!d->mName[0].isNull()))
         d->mChat->insertSeparator();
 
     d->mAct[KBgChatPrivate::Silent]->plug(d->mChat);
@@ -776,7 +774,7 @@ void KBgChat::slotUngag()
  */
 void KBgChat::slotInquire()
 {
-    kdDebug(d->mName[0] == QString::null, 10500) << "KBgChat::slotInquire: user == null" << endl;
+    kdDebug(d->mName[0].isNull(), 10500) << "KBgChat::slotInquire: user == null" << endl;
     emit fibsCommand("whois " + d->mName[0]);
 }
 
@@ -812,7 +810,7 @@ void KBgChat::slotCopy()
  */
 void KBgChat::slotInviteD()
 {
-    kdDebug(d->mName[0] == QString::null, 10500) << "KBgChat::slotInvite: user == null" << endl;
+    kdDebug(d->mName[0].isNull(), 10500) << "KBgChat::slotInvite: user == null" << endl;
     emit fibsRequestInvitation(d->mName[0]);
 }
 void KBgChat::slotInvite1() { emit fibsCommand("invite " + d->mName[0] + " 1"); }
