@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kplayerlist.cpp,v 1.16.2.1 2002/12/06 12:23:21 lunakl Exp $
+  $Id: kplayerlist.cpp,v 1.18 2003/03/07 22:09:20 waba Exp $
 
 */
 
