@@ -7,17 +7,17 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbggnubg.cpp,v 1.4 2002/04/22 19:13:09 binner Exp $
+  $Id: kbggnubg.cpp,v 1.7 2003/03/07 22:09:20 waba Exp $
 
 */
 
@@ -32,22 +32,19 @@
 #include <qlayout.h>
 #include <kiconloader.h>
 #include <kstdaction.h>
-#include <qbuttongroup.h> 
+#include <qbuttongroup.h>
 #include <qcheckbox.h>
 #include <kconfig.h>
-#include <iostream.h>
+#include <iostream>
 #include <klocale.h>
 #include <kmainwindow.h>
 #include <klineeditdlg.h>
-#include <qregexp.h> 
-#include <kregexp.h> 
+#include <qregexp.h>
+#include <kregexp.h>
 #include <knotifyclient.h>
 
-
-#include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
-#include <iostream.h>
 #include <signal.h>
 
 #include "kbgstatus.h"
@@ -80,7 +77,7 @@ void KBgEngineGNU::doubleCube(const int w)
 
 void KBgEngineGNU::handleLine(const QString &l)
 {
-	if (l.isEmpty()) 
+	if (l.isEmpty())
 		return;
 
 	QString line(l);
@@ -94,7 +91,7 @@ void KBgEngineGNU::handleLine(const QString &l)
 		if (int r = strcmp(e.group(1), e.group(2)))
 			turn = (r < 0) ? uRoll : tRoll;
 	}
-	
+
 	/*
 	 * Bug fixes for older versions of GNUBG - to be removed
 	 */
@@ -111,7 +108,7 @@ void KBgEngineGNU::handleLine(const QString &l)
 		handleLine(e.group(1));
 		handleLine(e.group(2));
 		return;
-	} 
+	}
 
 	/*
 	 * Cube handling
@@ -127,7 +124,7 @@ void KBgEngineGNU::handleLine(const QString &l)
 	}
 	if (line.contains(QRegExp("^gnubg doubles\\.$"))) {
 
-		// TODO: we need some generic class for this. the class 
+		// TODO: we need some generic class for this. the class
 		//       can be shared between all engines
 
 #if 0
@@ -135,7 +132,7 @@ void KBgEngineGNU::handleLine(const QString &l)
 
 		int ret = KMessageBox::warningYesNoCancel
 			(0, i18n("gnubg doubles the cube to %1.").arg(2*st.cube(THEM)),
-			 i18n("gnubg doubles"), 
+			 i18n("gnubg doubles"),
 			 i18n("&Accept"), i18n("Re&double"), i18n("&Reject"), true);
 
 		switch (ret) {
@@ -168,7 +165,7 @@ void KBgEngineGNU::handleLine(const QString &l)
 	if (line.contains(QRegExp("^board:"))) {
 
 		KBgStatus st(line);
-		
+
 		/*
 		 * Do preliminary analysis of board
 		 */
@@ -178,7 +175,7 @@ void KBgEngineGNU::handleLine(const QString &l)
 		}
 		if (strcmp(board.latin1(),line.latin1()))
 			++turn %= maxTurn;
-		board = line;       
+		board = line;
 
 		/*
 		 * Act according to the current state in the move/roll cycle
@@ -188,13 +185,13 @@ void KBgEngineGNU::handleLine(const QString &l)
 		case uRoll:
 
 			if (st.cube() > 0) {
-				emit infoText(i18n("Please roll or double"));
+				emit infoText(i18n("Please roll or double."));
 				KNotifyClient::event("roll or double");
 			} else {
-				emit infoText(i18n("Please roll"));
+				emit infoText(i18n("Please roll."));
 				KNotifyClient::event("roll");
 			}
-			
+
 			emit allowCommand(Roll, true);
 			emit allowCommand(Cube, true);
 			break;
@@ -230,7 +227,7 @@ void KBgEngineGNU::handleLine(const QString &l)
 			break;
 
 		}
-		
+
 		/*
 		 * Bookkeeping
 		 */
@@ -289,7 +286,7 @@ void KBgEngineGNU::newGame()
 	 * Start new game
 	 */
 	handleCommand("new game");
-	if (gameRunning) 
+	if (gameRunning)
 		handleCommand("yes");
 
 	gameRunning = true;
@@ -330,7 +327,7 @@ void KBgEngineGNU::load()
  */
 void KBgEngineGNU::setAllowed(int cmd, bool f)
 {
-	switch (cmd) {		
+	switch (cmd) {
 	case Roll:
 		rollingAllowed = f;
 		return;
@@ -434,7 +431,7 @@ KBgEngineGNU::KBgEngineGNU(QWidget *parent, QString *name, QPopupMenu *pmenu)
 	random.setSeed(getpid()*time(NULL));
 
 	/*
-	 * internal statue variables 
+	 * internal statue variables
 	 */
 	rollingAllowed = undoPossible = gameRunning = donePossible = false;
 	connect(this, SIGNAL(allowCommand(int, bool)), this, SLOT(setAllowed(int, bool)));
@@ -486,11 +483,11 @@ void KBgEngineGNU::start()
 	 * Start the process - this requires that gnubg is in the PATH
 	 */
 	gnubg << "gnubg" << "--tty";
-	
+
         connect(&gnubg, SIGNAL(processExited(KProcess *)), this, SLOT(gnubgExit(KProcess *)));
-        connect(&gnubg, SIGNAL(receivedStderr(KProcess *, char *, int)), 
+        connect(&gnubg, SIGNAL(receivedStderr(KProcess *, char *, int)),
 		this, SLOT(receiveData(KProcess *, char *, int)));
-	connect(&gnubg, SIGNAL(receivedStdout(KProcess *, char *, int)), 
+	connect(&gnubg, SIGNAL(receivedStdout(KProcess *, char *, int)),
 		this, SLOT(receiveData(KProcess *, char *, int)));
 	connect(&gnubg, SIGNAL(wroteStdin(KProcess *)), this, SLOT(wroteStdin(KProcess *)));
 
@@ -534,7 +531,7 @@ void KBgEngineGNU::gnubgExit(KProcess *proc)
 	emit allowCommand(Load, false);
 
 	emit allowMoving(false);
-	
+
 	emit infoText(QString("<br/><font color=\"red\">") + i18n("The GNU Backgammon process (%1) has exited. ")
 		      .arg(proc->pid()) + "</font><br/>");
 
@@ -555,8 +552,8 @@ void KBgEngineGNU::wroteStdin(KProcess *proc)
 }
 
 /*
- * Try to send the next command from the command list to gnubg. 
- * If it fails, make sure we call ourselves again. 
+ * Try to send the next command from the command list to gnubg.
+ * If it fails, make sure we call ourselves again.
  */
 void KBgEngineGNU::nextCommand()
 {
@@ -564,7 +561,7 @@ void KBgEngineGNU::nextCommand()
 		return;
 
         for (QStringList::Iterator it = cmdList.begin(); it != cmdList.end(); ++it) {
-		QString s = (*it) + "\n";			
+		QString s = (*it) + "\n";
 		if (!gnubg.writeStdin(s.latin1(), strlen(s.latin1()))) {
 			cmdTimer->start(250, true);
 			cmdList.remove(QString::null);
@@ -577,7 +574,7 @@ void KBgEngineGNU::nextCommand()
 }
 
 /*
- * Get data from GNU Backgammon and process them. Note that we may have 
+ * Get data from GNU Backgammon and process them. Note that we may have
  * to buffer the last line and wait for the closing newline...
  */
 void KBgEngineGNU::receiveData(KProcess *proc, char *buffer, int buflen)
@@ -586,12 +583,12 @@ void KBgEngineGNU::receiveData(KProcess *proc, char *buffer, int buflen)
 		return;
 
 	char *buf = new char[buflen+1];
-	
+
 	memcpy(buf, buffer, buflen);
 	buf[buflen] = '\0';
 
 	QStringList l(QStringList::split('\n', buf, true));
-	
+
 	/*
 	 * Restore partial lines from the previous time
 	 */
@@ -603,7 +600,7 @@ void KBgEngineGNU::receiveData(KProcess *proc, char *buffer, int buflen)
 	}
 
 	delete[] buf;
-		
+
 	/*
 	 * Handle the information from gnubg
 	 */
@@ -665,7 +662,7 @@ void KBgEngineGNU::redo()
 
 /*
  * Take the move string and make the changes on the working copy
- * of the state. 
+ * of the state.
  */
 void KBgEngineGNU::handleMove(QString *s)
 {
@@ -673,7 +670,7 @@ void KBgEngineGNU::handleMove(QString *s)
 
 	int index = 0;
 	QString t = s->mid(index, s->find(' ', index));
-	index += 1 + t.length();       
+	index += 1 + t.length();
 	int moves = t.toInt();
 
 	/*
@@ -700,7 +697,7 @@ void KBgEngineGNU::handleMove(QString *s)
  */
 void KBgEngineGNU::roll()
 {
-	if (turn == uRoll) 
+	if (turn == uRoll)
 		handleCommand("roll");
 }
 void KBgEngineGNU::rollDice(const int w)
