@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgoffline.cpp,v 1.11 2002/07/07 08:40:22 binner Exp $
+  $Id: kbgoffline.cpp,v 1.12 2003/03/07 22:09:21 waba Exp $
 
 */
 
