@@ -15,52 +15,55 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbg.cpp,v 1.24.2.4 2003/02/24 18:33:32 binner Exp $
+  $Id: kbg.cpp,v 1.35 2003/10/24 20:06:42 mhunter Exp $
 
 */
 
 #include "kbg.h"
 #include "kbg.moc"
 
-#include <kapplication.h>
-#include <kiconloader.h>
-#include <kkeydialog.h>
-#include <kedittoolbar.h>
 #include <qpainter.h>
-#include <qprinter.h>
-#include <kmenubar.h>
-#include <ktoolbar.h>
 #include <qlayout.h>
 #include <qgroupbox.h>
 #include <qpixmap.h>
 #include <qstring.h>
-#include <klocale.h>
-#include <kstdaction.h>
-#include <kstdgameaction.h>
-#include <kaboutdata.h>
 #include <qwhatsthis.h>
 #include <qstringlist.h>
 #include <qvaluelist.h>
-#include <kmessagebox.h>
 #include <qiconset.h>
+#include <qvbox.h>
+
+#include <kmenubar.h>
+#include <ktoolbar.h>
+#include <kapplication.h>
+#include <kiconloader.h>
+#include <kkeydialog.h>
+#include <kedittoolbar.h>
+#include <klocale.h>
+#include <kaction.h>
+#include <kstdaction.h>
+#include <kstdgameaction.h>
+#include <kaboutdata.h>
+#include <kmessagebox.h>
 #include <kconfig.h>
 #include <kcompletion.h>
 #include <kcompletionbox.h>
 #include <kpopupmenu.h>
-#include <qvbox.h>
 #include <kurllabel.h>
 #include <krun.h>
-
-#include <offline/kbgoffline.h>
-#include <fibs/kbgfibs.h>
-#include <gnubg/kbggnubg.h>
-#include <nextgen/kbgng.h>
-
-#include <version.h>
 #include <kstatusbar.h>
+#include <klineedit.h>
+#include <knuminput.h>
+#include <kprinter.h>
 
+#include "kbgtextview.h"
+#include "offline/kbgoffline.h"
+#include "fibs/kbgfibs.h"
+#include "gnubg/kbggnubg.h"
+#include "nextgen/kbgng.h"
+#include "version.h"
 
 
 // == setup ====================================================================
@@ -68,8 +71,7 @@
 /*
  * Constructor creates user interface, actions and first engine.
  */
-KBg::KBg(QWidget *parent, const char *name)
-	: KMainWindow(parent, name)
+KBg::KBg()
 {
 	/*
 	 * Initialize menu strings
@@ -99,46 +101,43 @@ KBg::KBg(QWidget *parent, const char *name)
 	/*
 	 * Create all actions needed by the application
 	 */
-	KStdGameAction::gameNew(this, SLOT(openNew()), actionCollection());
-	KStdGameAction::load   (this, SLOT(print()),   actionCollection());
-	KStdGameAction::save   (this, SLOT(print()),   actionCollection());
-
-	actionCollection()->action("game_new" )->setEnabled(false);
-	actionCollection()->action("game_load")->setEnabled(false);
-	actionCollection()->action("game_save")->setEnabled(false);
-
-	KStdGameAction::print  (this, SLOT(print()), actionCollection());
-	KStdGameAction::quit   (kapp, SLOT(quit()),  actionCollection());
+	newAction = KStdGameAction::gameNew(this, SLOT(openNew()), actionCollection());
+    newAction->setEnabled(false);
+	KStdGameAction::print(this, SLOT(print()), actionCollection());
+	KStdGameAction::quit(this, SLOT(close()),  actionCollection());
 
 	QStringList list;
 	for (int i = 0; i < MaxEngine; i++)
 		list.append(engineString[i]);
-	(engineSet = new KSelectAction(i18n("&Engine"), 0, this, SLOT(setupEngine()), actionCollection(),
-				       "move_engine"))->setItems(list);
+	engineSet = new KSelectAction(i18n("&Engine"), 0, this, SLOT(setupEngine()), actionCollection(),
+                                  "move_engine");
+    engineSet->setItems(list);
 
-	KStdAction::redisplay(this, SLOT(load()), actionCollection(), "move_load")->setEnabled(false); // AB: what the heck has this to do with redisplay? perhaps use reload instead?
-	KStdGameAction::undo     (this, SLOT(undo()), actionCollection())->setEnabled(false);
-	KStdGameAction::redo     (this, SLOT(redo()), actionCollection())->setEnabled(false);
+    // AB: what the heck has this to do with redisplay? perhaps use reload instead?
+	loadAction = KStdAction::redisplay(this, SLOT(load()), actionCollection(), "move_load");
+    loadAction->setEnabled(false);
+	undoAction = KStdGameAction::undo(this, SLOT(undo()), actionCollection());
+    undoAction->setEnabled(false);
+	redoAction = KStdGameAction::redo(this, SLOT(redo()), actionCollection());
+    redoAction->setEnabled(false);
 
-	KStdGameAction::roll(this, SLOT(roll()), actionCollection())->setEnabled(false);
-	KStdGameAction::endTurn(this, SLOT(done()), actionCollection(), "move_end_turn")->setEnabled(false);
-	(new KAction(i18n("Double Cube"), QIconSet(kapp->iconLoader()->loadIcon
-						   (PROG_NAME "-double.xpm", KIcon::Toolbar)),
-		     0, this, SLOT(cube()), actionCollection(), "move_cube"))->setEnabled(false);
+	rollAction = KStdGameAction::roll(this, SLOT(roll()), actionCollection());
+    rollAction->setEnabled(false);
+	endAction = KStdGameAction::endTurn(this, SLOT(done()), actionCollection());
+    endAction->setEnabled(false);
+    cubeAction = new KAction(i18n("Double Cube"), QIconSet(kapp->iconLoader()->loadIcon
+                                                          (PROG_NAME "-double.xpm", KIcon::Toolbar)),
+                              0, this, SLOT(cube()), actionCollection(), "move_cube");
+    cubeAction->setEnabled(false);
 
-	KStdAction::showMenubar  (this, SLOT(toggleMenubar()),     actionCollection(), "conf_menubar");
-	KStdAction::showToolbar  (this, SLOT(toggleMainToolbar()), actionCollection(), "conf_toolbar");
-	(new KToggleAction(i18n("Show Command &Line"), 0, this, SLOT(toggleCmdline()), actionCollection(),
-			   "conf_textbar"))->setChecked(true);
-	KStdAction::showStatusbar(this, SLOT(toggleStatusbar()),   actionCollection(), "conf_statbar");
+	KStdAction::showMenubar(this, SLOT(toggleMenubar()),     actionCollection());
+	setStandardToolBarMenuEnabled(true);
+	createStandardStatusBarAction();
 
-	KStdAction::keyBindings      (this, SLOT(configureKeys()), actionCollection(), "conf_keys");
-	KStdAction::configureToolbars(this,SLOT(configureToolbars()), actionCollection(), "conf_tool");
-	KStdAction::preferences(this, SLOT(setupDlg()), actionCollection(), "conf_conf");
-	KStdAction::saveOptions(this, SLOT(saveConfig()), actionCollection(), "conf_save");
-
-	KStdAction::help     (this, SLOT(help()), actionCollection(), "help");
-	KStdAction::whatsThis(this, SLOT(whatsThis()), actionCollection(), "whatsthis");
+	KStdAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
+	KStdAction::configureToolbars(this,SLOT(configureToolbars()), actionCollection());
+	KStdAction::preferences(this, SLOT(setupDlg()), actionCollection());
+	KStdAction::saveOptions(this, SLOT(saveConfig()), actionCollection());
 
 	KPopupMenu *p = (new KActionMenu(i18n("&Backgammon on the Web"),
 					 actionCollection(), "help_www"))->popupMenu();
@@ -283,7 +282,7 @@ void KBg::setupEngine()
 	config->setGroup("global settings");
 	if (config->readBoolEntry("enable timeout", true))
 		engine[currEngine]->setCommit(config->readDoubleNumEntry("timeout", 2.5));
-	actionCollection()->action("game_new")->setEnabled(engine[currEngine]->haveNewGame());
+	newAction->setEnabled(engine[currEngine]->haveNewGame());
 
 	// engine -> this
 	connect(engine[currEngine], SIGNAL(statText(const QString &)), this, SLOT(updateCaption(const QString &)));
@@ -539,7 +538,7 @@ void KBg::setupDlg()
 	QWhatsThis::add(gbt, i18n("After you finished your moves, they have to be sent to the engine. "
 				  "You can either do that manually (in which case you should not enable "
 				  "this feature), or you can specify an amount of time that has to pass "
-				  "before the move is commited. If you undo a move during the timeout, the "
+				  "before the move is committed. If you undo a move during the timeout, the "
 				  "timeout will be reset and restarted once you finish the move. This is "
 				  "very useful if you would like to review the result of your move."));
 
@@ -561,8 +560,8 @@ void KBg::setupDlg()
 	/*
 	 * Enable messages
 	 */
-	QWhatsThis::add(gbm, i18n("Check the box to enable all the messages the you have previously "
-				  "disabled by chosing the \"Don't show this message again\" option."));
+	QWhatsThis::add(gbm, i18n("Check the box to enable all the messages that you have previously "
+				  "disabled by choosing the \"Don't show this message again\" option."));
 
 	QGridLayout *glm = new QGridLayout(gbm, 1, 1, nb->spacingHint());
 	cbm = new QCheckBox(i18n("Reenable all messages"), gbm);
@@ -656,18 +655,18 @@ void KBg::print()
 	config->setGroup("printing");
 
 	prt->setNumCopies(config->readNumEntry("numcopies", 1));
-	prt->setOutputFileName(config->readEntry("outputfile", ""));
+	prt->setOutputFileName(config->readPathEntry("outputfile"));
 	prt->setOutputToFile(config->readBoolEntry("tofile", false));
 	prt->setPageSize((KPrinter::PageSize) config->readNumEntry("pagesize", KPrinter::A4));
 	prt->setOrientation((KPrinter::Orientation)config->readNumEntry("orientation", KPrinter::Landscape));
 
-	if (prt->setup() ) {
+	if (prt->setup(this, i18n("Print %1").arg(baseCaption))) {
 		QPainter p;
 		p.begin(prt);
 		board->print(&p);
 		p.end();
 		config->writeEntry("tofile",      prt->outputToFile());
-		config->writeEntry("outputfile",  prt->outputFileName());
+		config->writePathEntry("outputfile",  prt->outputFileName());
 		config->writeEntry("pagesize",    (int)prt->pageSize());
 		config->writeEntry("orientation", (int)prt->orientation());
 		config->writeEntry("numcopies",   prt->numCopies());
@@ -694,51 +693,12 @@ void KBg::toggleMenubar()
 	}
 }
 
-/*
- * Toggle the visibility of the toolbar with the XML name s
- */
-void KBg::toggleToolbar(const char *s)
-{
-	QToolBar *bar = toolBar(s);
-	if(bar->isVisible())
-		bar->hide();
-	else
-		bar->show();
-}
-
-/*
- * Toggle the main toolbar
- */
-void KBg::toggleMainToolbar()
-{
-	toggleToolbar("mainToolBar");
-}
-
-/*
- * Toggle the command line toolbar
- */
-void KBg::toggleCmdline()
-{
-	toggleToolbar("cmdToolBar");
-}
-
-/*
- * Toggle visibility of the statusbar
- */
-void KBg::toggleStatusbar()
-{
-	if (statusBar()->isVisible())
-		statusBar()->hide();
-	else
-		statusBar()->show();
-}
-
 /*
  * Display a standard dialog for key bindings
  */
 void KBg::configureKeys()
 {
-	KKeyDialog::configureKeys(actionCollection(), xmlFile(), true, this);
+	KKeyDialog::configure(actionCollection(), this);
 }
 
 /*
@@ -762,14 +722,6 @@ void KBg::newToolbarConfig()
 	applyMainWindowSettings(KGlobal::config(), "kedittoolbar settings");
 }
 
-/*
- * General help for the program
- */
-void KBg::help()
-{
-	kapp->invokeHelp();
-}
-
 /*
  * Help slots
  */
@@ -821,7 +773,8 @@ bool KBg::queryClose()
  */
 void KBg::updateCaption(const QString &s)
 {
-	QString msg = "";
+	baseCaption = s;
+	QString msg;
 	if (!s.isEmpty()) {
 		msg = s;
 		if (board->getPipCount(US) >= 0) {
@@ -856,22 +809,22 @@ void KBg::allowCommand(int cmd, bool f)
 {
 	switch (cmd) {
 	case KBgEngine::Undo:
-		actionCollection()->action("move_undo")->setEnabled(f);
+        undoAction->setEnabled(f);
 		break;
 	case KBgEngine::Redo:
-		actionCollection()->action("move_redo")->setEnabled(f);
+		redoAction->setEnabled(f);
 		break;
 	case KBgEngine::Roll:
-		actionCollection()->action("move_roll")->setEnabled(f);
+		rollAction->setEnabled(f);
 		break;
 	case KBgEngine::Cube:
-		actionCollection()->action("move_cube")->setEnabled(f);
+		cubeAction->setEnabled(f);
 		break;
 	case KBgEngine::Done:
-		actionCollection()->action("move_end_turn")->setEnabled(f);
+		endAction->setEnabled(f);
 		break;
 	case KBgEngine::Load:
-		actionCollection()->action("move_load")->setEnabled(f);
+		loadAction->setEnabled(f);
 		break;
 	}
 }
@@ -897,3 +850,4 @@ void KBg::showEvent(QShowEvent *e)
 }
 
 // EOF
+
