@@ -15,56 +15,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-*/
-
-/*
-
-  $Log: kbgboard.cpp,v $
-  Revision 1.18.2.1  2002/12/09 23:27:22  faure
-  Backport all the bugfixes from HEAD
-
-  Revision 1.18  2002/04/25 11:01:59  binner
-  CVS_SILENT Style guide fixes.
-
-  Revision 1.17  2001/11/02 10:25:07  mlaurent
-  Fix includes
-
-  Revision 1.16  2001/10/10 17:13:31  mueller
-  CVS_SILENT: more fixincludes..
-
-  Revision 1.15  2001/10/02 14:50:48  mueller
-  QT_NO_COMPAT fixlets, --enable-final problems, fix the .lsm
-
-  Revision 1.14  2001/09/01 11:52:18  danimo
-  Ported to Qt3:
-
-  - QList->QPtrList & Friends
-  - ASSERT->Q_ASSERT
-  - CHECK_PTR->Q_CHECK_PTR
-
-  most apps compile now, but some are broken because of the new QStyle API.
-  I will leave that to the respective authors :)
-
-  Revision 1.13  2001/05/02 00:58:35  hoefkens
-  Honor the user selected font size for the board.
-
-  Revision 1.12  2001/04/12 15:54:46  porten
-  explicit double/float casts for sqrt() and pow() on Irix 6.5. Based on
-  a patch by Albert Chin-A-Young <china@thewrittenword.com>
-
-  Revision 1.11  2001/03/23 02:12:56  hoefkens
-  More configuration changes
-
-  Revision 1.10  2001/03/19 05:34:04  hoefkens
-  Engine redesign and settings changes - not yet finished
-
-  Revision 1.9  2001/03/16 07:33:50  hoefkens
-  Rewrite of the setup dialog. First (not fully working) eventsrc file.
-
-  Revision 1.8  2001/03/14 05:02:00  hoefkens
-  Font selection was broken
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -96,6 +47,8 @@
 #include <qvbox.h>
 #include <kiconloader.h>
 #include <ktabctl.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "version.h"
 
@@ -103,6 +56,7 @@
 const int CUBE_UPPER = 3;
 const int CUBE_LOWER = 4;
 
+static const int MINIMUM_CHECKER_SIZE = 10;
 
 /*
  * Set the default settings in all user configurations
@@ -235,7 +189,7 @@ void KBgBoardSetup::getSetupPages(KDialogBase *nb)
 	for (int i = 0; i < 3; i++)
 		rbMove[i] = new QRadioButton(gm);
 
-	rbMove[SHORT_MOVE_NONE]->setText(i18n("&Disable short moves. Only drag'n drop will move."));
+	rbMove[SHORT_MOVE_NONE]->setText(i18n("&Disable short moves. Only drag and drop will move."));
 	rbMove[SHORT_MOVE_SINGLE]->setText(i18n("&Single clicks with the left mouse button will\n"
 			  "move a checker the shortest possible distance."));
 	rbMove[SHORT_MOVE_DOUBLE]->setText(i18n("D&ouble clicks with the left mouse button will\n"
@@ -434,8 +388,8 @@ KBgBoardQCube::KBgBoardQCube(int val, bool us, bool them)
 
 	cb[0]  = new QComboBox(this, "first sb");
 	cb[1]  = new QComboBox(this, "second sb");
-	ok     = new QPushButton(i18n("OK"), this);
-	cancel = new QPushButton(i18n("Cancel"), this);
+	ok     = new KPushButton(KStdGuiItem::ok(), this);
+	cancel = new KPushButton(KStdGuiItem::cancel(), this);
 
 	info->setText(i18n("Set the face value of the cube and select who should be able to\n"
 			   "double. Note that a face value of 1 automatically allows both\n"
@@ -584,8 +538,8 @@ KBgBoardQDice::KBgBoardQDice(const char *name)
 
 	sb[0]  = new QSpinBox(this, "first sb");
 	sb[1]  = new QSpinBox(this, "second sb");
-	ok     = new QPushButton(i18n("OK"), this);
-	cancel = new QPushButton(i18n("Cancel"), this);
+	ok     = new KPushButton(KStdGuiItem::ok(), this);
+	cancel = new KPushButton(KStdGuiItem::cancel(), this);
 
 	info->setText(i18n("Set the face values of the selected dice. The other player's\n"
 			   "dice will be cleared and it will be the dice's owner's turn."));
@@ -773,6 +727,9 @@ void KBgBoard::resizeEvent(QResizeEvent *)
         checkerDiam = (int)((width()/15-2)<(height()/10.0-2) ?
 			    (width()/15-2) : (height()/10.0-2));
 
+	if (checkerDiam < MINIMUM_CHECKER_SIZE)
+		checkerDiam = MINIMUM_CHECKER_SIZE;
+
 	for (int i = 0; i < 14; ++i) {
 		xo1  = int((i+1)*width()/15.0);
 		w = xo1 - xo0;
@@ -1598,7 +1555,7 @@ void KBgBoardCell::putPiece(int newColor)
 
 /*
  * This function handles mouse release events. It is important to know that
- * the cell where the first mousePressEvent occured receives the release event.
+ * the cell where the first mousePressEvent occurred receives the release event.
  * The release event marks the end of a drag or a single click short move.
  */
 void KBgBoardCell::mouseReleaseEvent(QMouseEvent *e)
@@ -2409,8 +2366,9 @@ void KBgBoardField::paintCell(QPainter *p, int xo, int yo, double sf) const
 	t.setNum(getNumber());
 
 	p->setFont(board->getFont());
-	p->drawText(xo, yo+sf*((cellID < 13) ? 5 : height()-5-p->font().pointSize()),
-		    width()*sf, p->font().pointSize()*sf, AlignCenter, t);
+	int textHeight = QFontMetrics(p->font()).height();
+	p->drawText(xo, yo+((cellID < 13) ? 5 : height()-5-textHeight),
+		    width()*sf, textHeight, AlignCenter, t);
 
 	/*
 	 * Put the checkers on the field.
@@ -2877,7 +2835,7 @@ KBgBoard::KBgBoard(QWidget *parent, const char *name, QPopupMenu *menu)
 	allowMoving(true);
 	setEditMode(false);
 	savedCursor = NULL;
-	checkerDiam = 1;
+	checkerDiam = MINIMUM_CHECKER_SIZE;
 
 	/*
 	 * We may be initialized with a popup menu by our parent.
@@ -2949,4 +2907,10 @@ KBgBoard::KBgBoard(QWidget *parent, const char *name, QPopupMenu *menu)
 	setFont(QApplication::font());
 }
 
+QSize KBgBoard::minimumSizeHint() const
+{
+	return QSize(MINIMUM_CHECKER_SIZE * 15, MINIMUM_CHECKER_SIZE * 11);
+}
+
+
 // EOF
