@@ -15,7 +15,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -176,6 +176,11 @@ class KBgBoard : public QWidget
 	 */
 	QFont getFont();
 
+	/**
+	 * This function has to be reimplemented to provide a minimum size for
+	 * the playing area.
+	 */
+	QSize minimumSizeHint() const;
 public slots:
 
 	/**
