@@ -7,16 +7,16 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-  
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 */
 
 #include <kapplication.h>
@@ -35,19 +35,19 @@ static const char *notice      = I18N_NOOP("This is a graphical backgammon progr
 					   "on-line games on the 'First Internet Backgammon Server'.");
 
 /*
- * Main program doesn't do much - more or less standard stuff. Right 
+ * Main program doesn't do much - more or less standard stuff. Right
  * after creating a KBg object, control is passed to it.
  */
 int main(int argc, char *argv[])
 {
-	KAboutData about(PROG_NAME, I18N_NOOP("KBackgammon"), PROG_VERSION, description, 
-			 KAboutData::License_GPL, "(C) 1999-2001 Jens Hoefkens", notice, 
+	KAboutData about(PROG_NAME, I18N_NOOP("KBackgammon"), PROG_VERSION, description,
+			 KAboutData::License_GPL, "(C) 1999-2001 Jens Hoefkens", notice,
 			 PROG_HOME, "jens@hoefkens.com");
 
 	about.addAuthor ("Jens Hoefkens", I18N_NOOP("Author & maintainer"),
 			 "jens@hoefkens.com", "http://www.hoefkens.com/");
 
-	about.addCredit ("Bo Thorsen", I18N_NOOP("Initial anti-aliasing of the board"), 
+	about.addCredit ("Bo Thorsen", I18N_NOOP("Initial anti-aliasing of the board"),
 			 "gobo@imada.sdu.dk");
 
 	KCmdLineArgs::init(argc, argv, &about);
@@ -58,11 +58,8 @@ int main(int argc, char *argv[])
 	if (app.isRestored())
 		RESTORE(KBg)
 	else {
-		KBg* widget = new KBg();
+		KBg* widget = new KBg;
 		app.setMainWidget(widget);
-		app.setTopWidget(widget);
-		app.setName(PROG_NAME); 
-       
 		widget->readConfig();
 		widget->show();
 	}
