@@ -15,15 +15,25 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qtimer.h>
 #include <stdlib.h>
+
 #include <qlayout.h>
+#include <qtimer.h>
+
 #include <kgamemisc.h>
-#include "main.h"
+#include <kinputdialog.h>
+#include <kkeydialog.h>
+#include <knotifyclient.h>
+#include <knotifydialog.h>
+#include <kstandarddirs.h>
 #include <kstatusbar.h>
+#include <kstdgameaction.h>
+
 #include "kbattleship.moc"
 
-KBattleshipApp::KBattleshipApp(QWidget *, const char *name) : KMainWindow(0, name)
+extern const char *clientVersion;
+
+KBattleshipApp::KBattleshipApp()
 {
 	setMinimumSize(750, 500);
 	m_connection = 0;
@@ -31,7 +41,6 @@ KBattleshipApp::KBattleshipApp(QWidget *, const char *name) : KMainWindow(0, nam
 	m_config = 0;
 	m_client = 0;
 	m_server = 0;
-	m_single = 0;
 	m_aiPlayer = 0;
 	m_aiHits = 0;
 
@@ -39,7 +48,7 @@ KBattleshipApp::KBattleshipApp(QWidget *, const char *name) : KMainWindow(0, nam
 	QString onePicCheck = locate("data", "kbattleship/pictures/hit.png");
 	if(picDirCheck.isEmpty() || onePicCheck.isEmpty())
 	{
-		KMessageBox::error(this, i18n("You don't have KBattleship Pictures installed. The game cannot run without them!"));
+		KMessageBox::error(this, i18n("You don't have KBattleship pictures installed. The game cannot run without them!"));
 		exit(0);
 	}
 	else
@@ -53,7 +62,6 @@ KBattleshipApp::~KBattleshipApp()
 	delete m_aiPlayer;
 	delete m_ownshiplist;
 	delete m_enemyshiplist;
-	delete m_sound;
 }
 
 void KBattleshipApp::init()
@@ -68,10 +76,20 @@ void KBattleshipApp::init()
 	readOptions();
 	initView();
 	initChat();
-	initSound();
 	initShipPlacing();
 }
 
+
+void KBattleshipApp::slotConfigureKeys()
+{
+  KKeyDialog::configure( actionCollection(), this );
+}
+
+void KBattleshipApp::slotConfigureNotifications()
+{
+  KNotifyDialog::configure(this);
+}
+
 void KBattleshipApp::initStatusBar()
 {
 	m_ownNickname = "-";
@@ -84,32 +102,24 @@ void KBattleshipApp::initStatusBar()
 
 void KBattleshipApp::initActions()
 {
-	m_gameServerConnect = new KAction(i18n("&Connect to Server..."), "connect_no", Key_F2, this, SLOT(slotServerConnect()), actionCollection(), "serverconnect");
-	m_gameNewServer = new KAction(i18n("&Start Server..."), "network", Key_F3, this, SLOT(slotNewServer()), actionCollection(), "newserver");
-	m_gameSingle = new KAction(i18n("S&ingle Player..."), "gear", Key_F4, this, SLOT(slotSinglePlayer()), actionCollection(), "singleplayer");
-	m_gameQuit = KStdAction::quit( this, SLOT(slotGameQuit()), actionCollection(), "gamequit");
-	(void) new KAction(i18n("&Highscore"), "view_text", Key_F10, this, SLOT(slotHighscore()), actionCollection(), "highscore");
-	m_gameEnemyInfo = new KAction(i18n("&Enemy Info..."), "view_text", Key_F11, this, SLOT(slotEnemyClientInfo()), actionCollection(), "enemyinfo");
+	KStdAction::keyBindings(this, SLOT( slotConfigureKeys() ), actionCollection() );
+	KStdAction::configureNotifications(this, SLOT(slotConfigureNotifications()), actionCollection());
+	m_gameServerConnect = new KAction(i18n("&Connect to Server..."), "connect_no", Key_F2, this, SLOT(slotServerConnect()), actionCollection(), "game_serverconnect");
+	m_gameNewServer = new KAction(i18n("&Start Server..."), "network", Key_F3, this, SLOT(slotNewServer()), actionCollection(), "game_newserver");
+	m_gameSingle = new KAction(i18n("S&ingle Player..."), "gear", Key_F4, this, SLOT(slotSinglePlayer()), actionCollection(), "game_singleplayer");
+	m_gameQuit = KStdGameAction::quit(this, SLOT(close()), actionCollection());
+	KStdGameAction::highscores(this, SLOT(slotHighscore()), actionCollection());
+	m_gameEnemyInfo = new KAction(i18n("&Enemy Info"), "view_text", Key_F11, this, SLOT(slotEnemyClientInfo()), actionCollection(), "game_enemyinfo");
 
-	m_viewStatusBar = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());
-	m_configSound = new KToggleAction(i18n("&Play Sounds"), 0, this, SLOT(slotConfigSound()), actionCollection(), "configsound");
-	m_configGrid = new KToggleAction(i18n("&Show Grid"), 0, this, SLOT(slotShowGrid()), actionCollection(), "showgrid");
+	createStandardStatusBarAction();
+	setAutoSaveSettings("General");
+	m_configSound = new KToggleAction(i18n("&Play Sounds"), 0, actionCollection(), "options_configure_sound");
+	m_configGrid = new KToggleAction(i18n("&Show Grid"), 0, this, SLOT(slotShowGrid()), actionCollection(), "options_show_grid");
 
 	m_gameEnemyInfo->setEnabled(false);
 	createGUI();
 }
 
-void KBattleshipApp::initSound()
-{
-	new Arts::Dispatcher;
-	m_sound = new KBattleshipSound();
-
-	if(!m_sound->initSoundServer())
-		m_configSound->setChecked(false);
-	else
-		slotConfigSound();
-}
-
 void KBattleshipApp::initChat()
 {
 	connect(m_chat, SIGNAL(sigSendMessage(const QString &)), this, SLOT(slotSendChatMessage(const QString &)));
@@ -211,106 +221,93 @@ void KBattleshipApp::slotEnemyFieldClick(int fieldx, int fieldy)
 
 				if(showstate == KBattleField::HIT)
 				{
-					if(m_enemyshiplist->shipTypeAt(fieldx, fieldy) != 0 && m_enemyshiplist->shipTypeAt(fieldx, fieldy) != 99)
+					KShip *ship = m_enemyshiplist->shipAt(fieldx, fieldy);
+					typedef QValueList<int> DeathValueList;
+					DeathValueList deathList;
+					bool xokay = true, yokay = true;
+					int tempy = 0, tempx = 0;
+
+					if(ship->placedLeft())
 					{
-						KShip *ship = m_enemyshiplist->shipAt(fieldx, fieldy);
-						typedef QValueList<int> DeathValueList;
-						DeathValueList deathList;
-						bool xokay = true, yokay = true;
-						int tempy = 0, tempx = 0;
-
-						if(ship->shipystart() == ship->shipystop() && ship->shipxstart() != ship->shipxstop())
+						for(tempx = ship->shipxstart(); tempx <= ship->shipxstop(); tempx++)
 						{
-							for(tempx = ship->shipxstart(); tempx <= ship->shipxstop(); tempx++)
+							if(m_view->enemyFieldState(tempx, fieldy) == KBattleField::HIT)
 							{
-								if(m_view->enemyFieldState(tempx, fieldy) == KBattleField::HIT)
-								{
-									deathList.append(tempx);
-									xokay = true;
-									yokay = false;
-								}
-								else
-								{
-									xokay = false;
-									yokay = false;
-									break;
-								}
+								deathList.append(tempx);
+								xokay = true;
+								yokay = false;
 							}
-						}
-						else if(ship->shipystart() != ship->shipystop() && ship->shipxstart() == ship->shipxstop())
-						{
-							for(tempy = ship->shipystart(); tempy <= ship->shipystop(); tempy++)
+							else
 							{
-								if(m_view->enemyFieldState(fieldx, tempy) == KBattleField::HIT)
-								{
-									deathList.append(tempy);
-									xokay = false;
-									yokay = true;
-								}
-								else
-								{
-									xokay = false;
-									yokay = false;
-									break;
-								}
-							}
-						}
-
-						if(xokay)
-						{
-							DeathValueList::Iterator it;
-							for(it = deathList.begin(); it != deathList.end(); it++){
-								if(fieldy+1<m_enemyshiplist->m_fieldy) m_view->changeEnemyFieldData(*it, fieldy+1, KBattleField::BORDER);
-								m_view->changeEnemyFieldData(*it, fieldy, KBattleField::DEATH);
-								if(fieldy>0) m_view->changeEnemyFieldData(*it, fieldy-1, KBattleField::BORDER);
-								}
-							if(ship->shipxstart()>0){
-							if (fieldy>0)m_view->changeEnemyFieldData(ship->shipxstart()-1, fieldy-1, KBattleField::BORDER);
-							m_view->changeEnemyFieldData(ship->shipxstart()-1, fieldy, KBattleField::BORDER);
-							if (fieldy<m_enemyshiplist->m_fieldy)m_view->changeEnemyFieldData(ship->shipxstart()-1, fieldy+1, KBattleField::BORDER);
-							}
-							if(ship->shipxstop()<m_enemyshiplist->m_fieldx){
-							if (fieldy>0)m_view->changeEnemyFieldData(ship->shipxstop()+1, fieldy-1, KBattleField::BORDER);
-							m_view->changeEnemyFieldData(ship->shipxstop()+1, fieldy, KBattleField::BORDER);
-							if (fieldy<m_enemyshiplist->m_fieldy)m_view->changeEnemyFieldData(ship->shipxstop()+1,fieldy+1, KBattleField::BORDER);
-							}
-
-						}
-						else if(yokay)
-						{
-							DeathValueList::Iterator it;
-							for(it = deathList.begin(); it != deathList.end(); it++){
-								if (fieldx>0) m_view->changeEnemyFieldData(fieldx-1, *it, KBattleField::BORDER);
-								m_view->changeEnemyFieldData(fieldx, *it, KBattleField::DEATH);
-								if(fieldx<m_enemyshiplist->m_fieldx) m_view->changeEnemyFieldData(fieldx+1, *it, KBattleField::BORDER);
-							}
-							if(ship->shipystart()>0){
-							if (fieldx>0)m_view->changeEnemyFieldData(fieldx-1, ship->shipystart()-1, KBattleField::BORDER);
-							m_view->changeEnemyFieldData(fieldx, ship->shipystart()-1, KBattleField::BORDER);
-							if (fieldx<m_enemyshiplist->m_fieldx)m_view->changeEnemyFieldData(fieldx+1, ship->shipystart()-1, KBattleField::BORDER);
-							}
-							if(ship->shipystop()<m_enemyshiplist->m_fieldy){
-							if (fieldx>0)m_view->changeEnemyFieldData(fieldx-1, ship->shipystop()+1, KBattleField::BORDER);
-							m_view->changeEnemyFieldData(fieldx, ship->shipystop()+1, KBattleField::BORDER);
-							if (fieldx<m_enemyshiplist->m_fieldx)m_view->changeEnemyFieldData(fieldx+1, ship->shipystop()+1, KBattleField::BORDER);
+								xokay = false;
+								yokay = false;
+								break;
 							}
 						}
 					}
-					else if(m_enemyshiplist->shipTypeAt(fieldx, fieldy) == 0){
-						m_view->changeEnemyFieldData(fieldx, fieldy, KBattleField::DEATH);
-							if (fieldx>0) m_view->changeEnemyFieldData(fieldx-1, fieldy, KBattleField::BORDER);
-							if(fieldx<m_enemyshiplist->m_fieldx) m_view->changeEnemyFieldData(fieldx+1, fieldy, KBattleField::BORDER);
-							if(fieldy>1){
-							if (fieldx>0)m_view->changeEnemyFieldData(fieldx-1, fieldy-1, KBattleField::BORDER);
-							m_view->changeEnemyFieldData(fieldx, fieldy-1, KBattleField::BORDER);
-							if (fieldx<m_enemyshiplist->m_fieldx)m_view->changeEnemyFieldData(fieldx+1, fieldy-1, KBattleField::BORDER);
+					else
+					{
+						for(tempy = ship->shipystart(); tempy <= ship->shipystop(); tempy++)
+						{
+							if(m_view->enemyFieldState(fieldx, tempy) == KBattleField::HIT)
+							{
+								deathList.append(tempy);
+								xokay = false;
+								yokay = true;
 							}
-							if(fieldy<m_enemyshiplist->m_fieldy){
-							if (fieldx>0)m_view->changeEnemyFieldData(fieldx-1, fieldy+1, KBattleField::BORDER);
-							m_view->changeEnemyFieldData(fieldx, fieldy+1, KBattleField::BORDER);
-							if (fieldx<m_enemyshiplist->m_fieldx)m_view->changeEnemyFieldData(fieldx+1, fieldy+1, KBattleField::BORDER);
+							else
+							{
+								xokay = false;
+								yokay = false;
+								break;
 							}
 						}
+					}
+
+					if(xokay)
+					{
+						DeathValueList::Iterator it;
+						for(it = deathList.begin(); it != deathList.end(); it++)
+						{
+							if(fieldy+1 < m_enemyshiplist->m_fieldy) m_view->changeEnemyFieldData(*it, fieldy+1, KBattleField::BORDER);
+							m_view->changeEnemyFieldData(*it, fieldy, KBattleField::DEATH);
+							if(fieldy > 0) m_view->changeEnemyFieldData(*it, fieldy-1, KBattleField::BORDER);
+						}
+						if(ship->shipxstart() > 0)
+						{
+							if (fieldy > 0) m_view->changeEnemyFieldData(ship->shipxstart()-1, fieldy-1, KBattleField::BORDER);
+							m_view->changeEnemyFieldData(ship->shipxstart()-1, fieldy, KBattleField::BORDER);
+							if (fieldy < m_enemyshiplist->m_fieldy) m_view->changeEnemyFieldData(ship->shipxstart()-1, fieldy+1, KBattleField::BORDER);
+						}
+						if(ship->shipxstop() < m_enemyshiplist->m_fieldx)
+						{
+							if (fieldy>0) m_view->changeEnemyFieldData(ship->shipxstop()+1, fieldy-1, KBattleField::BORDER);
+							m_view->changeEnemyFieldData(ship->shipxstop()+1, fieldy, KBattleField::BORDER);
+							if (fieldy < m_enemyshiplist->m_fieldy)m_view->changeEnemyFieldData(ship->shipxstop()+1,fieldy+1, KBattleField::BORDER);
+						}
+					}
+					else if(yokay)
+					{
+						DeathValueList::Iterator it;
+						for(it = deathList.begin(); it != deathList.end(); it++)
+						{
+							if (fieldx>0) m_view->changeEnemyFieldData(fieldx-1, *it, KBattleField::BORDER);
+							m_view->changeEnemyFieldData(fieldx, *it, KBattleField::DEATH);
+							if(fieldx<m_enemyshiplist->m_fieldx) m_view->changeEnemyFieldData(fieldx+1, *it, KBattleField::BORDER);
+						}
+						if(ship->shipystart()>0)
+						{
+							if (fieldx>0)m_view->changeEnemyFieldData(fieldx-1, ship->shipystart()-1, KBattleField::BORDER);
+							m_view->changeEnemyFieldData(fieldx, ship->shipystart()-1, KBattleField::BORDER);
+							if (fieldx<m_enemyshiplist->m_fieldx)m_view->changeEnemyFieldData(fieldx+1, ship->shipystart()-1, KBattleField::BORDER);
+						}
+						if(ship->shipystop()<m_enemyshiplist->m_fieldy)
+						{
+							if (fieldx>0)m_view->changeEnemyFieldData(fieldx-1, ship->shipystop()+1, KBattleField::BORDER);
+							m_view->changeEnemyFieldData(fieldx, ship->shipystop()+1, KBattleField::BORDER);
+							if (fieldx<m_enemyshiplist->m_fieldx)m_view->changeEnemyFieldData(fieldx+1, ship->shipystop()+1, KBattleField::BORDER);
+						}
+					}
 				}
 			}
 
@@ -338,7 +335,7 @@ void KBattleshipApp::slotEnemyFieldClick(int fieldx, int fieldy)
 				}
 				return;
 			}
-			else if(m_aiPlaying && m_aiPlayer != 0)
+			else if(m_aiPlayer != 0 && m_aiPlaying)
 				m_aiPlayer->slotRequestShot();
 		}
 	}
@@ -368,12 +365,44 @@ void KBattleshipApp::slotReceivedEnemyFieldData(int fieldx, int fieldy, int enem
 		if(xstart == xstop)
 		{
 			for(int i = ystart; i <= ystop; i++)
-				slotChangeEnemyFieldData(fieldx, i, KBattleField::DEATH);
+			{
+				if (fieldx>0) m_view->changeEnemyFieldData(fieldx-1, i, KBattleField::BORDER);
+				m_view->changeEnemyFieldData(fieldx, i, KBattleField::DEATH);
+				if(fieldx<m_enemyshiplist->m_fieldx) m_view->changeEnemyFieldData(fieldx+1, i, KBattleField::BORDER);
+			}
+			if(ystart>0)
+			{
+				if (fieldx>0)m_view->changeEnemyFieldData(fieldx-1, ystart-1, KBattleField::BORDER);
+				m_view->changeEnemyFieldData(fieldx, ystart-1, KBattleField::BORDER);
+				if (fieldx<m_enemyshiplist->m_fieldx)m_view->changeEnemyFieldData(fieldx+1, ystart-1, KBattleField::BORDER);
+			}
+			if(ystop<m_enemyshiplist->m_fieldy)
+			{
+				if (fieldx>0)m_view->changeEnemyFieldData(fieldx-1, ystop+1, KBattleField::BORDER);
+				m_view->changeEnemyFieldData(fieldx, ystop+1, KBattleField::BORDER);
+				if (fieldx<m_enemyshiplist->m_fieldx)m_view->changeEnemyFieldData(fieldx+1, ystop+1, KBattleField::BORDER);
+			}
 		}
 		else if(ystart == ystop)
 		{
 			for(int i = xstart; i <= xstop; i++)
-				slotChangeEnemyFieldData(i, fieldy, KBattleField::DEATH);
+			{
+				if(fieldy+1 < m_enemyshiplist->m_fieldy) m_view->changeEnemyFieldData(i, fieldy+1, KBattleField::BORDER);
+				m_view->changeEnemyFieldData(i, fieldy, KBattleField::DEATH);
+				if(fieldy > 0) m_view->changeEnemyFieldData(i, fieldy-1, KBattleField::BORDER);
+			}
+			if(xstart > 0)
+			{
+				if (fieldy > 0) m_view->changeEnemyFieldData(xstart-1, fieldy-1, KBattleField::BORDER);
+				m_view->changeEnemyFieldData(xstart-1, fieldy, KBattleField::BORDER);
+				if (fieldy < m_enemyshiplist->m_fieldy) m_view->changeEnemyFieldData(xstart-1, fieldy+1, KBattleField::BORDER);
+			}
+			if(xstop < m_enemyshiplist->m_fieldx)
+			{
+				if (fieldy>0) m_view->changeEnemyFieldData(xstop+1, fieldy-1, KBattleField::BORDER);
+				m_view->changeEnemyFieldData(xstop+1, fieldy, KBattleField::BORDER);
+				if (fieldy < m_enemyshiplist->m_fieldy)m_view->changeEnemyFieldData(xstop+1,fieldy+1, KBattleField::BORDER);
+			}
 		}
 	}
 
@@ -381,7 +410,7 @@ void KBattleshipApp::slotReceivedEnemyFieldData(int fieldx, int fieldy, int enem
 		slotStatusMsg(i18n("Waiting for enemy to shoot.."));
 	else
 	{
-		KMessage *msg = new KMessage(KMessage::WON);
+		KMessage *msg = m_view->getAliveShips(m_ownshiplist); // let's show ai player ships
 		slotSendMessage(msg);
 		slotStatusMsg(i18n("You won the game :)"));
 		m_stat->slotAddOwnWon();
@@ -426,16 +455,21 @@ void KBattleshipApp::slotAbortNetworkGame()
 	m_placeable = false;
 	m_serverHasClient = false;
 
-	if(m_connection->type() == KonnectionHandling::SERVER)
+	if (m_connection)
 	{
-		delete m_kbserver;
-		m_kbserver = 0;
+		if(m_connection->type() == KonnectionHandling::SERVER)
+		{
+			delete m_kbserver;
+			m_kbserver = 0;
+		}
+		else
+		{
+			delete m_kbclient;
+			m_kbclient = 0;
+		}
+		delete m_connection;
+		m_connection = 0;
 	}
-	else
-		QTimer::singleShot(0, this, SLOT(slotDeleteClient()));
-
-	delete m_connection;
-	m_connection = 0;
 }
 
 void KBattleshipApp::slotReplay()
@@ -539,7 +573,7 @@ void KBattleshipApp::slotShipsReady()
 	slotSendMessage(msg);
 
 	if(m_connection->type() == KonnectionHandling::SERVER)
-		slotStatusMsg(i18n("Waiting for other player to place the ships..."));
+		slotStatusMsg(i18n("Waiting for other player to place their ships..."));
 	else
 		slotStatusMsg(i18n("Waiting for other player to start the match..."));
 
@@ -595,6 +629,11 @@ KShip *KBattleshipApp::shipAt(int fieldx, int fieldy)
 	return m_ownshiplist->shipAt(fieldx, fieldy);
 }
 
+KShip *KBattleshipApp::enemyShipAt(int fieldx, int fieldy)
+{
+	return m_enemyshiplist->shipAt(fieldx, fieldy);
+}
+
 void KBattleshipApp::slotUpdateHighscore()
 {
 	m_score->save(m_ownNickname, m_stat->shot(), m_stat->hit(), m_stat->water());
@@ -604,9 +643,7 @@ void KBattleshipApp::slotUpdateHighscore()
 void KBattleshipApp::saveOptions()
 {
 	m_config->setGroup("General");
-	m_config->writeEntry("ShowStatusbar", m_viewStatusBar->isChecked());
-	if(!m_sound->serverError())
-		m_config->writeEntry("PlaySounds", m_configSound->isChecked());
+	m_config->writeEntry("PlaySounds", m_configSound->isChecked());
 	m_config->writeEntry("ShowGrid", m_configGrid->isChecked());
 	m_config->sync();
 }
@@ -614,20 +651,10 @@ void KBattleshipApp::saveOptions()
 void KBattleshipApp::readOptions()
 {
 	m_config->setGroup("General");
-
-	m_viewStatusBar->setChecked(m_config->readBoolEntry("ShowStatusbar", true));
-	slotViewStatusBar();
-
 	m_configSound->setChecked(m_config->readBoolEntry("PlaySounds", true));
 	m_configGrid->setChecked(m_config->readBoolEntry("ShowGrid", false));
 }
 
-void KBattleshipApp::slotGameQuit()
-{
-	delete this;
-	kapp->quit();
-}
-
 void KBattleshipApp::slotHighscore()
 {
 	m_score->setCaption(i18n("Highscore"));
@@ -673,19 +700,17 @@ void KBattleshipApp::slotDeleteConnectDialog()
 	m_client = 0;
 }
 
-void KBattleshipApp::slotDeleteClient()
-{
-	delete m_kbclient;
-	m_kbclient = 0;
-}
-
 void KBattleshipApp::slotReplayRequest()
 {
-	switch(KMessageBox::questionYesNo(this, i18n("The client asks for restarting the game. Do you accept?")))
+	switch(KMessageBox::questionYesNo(this, i18n("The client is asking to restart the game. Do you accept?")))
 	{
 		case KMessageBox::Yes:
-			slotReplay();
-			slotStatusMsg(i18n("Please place your ships. Use the \"Shift\" key to place the ships vertically."));
+			if (m_connection)
+			{ // the client could have closed while the user was thinking if he wanted to replay
+				slotReplay();
+				slotStatusMsg(i18n("Please place your ships. Use the \"Shift\" key to place the ships vertically."));
+			}
+			else slotAbortNetworkGame();
 			break;
 
 		case KMessageBox::No:
@@ -700,9 +725,17 @@ void KBattleshipApp::slotServerReplay()
 	switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?")))
 	{
 		case KMessageBox::Yes:
-			slotReplay();
-			slotStatusMsg(i18n("Please place your ships. Use the \"Shift\" key to place the ships vertically."));
-			slotSendMessage(msg);
+			if (m_connection)
+			{ // the client could have closed while the user was thinking if he wanted to replay
+				slotReplay();
+				slotStatusMsg(i18n("Please place your ships. Use the \"Shift\" key to place the ships vertically."));
+				slotSendMessage(msg);
+			}
+			else
+			{
+				delete msg;
+				slotAbortNetworkGame();
+			}
 			break;
 
 		case KMessageBox::No:
@@ -718,9 +751,17 @@ void KBattleshipApp::slotClientReplay()
 	switch(KMessageBox::questionYesNo(this, i18n("Do you want to ask the server restarting the game?")))
 	{
 		case KMessageBox::Yes:
-			slotReplay();
-			slotStatusMsg(i18n("Waiting for an answer..."));
-			slotSendMessage(msg);
+			if (m_connection)
+			{ // the server could have closed while the user was thinking if he wanted to replay
+				slotReplay();
+				slotStatusMsg(i18n("Waiting for an answer..."));
+				slotSendMessage(msg);
+			}
+			else
+			{
+				delete msg;
+				slotAbortNetworkGame();
+			}
 			break;
 
 		case KMessageBox::No:
@@ -820,7 +861,7 @@ void KBattleshipApp::slotStartBattleshipServer()
 		connect(m_connection, SIGNAL(sigReplay()), this, SLOT(slotReplayRequest()));
 		connect(m_connection, SIGNAL(sigChatMessage(const QString &, const QString &, bool)), m_chat, SLOT(slotReceivedMessage(const QString &, const QString &, bool)));
 		connect(m_connection, SIGNAL(sigClientInformation(const QString &, const QString &, const QString &, const QString &)), this, SLOT(slotReceivedClientInformation(const QString &, const QString &, const QString &, const QString &)));
-		connect(m_connection, SIGNAL(sigLost()), this, SLOT(slotLost()));
+		connect(m_connection, SIGNAL(sigLost(KMessage *)), this, SLOT(slotLost(KMessage *)));
 	}
 	else
 	{
@@ -837,7 +878,7 @@ void KBattleshipApp::slotStartBattleshipServer()
 			disconnect(m_connection, SIGNAL(sigServerLost()), this, SLOT(slotServerLost()));
 			disconnect(m_connection, SIGNAL(sigReplay()), this, SLOT(slotReplay()));
 			disconnect(m_connection, SIGNAL(sigChatMessage(const QString &, const QString &, bool)), m_chat, SLOT(slotReceivedMessage(const QString &, const QString &, bool)));
-			disconnect(m_connection, SIGNAL(sigLost()), this, SLOT(slotLost()));
+			disconnect(m_connection, SIGNAL(sigLost(KMessage *)), this, SLOT(slotLost(KMessage *)));
 			m_connection->updateInternal(m_kbserver);
 			connect(m_connection, SIGNAL(sigStatusBar(const QString &)), this, SLOT(slotStatusMsg(const QString &)));
 			connect(m_connection, SIGNAL(sigEnemyNickname(const QString &)), this, SLOT(slotChangeEnemyPlayer(const QString &)));
@@ -850,7 +891,7 @@ void KBattleshipApp::slotStartBattleshipServer()
 			connect(m_connection, SIGNAL(sigAbortNetworkGame()), this, SLOT(slotAbortNetworkGame()));
 			connect(m_connection, SIGNAL(sigReplay()), this, SLOT(slotReplayRequest()));
 			connect(m_connection, SIGNAL(sigChatMessage(const QString &, const QString &, bool)), m_chat, SLOT(slotReceivedMessage(const QString &, const QString &, bool)));
-			connect(m_connection, SIGNAL(sigLost()), this, SLOT(slotLost()));
+			connect(m_connection, SIGNAL(sigLost(KMessage *)), this, SLOT(slotLost(KMessage *)));
 		}
 		else
 			m_connection->updateInternal(m_kbserver);
@@ -858,9 +899,10 @@ void KBattleshipApp::slotStartBattleshipServer()
 	m_kbserver->init();
 }
 
-void KBattleshipApp::slotLost()
+void KBattleshipApp::slotLost(KMessage *msg)
 {
 	m_stat->slotAddEnemyWon();
+	if (msg->field("ship0") != QString::null) m_view->drawEnemyShipsHuman(msg, m_enemyshiplist);
 	m_lost = true;
 }
 
@@ -970,22 +1012,25 @@ void KBattleshipApp::slotChangeOwnFieldData(int fieldx, int fieldy, int type)
 
 void KBattleshipApp::playSound(bool enemy, int fieldstate)
 {
-	switch(fieldstate)
+	if (m_configSound->isChecked())
 	{
-		case KBattleField::WATER:
-			m_sound->playSound(KBattleshipSound::PLAYER_SHOOT_WATER);
-			break;
+		switch(fieldstate)
+		{
+			case KBattleField::WATER:
+				KNotifyClient::event(winId(), "shoot_water");
+				break;
 
-		case KBattleField::HIT:
-			if(enemy)
-				m_sound->playSound(KBattleshipSound::PLAYER1_SHOOT_HIT);
-			else
-				m_sound->playSound(KBattleshipSound::PLAYER2_SHOOT_HIT);
-			break;
+			case KBattleField::HIT:
+				if(enemy)
+					KNotifyClient::event(winId(), "shoot_hit_1");
+				else
+					KNotifyClient::event(winId(), "shoot_hit_2");
+				break;
 
-		case KBattleField::DEATH:
-			m_sound->playSound(KBattleshipSound::SHIP_SINK);
-			break;
+			case KBattleField::DEATH:
+				KNotifyClient::event(winId(), "shoot_sink");
+				break;
+		}
 	}
 }
 
@@ -1027,7 +1072,7 @@ void KBattleshipApp::slotConnectToBattleshipServer()
 		connect(m_connection, SIGNAL(sigReplay()), this, SLOT(slotReplay()));
 		connect(m_connection, SIGNAL(sigChatMessage(const QString &, const QString &, bool)), m_chat, SLOT(slotReceivedMessage(const QString &, const QString &, bool)));
 		connect(m_connection, SIGNAL(sigClientInformation(const QString &, const QString &, const QString &, const QString &)), this, SLOT(slotReceivedClientInformation(const QString &, const QString &, const QString &, const QString &)));
-		connect(m_connection, SIGNAL(sigLost()), this, SLOT(slotLost()));
+		connect(m_connection, SIGNAL(sigLost(KMessage *)), this, SLOT(slotLost(KMessage *)));
 	}
 	else
 	{
@@ -1044,7 +1089,7 @@ void KBattleshipApp::slotConnectToBattleshipServer()
 			disconnect(m_connection, SIGNAL(sigAbortNetworkGame()), this, SLOT(slotAbortNetworkGame()));
 			disconnect(m_connection, SIGNAL(sigReplay()), this, SLOT(slotReplayRequest()));
 			disconnect(m_connection, SIGNAL(sigChatMessage(const QString &, const QString &, bool)), m_chat, SLOT(slotReceivedMessage(const QString &, const QString &, bool)));
-			disconnect(m_connection, SIGNAL(sigLost()), this, SLOT(slotLost()));
+			disconnect(m_connection, SIGNAL(sigLost(KMessage *)), this, SLOT(slotLost(KMessage *)));
 			m_connection->updateInternal(m_kbclient);
 			connect(m_kbclient, SIGNAL(sigConnected()), this, SLOT(slotSendVersion()));
 			connect(m_connection, SIGNAL(sigAbortNetworkGame()), this, SLOT(slotAbortNetworkGame()));
@@ -1059,7 +1104,7 @@ void KBattleshipApp::slotConnectToBattleshipServer()
 			connect(m_connection, SIGNAL(sigChatMessage(const QString &, const QString &, bool)), m_chat, SLOT(slotReceivedMessage(const QString &, const QString &, bool)));
 			m_kbclient->init();
 			connect(m_connection, SIGNAL(sigClientInformation(const QString &, const QString &, const QString &, const QString &)), this, SLOT(slotReceivedClientInformation(const QString &, const QString &, const QString &, const QString &)));
-			connect(m_connection, SIGNAL(sigLost()), this, SLOT(slotLost()));
+			connect(m_connection, SIGNAL(sigLost(KMessage *)), this, SLOT(slotLost(KMessage *)));
 		}
 		else
 			m_connection->updateInternal(m_kbclient);
@@ -1085,22 +1130,6 @@ void KBattleshipApp::slotShowGrid()
 		m_view->field()->enableGrid();
 }
 
-void KBattleshipApp::slotConfigSound()
-{
-	if(!m_configSound->isChecked())
-		m_sound->turnOff();
-	else
-		m_sound->turnOn();
-}
-
-void KBattleshipApp::slotViewStatusBar()
-{
-	if(!m_viewStatusBar->isChecked())
-		statusBar()->hide();
-	else
-		statusBar()->show();
-}
-
 void KBattleshipApp::slotStatusMsg(const QString &text)
 {
 	statusBar()->clear();
@@ -1121,19 +1150,16 @@ void KBattleshipApp::slotChangeEnemyPlayer(const QString &text)
 
 void KBattleshipApp::slotSinglePlayer()
 {
+	bool ok;
 	if(!m_aiPlaying)
 	{
-		if(m_single != 0)
-			return;
-
-		slotStatusMsg(i18n("Loading Single-Game dialog..."));
-
-		m_single = new KSingleDialog();
-		connect(m_single, SIGNAL(sigStartGame()), this, SLOT(slotStartBattleshipGame()));
-		connect(m_single, SIGNAL(sigCancelGame()), this, SLOT(slotDeleteSingleDialog()));
-		m_single->show();
-
-		slotStatusMsg(i18n("Ready"));
+		m_ownNickname = KInputDialog::getText(i18n("Start Game"), i18n("Nick name:"),
+			QString::fromLocal8Bit(getenv("LOGNAME")), &ok, this);
+		if (ok)
+		{
+			slotStatusMsg(i18n("Ready"));
+			slotStartBattleshipGame();
+		}
 	}
 	else
 	{
@@ -1154,13 +1180,6 @@ void KBattleshipApp::slotSinglePlayer()
 	}
 }
 
-void KBattleshipApp::slotDeleteSingleDialog()
-{
-	delete m_single;
-	m_single = 0;
-}
-
-
 void KBattleshipApp::slotStartBattleshipGame()
 {
 	slotStartBattleshipGame(true);
@@ -1172,12 +1191,6 @@ void KBattleshipApp::slotStartBattleshipGame(bool clearstat)
 	m_gameNewServer->setEnabled(false);
 	m_gameServerConnect->setEnabled(false);
 	slotStatusMsg(i18n("Waiting for the AI player to place the ships..."));
-	if(m_single != 0)
-	{
-		m_ownNickname = m_single->nickname();
-		delete m_single;
-		m_single = 0;
-	}
 	slotChangeOwnPlayer(m_ownNickname);
 	slotChangeEnemyPlayer(KGameMisc::randomName());
 	cleanup(true);
@@ -1228,7 +1241,7 @@ void KBattleshipApp::slotAIShootsAt(const QPoint pos)
 		m_aiHits++;
 	}
 
-	slotStatusMsg(i18n("Enemy has shot. Shoot now"));
+	slotStatusMsg(i18n("Enemy has shot. Shoot now."));
 	slotChangeOwnFieldData(pos.x(), pos.y(), showstate);
 
 	if(m_aiHits == 10 && m_stat->hit() != 10)
@@ -1243,6 +1256,7 @@ void KBattleshipApp::slotAIShootsAt(const QPoint pos)
 		slotStatusMsg(i18n("You lost the game :("));
 		m_stat->slotAddEnemyWon();
 		slotUpdateHighscore();
+		m_view->drawEnemyShipsAI(m_enemyshiplist); // let's show ai player ships
 		switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?")))
 		{
 			case KMessageBox::Yes:
