@@ -19,12 +19,16 @@
 #define KBATTLESHIPVIEW_H
 
 #include <kmainwindow.h>
+
 #include <qpainter.h>
-#include <qwidget.h>
-#include <qstring.h>
 #include <qptrlist.h>
-#include "kship.h"
+#include <qstring.h>
+#include <qwidget.h>
+
 #include "kbattlefield.h"
+#include "kmessage.h"
+#include "kship.h"
+#include "kshiplist.h"
 
 class KBattleshipView : public QWidget
 {
@@ -45,6 +49,10 @@ public:
 	int ownFieldState(int fieldx, int fieldy);
 	int enemyFieldState(int &fieldx, int &fieldy);
 
+	void drawEnemyShipsAI(KShipList *list);
+	void drawEnemyShipsHuman(KMessage *msg, KShipList *list);
+	KMessage *getAliveShips(KShipList *list);
+
 signals:
 	void sigEnemyFieldClicked(int, int);
 	void sigOwnFieldClicked(int, int, int);
