@@ -15,10 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "main.h"
-#include "konnectionhandling.h"
 #include "konnectionhandling.moc"
 
+extern const char *protocolVersion;
+
 KonnectionHandling::KonnectionHandling(QWidget *parent, KBattleshipServer *server) : QObject(parent)
 {
 	m_kbserver = server;
@@ -42,10 +42,6 @@ KonnectionHandling::KonnectionHandling(QWidget *parent, KBattleshipClient *clien
 	connect(client, SIGNAL(sigMessageSent(KMessage *)), this, SLOT(slotMessageSent(KMessage *)));
 }
 
-KonnectionHandling::~KonnectionHandling()
-{
-}
-
 void KonnectionHandling::updateInternal(KBattleshipServer *server)
 {
 	m_kbserver = server;
@@ -75,7 +71,7 @@ void KonnectionHandling::slotNewClient()
 
 void KonnectionHandling::slotLostClient()
 {
-	KMessageBox::error(0L, i18n("Connection to client lost. Aborting the game!"));
+	KMessageBox::error(0L, i18n("Connection to client lost. Aborting the game."));
 	emit sigClientLost();
 }
 
@@ -89,6 +85,7 @@ void KonnectionHandling::slotMessageSent(KMessage *msg)
 
 void KonnectionHandling::slotNewMessage(KMessage *msg)
 {
+	KMessage *copy;
 	if(type() == KonnectionHandling::CLIENT)
 	{
 		switch(msg->type())
@@ -97,7 +94,7 @@ void KonnectionHandling::slotNewMessage(KMessage *msg)
 			case KMessage::DISCARD:
 				if(msg->field("kmversion") == QString("true"))
 				{
-					KMessageBox::error(0L, i18n("Connection dropped by enemy. The client's protocol implementation (%1) is not compatible with our (%2) version!").arg(msg->field("reason")).arg(protocolVersion));
+					KMessageBox::error(0L, i18n("Connection dropped by enemy. The client's protocol implementation (%1) is not compatible with our (%2) version.").arg(msg->field("reason")).arg(protocolVersion));
 					emit sigAbortNetworkGame();
 				}
 				else
@@ -112,7 +109,7 @@ void KonnectionHandling::slotNewMessage(KMessage *msg)
 				// Got the enemy's nickname
 			case KMessage::GREET:
 				emit sigEnemyNickname(msg->field("nickname"));
-				emit sigStatusBar(i18n("Waiting for other player to place the ships..."));
+				emit sigStatusBar(i18n("Waiting for other player to place their ships..."));
 				break;
 
 				// The server wants ous to place the ships
@@ -124,7 +121,7 @@ void KonnectionHandling::slotNewMessage(KMessage *msg)
 				// The server shot and wants the field state
 			case KMessage::SHOOT:
 				emit sigSendFieldState(msg->field("fieldx").toInt(), msg->field("fieldy").toInt());
-				emit sigStatusBar(i18n("Enemy has shot. Shoot now"));
+				emit sigStatusBar(i18n("Enemy has shot. Shoot now."));
 				emit sigShootable(true);
 				break;
 
@@ -136,14 +133,15 @@ void KonnectionHandling::slotNewMessage(KMessage *msg)
 
 				// The server starts a new game
 			case KMessage::REPLAY:
-				emit sigStatusBar(i18n("Waiting for other player to place the ships..."));
+				emit sigStatusBar(i18n("Waiting for other player to place their ships..."));
 				emit sigReplay();
 				break;
 
 				// We lost the game
 			case KMessage::WON:
 				emit sigStatusBar(i18n("You lost the game :("));
-				emit sigLost();
+				copy = new KMessage(msg);
+				emit sigLost(copy);
 				break;
 
 				// We got a chat message
@@ -161,7 +159,7 @@ void KonnectionHandling::slotNewMessage(KMessage *msg)
 				if(msg->field("protocolVersion") != QString::fromLatin1(protocolVersion))
 				{
 					m_kbserver->slotDiscardClient(protocolVersion, true, false);
-					KMessageBox::error(0L, i18n("Connection to client dropped. The client's protocol implementation (%1) is not compatible with our (%2) version!").arg(msg->field("protocolVersion")).arg(protocolVersion));
+					KMessageBox::error(0L, i18n("Connection to client dropped. The client's protocol implementation (%1) is not compatible with our (%2) version.").arg(msg->field("protocolVersion")).arg(protocolVersion));
 				}
 				else
 					emit sigClientInformation(msg->field("clientName"), msg->field("clientVersion"), msg->field("clientDescription"), msg->field("protocolVersion"));
@@ -179,7 +177,7 @@ void KonnectionHandling::slotNewMessage(KMessage *msg)
 				// The client placed his ships...we can shoot now
 			case KMessage::SHIPSREADY:
 				emit sigShootable(true);
-				emit sigStatusBar(i18n("You can shoot now"));
+				emit sigStatusBar(i18n("You can shoot now."));
 				break;
 
 				// The client gave us the field data of our last shot
@@ -191,7 +189,7 @@ void KonnectionHandling::slotNewMessage(KMessage *msg)
 				// The client shot and wants the field state
 			case KMessage::SHOOT:
 				emit sigSendFieldState(msg->field("fieldx").toInt(), msg->field("fieldy").toInt());
-				emit sigStatusBar(i18n("Enemy has shot. Shoot now"));
+				emit sigStatusBar(i18n("Enemy has shot. Shoot now."));
 				emit sigShootable(true);
 				break;
 
@@ -203,7 +201,8 @@ void KonnectionHandling::slotNewMessage(KMessage *msg)
 				// We lost the game
 			case KMessage::WON:
 				emit sigStatusBar(i18n("You lost the game :("));
-				emit sigLost();
+				copy = new KMessage(msg);
+				emit sigLost(copy);
 				break;
 
 				// We got a chat message
@@ -221,15 +220,15 @@ void KonnectionHandling::slotSocketError(int error)
 	switch(error)
 	{
 		case IO_ConnectError:
-			KMessageBox::error(0L, i18n("Connection refused by other host!"));
+			KMessageBox::error(0L, i18n("Connection refused by other host."));
 			break;
 
 		case IO_LookupError:
-			KMessageBox::error(0L, i18n("Couldn't lookup host!"));
+			KMessageBox::error(0L, i18n("Couldn't lookup host."));
 			break;
 
 		case IO_ReadError:
-			KMessageBox::error(0L, i18n("Couldn't connect to server!"));
+			KMessageBox::error(0L, i18n("Couldn't connect to server."));
 			break;
 
 		default:
@@ -242,6 +241,6 @@ void KonnectionHandling::slotSocketError(int error)
 
 void KonnectionHandling::slotLostServer()
 {
-	KMessageBox::error(0L, i18n("Connection to server lost. Aborting the game!"));
+	KMessageBox::error(0L, i18n("Connection to server lost. Aborting the game."));
 	emit sigServerLost();
 }
