@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -23,6 +23,7 @@
 #include <kapplication.h>
 #include <kdebug.h>
 #include <qimage.h>
+#include <kglobalsettings.h>
 
 #include "game.h"
 
@@ -45,6 +46,7 @@
 
 SimpleSoundServer *JezzGame::m_artsServer = 0;
 QString JezzGame::m_soundPath;
+bool JezzGame::m_sound = true;
 
 #define MS2TICKS( ms ) ((ms)/GAME_DELAY)
 
@@ -421,8 +423,9 @@ void JezzGame::display( QString text, int size )
     {
         //kdDebug() << "text = " << text << endl;
 
-        QFont font( "Helvetica", size, QFont::Bold );
-        font.setStyleHint( QFont::Helvetica );
+        QFont font = KGlobalSettings::generalFont();
+        font.setBold(true);
+        font.setPointSize(size);
         m_text->setFont( font );
         m_text->setText( text );
 
@@ -439,7 +442,7 @@ void JezzGame::display( QString text, int size )
 
 void JezzGame::playSound( QString name )
 {
-    if( !m_artsServer->isNull() )
+    if( !m_artsServer->isNull() && m_sound)
     {
         QString path = m_soundPath + name;
         m_artsServer->play( path.latin1() );
@@ -451,6 +454,11 @@ void JezzGame::setBackground( QPixmap background )
     m_field->setBackground( background );
 }
 
+void JezzGame::setSound( bool sound )
+{
+    m_sound = sound;
+}
+
 void JezzGame::start()
 {
     m_running = true;
