@@ -13,11 +13,10 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <kapplication.h>
-#include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <arts/dispatcher.h>
@@ -38,21 +37,24 @@ int main(int argc, char **argv)
 
   aboutData.addAuthor("Stefan Schimanski", I18N_NOOP("Original author"), "schimmi@kde.org");
   aboutData.addAuthor("Sandro Sigala", I18N_NOOP("Highscore"), "ssigala@globalnet.it");
-  aboutData.addAuthor("Benjamin Meyer", I18N_NOOP("Contributions"), "ben-devel@meyerhome.net");
-	
+  aboutData.addAuthor("Benjamin Meyer", I18N_NOOP("Contributions"), "ben+kbounce@meyerhome.net");
+
   KCmdLineArgs::init( argc, argv, &aboutData );
 
   QApplication::setColorSpec(QApplication::ManyColor);
   KApplication a;
   KGlobal::locale()->insertCatalogue("libkdegames");
-   
+
   // setup MCOP
   Dispatcher dispatcher;
 
-  KJezzball *top = new KJezzball;
-  a.setMainWidget(top);
-  top->show();
-
+  if (a.isRestored())
+      RESTORE(KJezzball)
+  else {
+      KJezzball *w = new KJezzball;
+      a.setMainWidget(w);
+      w->show();
+  }
   return a.exec();
 }
 
