@@ -26,6 +26,7 @@
 #include "EvalDlgImpl.h"
 #include "EvalScheme.h"
 #include "Network.h"
+#include "Spy.h"
 #include "version.h"
 
 #include <stdio.h>
@@ -33,6 +34,20 @@
 
 // #define MYTRACE 1
 
+const AbTop::Data AbTop::LEVEL[Nb_Levels] = {
+    { "Easy",   I18N_NOOP("&Easy")   },
+    { "Normal", I18N_NOOP("&Normal") },
+    { "Hard",   I18N_NOOP("&Hard")   },
+    { "Challange", I18N_NOOP("&Challenge") }
+};
+
+const AbTop::Data AbTop::IPLAY[Nb_IPlays] = {
+    { "Red",    I18N_NOOP("&Red")    },
+    { "Yellow", I18N_NOOP("&Yellow") },
+    { "Both",   I18N_NOOP("&Both")   },
+    { "None",   I18N_NOOP("&None")   }
+};
+
 AbTop::AbTop()
   :KMainWindow(0)
 {
@@ -57,7 +72,7 @@ AbTop::AbTop()
 
   connect( board, SIGNAL(searchBreak()), this, SLOT(searchBreak()) );
   Q_CHECK_PTR(board);
-  boardWidget = new BoardWidget(*board,this);  
+  boardWidget = new BoardWidget(*board,this);
 
 #ifdef SPION
   spy = new Spy(*board);
@@ -77,7 +92,6 @@ AbTop::AbTop()
 
 
   // RMB context menu
-  setupRMBMenu();
   connect( boardWidget, SIGNAL(rightButtonPressed(int,const QPoint&)),
 	   this, SLOT(rightButtonPressed(int,const QPoint&)) );
 
@@ -87,16 +101,16 @@ AbTop::AbTop()
   connect( board, SIGNAL(updateBestMove(Move&,int)),
 	   this, SLOT(updateBestMove(Move&,int)) );
 
-  connect( boardWidget, SIGNAL(moveChoosen(Move&)), 
+  connect( boardWidget, SIGNAL(moveChoosen(Move&)),
 	   this, SLOT(moveChoosen(Move&)) );
 
   /* default */
-  easy();
-  play_red();
+  setLevel(Easy);
+  setIPlay(Red);
   showMoveLong = true;
   showSpy = false;
   renderBalls = true;
-  
+
   updateStatus();
   updateActions();
 }
@@ -104,8 +118,7 @@ AbTop::AbTop()
 AbTop::~AbTop()
 {
   /* Unregister from other abalone processes */
-  if (net)
-    delete net;
+  delete net;
   delete timer;
 #ifdef SPION
   delete spy;
@@ -122,34 +135,33 @@ AbTop::~AbTop()
 
 void AbTop::setupActions()
 {
-  KStdGameAction::gameNew( this, SLOT(newGame()), actionCollection() );
-  KStdGameAction::quit( this, SLOT(quit()), actionCollection() );
+  newAction = KStdGameAction::gameNew( this, SLOT(newGame()), actionCollection() );
+  KStdGameAction::quit( this, SLOT(close()), actionCollection() );
 
-  (void) new KAction( i18n("&Stop Search"), "stop", Key_S, this,
-		      SLOT(stopSearch()), actionCollection(), "game_stop");
+  stopAction = new KAction( i18n("&Stop Search"), "stop", Key_S, this,
+                            SLOT(stopSearch()), actionCollection(), "move_stop");
 
-  (void) new KAction( i18n("Take &Back"), "back",
-		      KStdAccel::key(KStdAccel::Prior), this,
-		      SLOT(back()), actionCollection(), "game_back");
+  backAction = new KAction( i18n("Take &Back"), "back",
+                            KStdAccel::shortcut(KStdAccel::Prior), this,
+                            SLOT(back()), actionCollection(), "move_back");
 
-  (void) new KAction( i18n("&Forward"), "forward",
-		      KStdAccel::key(KStdAccel::Next), this,
-		      SLOT(forward()), actionCollection(), "game_forward");
+  forwardAction = new KAction( i18n("&Forward"), "forward",
+                            KStdAccel::shortcut(KStdAccel::Next), this,
+                            SLOT(forward()), actionCollection(), "move_forward");
 
-  (void) new KAction( i18n("&Hint"), "hint", Key_H, this,
-		      SLOT(suggestion()), actionCollection(), "game_hint");
+  hintAction = KStdGameAction::hint(this, SLOT(suggestion()), actionCollection());
 
   KStdAction::copy( this, SLOT(copy()), actionCollection());
-  KStdAction::paste( this, SLOT(paste()), actionCollection());
+  pasteAction = KStdAction::paste( this, SLOT(paste()), actionCollection());
 
   (void) new KAction( i18n("&Restore Position"),
-		      KStdAccel::key(KStdAccel::Open), 
-		      this, SLOT(restorePosition()), 
+		      KStdAccel::shortcut(KStdAccel::Open),
+		      this, SLOT(restorePosition()),
 		      actionCollection(), "edit_restore" );
 
   (void) new KAction( i18n("&Save Position"),
-		      KStdAccel::key(KStdAccel::Save), 
-		      this, SLOT(savePosition()), 
+		      KStdAccel::shortcut(KStdAccel::Save),
+		      this, SLOT(savePosition()),
 		      actionCollection(), "edit_save" );
 
   KToggleAction *ta;
@@ -158,82 +170,45 @@ void AbTop::setupActions()
 			  actionCollection(), "game_net");
   connect(ta, SIGNAL(toggled(bool)), this, SLOT(gameNetwork(bool)));
 
-  ta = new KToggleAction( i18n("&Modify"), "edit",
-			  CTRL+Key_Insert, 
-			  actionCollection(), "edit_modify");
-  connect(ta, SIGNAL(toggled(bool)), this, SLOT( editModify(bool)));   
+  editAction = new KToggleAction( i18n("&Modify"), "edit",
+                                  CTRL+Key_Insert, actionCollection(), "edit_modify");
+  connect(editAction, SIGNAL(toggled(bool)), this, SLOT( editModify(bool)));
 
-  KStdAction::showMenubar(this, SLOT(toggleMenubar()), actionCollection());
-  KStdAction::showToolbar(this, SLOT(toggleToolbar()), actionCollection());
-  KStdAction::showStatusbar(this, SLOT(toggleStatusbar()), actionCollection());
+  showMenubar = KStdAction::showMenubar(this, SLOT(toggleMenubar()), actionCollection());
+  createStandardStatusBarAction();
+  setStandardToolBarMenuEnabled(true);
   KStdAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
   KStdAction::configureToolbars(this,SLOT(configureToolbars()), actionCollection());
   KStdAction::saveOptions( this, SLOT(writeConfig()), actionCollection());
 
   KStdAction::preferences( this, SLOT(configure()), actionCollection());
 
-  ta =  new KToggleAction( i18n("&Move Slow"), 0,
-			   actionCollection(), "option_moveSlow");
-  connect(ta, SIGNAL(toggled(bool)), this, SLOT(optionMoveSlow(bool)));
+  moveSlowAction =  new KToggleAction( i18n("&Move Slow"), 0,
+                                       actionCollection(), "options_moveSlow");
+  connect(moveSlowAction, SIGNAL(toggled(bool)), this, SLOT(optionMoveSlow(bool)));
 
-  ta =  new KToggleAction( i18n("&Render Balls"), 0,
-			   actionCollection(), "option_renderBalls");
-  connect(ta, SIGNAL(toggled(bool)), this, SLOT(optionRenderBalls(bool)));
+  renderBallsAction =  new KToggleAction( i18n("&Render Balls"), 0,
+                                          actionCollection(), "options_renderBalls");
+  connect(renderBallsAction, SIGNAL(toggled(bool)), this, SLOT(optionRenderBalls(bool)));
 
-  ta =  new KToggleAction( i18n("&Spy"), 0,
-			   actionCollection(), "option_showSpy");
-  connect(ta, SIGNAL(toggled(bool)), this, SLOT(optionShowSpy(bool)));
+  showSpyAction =  new KToggleAction( i18n("&Spy"), 0,
+                                      actionCollection(), "options_showSpy");
+  connect(showSpyAction, SIGNAL(toggled(bool)), this, SLOT(optionShowSpy(bool)));
 
 
-  KRadioAction *ra;
+  levelAction = KStdGameAction::chooseGameType(0, 0, actionCollection());
+  QStringList list;
+  for (uint i=0; i<Nb_Levels; i++)
+      list.append( i18n(LEVEL[i].label) );
+  levelAction->setItems(list);
+  connect(levelAction, SIGNAL(activated(int)), SLOT(setLevel(int)));
 
-  ra =  new KRadioAction( i18n("&Easy"), 0,
-			  actionCollection(), "level_easy");
-  ra->setExclusiveGroup( "Level" );
-  ra->setChecked( false );
-  connect(ra, SIGNAL(toggled(bool)), this, SLOT(levelEasy(bool)));
-
-  ra =  new KRadioAction( i18n("&Normal"), 0,
-			  actionCollection(), "level_normal");
-  ra->setExclusiveGroup( "Level" );
-  ra->setChecked( true );
-  connect(ra, SIGNAL(toggled(bool)), this, SLOT(levelNormal(bool)));
-
-  ra =  new KRadioAction( i18n("&Hard"), 0,
-			  actionCollection(), "level_hard");
-  ra->setExclusiveGroup( "Level" );
-  ra->setChecked( false );
-  connect(ra, SIGNAL(toggled(bool)), this, SLOT(levelNormal(bool)));
-
-  ra =  new KRadioAction( i18n("&Challenge"), 0,
-			  actionCollection(), "level_challange");
-  ra->setExclusiveGroup( "Level" );
-  ra->setChecked( false );
-  connect(ra, SIGNAL(toggled(bool)), this, SLOT(levelChallange(bool)));
-
-  ra =  new KRadioAction( i18n("&Red"), 0,
-			  actionCollection(), "iplay_red");
-  ra->setExclusiveGroup( "IPlay" );
-  ra->setChecked( true );
-  connect(ra, SIGNAL(toggled(bool)), this, SLOT(iplayRed(bool)));
-
-  ra =  new KRadioAction( i18n("&Yellow"), 0,
-			  actionCollection(), "iplay_yellow");
-  ra->setExclusiveGroup( "IPlay" );
-  ra->setChecked( false );
-  connect(ra, SIGNAL(toggled(bool)), this, SLOT(iplayYellow(bool)));
-
-  ra =  new KRadioAction( i18n("&Both"), 0,
-			  actionCollection(), "iplay_both");
-  ra->setExclusiveGroup( "IPlay" );
-  ra->setChecked( false );
-  connect(ra, SIGNAL(toggled(bool)), this, SLOT(iplayBoth(bool)));
-
-  ra =  new KRadioAction( i18n("&None"), 0,
-			  actionCollection(), "iplay_none");
-  ra->setExclusiveGroup( "IPlay" );
-  ra->setChecked( false );
-  connect(ra, SIGNAL(toggled(bool)), this, SLOT(iplayNone(bool)));
+  iplayAction = new KSelectAction(i18n("&Computer Play"), 0, actionCollection(), "options_iplay");
+  list.clear();
+  for (uint i=0; i<Nb_IPlays; i++)
+      list.append( i18n(IPLAY[i].label) );
+  iplayAction->setItems(list);
+  connect(iplayAction, SIGNAL(activated(int)), SLOT(setIPlay(int)));
 }
 
 void AbTop::toggleMenubar()
@@ -244,28 +219,11 @@ void AbTop::toggleMenubar()
     menuBar()->show();
 }
 
-void AbTop::toggleToolbar()
-{
-  QToolBar *bar = toolBar();
-  if(bar->isVisible())
-    bar->hide();
-  else
-    bar->show();
-}
-
-void AbTop::toggleStatusbar()
-{
-  if (statusBar()->isVisible())
-    statusBar()->hide();
-  else
-    statusBar()->show();
-}
-
 void AbTop::configure()
 {
   KDialogBase *dlg = new KDialogBase( 0, "ConfigureEvaluation", true,
 				      i18n("Configure Evaluation"),
-				      KDialogBase::Ok | KDialogBase::Cancel, 
+				      KDialogBase::Ok | KDialogBase::Cancel,
 				      KDialogBase::Ok, true);
 
   EvalDlgImpl *edlg = new EvalDlgImpl(dlg,board);
@@ -281,32 +239,33 @@ void AbTop::configure()
 
 void AbTop::configureKeys()
 {
-  KKeyDialog::configureKeys(actionCollection(), xmlFile(), true, this);
+  KKeyDialog::configure(actionCollection(), this);
 }
 
 
 void AbTop::configureToolbars()
 {
-  KEditToolbar *dlg = new KEditToolbar(guiFactory(),this);
-
-  if (dlg->exec())
-    createGUI();
-
-  delete dlg;
+  saveMainWindowSettings(KGlobal::config(), "kedittoolbar settings"); // temp group
+  KEditToolbar dlg(actionCollection(), QString::null, true, this);
+  connect( &dlg, SIGNAL( newToolbarConfig() ),this,SLOT( newToolbarConfig() ) );
+  dlg.exec();
+  KGlobal::config()->deleteGroup( "kedittoolbar settings" ); // delete temp group
 }
 
 
-void AbTop::setupRMBMenu()
+void AbTop::newToolbarConfig()
 {
-  /* use XML description */
-  rmbMenu = static_cast<QPopupMenu*> (factory()->container("rmbPopup",this));
+  createGUI();
+  applyMainWindowSettings(KGlobal::config(), "kedittoolbar settings");
 }
 
 
 /* Right Mouse button pressed in BoardWidget area */
 void AbTop::rightButtonPressed(int /* field */, const QPoint& pos)
 {
-  rmbMenu->popup( pos );
+  QPopupMenu* rmbMenu = static_cast<QPopupMenu*> (factory()->container("rmbPopup",this));
+  if (rmbMenu)
+    rmbMenu->popup( pos );
 }
 
 /* Read config options
@@ -319,54 +278,12 @@ void AbTop::readConfig()
 
   KConfig* config = kapp->config();
   config->setGroup("Options");
-	
+
   readOptions(config);
 
-  /* Size, Statusbar/Menubar */
-  QString entry;
+  applyMainWindowSettings( config, "Appearance" );
 
-  config->setGroup("Appearance");
-  if (!(entry = config->readEntry("Geometry")).isNull()) {
-    int x=215, y=280;    
-    sscanf(entry.ascii(),"%dx%d",&x,&y);
-    resize(x,y);
-  }
-
-  if (!(entry = config->readEntry("MenuBar")).isNull()) {
-    if (entry == QString::fromLatin1("Enabled"))
-      menuBar()->show();
-    else {
-      menuBar()->hide();
-
-      KToggleAction *a = static_cast<KToggleAction*>
-	(actionCollection()->action(KStdAction::stdName(KStdAction::ShowMenubar)));
-      if (a) a->setChecked(false);
-    }
-  }
-
-  if (!(entry = config->readEntry("StatusBar")).isNull()) {
-    if (entry == QString::fromLatin1("Enabled"))
-      statusBar()->show();
-    else {
-      statusBar()->hide();
-
-      KToggleAction *a = static_cast<KToggleAction*>
-	(actionCollection()->action(KStdAction::stdName(KStdAction::ShowStatusbar)));
-      if (a) a->setChecked(false);
-    }
-  }
-
-  if (!(entry = config->readEntry("ToolBar")).isNull()) {
-    if (entry == QString::fromLatin1("Enabled"))
-      toolBar("mainToolBar")->show();
-    else {
-      toolBar("mainToolBar")->hide();
-
-      KToggleAction *a = static_cast<KToggleAction*>
-	(actionCollection()->action(KStdAction::stdName(KStdAction::ShowToolbar)));
-      if (a) a->setChecked(false);
-    }
-  }
+  showMenubar->setChecked( !menuBar()->isHidden() );
 
   currentEvalScheme = new EvalScheme("Current");
   currentEvalScheme->read(config);
@@ -374,60 +291,43 @@ void AbTop::readConfig()
 }
 
 void AbTop::readOptions(KConfig* config)
-{	
-  QString entry;
-  if (!(entry = config->readEntry("Level")).isNull()) {
-    if (entry == "Easy")  easy();
-    else if (entry == "Normal") normal();
-    else if (entry == "Hard") hard();
-    else if (entry == "Challange") challange();
-  }
+{
+  QString entry = config->readEntry("Level");
+  for (uint i=0; i<Nb_Levels; i++)
+      if ( entry==LEVEL[i].key ) setLevel(i);
 
-  if (!(entry = config->readEntry("Computer")).isNull()) {
-    if (entry == "Red") play_red();
-    else if (entry == "Yellow") play_yellow();
-    else if (entry == "Both") play_both();
-    else if (entry == "None") play_none();
-  }
+  entry = config->readEntry("Computer");
+  for (uint i=0; i<Nb_IPlays; i++)
+      if ( entry==IPLAY[i].key ) setIPlay(i);
 
-  showMoveLong = false; // default
-  if (!(entry = config->readEntry("MoveSlow")).isNull()) 
-    showMoveLong = (entry == "Yes");
-  ((KToggleAction*) actionCollection()->action("option_moveSlow"))
-    ->setChecked( showMoveLong );
+  showMoveLong = config->readBoolEntry("MoveSlow", false);
+  moveSlowAction->setChecked( showMoveLong );
 
-  renderBalls = true; // default  
-  if (!(entry = config->readEntry("RenderBalls")).isNull()) 
-    renderBalls = (entry == "Yes");
+  renderBalls = config->readBoolEntry("RenderBalls", true);
   boardWidget->renderBalls(renderBalls);
-  ((KToggleAction*) actionCollection()->action("option_renderBalls"))
-    ->setChecked( renderBalls );
+  renderBallsAction->setChecked( renderBalls );
 
-  showSpy = true; // default
-  if (!(entry = config->readEntry("ShowSpy")).isNull()) 
-    showSpy = (entry == "Yes");
+  showSpy = config->readBoolEntry("ShowSpy", true);
   board->updateSpy(showSpy);
-  ((KToggleAction*) actionCollection()->action("option_showSpy"))
-    ->setChecked( showSpy );
+  showSpyAction->setChecked( showSpy );
 }
 
 void AbTop::readProperties(KConfig *config)
 {
   QString entry;
-	
+
   readOptions(config);
 
   currentEvalScheme = new EvalScheme("Current");
   currentEvalScheme->read(config);
   board->setEvalScheme( currentEvalScheme );
 
-	
+
   if (!(entry = config->readEntry("TimerState")).isNull())
     timerState = entry.toInt();
   if (timerState == noGame) return;
 
-  if (!(entry = config->readEntry("GameStopped")).isNull())  
-    stop = (entry == "Yes");
+  stop = config->readBoolEntry("GameStopped", false);
 
   int mNo = 0;
   if (!(entry = config->readEntry("Position")).isNull()) {
@@ -449,12 +349,8 @@ void AbTop::writeConfig()
 
   writeOptions(config);
 
-  QString entry;
-  config->setGroup("Appearance");
-  config->writeEntry("Geometry", entry.sprintf("%dx%d",width(),height()) );  
-  config->writeEntry("MenuBar", menuBar()->isVisible() ? "Enabled": "Disabled");
-  config->writeEntry("ToolBar", toolBar("mainToolBar")->isVisible() ? "Enabled": "Disabled");
-  config->writeEntry("StatusBar", statusBar()->isVisible() ? "Enabled": "Disabled");
+  saveMainWindowSettings( config, "Appearance" );
+
   if (currentEvalScheme)
     currentEvalScheme->save(config);
   config->sync();
@@ -463,74 +359,29 @@ void AbTop::writeConfig()
 
 void AbTop::writeOptions(KConfig *config)
 {
-  QString entry;
+  config->writeEntry("Level", LEVEL[levelAction->currentItem()].key);
+  config->writeEntry("Computer", IPLAY[iplayAction->currentItem()].key);
 
-  if (((KRadioAction*) actionCollection()->action("level_easy"))
-      ->isChecked()) {
-    entry = "Easy";
-  }
-  else if (((KRadioAction*) actionCollection()->action("level_normal"))
-	   ->isChecked()) {
-    entry = "Normal";
-  }
-  else if (((KRadioAction*) actionCollection()->action("level_hard"))
-	   ->isChecked()) {
-    entry = "Hard";
-  }
-  else
-    entry = "Challange";
-
-  config->writeEntry("Level",entry);
-
-  if (((KRadioAction*) actionCollection()->action("iplay_red"))
-      ->isChecked()) {
-    entry = "Red";
-  }
-  else if (((KRadioAction*) actionCollection()->action("iplay_yellow"))
-	   ->isChecked()) {
-    entry = "Yellow";
-  }
-  else if (((KRadioAction*) actionCollection()->action("iplay_both"))
-	   ->isChecked()) {
-    entry = "Both";
-  }
-  else
-    entry = "None";
-
-  config->writeEntry("Computer",entry);
-
-  entry = showMoveLong ? "Yes" : "No";
-  config->writeEntry("MoveSlow",entry);
-
-  entry = renderBalls ? "Yes" : "No";
-  config->writeEntry("RenderBalls",entry);
-	
-  entry = showSpy ? "Yes" : "No";
-  config->writeEntry("ShowSpy",entry);
+  config->writeEntry("MoveSlow", showMoveLong);
+  config->writeEntry("RenderBalls", renderBalls);
+  config->writeEntry("ShowSpy", showSpy);
 }
 
 void AbTop::saveProperties(KConfig *config)
 {
-  QString entry;
-  
   writeOptions(config);
   if (currentEvalScheme)
     currentEvalScheme->save(config);
-	
-  config->writeEntry("TimerState",entry.setNum(timerState));
+
+  config->writeEntry("TimerState", timerState);
 
   if (timerState == noGame) return;
 
-  config->writeEntry("GameStopped", stop ? "Yes":"No");
+  config->writeEntry("GameStopped", stop);
   config->writeEntry("Position", board->getState(moveNo));
   config->sync();
 }
 
-void AbTop::closeEvent(QCloseEvent *)
-{
-  quit();
-}
-
 void AbTop::savePosition()
 {
   KConfig* config = kapp->config();
@@ -543,9 +394,9 @@ void AbTop::restorePosition()
   KConfig* config = kapp->config();
   config->setGroup("SavedPosition");
   QString  entry = config->readEntry("Position");
-  
+
   timerState = notStarted;
-  timer->stop();	
+  timer->stop();
   board->begin(Board::color1);
   stop = false;
   setMoveNo( board->setState(entry), true );
@@ -561,19 +412,17 @@ void AbTop::restorePosition()
 void AbTop::setupStatusBar()
 {
   QString tmp;
-  KStatusBar* status = statusBar();
 
-  QString t = i18n("Press %1 for a new game")
-    .arg( actionCollection()->action("game_new")->shortcut().seq(0).toString());
-  statusLabel = new QLabel( t, status, "statusLabel" );
-  status->addWidget(statusLabel,1,false);
+  QString t = i18n("Press %1 for a new game").arg( newAction->shortcut().toString());
+  statusLabel = new QLabel( t, statusBar(), "statusLabel" );
+  statusBar()->addWidget(statusLabel,1,false);
 
   // PERMANENT: Moving side + move No.
 
   // validPixmap, only visible in Modify mode: is position valid ?
   warningPix = BarIcon( "warning" );
   okPix = BarIcon( "ok" );
-  validLabel = new QLabel( "", status, "validLabel" );
+  validLabel = new QLabel( "", statusBar(), "validLabel" );
   validLabel->setFixedSize( 18, statusLabel->sizeHint().height() );
   validLabel->setAlignment( AlignCenter );
   validLabel->hide();
@@ -582,16 +431,16 @@ void AbTop::setupStatusBar()
   redBall = BarIcon( "redball" );
   yellowBall = BarIcon( "yellowball" );
   noBall = BarIcon( "noball" );
-  ballLabel = new QLabel( "", status, "ballLabel" );
+  ballLabel = new QLabel( "", statusBar(), "ballLabel" );
   ballLabel->setPixmap(noBall);
   ballLabel->setFixedSize( 18, statusLabel->sizeHint().height() );
   ballLabel->setAlignment( AlignCenter );
-  status->addWidget(ballLabel, 0, true);
+  statusBar()->addWidget(ballLabel, 0, true);
 
-  moveLabel = new QLabel( i18n("Move %1").arg("--"), status, "moveLabel" );
-  status->addWidget(moveLabel, 0, true);
+  moveLabel = new QLabel( i18n("Move %1").arg("--"), statusBar(), "moveLabel" );
+  statusBar()->addWidget(moveLabel, 0, true);
 
-#ifdef MYTRACE	
+#ifdef MYTRACE
   /* Create a toolbar menu for debugging output level */
   KToolBar *tb = toolBar("mainToolBar");
   if (tb) {
@@ -603,8 +452,8 @@ void AbTop::setupStatusBar()
     spyPopup->insertItem(spy0, 0);
     spyPopup->insertItem(spy1, 1);
     spyPopup->insertItem(spy2, 2);
-    spyPopup->insertItem(spy3, 3);	
-    connect( spyPopup, SIGNAL(activated(int)), 
+    spyPopup->insertItem(spy3, 3);
+    connect( spyPopup, SIGNAL(activated(int)),
 	     this, SLOT(setSpy(int)) );
     tb->insertButton(spy0, 30, spyPopup,
 			    TRUE, i18n("Spy"));
@@ -618,7 +467,7 @@ void AbTop::setupStatusBar()
 void AbTop::updateSpy(QString s)
 {
   if (showSpy) {
-    if (s.isEmpty()) {      
+    if (s.isEmpty()) {
       updateStatus();
       //      statusBar()->clear();
     }
@@ -662,24 +511,23 @@ void AbTop::updateStatus()
       .arg( i18n("Edit") )
       .arg( i18n("Red") ).arg(boardWidget->getColor1Count())
       .arg( i18n("Yellow") ).arg(boardWidget->getColor2Count());
-    validLabel->setPixmap( (board->validState() == Board::invalid) 
+    validLabel->setPixmap( (board->validState() == Board::invalid)
 			   ? warningPix:okPix );
     showValid = true;
   }
   else if (timerState == noGame) {
-    tmp = i18n("Press %1 for a new game")
-      .arg( actionCollection()->action("game_new")->shortcut().toString());
+    tmp = i18n("Press %1 for a new game").arg( newAction->shortcut().toString());
   }
   else {
     if (timerState == gameOver) {
-      tmp = (board->actColor() == Board::color2) ? 
+      tmp = (board->actColor() == Board::color2) ?
 	      i18n("Red won"):i18n("Yellow won");
       validLabel->setPixmap( warningPix );
       showValid = true;
     }
     else {
       tmp = QString("%1 - %2")
-	.arg( (board->actColor() == Board::color1) ? 
+	.arg( (board->actColor() == Board::color1) ?
 	      i18n("Red"):i18n("Yellow") )
 	.arg( iPlayNow() ?
 	      i18n("I am thinking...") : i18n("It's your turn!") );
@@ -718,26 +566,26 @@ void AbTop::updateActions()
 
   /* Paste */
   pastePossible = !iPlay;
-  ((KAction*)actionCollection()->action("edit_paste"))->setEnabled(!iPlay);
-  
+  pasteAction->setEnabled(!iPlay);
+
   /* Edit */
-  ((KAction*)actionCollection()->action("edit_modify"))->setEnabled(!iPlay);
+  editAction->setEnabled(!iPlay);
 
   /* Stop search */
-  ((KAction*)actionCollection()->action("game_stop"))->setEnabled(iPlay);
+  stopAction->setEnabled(iPlay);
 
   /* Back */
-  bool bBack = (editMode && moveNo>0) || 
+  bool bBack = (editMode && moveNo>0) ||
     (board->movesStored() >=1 && !iPlay);
-  ((KAction*)actionCollection()->action("game_back"))->setEnabled(bBack);
-	
+  backAction->setEnabled(bBack);
+
   /* Forward */
   bool bForward = editMode && moveNo<999;
-  ((KAction*)actionCollection()->action("game_forward"))->setEnabled(bForward);
+  forwardAction->setEnabled(bForward);
 
   /* Hint */
   bool bHint = !editMode && !iPlay && (haveHint().type != Move::none);
-  ((KAction*)actionCollection()->action("game_hint"))->setEnabled(bHint);
+  hintAction->setEnabled(bHint);
 }
 
 /* let the program be responsive even in a long search... */
@@ -799,7 +647,7 @@ void AbTop::userMove()
 {
     /* User has to move */
     static MoveList list;
-    
+
     list.clear();
     board->generateMoves(list);
 
@@ -820,11 +668,11 @@ bool AbTop::iPlayNow()
     return false;
 
   int c = board->actColor();
-    
+
   /* color1 is red */
-  return ((iplay == cBoth) || 
-	  ((c == Board::color1) && (iplay == cRed) ) ||
-	  ((c == Board::color2) && (iplay == cYellow) ));
+  return ((iplay == Both) ||
+	  ((c == Board::color1) && (iplay == Red) ) ||
+	  ((c == Board::color2) && (iplay == Yellow) ));
 }
 
 void AbTop::playGame()
@@ -841,7 +689,7 @@ void AbTop::playGame()
     boardWidget->updatePosition(true);
     timerState = notStarted;
   }
-  if (!board->isValid()) { 
+  if (!board->isValid()) {
     stop = true;
     timerState = gameOver;
   }
@@ -856,7 +704,7 @@ void AbTop::playGame()
     userMove();
     return;
   }
-  boardWidget->setCursor(waitCursor);	
+  boardWidget->setCursor(waitCursor);
   kapp->processEvents();
 
   if (moveNo <4) {
@@ -897,7 +745,7 @@ void AbTop::newGame()
 {
   /* stop a running animation */
   timerState = notStarted;
-  timer->stop();	
+  timer->stop();
 
   /* reset board */
   board->begin(Board::color1);
@@ -909,7 +757,7 @@ void AbTop::newGame()
 
   /* if not in EditMode, start Game immediately */
   if (!editMode) {
-    stop = false;	
+    stop = false;
     playGame();
   }
 }
@@ -938,7 +786,7 @@ void AbTop::pastePosition(const char * text)
   if (!pastePossible) return;
   if ( text ) {
     timerState = notStarted;
-    timer->stop();	
+    timer->stop();
     board->begin(Board::color1);
     stop = false;
 
@@ -949,7 +797,7 @@ void AbTop::pastePosition(const char * text)
     boardWidget->updatePosition(true);
 
     if ( (board->validState()==Board::invalid) && !editMode) {
-      ((KToggleAction*)actionCollection()->action("edit_modify"))->setChecked(true);
+      editAction->setChecked(true);
       return;
     }
 
@@ -987,7 +835,7 @@ void AbTop::gameNetwork(bool on)
   QObject::connect(net, SIGNAL(gotPosition(const char *)),
 		   this, SLOT(pastePosition(const char *)) );
 }
-  
+
 
 void AbTop::editModify(bool on)
 {
@@ -1003,7 +851,7 @@ void AbTop::editModify(bool on)
     actMove.type = Move::none;
     timerState = moveShown;
     playGame();
-  }  
+  }
 }
 
 void AbTop::stopGame()
@@ -1015,19 +863,17 @@ void AbTop::stopGame()
 void AbTop::stopSearch()
 {
   // When computer plays both, switch back to human for next color
-  if (iplay == cBoth) {
-    if (board->actColor() == Board::color1)
-      play_red();
-    else
-      play_yellow();
+  if (iplay == Both) {
+      if (board->actColor() == Board::color1) setIPlay(Red);
+      else setIPlay(Yellow);
   }
   board->stopSearch();
 }
 
-void AbTop::quit()
+bool AbTop::queryClose()
 {
   board->stopSearch();
-  kapp->quit();
+  return true;
 }
 
 void AbTop::continueGame()
@@ -1053,7 +899,7 @@ void AbTop::setMoveNo(int m, bool updateGUI)
     updateStatus();
     updateActions();
   }
-}  
+}
 
 
 /* "Back" action activated
@@ -1064,7 +910,7 @@ void AbTop::setMoveNo(int m, bool updateGUI)
 void AbTop::back()
 {
   if (editMode) {
-    if (moveNo > 0) 
+    if (moveNo > 0)
       setMoveNo(moveNo-1, true);
     return;
   }
@@ -1079,7 +925,7 @@ void AbTop::back()
   if (moveNo>0 && board->takeBack()) moveNo--;
   if (moveNo>0 && board->takeBack()) moveNo--;
   setMoveNo( moveNo, true );
-  
+
   boardWidget->updatePosition(true);
 
   userMove();
@@ -1089,7 +935,7 @@ void AbTop::back()
 void AbTop::forward()
 {
   if (editMode) {
-    if (moveNo < 999) 
+    if (moveNo < 999)
       setMoveNo(moveNo+1, true);
     return;
   }
@@ -1105,7 +951,7 @@ Move AbTop::haveHint()
   }
   else if (moveNo != oldMoveNo) {
     MoveList list;
-    
+
     oldMoveNo = moveNo;
     m = board->nextMove();
     board->generateMoves(list);
@@ -1128,84 +974,19 @@ void AbTop::suggestion()
   timerDone();
 }
 
-void AbTop::setLevel(int d)
+void AbTop::setLevel(int l)
 {
-  depth = d;
-  board->setDepth(depth);
+    levelAction->setCurrentItem(l);
+    depth = l+2;
+    board->setDepth(depth);
   //  kdDebug() << "Level set to " << d << endl;
 }
 
-void AbTop::levelEasy(bool on)      { if (on) setLevel(2); }
-void AbTop::levelNormal(bool on)    { if (on) setLevel(3); }
-void AbTop::levelHard(bool on)      { if (on) setLevel(4); }
-void AbTop::levelChallange(bool on) { if (on) setLevel(5); }
-
-void AbTop::easy()
-{  
-  ((KRadioAction*) actionCollection()->action("level_easy"))
-    ->setChecked( true );
-  levelEasy(true);
-}
-
-void AbTop::normal()
-{  
-  ((KRadioAction*) actionCollection()->action("level_normal"))
-    ->setChecked( true );
-  levelNormal(true);
-}
-
-void AbTop::hard()
-{  
-  ((KRadioAction*) actionCollection()->action("level_hard"))
-    ->setChecked( true );
-  levelHard(true);
-}
-
-void AbTop::challange()
-{  
-  ((KRadioAction*) actionCollection()->action("level_challange"))
-    ->setChecked( true );
-  levelChallange(true);
-}
-
-void AbTop::setIplay(int v)
+void AbTop::setIPlay(int i)
 {
-  iplay = v;
-  continueGame();
-}
-
-void AbTop::iplayRed(bool on)    { if (on) setIplay(cRed); }
-void AbTop::iplayYellow(bool on) { if (on) setIplay(cYellow); }
-void AbTop::iplayBoth(bool on)   { if (on) setIplay(cBoth); }
-void AbTop::iplayNone(bool on)   { if (on) setIplay(cNone); }
-
-void AbTop::play_red()
-{
-  ((KRadioAction*) actionCollection()->action("iplay_red"))
-    ->setChecked( true );
-  iplayRed(true);
-}
-
-void AbTop::play_yellow()
-{
-  ((KRadioAction*) actionCollection()->action("iplay_yellow"))
-    ->setChecked( true );
-  iplayYellow(true);
-}
-
-void AbTop::play_both()
-{
-  ((KRadioAction*) actionCollection()->action("iplay_both"))
-    ->setChecked( true );
-  iplayBoth(true);
-}
-
-void AbTop::play_none()
-{
-  ((KRadioAction*) actionCollection()->action("iplay_none"))
-    ->setChecked( true );
-  iplayNone(true);
-
+    iplayAction->setCurrentItem(i);
+    iplay = (IPlay)i;
+    continueGame();
 }
 
 void AbTop::optionMoveSlow(bool on)
@@ -1236,11 +1017,4 @@ void AbTop::optionShowSpy(bool on)
 }
 
 
-void AbTop::help()
-{
-  kapp->invokeHelp();
-}
-
-
-
 #include "AbTop.moc"
