@@ -953,6 +953,7 @@ void Board::showHist()
 */
 
 
+
 /*
  * We always try the maximize the board value
  */
@@ -961,7 +962,7 @@ int Board::search(int depth, int alpha, int beta)
 	int actValue= -14999+depth, value;
 	Move m;
 	MoveList list;
-	bool stop = false;
+	bool depthPhase, doDepthSearch;
 
 	searchCalled++;
 
@@ -974,6 +975,15 @@ int Board::search(int depth, int alpha, int beta)
 
 #ifdef MYTRACE
 
+        int oldRatedPositions;
+        int oldWonPositions;
+        int oldSearchCalled;
+        int oldMoveCount;
+        int oldNormalCount;
+        int oldPushCount;
+        int oldOutCount;
+        int oldCutoffCount;
+
 	spyDepth = depth;
 
 	moveCount += list.getLength();
@@ -992,30 +1002,38 @@ int Board::search(int depth, int alpha, int beta)
 	/* check for a old best move in main combination */
 	if (inPrincipalVariation) {
 	  m = pv[depth];
-          if ((m.type != Move::none) &&
+
+	  if ((m.type != Move::none) &&
               (!list.isElement(m, 0, true)))
 	    m.type = Move::none;
-	  if (m.type == Move::none)
+
+          if (m.type == Move::none)
 	    inPrincipalVariation = false;
+
 #ifdef MYTRACE
-	  else {
+          else {
 	    if (spyLevel>1) {
 	      indent(spyDepth);
 	      printf("Got from pv !\n" );
 	    }
 	  }
 #endif
-	  /* for moves in PrincipalVariation we do depth search
-	   * even if we don't normally in this depth => Comment out
-	   */
-	  //if (m.type > maxType)
-	  //  m.type = Move::none;
-	}
-	if (m.type == Move::none)
-	  stop = !list.getNext(m, maxType);
+        }
 
-	/* depth first search */
-	while(!stop) {
+        // first, play all moves with depth search
+        depthPhase = true;
+
+        while (1) {
+
+          // get next move
+          if (m.type == Move::none) {
+            if (depthPhase)
+              depthPhase = list.getNext(m, maxType);
+            if (!depthPhase)
+              if (!list.getNext(m, Move::none)) break;
+          }
+          // we could start with a non-depth move from principal variation
+          doDepthSearch = depthPhase && (m.type <= maxType);
 
 #ifdef MYTRACE
 
@@ -1023,27 +1041,30 @@ int Board::search(int depth, int alpha, int beta)
 	  else if (m.isPushMove()) pushCount++;
 	  else normalCount++;
 
-	  int oldRatedPositions = ratedPositions;
-	  int oldWonPositions = wonPositions;
-	  int oldSearchCalled = searchCalled;
-	  int oldMoveCount = moveCount;
-	  int oldNormalCount = normalCount;
-	  int oldPushCount = pushCount;
-	  int oldOutCount = outCount;
-	  int oldCutoffCount = cutoffCount;
+          if (doDepthSearch) {
+            oldRatedPositions = ratedPositions;
+            oldWonPositions = wonPositions;
+            oldSearchCalled = searchCalled;
+            oldMoveCount = moveCount;
+            oldNormalCount = normalCount;
+            oldPushCount = pushCount;
+            oldOutCount = outCount;
+            oldCutoffCount = cutoffCount;
 
-	  if (spyLevel>1) {
-	    indent(spyDepth);
-	    printf("%s [%6d .. %6d] ",
-		   (color==color1)?"O":"X", alpha,beta);
-	    m.print();
-	    printf("\n");
-	  }
-#endif
+            if (spyLevel>1) {
+              indent(spyDepth);
+              printf("%s [%6d .. %6d] ",
+                     (color==color1)?"O":"X", alpha,beta);
+              m.print();
+              printf("\n");
+            }
 
 #ifdef SPION
-	  if (bUpdateSpy) emit update(depth, 0, m, false);
+            if (bUpdateSpy) emit update(depth, 0, m, false);
 #endif
+          }
+#endif
+
 	  playMove(m);
 	  if (!isValid()) {
 	    /* Possibility (1) to win: Ball Count <9 */
@@ -1055,47 +1076,71 @@ int Board::search(int depth, int alpha, int beta)
 	  }
 	  else {
 
-	    /* opponent searches for his maximum; but we want the
-	     * minimum: so change sign (for alpha/beta window too!)
-	     */
-	    value = - search(depth+1,-beta,-alpha);
+            if (doDepthSearch) {
+              /* opponent searches for his maximum; but we want the
+               * minimum: so change sign (for alpha/beta window too!)
+               */
+              value = - search(depth+1,-beta,-alpha);
+            }
+            else {
+              ratedPositions++;
+
+              value = calcEvaluation();
+            }
 	  }
 	  takeBack();
 
-	  /* For GUI response */
-	  if (maxDepth - depth >2)
-	    emit searchBreak();
+          /* For GUI response */
+          if (doDepthSearch && (maxDepth - depth >2))
+            emit searchBreak();
 
 #ifdef MYTRACE
-	  if (spyLevel>1) {
 
-	    indent(spyDepth);
-	    if (oldSearchCalled < searchCalled) {
-	      printf("  %d Calls", searchCalled-oldSearchCalled);
-	      if (cutoffCount>oldCutoffCount)
-		printf(" (%d Cutoffs)", cutoffCount-oldCutoffCount);
-	      printf(", GenMoves %d (%d/%d/%d played)",
-		     moveCount - oldMoveCount,
-		     normalCount - oldNormalCount,
-		     pushCount-oldPushCount,
-		     outCount-oldOutCount);
-	      printf(", Rate# %d",
-		     ratedPositions+wonPositions
-		     - oldRatedPositions - oldWonPositions);
-	      if (wonPositions > oldWonPositions)
-		printf(" (%d Won)", wonPositions- oldWonPositions);
-	      printf("\n");
-	      indent(spyDepth);
-	    }
+          if (doDepthSearch) {
+            spyDepth = depth;
 
-	    printf("  => Rated %d%s\n",
-		   value,
-		   (value>14900)  ? ", WON !":
-		   (value>=beta)  ? ", CUTOFF !":
-		   (value>actValue)  ? ", Best !": "");
-	  }
+            if (spyLevel>1) {
 
-	  if (value>=beta) cutoffCount++;
+              indent(spyDepth);
+              if (oldSearchCalled < searchCalled) {
+                printf("  %d Calls", searchCalled-oldSearchCalled);
+                if (cutoffCount>oldCutoffCount)
+                  printf(" (%d Cutoffs)", cutoffCount-oldCutoffCount);
+                printf(", GenMoves %d (%d/%d/%d played)",
+                       moveCount - oldMoveCount,
+                       normalCount - oldNormalCount,
+                       pushCount-oldPushCount,
+                       outCount-oldOutCount);
+                printf(", Rate# %d",
+                       ratedPositions+wonPositions
+                       - oldRatedPositions - oldWonPositions);
+                if (wonPositions > oldWonPositions)
+                  printf(" (%d Won)", wonPositions- oldWonPositions);
+                printf("\n");
+                indent(spyDepth);
+              }
+
+              printf("  => Rated %d%s\n",
+                     value,
+                     (value>14900)  ? ", WON !":
+                     (value>=beta)  ? ", CUTOFF !":
+                     (value>actValue)  ? ", Best !": "");
+            }
+          }
+          else {
+            if (spyLevel>2) {
+              indent(spyDepth);
+              printf("%s (%6d .. %6d) %-25s => Rating %6d%s\n",
+                     (color==color1)?"O":"X", alpha,beta,
+                     m.name().latin1(),
+                     value,
+                     (value>14900)  ? ", WON !":
+                     (value>=beta)  ? ", CUTOFF !":
+                     (value>actValue)  ? ", Best !": "");
+            }
+          }
+
+          if (value>=beta) cutoffCount++;
 #endif
 
 #ifdef SPION
@@ -1109,20 +1154,25 @@ int Board::search(int depth, int alpha, int beta)
 	    actValue = value;
 	    pv.update(depth, m);
 
-	    if (bUpdateSpy && depth == 0) {
-	      emit updateBestMove(m, actValue);
+            // Only update best move if not stopping search
+            if (!breakOut && (depth == 0)) {
+              _bestMove = m;
+
+              if (bUpdateSpy) {
+                emit updateBestMove(m, actValue);
 #ifdef MYTRACE
-	      if (spyLevel>0) {
-		int i;
-		printf(">      New pv (Rating %d):", actValue);
-		for(i=0;i<=maxDepth;i++) {
-		  printf("\n>          D %d: %s",
-			 i, (const char*)(pv[i].name()) );
-		}
-		printf("\n>\n");
-	      }
+                if (spyLevel>0) {
+                  int i;
+                  printf(">      New pv (Rating %d):", actValue);
+                  for(i=0;i<=maxDepth;i++) {
+                    printf("\n>          D %d: %s",
+                           i, pv[i].name().latin1() );
+                  }
+                  printf("\n>\n");
+                }
 #endif
-	    }
+              }
+            }
 
 	    if (actValue>14900 || actValue >= beta)
 	      return actValue;
@@ -1131,78 +1181,10 @@ int Board::search(int depth, int alpha, int beta)
 	    if (actValue > alpha) alpha = actValue;
 	  }
 
-	  stop = (!list.getNext(m, maxType)) || breakOut;
+          if (breakOut) depthPhase=false;
+          m.type = Move::none;
 	}
 
-	/* other moves: calculate rating */
-	while(list.getNext(m, Move::none)) {
-
-	  if (m.isOutMove()) outCount++;
-	  else if (m.isPushMove()) pushCount++;
-	  else normalCount++;
-
-	  playMove(m);
-	  if (!isValid()) {
-	    value = 14999 - depth;
-	    //  value = ((depth < maxDepth) ? 15999:14999) - depth;
-#ifdef MYTRACE
-	    wonPositions++;
-#endif
-	  }
-	  else {
-	    ratedPositions++;
-
-	    value = calcEvaluation();
-	  }
-	  takeBack();
-
-#ifdef SPION
-	  if (bUpdateSpy) {
-	    if (value > actValue)
-	      emit updateBest(depth, value, m, value >= beta);
-	    emit update(depth, value, m, true);
-	  }
-#endif
-
-#ifdef MYTRACE
-	  if (spyLevel>2) {
-	    indent(spyDepth);
-	    printf("%s (%6d .. %6d) %-25s => Rating %6d%s\n",
-		   (color==color1)?"O":"X", alpha,beta,
-		   (const char*)m.name(),
-		   value,
-		   (value>14900)  ? ", WON !":
-		   (value>=beta)  ? ", CUTOFF !":
-		   (value>actValue)  ? ", Best !": "");
-	  }
-
-	  if (value>=beta) cutoffCount++;
-#endif
-	  if (value > actValue) {
-	    actValue = value;
-	    pv.update(depth, m);
-
-	    if (bUpdateSpy && depth == 0) {
-	      emit updateBestMove(m, actValue);
-#ifdef MYTRACE
-	      if (spyLevel>0) {
-		int i;
-		printf(">      New pv (Rating %d):", actValue);
-		for(i=0;i<=maxDepth;i++) {
-		  printf("\n>          D %d: %s",
-			 i, (const char*)(pv[i].name()) );
-		}
-		printf("\n>\n");
-	      }
-#endif
-	    }
-
-	    if (actValue>14900 || actValue >= beta)
-	      return actValue;
-
-	    if (actValue > alpha) alpha = actValue;
-	  }
-	}
 	return actValue;
 }
 
@@ -1218,6 +1200,7 @@ Move& Board::bestMove()
 	}
 
 	pv.clear(realMaxDepth);
+        _bestMove.type = Move::none;
 
 	maxDepth=1;
 	show = false;
@@ -1274,19 +1257,19 @@ Move& Board::bestMove()
 
 		    }
 
-		  /* Don't break out if we haven't found a move */
-		  if (pv[0].type == Move::none)
-		    breakOut=false;
-
-		  if (actValue > 14900 || actValue < -14900)
+                  if (actValue > 14900 || actValue < -14900)
 		    breakOut=true;
 
+		  /* Don't break out if we haven't found a move */
+		  if (_bestMove.type == Move::none)
+		    breakOut=false;
+
                   // widen alpha-beta window if needed
-                  if (actValue <= nalpha) {
-                    alpha = -15000;
+		  if (actValue <= nalpha) {
+		    alpha = -15000;
                     if (beta<15000) beta=actValue+1;
                   }
-                  if (actValue >= nbeta) {
+		  if (actValue >= nbeta) {
                     if (alpha > -15000) alpha = actValue-1;
                     beta=15000;
                   }
@@ -1323,7 +1306,7 @@ Move& Board::bestMove()
 
 	spyDepth = 0;
 
-	return(pv[0]);
+	return _bestMove;
 }
 
 Move Board::randomMove()
