@@ -13,7 +13,7 @@
 #include "AbTop.h"
 
 
-static const char *description = 
+static const char *description =
 	I18N_NOOP("Board Game inspired by Abalone");
 
 static KCmdLineOptions options[] =
@@ -22,13 +22,24 @@ static KCmdLineOptions options[] =
   { "host <host>", I18N_NOOP("Use 'host' for network game"), 0 },
   { "p", 0, 0},
   { "port <port>", I18N_NOOP("Use 'port' for network game"), 0 },
-  { 0, 0, 0 }
+  KCmdLineLastOption
 };
 
+AbTop *create(KCmdLineArgs *args)
+{
+    AbTop* top = new AbTop;
+	if (args->isSet("port"))
+	    top->netPort( args->getOption("port").toInt() );
+	if (args->isSet("host"))
+	    top->netHost( args->getOption("host").data() );
+    top->readConfig();
+    return top;
+}
+
 int main(int argc, char *argv[])
 {
-	KAboutData aboutData( "kenolaba", I18N_NOOP("Kenolaba"), 
-		KENOLABA_VERSION, description, KAboutData::License_GPL, 
+	KAboutData aboutData( "kenolaba", I18N_NOOP("Kenolaba"),
+		KENOLABA_VERSION, description, KAboutData::License_GPL,
 		"(c) 1997-2000, Josef Weidendorfer");
 	aboutData.addAuthor("Josef Weidendorfer",0, "Josef.Weidendorfer@gmx.de");
 	aboutData.addAuthor("Robert Williams");
@@ -37,29 +48,24 @@ int main(int argc, char *argv[])
 
 	KApplication app;
 	KGlobal::locale()->insertCatalogue("libkdegames");
-	AbTop* top = new AbTop;
-	int res;
 
 	/* command line handling */
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
-	if (args->isSet("port"))
-	    top->netPort( args->getOption("port").toInt() );
-	if (args->isSet("host"))
-	    top->netHost( args->getOption("host").data() );
-	args->clear();
-
 	/* session management */
-	if (app.isRestored())
-	  top->restore(1);
-	else
-	  top->readConfig();
-
-	app.setMainWidget(top);
-	top->show();	
-	res = app.exec();
-
-	delete top;
-	return res;
+	if ( app.isRestored() ) {
+        uint n = 1;
+        while ( KMainWindow::canBeRestored(n) ) {
+            AbTop *top = create(args);
+            top->restore(n);
+            n++;
+        }
+    } else {
+        AbTop *top = create(args);
+        app.setMainWidget(top);
+        top->show();
+    }
+    args->clear();
+	return app.exec();
 }
 
