@@ -16,21 +16,20 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 **************************************************************************** */
 #include "kcubeboxwidget.h"
-#include "kcubewidget.h"
-#include "cubebox.h"
 
-#include <qpalette.h>
+#include <kapplication.h>
+#include <kconfig.h>
 #include <qlayout.h>
 #include <qtimer.h>
-#include <qstrlist.h>
 #include <assert.h>
-#include <kconfigbase.h>
 #include <kcursor.h>
 
+#include "prefs.h"
+
 KCubeBoxWidget::KCubeBoxWidget(const int d,QWidget *parent,const char *name)
         : QWidget(parent,name),
           CubeBoxBase<KCubeWidget>(d)
@@ -79,14 +78,24 @@ KCubeBoxWidget::KCubeBoxWidget(const KCubeBoxWidget& box,QWidget *parent,const c
 
 KCubeBoxWidget::~KCubeBoxWidget()
 {
+   if(isActive())
+    stopActivities();
    if(cubes)
       deleteCubes();
    if(undoBox)
       delete undoBox;
 }
 
+void KCubeBoxWidget::loadSettings(){
+  setColor(KCubeBoxWidget::One, Prefs::color1());
+  setColor(KCubeBoxWidget::Two, Prefs::color2());
 
+  setDim(Prefs::cubeDim());
+  brain.setSkill( Prefs::skill() );
 
+  setComputerplayer(KCubeBoxWidget::One, Prefs::computerPlayer1());
+  setComputerplayer(KCubeBoxWidget::Two, Prefs::computerPlayer2());
+}
 
 KCubeBoxWidget& KCubeBoxWidget::operator=(const KCubeBoxWidget& box)
 {
@@ -106,12 +115,9 @@ KCubeBoxWidget& KCubeBoxWidget::operator=(const KCubeBoxWidget& box)
          
       currentPlayer=box.currentPlayer;
    }
-   
-   
    return *this;
 }
 
-
 KCubeBoxWidget& KCubeBoxWidget::operator=(CubeBox& box)
 {
    if(dim()!=box.dim())
@@ -129,9 +135,6 @@ KCubeBoxWidget& KCubeBoxWidget::operator=(CubeBox& box)
       
    return *this;
 }
- 
-
-
 
 void KCubeBoxWidget::reset()
 {
@@ -152,7 +155,6 @@ void KCubeBoxWidget::reset()
    checkComputerplayer(One);
 }
 
-
 void KCubeBoxWidget::undo()
 {
    if(isActive())
@@ -215,12 +217,6 @@ void KCubeBoxWidget::setDim(int d)
    }
 }
 
-void KCubeBoxWidget::setSkill(Brain::Skill skill)
-{
-   brain.setSkill(skill);
-}
-  
-
 void KCubeBoxWidget::setComputerplayer(Player player,bool flag)
 {
    if(player==One)
@@ -247,8 +243,7 @@ void KCubeBoxWidget::stopActivities()
 
 }
 
-
-void KCubeBoxWidget::saveGame(KConfigBase* config)
+void KCubeBoxWidget::saveProperties(KConfigBase* config)
 {
    if(isMoving())
    {
@@ -278,13 +273,15 @@ void KCubeBoxWidget::saveGame(KConfigBase* config)
 
 	list.clear();
       }
-
+  config->writeEntry("CubeDim",dim());
 }
-void KCubeBoxWidget::restoreGame(KConfigBase* config)
+
+void KCubeBoxWidget::readProperties(KConfigBase* config)
 {
   QStrList list;
   list.setAutoDelete(true);
   QString owner, value, key;
+  setDim(config->readNumEntry("CubeDim",5));
   int cubeDim=dim();
 
   for(int row=0; row < cubeDim ; row++)
@@ -308,7 +305,6 @@ void KCubeBoxWidget::restoreGame(KConfigBase* config)
    checkComputerplayer((Player)onTurn);
 }
 
-
 /* ***************************************************************** **
 **                               slots                               **
 ** ***************************************************************** */ 
@@ -323,7 +319,6 @@ void KCubeBoxWidget::setNormalCursor()
 {
    setCursor(KCursor::handCursor());
 }
-  
 
 void KCubeBoxWidget::stopHint()
 {
@@ -337,7 +332,6 @@ void KCubeBoxWidget::stopHint()
 
 }
 
-
 bool KCubeBoxWidget::checkClick(int row,int column)
 {
    if(isActive())
@@ -353,8 +347,6 @@ bool KCubeBoxWidget::checkClick(int row,int column)
       return false;
 }
 
-
-
 void KCubeBoxWidget::checkComputerplayer(Player player)
 {
    // checking if a process is running or the Widget isn't shown yet
@@ -411,10 +403,9 @@ bool KCubeBoxWidget::isComputer(Player player) const
 }
   
 
-Brain::Skill KCubeBoxWidget::skill() const
+int KCubeBoxWidget::skill() const
 {
-   Brain::Skill skill=brain.skill();
-   return skill;
+   return brain.skill();
 }
    
 QPalette KCubeBoxWidget::color(Player forWhom)
@@ -437,7 +428,7 @@ void KCubeBoxWidget::init()
    computerPlOne=false;
    computerPlTwo=false;
    KCubeWidget::enableClicks(true);
-   
+   loadSettings();
    
    connect(moveTimer,SIGNAL(timeout()),SLOT(nextLoopStep()));
    connect(this,SIGNAL(startedThinking()),SLOT(setWaitCursor()));
@@ -554,7 +545,6 @@ void KCubeBoxWidget::startLoop()
    moveTimer->start(moveDelay);
 }
 
-
 void KCubeBoxWidget::stopLoop()
 {
    moveTimer->stop();
@@ -562,7 +552,6 @@ void KCubeBoxWidget::stopLoop()
    KCubeWidget::enableClicks(true);
 }
 
-
 void KCubeBoxWidget::nextLoopStep()
 {
    // search cube with to many points
@@ -609,7 +598,6 @@ void KCubeBoxWidget::nextLoopStep()
    }
 }
 
-
 bool KCubeBoxWidget::hasPlayerWon(Player player)
 {
    for(int i=0;i<dim();i++)
@@ -710,3 +698,4 @@ void KCubeBoxWidget::increaseNeighbours(KCubeBoxWidget::Player forWhom,int row,i
 }
 
 #include "kcubeboxwidget.moc"
+
