@@ -16,43 +16,39 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 **************************************************************************** */
 #include "version.h"
 #include "kjumpingcube.h"
 #include <kapplication.h>
-#include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
 
-static const char *description = 
+static const char *description =
 	I18N_NOOP("Tactical one- or two-player game");
 
 
 int main(int argc, char *argv[])
 {
-        KAboutData aboutData( "kjumpingcube", I18N_NOOP("KJumpingCube"),
-                KJC_VERSION, description, KAboutData::License_GPL,
-                "(c) 1998-2000, Matthias Kiefer");
-        aboutData.addAuthor("Matthias Kiefer",0, "matthias.kiefer@gmx.de");
-        KCmdLineArgs::init( argc, argv, &aboutData );
+    KAboutData aboutData( "kjumpingcube", I18N_NOOP("KJumpingCube"),
+                          KJC_VERSION, description, KAboutData::License_GPL,
+                          "(c) 1998-2000, Matthias Kiefer");
+    aboutData.addAuthor("Matthias Kiefer",0, "matthias.kiefer@gmx.de");
+    aboutData.addAuthor("Benjamin Meyer",I18N_NOOP("Various improvements"), "ben+kjumpingcube@meyerhome.net");
+    KCmdLineArgs::init( argc, argv, &aboutData );
 
-        KApplication app;
+    KApplication app;
+    KGlobal::locale()->insertCatalogue("libkdegames");
 
-        KGlobal::locale()->insertCatalogue("libkdegames");
-
-        // All session management is handled in the RESTORE macro
+    // All session management is handled in the RESTORE macro
 	if (app.isRestored())
-	{
-           RESTORE(KJumpingCube)
+        RESTORE(KJumpingCube)
+    else {
+		KJumpingCube *kjumpingcube = new KJumpingCube;
+		app.setMainWidget(kjumpingcube);
+		kjumpingcube->show();
 	}
-	else
-	{
-		KJumpingCube *widget = new KJumpingCube;
-		widget->show();
-	}
-
-	return app.exec();
+   return app.exec();
 }
