@@ -18,7 +18,7 @@ class Field : public QWidget, public BaseField, public BaseInterface
     QSizePolicy sizePolicy() const;
 
  private slots:
-    void scoreUpdatedSlot(int score) { scoreUpdated(score); }
+    void scoreUpdatedSlot() { scoreUpdated(); }
     void start();
     void gameOver();
     void settingsChanged() { BaseField::settingsChanged(); }
@@ -27,9 +27,9 @@ class Field : public QWidget, public BaseField, public BaseInterface
     KGameLCDClock *elapsedTime;
 
     void pause();
-    KExtHighscores::Score currentScore() const;
-    void _start()          { start(); }
-    void _pause()          { pause(); }
+    KExtHighscore::Score currentScore() const;
+    void _start() { start(); }
+    void _pause() { pause(); }
     bool _isPaused() const;
 };
 
