@@ -17,18 +17,15 @@
 #ifndef KLINES_H
 #define KLINES_H
 
-#include <qwidget.h>
-#include <qmenubar.h> 
-#include <qlabel.h>
-#include <qpushbutton.h>
-
 #include <kmainwindow.h>
 
 #include "linesboard.h"
 #include "mwidget.h"
 #include "prompt.h"
 
-class KRadioAction;
+class KSelectAction;
+class KAction;
+class KToggleAction;
 
 class KLines : public KMainWindow
 {
@@ -41,7 +38,6 @@ protected:
   void keyPressEvent(QKeyEvent *e);
   void initKAction();
   void setLevel(int level);
-  int currentLevel(QString *levelStr=0);
 
   void focusOutEvent(QFocusEvent *);
   void focusInEvent(QFocusEvent *);
@@ -55,8 +51,10 @@ public slots:
   void userTurn();
   void addScore(int ballsErased);
   void switchPrompt();
+  void switchNumbered();
   void undo();
   void slotDemo();
+  void slotConfigureKeys();
 
 private slots:
   void viewHighScore();
@@ -65,12 +63,10 @@ private:
   LinesBoard* lsb;
   MainWidget *mwidget;
   LinesPrompt *lPrompt;
-  KAction *act_demo;
-  KRadioAction *act_level1;
-  KRadioAction *act_level2;
-  KRadioAction *act_level3;
-  KRadioAction *act_level4;
-  KRadioAction *act_level5;
+  KAction *act_demo, *undoAction, *endTurnAction;
+  KSelectAction *levelAction;
+  KToggleAction *showNextAction;
+  KToggleAction *showNumberedAction;
   QString levelStr;
 
   bool bNewTurn;
@@ -84,7 +80,7 @@ private:
   bool bUndo;
   bool bFirst;
   bool bDemo;
-  
+
   int demoStep;
   QTimer demoTimer;
 
@@ -93,6 +89,7 @@ private:
   void placeBalls();
   void updateStat();
   void switchUndo( bool bu );
+  void stopDemo();
 };
 
 #endif
