@@ -1,11 +1,9 @@
 
-#include "KmTypes.h"
 #include "Background.h"
-#include "Preferences.h"
 #include <qimage.h>
-#include <qpixmap.h>
-Background::Background()
-{
+
+Background::Background(): tile(true) {
+
   sourceImage = 0;
   backgroundImage = 0;
   backgroundPixmap = 0;
@@ -13,16 +11,13 @@ Background::Background()
 }
 
 Background::~Background() {
-/* already handled by Qt
   delete sourceImage;
   delete backgroundImage;
   delete backgroundPixmap;
   delete backgroundShadowPixmap;
-*/
 }
 
 bool Background::load(const QString &file, short width, short height) {
- 
   w=width;
   h=height; 
 
@@ -72,7 +67,7 @@ void Background::sourceToBackground(void) {
   // to avoid the old color limitation.
   backgroundImage->create(w, h, 32);
 
-  // Now we decide if we should scale the incomming image
+  // Now we decide if we should scale the incoming image
   // or if we tile. First we check for an exact match which
   // should be true for all images created specifically for us.
   if ((sourceImage->width() == w) && (sourceImage->height() == h)) {
@@ -80,7 +75,7 @@ void Background::sourceToBackground(void) {
     return;
   }
     
-  if (!preferences.scaleMode()) {
+  if (tile) {
     // copy new to background wrapping on w and height
     for (int y=0; y<backgroundImage->height(); y++) {
       QRgb *dest = (QRgb *) backgroundImage->scanLine(y);
