@@ -1,19 +1,16 @@
 
 #include <stdlib.h>
 #include <kapplication.h>
-#include <qpixmap.h>
 #include <qlayout.h>
 #include <qpainter.h>
+
 #include "Editor.h"
-#include "Editor.moc"
-#include "Preferences.h"
+#include "prefs.h"
+
 #include <kmessagebox.h>
-
-#include<kglobal.h>
-#include<kconfig.h>     // Needed to use KConfig
-#include<klocale.h>     // Needed to use KLocale
-#include<kiconloader.h> //
-
+#include <klocale.h>     // Needed to use KLocale
+#include <kiconloader.h> //
+#include <kstandarddirs.h>
 #include <ktoolbarradiogroup.h>
 
 #define ID_TOOL_NEW  100
@@ -51,6 +48,10 @@ Editor::Editor
     QDialog( parent, name, TRUE, 0 ), tiles(false)
 {
 
+    clean= true;
+    numTiles=0;
+    mode = insert;
+
     int sWidth = (BoardLayout::width+2)*(tiles.qWidth());
     int sHeight =( BoardLayout::height+2)*tiles.qHeight();
 
@@ -62,10 +63,6 @@ Editor::Editor
     drawFrame->setMaximumSize( 32767, 32767 );
     drawFrame->setFocusPolicy( QWidget::NoFocus );
     drawFrame->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300
-    drawFrame->setFontPropagation( QWidget::NoChildren );
-    drawFrame->setPalettePropagation( QWidget::NoChildren );
-#endif
     drawFrame->setFrameStyle( 49 );
     drawFrame->setMouseTracking(true);
 
@@ -81,9 +78,9 @@ Editor::Editor
     setMinimumSize( sWidth+60, sHeight+60);
     setMaximumSize( sWidth+60, sHeight+60);
 
-
-   // load in the tile set
-   tiles.loadTileset(preferences.tileset());
+   QString tile = "pics/" + Prefs::tileSet();
+   tile = locate("appdata", tile);
+   tiles.loadTileset(tile);
 
    // tell the user what we do
    setCaption(kapp->makeStdCaption(i18n("Edit Board Layout")));
@@ -94,9 +91,6 @@ Editor::Editor
    connect( drawFrame, SIGNAL(mouseMoved(QMouseEvent *) ),
 		SLOT(drawFrameMouseMovedEvent(QMouseEvent *)));
 
-   clean= true;
-   mode = insert;
-   numTiles=0;
    statusChanged();
 
    update();
@@ -278,8 +272,8 @@ void Editor::loadBoard(void) {
 
     KURL url = KFileDialog::getOpenURL(
 				NULL,
-				i18n("*.layout|Board layout (*.layout)\n"
-				"*|All files"),
+				i18n("*.layout|Board Layout (*.layout)\n"
+				"*|All Files"),
 				this,
 				i18n("Open Board Layout" ));
 
@@ -315,8 +309,8 @@ bool Editor::saveBoard(void) {
     // get a save file name
     KURL url = KFileDialog::getSaveURL(
 				NULL,
-				i18n("*.layout|Board layout (*.layout)\n"
-				"*|All files"),
+				i18n("*.layout|Board Layout (*.layout)\n"
+				"*|All Files"),
 				this,
 				i18n("Save Board Layout" ));
    if( !url.isLocalFile() )
@@ -333,7 +327,7 @@ bool Editor::saveBoard(void) {
 	// if it already exists, querie the user for replacement
 	int res=KMessageBox::warningYesNo(this,
 			i18n("A file with that name "
-					   "already exists, do you "
+					   "already exists. Do you "
 					   "wish to overwrite it?"),
 					i18n("Save Board Layout" ));
 	if (res != KMessageBox::Yes)
@@ -360,7 +354,7 @@ bool Editor::testSave(void)
 
     int res;
     res=KMessageBox::warningYesNoCancel(this,
-	i18n("The board has been modified, would you"
+	i18n("The board has been modified. Would you "
 		"like to save the changes?"));
 
     if (res == KMessageBox::Yes) {
@@ -415,25 +409,22 @@ void Editor::drawBackground(QPixmap *pixmap) {
 	int nextX=sx+(x*tiles.qWidth());
 	p.drawLine(nextX, sy, nextX, sy+BoardLayout::height*tiles.qHeight());
     }
-
-
 }
 
-
-
 void Editor::drawTiles(QPixmap *dest) {
 
     QPainter p(dest);
 
+    QString tile1 = "pics/" + Prefs::tileSet();
+    tile1 = locate("appdata", tile1);
+    tiles.loadTileset(tile1);
 
-    // blast in a white background
-   tiles.loadTileset(preferences.tileset());
 
     int xOffset = tiles.width()/2;
     int yOffset = tiles.height()/2;
     short tile = 0;
 
-    // we iterate over the depth stacking order. zach sucessive level is
+    // we iterate over the depth stacking order. Each successive level is
     // drawn one indent up and to the right. The indent is the width
     // of the 3d relief on the tile left (tile shadow width)
     for (int z=0; z<BoardLayout::depth; z++) {
@@ -630,7 +621,7 @@ void Editor::drawFrameMouseMovedEvent( QMouseEvent* e ){
     statusChanged();
 
     switch(mode) {
-	case insert:
+	case insert: {
 		POSITION next;
 		next = currPos;
 		if (next.e == 100)
@@ -640,7 +631,7 @@ void Editor::drawFrameMouseMovedEvent( QMouseEvent* e ){
 
 		drawCursor(next, canInsert(next));
 	break;
-
+	}
 	case remove:
     		drawCursor(currPos, 1);
 	break;
@@ -680,3 +671,5 @@ bool Editor::canInsert(POSITION &p) {
 }
 
 
+
+#include "Editor.moc"
