@@ -1,23 +1,19 @@
 #include <sys/param.h>
 #include <kapplication.h>
-#include <qdir.h>
-#include <qpixmap.h>
 #include <qimage.h>
 #include <qregexp.h>
 #include <kfiledialog.h>
 #include <qpainter.h>
-#include <qfile.h>
-#include "Preview.h"
-#include "Preview.moc"
-#include "Preferences.h"
-#include "kmessagebox.h"
-#include "kstandarddirs.h"
-#include "klocale.h"
-#include <qfileinfo.h>
-
-#include <qpushbutton.h>
+#include <kmessagebox.h>
+#include <kstandarddirs.h>
+#include <klocale.h>
 #include <qcombobox.h>
 #include <qbuttongroup.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
+
+#include "prefs.h"
+#include "Preview.h"
 
 static const char * themeMagicV1_0= "kmahjongg-theme-v1.0";
 
@@ -38,10 +34,6 @@ Preview::Preview
 	bottomGroup->setMaximumSize( 32767, 32767 );
 	bottomGroup->setFocusPolicy( QWidget::NoFocus );
 	bottomGroup->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300
-	bottomGroup->setFontPropagation( QWidget::NoChildren );
-	bottomGroup->setPalettePropagation( QWidget::NoChildren );
-#endif
 	bottomGroup->setFrameStyle( 49 );
 	bottomGroup->setTitle( "" );
 	bottomGroup->setAlignment( 1 );
@@ -52,10 +44,6 @@ Preview::Preview
 	topGroup->setMaximumSize( 32767, 32767 );
 	topGroup->setFocusPolicy( QWidget::NoFocus );
 	topGroup->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300
-	topGroup->setFontPropagation( QWidget::NoChildren );
-	topGroup->setPalettePropagation( QWidget::NoChildren );
-#endif
 	topGroup->setFrameStyle( 49 );
 	topGroup->setTitle( "" );
 	topGroup->setAlignment( 1 );
@@ -66,10 +54,6 @@ Preview::Preview
 	combo->setMaximumSize( 32767, 32767 );
 	combo->setFocusPolicy( QWidget::StrongFocus );
 	combo->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300  
-	combo->setFontPropagation( QWidget::AllChildren );
-	combo->setPalettePropagation( QWidget::AllChildren );
-#endif
 	combo->setSizeLimit( 10 );
 	connect( combo, SIGNAL(activated(int)), SLOT(selectionChanged(int)) );
 
@@ -80,10 +64,6 @@ Preview::Preview
 	connect( loadButton, SIGNAL(clicked()), SLOT(load()) );
 	loadButton->setFocusPolicy( QWidget::TabFocus );
 	loadButton->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300  
-	loadButton->setFontPropagation( QWidget::NoChildren );
-	loadButton->setPalettePropagation( QWidget::NoChildren );
-#endif
 	loadButton->setText(i18n("Load"));
 	loadButton->setAutoRepeat( FALSE );
 
@@ -91,49 +71,34 @@ Preview::Preview
 	int bw = ((310+dx) - ((90+(dx/3))*3))/4 ;
 	int pos = bw +10;
 
-	okButton = new QPushButton( this, "okButton" );
+	okButton = new KPushButton( KStdGuiItem::ok(), this, "okButton" );
 	okButton->setGeometry( pos, 240+dy, 90+(dx/3), 26 ); // was 20
 	okButton->setMinimumSize( 0, 0 );
 	okButton->setMaximumSize( 32767, 32767 );
 	connect( okButton, SIGNAL(clicked()), SLOT(ok()) );
 	okButton->setFocusPolicy( QWidget::TabFocus );
 	okButton->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300  
-	okButton->setFontPropagation( QWidget::NoChildren );
-	okButton->setPalettePropagation( QWidget::NoChildren );
-#endif
-	okButton->setText( i18n("&OK") );
 	okButton->setAutoRepeat( FALSE );
         okButton->setDefault(true);
 
 	pos += (90+(dx/3))+bw;
-	applyButton = new QPushButton( this, "applyButton" );
+	applyButton = new KPushButton( KStdGuiItem::apply(), this, "applyButton" );
 	applyButton->setGeometry( pos, 240+dy, 90+(dx/3), 26 );
 	applyButton->setMinimumSize( 0, 0 );
 	applyButton->setMaximumSize( 32767, 32767 );
 	connect( applyButton, SIGNAL(clicked()), SLOT(apply()) );
 	applyButton->setFocusPolicy( QWidget::TabFocus );
 	applyButton->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300  
-	applyButton->setFontPropagation( QWidget::NoChildren );
-	applyButton->setPalettePropagation( QWidget::NoChildren );
-#endif
-	applyButton->setText( i18n("Apply") );
 	applyButton->setAutoRepeat( FALSE );
 
 	pos += (90+(dx/3))+bw;
-	cancelButton = new QPushButton( this, "cancelButton" );
+	cancelButton = new KPushButton( KStdGuiItem::cancel(), this, "cancelButton" );
 	cancelButton->setGeometry( pos, 240+dy, 90+(dx/3), 26 );
 	cancelButton->setMinimumSize( 0, 0 );
 	cancelButton->setMaximumSize( 32767, 32767 );
 	connect( cancelButton, SIGNAL(clicked()), SLOT(reject()) );
 	cancelButton->setFocusPolicy( QWidget::TabFocus );
 	cancelButton->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300  
-	cancelButton->setFontPropagation( QWidget::NoChildren );
-	cancelButton->setPalettePropagation( QWidget::NoChildren );
-#endif
-	cancelButton->setText( i18n("&Cancel") );
 	cancelButton->setAutoRepeat( FALSE );
 
 	drawFrame = new FrameImage( this, "drawFrame" );
@@ -142,10 +107,6 @@ Preview::Preview
 	drawFrame->setMaximumSize( 32767, 32767 );
 	drawFrame->setFocusPolicy( QWidget::NoFocus );
 	drawFrame->setBackgroundMode( QWidget::PaletteBackground );
-#if QT_VERSION < 300  
-	drawFrame->setFontPropagation( QWidget::NoChildren );
-	drawFrame->setPalettePropagation( QWidget::NoChildren );
-#endif
 	drawFrame->setFrameStyle( 49 );
 
 
@@ -193,24 +154,31 @@ void Preview::markUnchanged(void)
 
 void Preview::initialise(const PreviewType type, const char *extension)
 {
+    QString tile = "pics/" + Prefs::tileSet();
+    QString back = "pics/" + Prefs::background();
+    QString layout = "pics/" + Prefs::layout();
+    tile = locate("appdata", tile);
+    back = locate("appdata", back);
+    layout = locate("appdata", layout);
+
 	// set up the concept of the current file. Initialised to the preferences
 	// value initially. Set the caption to indicate what we are doing
 	switch (type) {
 	    case background:
 		      setCaption(kapp->makeStdCaption(i18n("Change Background Image")));
-		      selectedFile = preferences.background();
+		      selectedFile = back;
 		      fileSelector = i18n("*.bgnd|Background Image\n"
 				     "*.bmp|Windows bitmap file (*.bmp)\n");
 		  break;
             case tileset:
 		      setCaption(kapp->makeStdCaption(i18n("Change Tile Set")));
 		      fileSelector = i18n("*.tileset|Tile set file\n");
-		      selectedFile = preferences.tileset();
+		      selectedFile = tile;
 		  break;
             case board:
 		      fileSelector = i18n("*.layout|Board layout file\n");
 		      setCaption(kapp->makeStdCaption(i18n("Change Board Layout")));
-		      selectedFile = preferences.layout();
+		      selectedFile = layout;
 	          break;
 
 	    case theme:
@@ -225,7 +193,7 @@ void Preview::initialise(const PreviewType type, const char *extension)
             default:
                   break;
 	}
-	fileSelector += i18n("*|All files\n");
+	fileSelector += i18n("*|All Files\n");
 	applyButton->setEnabled(type != board);
 
 
@@ -258,7 +226,7 @@ void Preview::initialise(const PreviewType type, const char *extension)
 	// duplicates on insertion
 
 
-	if (current->fileName() != "")
+	if (!current->fileName().isEmpty())
 		list->insert(0, current);
 
 	QFileInfo *info=list->first();
@@ -326,11 +294,13 @@ void Preview::load(void) {
 // chaps.
 
 void Preview::drawPreview(void) {
+    QString tile = "pics/" + Prefs::tileSet();
+    QString back = "pics/" + Prefs::background();
+    QString layout = "pics/" + Prefs::layout();
+    tile = locate("appdata", tile);
+    back = locate("appdata", back);
+    layout = locate("appdata", layout);
 
-
-    QString back = preferences.background();
-    QString tile = preferences.tileset();
-    QString layout = preferences.layout();
     switch (previewType) {
 	case background:
 		back = selectedFile;
@@ -347,7 +317,7 @@ void Preview::drawPreview(void) {
 
 	     // a theme is quite a bit of work. We load the
 	     // specified bits in (layout, background and tileset
-	    if (selectedFile != "") {
+	    if (!selectedFile.isEmpty()) {
 		char backRaw[MAXPATHLEN];
 		char layoutRaw[MAXPATHLEN];
 		char tilesetRaw[MAXPATHLEN];
@@ -365,32 +335,41 @@ void Preview::drawPreview(void) {
 			in.close();
 
         		KMessageBox::sorry(this,
-                		i18n("Thats not a valid theme file."));
+                		i18n("That is not a valid theme file."));
 			break;
 		    }
 
 		    in.readLine(tilesetRaw, MAXPATHLEN);
-
-
 		    in.readLine(backRaw, MAXPATHLEN);
 		    in.readLine(layoutRaw, MAXPATHLEN);
 
-		    parseFile(tilesetRaw, tile);
-		    parseFile(backRaw, back);
-		    parseFile(layoutRaw, layout);
+		    tile = QString("pics") + tilesetRaw;
+		    back = QString("pics") + backRaw;
+		    layout = QString("pics") + layoutRaw;
 
+		    layout.replace(QRegExp(":"), "/");
+		    layout.replace(QRegExp("\n"), QString::null);
+		    tile.replace(QRegExp(":"), "/");
+		    tile.replace(QRegExp("\n"), QString::null);
+		    back.replace(QRegExp(":"), "/");
+		    back.replace(QRegExp("\n"), QString::null);
+
+
+		    tile = locate("appdata", tile);
+		    back = locate("appdata", back);
+		    layout = locate("appdata", layout);
+
+		    //parseFile(tilesetRaw, tile);
+		    //parseFile(backRaw, back);
+		    //parseFile(layoutRaw, layout);
 
 		    in.close();
 
 		    themeBack=back;
 		    themeLayout=layout;
 		    themeTileset=tile;
-
 		}
-
    	    }
-
-
              break;
     }
 
@@ -398,31 +377,24 @@ void Preview::drawPreview(void) {
     renderTiles(tile, layout);
 }
 
-
 void Preview::paintEvent( QPaintEvent*  ){
-	drawFrame->repaint(false);
+  drawFrame->repaint(false);
 }
 
-
-void Preview::parseFile(const QString &, QString &out) {
-	QString tmp;
-
-	QString prefix;
-	prefix=locate("appdata", "pics/default.tileset");
-	QFileInfo f(prefix);
-	prefix=f.dirPath();
+void Preview::parseFile(const QString &in, QString &out) {
+	//QString prefix = locate("appdata", QString("pics/") +in);
+	QString prefix = locate("appdata", "pics/default.tileset");
+	QFileInfo f( prefix );
+	prefix = f.dirPath();
 
 	// remove any trailing \n
+	QString tmp;
 	tmp.replace(QRegExp("\n"), QString::null);
 	tmp.replace(QRegExp(":"), prefix + '/');
 
 	out = tmp;
 }
 
-
-
-
-
 // the user selected ok, or apply. This method passes the changes
 // across to the game widget and if necessary forces a board redraw
 // (unnecessary on layout changes since it only effects the next game)
@@ -440,7 +412,7 @@ void Preview::applyChange(void) {
              break;
 
 	case theme:
-		if (themeLayout != "" && themeBack != "" && themeTileset !="") {
+		if (!themeLayout.isEmpty() && !themeBack.isEmpty() && !themeTileset.isEmpty()) {
 		    loadBackground(themeBack, false);
 		    loadTileset(themeTileset);
 		    loadBoard(themeLayout);
@@ -463,7 +435,6 @@ void Preview::applyChange(void) {
 }
 
 // Render the background to the pixmap.
-
 void Preview::renderBackground(const QString &bg) {
    QImage img;
    QImage tmp;
@@ -474,8 +445,6 @@ void Preview::renderBackground(const QString &bg) {
    b = back.getBackground();
    bitBlt( p, 0,0,
             b,0,0, b->width(), b->height(), CopyROP );
-
-
 }
 
 // This method draws a mini-tiled board with no tiles missing.
@@ -489,7 +458,7 @@ void Preview::renderTiles(const QString &file, const QString &layout) {
     int yOffset = tiles.height()/2;
     short tile = 0;
 
-    // we iterate over the depth stacking order. Each sucessive level is
+    // we iterate over the depth stacking order. Each successive level is
     // drawn one indent up and to the right. The indent is the width
     // of the 3d relief on the tile left (tile shadow width)
     for (int z=0; z<BoardLayout::depth; z++) {
@@ -532,17 +501,16 @@ void Preview::renderTiles(const QString &file, const QString &layout) {
     }
 }
 
-
-
 // this really does not belong here. It will be fixed in v1.1 onwards
 void Preview::saveTheme(void) {
+    QString tile = "pics/" + Prefs::tileSet();
+    QString back = "pics/" + Prefs::background();
+    QString layout = "pics/" + Prefs::layout();
+    tile = locate("appdata", tile);
+    back = locate("appdata", back);
+    layout = locate("appdata", layout);
 
-    QString back = preferences.background();
-    QString tile = preferences.tileset();
-    QString layout = preferences.layout();
     QString with = ":";
-
-
     // we want to replace any path in the default store
     // with a +
     QRegExp p(locate("data_dir", "/kmahjongg/pics/"));
@@ -575,7 +543,7 @@ void Preview::saveTheme(void) {
         // if it already exists, querie the user for replacement
         int res=KMessageBox::warningYesNo(this,
                         i18n("A file with that name "
-                                           "already exists, do you "
+                                           "already exists. Do you "
                                            "wish to overwrite it?"));
         if (res != KMessageBox::Yes)
                 return ;
@@ -602,6 +570,11 @@ FrameImage::FrameImage (QWidget *parent, const char *name)
 	thePixmap = new QPixmap();
 }
 
+FrameImage::~FrameImage()
+{
+	delete thePixmap;
+}
+
 void FrameImage::setGeometry(int x, int y, int w, int h) {
     QFrame::setGeometry(x,y,w,h);
 
@@ -682,3 +655,5 @@ void FrameImage::mouseMoveEvent(QMouseEvent *e) {
 }
 
 
+
+#include "Preview.moc"
