@@ -1,19 +1,19 @@
 /*
  * Copyright (c) 1996-2002 Nicolas HADACEK (hadacek@kde.org)
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include "field.h"
@@ -27,11 +27,12 @@
 
 #include <klocale.h>
 
+#include "settings.h"
 #include "solver/solver.h"
 #include "dialogs.h"
 
 
-using namespace Grid2D;
+using namespace KGrid2D;
 
 const char *Field::ACTION_NAMES[Nb_Actions] = {
     "Reveal", "AutoReveal", "SetFlag", "UnsetFlag", "SetUncertain",
@@ -39,19 +40,16 @@ const char *Field::ACTION_NAMES[Nb_Actions] = {
 };
 
 Field::Field(QWidget *parent)
-    : FieldFrame(parent), _state(Init), _level(Level::Easy)
+    : FieldFrame(parent), _state(Init), _solvingState(Regular), _level(Level::Easy)
 {}
 
 void Field::readSettings()
 {
-    _umark = KConfigCollection::configValue("uncertain mark").toBool();
-    _cursorShown = KConfigCollection::configValue("keyboard game").toBool();
-    if ( inside(_cursor) ) placeCursor(_cursor);
-	for (uint i=0; i<NB_MOUSE_BUTTONS; i++)
-		_mb[i] =
-            (MouseAction)KConfigCollection::configIndex(MOUSE_CONFIG_NAMES[i]);
-    _completeReveal = KConfigCollection::configValue("magic reveal").toBool();
-    if (_completeReveal) emit setCheating();
+    if ( inside(_cursor) ) {
+        QPainter p(this);
+        drawCase(p, _cursor);
+    }
+    if (Settings::magicReveal()) emit setCheating();
 
     FieldFrame::readSettings();
     updateGeometry();
@@ -94,13 +92,13 @@ void Field::reset(bool init)
     BaseField::reset(_level.width(), _level.height(), _level.nbMines());
     if ( init || _state==Init ) setState(Init);
     else setState(Stopped);
-    if (_completeReveal) emit setCheating();
-	_currentAction = None;
+    if (Settings::magicReveal()) emit setCheating();
+    _currentAction = Settings::EnumMouseAction::None;
     _reveal = false;
     _cursor.first = _level.width()/2;
     _cursor.second = _level.height()/2;
-    _advised = Coord(-1, -1);
-	update();
+    _advisedCoord = Coord(-1, -1);
+    update();
 }
 
 void Field::paintEvent(QPaintEvent *e)
@@ -141,13 +139,13 @@ Coord Field::fromPoint(const QPoint &qp) const
     return Coord((int)floor(i), (int)floor(j));
 }
 
-KMines::MouseAction Field::mapMouseButton(QMouseEvent *e) const
+int Field::mapMouseButton(QMouseEvent *e) const
 {
 	switch (e->button()) {
-	case Qt::LeftButton:  return _mb[KMines::LeftButton];
-	case Qt::MidButton:   return _mb[KMines::MidButton];
-	case Qt::RightButton: return _mb[KMines::RightButton];
-	default:              return Mark;
+	case Qt::LeftButton:  return Settings::mouseAction(Settings::EnumButton::left);
+	case Qt::MidButton:   return Settings::mouseAction(Settings::EnumButton::mid);
+	case Qt::RightButton: return Settings::mouseAction(Settings::EnumButton::right);
+	default:              return Settings::EnumMouseAction::ToggleFlag;
 	}
 }
 
@@ -170,39 +168,39 @@ void Field::revealActions(bool press)
 
 void Field::mousePressEvent(QMouseEvent *e)
 {
-	if ( !isActive() || _currentAction!=None ) return;
+    if ( !isActive() || (_currentAction!=Settings::EnumMouseAction::None) ) return;
 
     emit setMood(Stressed);
-	_currentAction = mapMouseButton(e);
+    _currentAction = mapMouseButton(e);
 
     Coord p = fromPoint(e->pos());
     if ( !inside(p) ) return;
     placeCursor(p);
-	revealActions(true);
+    revealActions(true);
 }
 
 void Field::mouseReleaseEvent(QMouseEvent *e)
 {
-	if ( !isActive() ) return;
+    if ( !isActive() ) return;
 
-    MouseAction tmp = _currentAction;
+    int tmp = _currentAction;
     emit setMood(Normal);
-	revealActions(false);
-    MouseAction ma = mapMouseButton(e);
-    _currentAction = None;
+    revealActions(false);
+    int ma = mapMouseButton(e);
+    _currentAction = Settings::EnumMouseAction::None;
     if ( ma!=tmp ) return;
 
     Coord p = fromPoint(e->pos());
     if ( !inside(p) ) return;
     placeCursor(p);
 
-	switch (ma) {
-    case Mark:       doMark(p); break;
-    case UMark:      doUmark(p); break;
-	case Reveal:     doReveal(p); break;
-	case AutoReveal: doAutoReveal(p); break;
-    case None:       Q_ASSERT(false); break;
-	}
+    switch (ma) {
+    case Settings::EnumMouseAction::ToggleFlag:          doMark(p); break;
+    case Settings::EnumMouseAction::ToggleUncertainFlag: doUmark(p); break;
+    case Settings::EnumMouseAction::Reveal:              doReveal(p); break;
+    case Settings::EnumMouseAction::AutoReveal:          doAutoReveal(p); break;
+    default: break;
+    }
 }
 
 void Field::mouseMoveEvent(QMouseEvent *e)
@@ -229,10 +227,9 @@ void Field::pressCase(const Coord &c, bool pressed)
 void Field::pressClearFunction(const Coord &p, bool pressed)
 {
     pressCase(p, pressed);
-    CoordSet n;
-    coveredNeighbours(p, n);
+    CoordList n = coveredNeighbours(p);
     QPainter painter(this);
-    for (CoordSet::iterator it=n.begin(); it!=n.end(); ++it)
+    for (CoordList::const_iterator it=n.begin(); it!=n.end(); ++it)
         drawCase(painter, *it, pressed);
 }
 
@@ -254,7 +251,7 @@ void Field::doAutoReveal(const Coord &c)
     if ( state(c)!=Uncovered ) return;
     emit addAction(c, AutoReveal);
     resetAdvised();
-    doAction(AutoReveal, c, _completeReveal);
+    doAction(AutoReveal, c, Settings::magicReveal());
 }
 
 void Field::pause()
@@ -279,40 +276,36 @@ void Field::moveToEdge(Neighbour n)
     if ( inside(c) ) placeCursor(c);
 }
 
-bool Field::doReveal(const Coord &c, CoordSet *autorevealed,
+bool Field::doReveal(const Coord &c, CoordList *autorevealed,
                      bool *caseUncovered)
 {
 	if ( !isActive() ) return true;
     if ( state(c)!=Covered ) return true;
-    resetAdvised();
-
     if ( firstReveal() ) setState(Playing);
-    emit addAction(c, Reveal);
     CaseState state =
-        doAction(Reveal, c, _completeReveal, autorevealed, caseUncovered);
+        doAction(Reveal, c, Settings::magicReveal(), autorevealed, caseUncovered);
+    emit addAction(c, Reveal);
     return ( state!=Error );
 }
 
 void Field::doMark(const Coord &c)
 {
 	if ( !isActive() ) return;
-    resetAdvised();
     ActionType action;
     CaseState oldState = state(c);
     switch (oldState) {
 	case Covered:   action = SetFlag; break;
-	case Marked:    action = (_umark ? SetUncertain : UnsetFlag); break;
+	case Marked:    action = (Settings::uncertainMark() ? SetUncertain : UnsetFlag); break;
 	case Uncertain:	action = UnsetUncertain; break;
 	default:        return;
 	}
-    CaseState newState = doAction(action, c, _completeReveal);
+    CaseState newState = doAction(action, c, Settings::magicReveal());
     addMarkAction(c, newState, oldState);
 }
 
 void Field::doUmark(const Coord &c)
 {
 	if ( !isActive() ) return;
-    resetAdvised();
     ActionType action;
     CaseState oldState = state(c);
     switch (oldState) {
@@ -321,15 +314,17 @@ void Field::doUmark(const Coord &c)
 	case Uncertain: action = UnsetUncertain; break;
 	default:        return;
 	}
-    CaseState newState = doAction(action, c, _completeReveal);
+    CaseState newState = doAction(action, c, Settings::magicReveal());
     addMarkAction(c, newState, oldState);
 }
 
 KMines::CaseState Field::doAction(ActionType type, const Coord &c,
-                                  bool complete, CoordSet *autorevealed,
+                                  bool complete, CoordList *autorevealed,
                                   bool *caseUncovered)
 {
+    resetAdvised();
     CaseState state = Error;
+    if ( _solvingState==Solved ) complete = false;
 
     switch (type) {
     case Reveal:
@@ -384,34 +379,34 @@ void Field::addMarkAction(const Coord &c, CaseState newS, CaseState oldS)
 
 void Field::placeCursor(const Coord &p)
 {
-	if ( !isActive() ) return;
+    if ( !isActive() ) return;
 
     Q_ASSERT( inside(p) );
     Coord old = _cursor;
     _cursor = p;
-	if ( _cursorShown ) {
+    if ( Settings::keyboardGame() ) {
         QPainter painter(this);
-		drawCase(painter, old);
-		drawCase(painter, _cursor);
-	}
+        drawCase(painter, old);
+        drawCase(painter, _cursor);
+    }
 }
 
 void Field::resetAdvised()
 {
-    if ( !inside(_advised) ) return;
+    if ( !inside(_advisedCoord) ) return;
     QPainter p(this);
-    Coord tmp = _advised;
-    _advised = Coord(-1, -1);
+    Coord tmp = _advisedCoord;
+    _advisedCoord = Coord(-1, -1);
     drawCase(p, tmp);
 }
 
 void Field::setAdvised(const Coord &c, double proba)
 {
     resetAdvised();
-
-    _advised = c;
+    _solvingState = Advised;
+    _advisedCoord = c;
     _advisedProba = proba;
-    if ( inside(_advised) ) {
+    if ( inside(c) ) {
         QPainter p(this);
         drawCase(p, c);
     }
@@ -454,7 +449,7 @@ void Field::drawCase(QPainter &painter, const Coord &c, bool pressed) const
 	}
 
     int i = -1;
-    if ( c==_advised ) {
+    if ( c==_advisedCoord ) {
         if ( _advisedProba==1 ) i = 0;
         else if ( _advisedProba>0.75 ) i = 1;
         else if ( _advisedProba>0.5  ) i = 2;
@@ -462,6 +457,6 @@ void Field::drawCase(QPainter &painter, const Coord &c, bool pressed) const
         else i = 4;
     }
 
-    bool hasFocus = ( _cursorShown && c==_cursor );
+    bool hasFocus = ( Settings::keyboardGame() && (c==_cursor) );
     drawBox(painter, toPoint(c), pressed, type, text, nbMines, i, hasFocus);
 }
