@@ -1,19 +1,19 @@
 /*
  * Copyright (c) 1996-2002 Nicolas HADACEK (hadacek@kde.org)
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef MAIN_H
@@ -21,7 +21,6 @@
 
 #include <kmainwindow.h>
 
-#include "generic/gsettings.h"
 #include "defines.h"
 
 
@@ -34,13 +33,14 @@ class MainWidget : public KMainWindow, public KMines
 {
  Q_OBJECT
  public:
-	MainWidget();
-    ~MainWidget();
+     MainWidget();
 
  private slots:
-	void toggleMenubar();
+    void toggleMenubar();
     void configureKeys();
     void configureSettings();
+    void configureNotifications();
+    void configureHighscores();
 	void gameStateChanged(KMines::GameState);
     void showHighscores();
     void settingsChanged();
@@ -53,11 +53,9 @@ class MainWidget : public KMainWindow, public KMines
 
  private:
 	Status            *_status;
-    KConfigCollection  _configCollection;
     KToggleAction     *_menu, *_pause;
     KSelectAction     *_levels;
     KAction           *_advise, *_solve;
-    bool               _pauseIfFocusLost;
     KActionCollection *_keybCollection;
 
     struct KeyData {
