@@ -6,7 +6,6 @@
 #include <kconfig.h>
 #include <kcursor.h>
 #include <kdebug.h>
-#include <kdebugclasses.h>
 #include <knuminput.h>
 #include <kfiledialog.h>
 #include <kglobal.h>
@@ -14,7 +13,6 @@
 #include <kmessagebox.h>
 #include <kpixmapeffect.h>
 #include <kprinter.h>
-#include <kconfig.h>
 #include <kstandarddirs.h>
 
 #include <qbrush.h>
@@ -1297,7 +1295,7 @@ void BlackHole::setExitDeg(int newdeg)
 	exitDeg = newdeg;
 	if (game && game->isEditing() && game->curSelectedItem() == exitItem)
 		game->updateHighlighter();
-	
+
 	exitItem->updateArrowAngle();
 	finishMe();
 }
@@ -1342,7 +1340,7 @@ bool BlackHole::place(Ball *ball, bool /*wasCenter*/)
 	ball->setState(Stopped);
 	ball->setVisible(false);
 	ball->setForceStillGoing(true);
-	
+
 	double magnitude = Vector(QPoint(x(), y()), QPoint(exitItem->x(), exitItem->y())).magnitude();
 	BlackHoleTimer *timer = new BlackHoleTimer(ball, speed, magnitude * 2.5 - speed * 35 + 500);
 
@@ -1759,7 +1757,9 @@ void Wall::selectedItem(QCanvasItem *item)
 	if (item->rtti() == Rtti_WallPoint)
 	{
 		WallPoint *wallPoint = dynamic_cast<WallPoint *>(item);
-		setPoints(startPoint().x(), startPoint().y(), wallPoint->x() - x(), wallPoint->y() - y());
+		if (wallPoint) {
+			setPoints(startPoint().x(), startPoint().y(), wallPoint->x() - x(), wallPoint->y() - y());
+		}
 	}
 }
 
@@ -2793,13 +2793,7 @@ void KolfGame::timeout()
 			if ((*it).score(curHole) < holeInfo.maxStrokes() - 1 || !holeInfo.hasMaxStrokes())
 			{
 				loadStateList();
-				
-				// increment curPlayer; he did take a shot, after all
-				// 5-23, oops, no, he gets incremented in shotDone().
-				//(*curPlayer).addStrokeToHole(curHole);
-				//emit scoreChanged((*curPlayer).id(), curHole, (*curPlayer).score(curHole));
 			}
-
 			shotDone();
 
 			return;
@@ -3057,7 +3051,7 @@ void KolfGame::recreateStateList()
 	ballStateList.clear();
 	for (PlayerList::Iterator it = players->begin(); it != players->end(); ++it)
 		ballStateList.append((*it).stateInfo(curHole));
-	
+
 	ballStateList.canUndo = true;
 }
 
@@ -3280,6 +3274,11 @@ void KolfGame::startBall(const Vector &vector)
 
 void KolfGame::shotStart()
 {
+	// ensure we never hit the ball back into the hole which
+	// can cause hole skippage
+	if ((*curPlayer).ball()->curState() == Holed)
+		return;
+
 	// save state
 	recreateStateList();
 
@@ -3361,7 +3360,7 @@ void KolfGame::startNextHole()
 	// don't do the score stuff below
 	curPlayer = players->begin();
 	double oldx=(*curPlayer).ball()->x(), oldy=(*curPlayer).ball()->y();
-	
+
 	for (PlayerList::Iterator it = players->begin(); it != players->end(); ++it)
 	{
 		if (curHole > 1)
@@ -3446,7 +3445,7 @@ void KolfGame::startNextHole()
 
 		(*curPlayer).ball()->collisionDetect(oldx, oldy);
 	}
-	
+
 	unPause();
 }
 
@@ -3783,7 +3782,7 @@ bool KolfGame::askSave(bool noMoreChances)
 		// not cancel, don't save
 		return false;
 
-	int result = KMessageBox::warningYesNoCancel(this, i18n("There are unsaved changes to current hole. Save them?"), i18n("Unsaved Changes"), i18n("&Save"), noMoreChances? i18n("Disca&rd") : i18n("Save &Later"), noMoreChances? "DiscardAsk" : "SaveAsk", true);
+	int result = KMessageBox::warningYesNoCancel(this, i18n("There are unsaved changes to current hole. Save them?"), i18n("Unsaved Changes"), KStdGuiItem::save(), noMoreChances? KStdGuiItem::discard() : i18n("Save &Later"), noMoreChances? "DiscardAsk" : "SaveAsk", true);
 	switch (result)
 	{
 		case KMessageBox::Yes:
@@ -3892,7 +3891,7 @@ void KolfGame::switchHole(int hole)
 		return;
 	if (hole < 1 || hole > highestHole)
 		return;
-	
+
 	bool wasEditing = editing;
 	if (editing)
 		toggleEditMode();
@@ -4127,7 +4126,7 @@ void KolfGame::playSound(QString file, double vol)
 			{
 				//new KVolumeControl(vol, artsServer.server(), playObject);
 			}
-			
+
 			playObject->play();
 			oldPlayObjects.append(playObject);
 		}
@@ -4161,8 +4160,7 @@ void KolfGame::print(KPrinter &pr)
 
 	if (pr.option("kde-kolf-title") == "true")
 	{
-		QString text("%1 - Hole %2; by %3");
-		text = text.arg(holeInfo.name()).arg(curHole).arg(holeInfo.author());
+		QString text = i18n("%1 - Hole %2; by %3").arg(holeInfo.name()).arg(curHole).arg(holeInfo.author());
 		QFont font(kapp->font());
 		font.setPointSize(18);
 		QRect rect = QFontMetrics(font).boundingRect(text);
