@@ -19,6 +19,7 @@
 #include <kstdaccel.h>
 #include <kstdaction.h>
 #include <kstdgameaction.h>
+#include <kstdguiitem.h>
 
 #include <qcolor.h>
 #include <qevent.h>
@@ -73,7 +74,7 @@ Kolf::Kolf()
 	layout = new QGridLayout(dummy, 3, 1);
 
 	resize(420, 480);
-	applyMainWindowSettings(KGlobal::config(), "TopLevelWindow");
+	setAutoSaveSettings("TopLevelWindow");
 }
 
 Kolf::~Kolf()
@@ -109,16 +110,16 @@ void Kolf::initGUI()
 
 	editingAction = new KToggleAction(i18n("&Edit"), "pencil", CTRL+Key_E, this, SLOT(emptySlot()), actionCollection(), "editing");
 	newHoleAction = new KAction(i18n("&New"), "filenew", CTRL+SHIFT+Key_N, this, SLOT(emptySlot()), actionCollection(), "newhole");
-	clearHoleAction = new KAction(i18n("&Clear"), "locationbar_erase", CTRL+Key_Delete, this, SLOT(emptySlot()), actionCollection(), "clearhole");
+	clearHoleAction = new KAction(KStdGuiItem::clear().text(), "locationbar_erase", CTRL+Key_Delete, this, SLOT(emptySlot()), actionCollection(), "clearhole");
 	resetHoleAction = new KAction(i18n("&Reset"), CTRL+Key_R, this, SLOT(emptySlot()), actionCollection(), "resethole");
 	undoShotAction = KStdAction::undo(this, SLOT(emptySlot()), actionCollection(), "undoshot");
 	undoShotAction->setText(i18n("&Undo Shot"));
 	//replayShotAction = new KAction(i18n("&Replay Shot"), 0, this, SLOT(emptySlot()), actionCollection(), "replay");
 
 	holeAction = new KListAction(i18n("Switch to Hole"), 0, this, SLOT(emptySlot()), actionCollection(), "switchhole");
-	nextAction = new KAction(i18n("&Next Hole"), "forward", KStdAccel::key(KStdAccel::Forward), this, SLOT(emptySlot()), actionCollection(), "nexthole");
-	prevAction = new KAction(i18n("&Previous Hole"), "back", KStdAccel::key(KStdAccel::Back), this, SLOT(emptySlot()), actionCollection(), "prevhole");
-	firstAction = new KAction(i18n("&First Hole"), "gohome", KStdAccel::key(KStdAccel::Home), this, SLOT(emptySlot()), actionCollection(), "firsthole");
+	nextAction = new KAction(i18n("&Next Hole"), "forward", KStdAccel::shortcut(KStdAccel::Forward), this, SLOT(emptySlot()), actionCollection(), "nexthole");
+	prevAction = new KAction(i18n("&Previous Hole"), "back", KStdAccel::shortcut(KStdAccel::Back), this, SLOT(emptySlot()), actionCollection(), "prevhole");
+	firstAction = new KAction(i18n("&First Hole"), "gohome", KStdAccel::shortcut(KStdAccel::Home), this, SLOT(emptySlot()), actionCollection(), "firsthole");
 	lastAction = new KAction(i18n("&Last Hole"), CTRL+SHIFT+Key_End, this, SLOT(emptySlot()), actionCollection(), "lasthole");
 	randAction = new KAction(i18n("&Random Hole"), "goto", 0, this, SLOT(emptySlot()), actionCollection(), "randhole");
 
@@ -155,13 +156,12 @@ void Kolf::initGUI()
 	createGUI();
 }
 
-void Kolf::closeEvent(QCloseEvent *e)
+bool Kolf::queryClose()
 {
 	if (game)
 		if (game->askSave(true))
-			return;
-	saveMainWindowSettings(KGlobal::config(), "TopLevelWindow");
-	e->accept();
+			return false;
+	return true;
 }
 
 void Kolf::startNewGame()
@@ -256,10 +256,10 @@ void Kolf::startNewGame()
 	//connect(replayShotAction, SIGNAL(activated()), game, SLOT(replay()));
 	connect(aboutAction, SIGNAL(activated()), game, SLOT(showInfoDlg()));
 	connect(useMouseAction, SIGNAL(toggled(bool)), game, SLOT(setUseMouse(bool)));
-	connect(useAdvancedPuttingAction, SIGNAL(toggled(bool)), game, SLOT(setUseAdvancedPutting(bool)));		
-	connect(soundAction, SIGNAL(toggled(bool)), game, SLOT(setSound(bool)));		
-	connect(showGuideLineAction, SIGNAL(toggled(bool)), game, SLOT(setShowGuideLine(bool)));		
-	connect(showInfoAction, SIGNAL(toggled(bool)), game, SLOT(setShowInfo(bool)));		
+	connect(useAdvancedPuttingAction, SIGNAL(toggled(bool)), game, SLOT(setUseAdvancedPutting(bool)));
+	connect(soundAction, SIGNAL(toggled(bool)), game, SLOT(setSound(bool)));
+	connect(showGuideLineAction, SIGNAL(toggled(bool)), game, SLOT(setShowGuideLine(bool)));
+	connect(showInfoAction, SIGNAL(toggled(bool)), game, SLOT(setShowInfo(bool)));
 
 	game->setUseMouse(useMouseAction->isChecked());
 	game->setUseAdvancedPutting(useAdvancedPuttingAction->isChecked());
@@ -311,7 +311,7 @@ void Kolf::tutorial()
 	QString newfilename = KGlobal::dirs()->findResource("appdata", "tutorial.kolfgame");
 	if (newfilename.isNull())
 	        return;
-	
+
 	filename = QString::null;
 	loadedGame = newfilename;
 	isTutorial = true;
@@ -356,7 +356,7 @@ void Kolf::closeGame()
 	loadGameAction->setEnabled(true);
 	tutorialAction->setEnabled(true);
 
-	titleChanged("");
+	titleChanged(QString::null);
 	updateModified(false);
 
 	QTimer::singleShot(100, this, SLOT(createSpacer()));
@@ -384,55 +384,64 @@ void Kolf::createSpacer()
 
 void Kolf::gameOver()
 {
-	if (competition)
+	int curPar = 0;
+	int lowScore = INT_MAX; // let's hope it doesn't stay this way!
+	int curScore = 1;
+
+	// names of people who had the lowest score
+	QStringList names;
+
+	HighScoreList highScores;
+	int scoreBoardIndex = 1;
+
+	while (curScore != 0)
 	{
-		int curPar = 0;
-		int lowScore = INT_MAX; // let's hope it doesn't stay this way!
-		int curScore = 1;
-		QStringList names;
-		HighScoreList highScores;
-		int i = 1;
-		HighScore topScore;
+		QString curName;
 
-		while (curScore != 0)
+		// name taken as a reference and filled out
+		curScore = scoreboard->total(scoreBoardIndex, curName);
+
+		scoreBoardIndex++;
+
+		if (curName == i18n("Par"))
 		{
-			QString curName;
-			curScore = scoreboard->total(i, curName);
-
-			i++;
-
-			if (curName == i18n("Par"))
-			{
-				curPar = curScore;
-				continue;
-			}
-
-			if (curScore == 0)
-				continue;
-
-			if (curScore < lowScore)
-			{
-				names.clear();
-				lowScore = curScore;
-				names.append(curName);
-				topScore.name = curName;
-				topScore.score = curScore;
-			}
-			else if (curScore == lowScore)
-				names.append(curName);
-			else
-				highScores.append(HighScore(curName, curScore));
+			curPar = curScore;
+			continue;
 		}
-		highScores.append(topScore);
 
+		if (curScore == 0)
+			continue;
+
+		// attempt to add everybody to the highscore list
+		// (ignored if we aren't competing down below)
+		highScores.append(HighScore(curName, curScore));
+
+		if (curScore < lowScore)
+		{
+			names.clear();
+			lowScore = curScore;
+			names.append(curName);
+		}
+		else if (curScore == lowScore)
+			names.append(curName);
+	}
+
+	// only announce a winner if more than two entries
+	// (player and par) are on the scoreboard + one to go past end
+	// + 1 for koodoo
+	if (scoreBoardIndex > 4)
+	{
 		if (names.count() > 1)
 		{
 			QString winners = names.join(i18n(" and "));
-			statusBar()->message(i18n("%1 tied").arg(winners));
+			KMessageBox::information(this, i18n("%1 tied").arg(winners));
 		}
 		else
-			statusBar()->message(i18n("%1 won!").arg(names.first()));
+			KMessageBox::information(this, i18n("%1 won!").arg(names.first()));
+	}
 
+	if (competition)
+	{
 		// deal with highscores
 		// KScoreDialog makes it very easy :-))
 
@@ -504,9 +513,9 @@ void Kolf::saveGameAs()
 	QString newfilename = KFileDialog::getSaveFileName(QString::null, "application/x-kolf", this, i18n("Pick Saved Game to Save To"));
 	if (newfilename.isNull())
 		return;
-	
+
 	loadedGame = newfilename;
-	
+
 	saveGame();
 }
 
@@ -517,7 +526,7 @@ void Kolf::saveGame()
 		saveGameAs();
 		return;
 	}
-	
+
 	KConfig config(loadedGame);
 	config.setGroup("0 Saved Game");
 
@@ -691,7 +700,7 @@ void Kolf::print()
 	KPrinter pr;
 	pr.addDialogPage(new PrintDialogPage());
 
-	if (pr.setup())
+    if (pr.setup(this, i18n("Print %1 - Hole %2").arg(game->courseName()).arg(game->currentHole())))
 	{
 		pr.newPage();
 		if (game)
@@ -804,13 +813,12 @@ void Kolf::configureToolBars()
 
 	KEditToolbar dlg(actionCollection());
 	connect(&dlg, SIGNAL(newToolbarConfig()), SLOT(newToolBarConfig()));
-
-	if (dlg.exec())
-		createGUI();
+	dlg.exec();
 }
 
 void Kolf::newToolBarConfig()
 {
+	createGUI();
 	applyMainWindowSettings(KGlobal::config(), "TopLevelWindow");
 }
 
