@@ -9,6 +9,8 @@
 #include <qlineedit.h>
 #include <kapplication.h>
 #include <klocale.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "newgamedlg.h"
 #include "newgamedlg.moc"
@@ -32,25 +34,28 @@ NewGameDlg::NewGameDlg( QWidget *parent, Map *pmap, PlayerList *players,
 
     rejectMapBtn = new QPushButton( i18n("&Reject Map"), this );
     rejectMapBtn->setFixedSize( rejectMapBtn->sizeHint() );
-    
+
     playerList = new QListBox( this );
     playerList->setMinimumSize( 0, 150 );
-    
+
     QLabel *listLabel = new QLabel( playerList, i18n("&Player list:"), this );
     listLabel->setFixedSize( listLabel->size() );
 
+    addAiPlayer = new QPushButton( i18n("&Add Computer Player"), this );
+    addAiPlayer->setMinimumSize( addAiPlayer->sizeHint() );
+
     newPlayer = new QLineEdit( this );
     newPlayer->setMaxLength( 8 );
-    newPlayer->setMinimumSize(newPlayer->sizeHint());
-    
+    newPlayer->setMaximumWidth(100);
+
     addPlayer = new QPushButton( i18n("&Add"), this );
-    addPlayer->setFixedSize( addPlayer->sizeHint() );
+    addPlayer->setMinimumSize( addPlayer->sizeHint() );
 
     deletePlayer = new QPushButton( i18n("&Delete"), this );
-    deletePlayer->setFixedSize( addPlayer->sizeHint() );
-    
-    clearList = new QPushButton( i18n("&Clear"), this );
-    clearList->setFixedSize( clearList->sizeHint() );
+    deletePlayer->setMinimumSize( deletePlayer->sizeHint() );
+
+    clearList = new KPushButton( KStdGuiItem::clear(), this );
+    clearList->setMinimumSize( clearList->sizeHint() );
 
     neutralPlanets = new QSlider( 1, 35, 1, 1, Qt::Horizontal, this );
     neutralPlanets->setMinimumHeight(neutralPlanets->sizeHint().height());
@@ -62,14 +67,14 @@ NewGameDlg::NewGameDlg( QWidget *parent, Map *pmap, PlayerList *players,
     turnCount->setTickmarks( QSlider::Below );
     turnCount->setMinimumHeight(turnCount->sizeHint().height());
 
-    turnCountLbl = new QLabel("Number of turns: 99", this);
+    turnCountLbl = new QLabel("Number of turns:", this);
     turnCountLbl->setMinimumSize(turnCountLbl->sizeHint());
-    
+
     okBtn = new QPushButton( i18n("&Start Game"), this );
     okBtn->setFixedSize( okBtn->sizeHint() );
     okBtn->setEnabled(false);
 
-    cancelBtn = new QPushButton( i18n("&Cancel"), this );
+    cancelBtn = new KPushButton( KStdGuiItem::cancel(), this );
     cancelBtn->setFixedSize( cancelBtn->sizeHint() );
 
 
@@ -84,31 +89,33 @@ NewGameDlg::NewGameDlg( QWidget *parent, Map *pmap, PlayerList *players,
 
     QBoxLayout *playerColumn = new QVBoxLayout(5);
 
-    QBoxLayout *playerEditRow = new QHBoxLayout;
+    QBoxLayout *playerEditRow = new QVBoxLayout( );
 
     mainLayout->addLayout( mainHLayout, 2 );
 
     mainHLayout->addSpacing( 5 );
     mainHLayout->addLayout( playerColumn, 2 );
-    mainHLayout->addSpacing( 5 );
+    mainHLayout->addLayout( playerEditRow );
+    mainHLayout->addSpacing( 20 );
     mainHLayout->addLayout( mapColumn );
     mainHLayout->addSpacing(5);
-    
+
     mapColumn->addSpacing( 5 );
     mapColumn->addWidget( mapLabel, 0, AlignLeft );
     mapColumn->addWidget( miniMap, 0, AlignLeft );
     mapColumn->addSpacing( 5 );
     mapColumn->addWidget( rejectMapBtn, 0, AlignCenter );
     mapColumn->addStretch(1);
-    
-    playerColumn->addWidget( listLabel, 0, AlignLeft );
-    playerColumn->addWidget( playerList, 1, AlignLeft );
-    playerColumn->addLayout( playerEditRow );
 
-    playerEditRow->addWidget( newPlayer, 1 );
-    playerEditRow->addWidget( addPlayer );
-    playerEditRow->addWidget( deletePlayer );
-    playerEditRow->addWidget( clearList );
+    playerColumn->addWidget( listLabel, 0, AlignLeft );
+    playerColumn->addWidget( newPlayer, 1, AlignLeft );
+    playerColumn->addWidget( playerList, 1, AlignLeft );
+
+    playerEditRow->addSpacing( 35 );
+    playerEditRow->addWidget( addPlayer, 0 );
+    playerEditRow->addWidget( addAiPlayer, 0 );
+    playerEditRow->addWidget( deletePlayer, 0 );
+    playerEditRow->addWidget( clearList, 0, AlignTop );
 
     mainLayout->addStretch(1);
 
@@ -116,7 +123,7 @@ NewGameDlg::NewGameDlg( QWidget *parent, Map *pmap, PlayerList *players,
     mainLayout->addWidget( neutralPlanets, 1 );
     mainLayout->addWidget( turnCountLbl, 1, AlignLeft );
     mainLayout->addWidget( turnCount, 1 );
-    
+
     mainLayout->addStretch(1);
 
     mainLayout->addSpacing(10);
@@ -131,12 +138,13 @@ NewGameDlg::NewGameDlg( QWidget *parent, Map *pmap, PlayerList *players,
     mainLayout->activate();
 
     // Connect controls
-    
+
     connect( okBtn, SIGNAL( clicked() ), this, SLOT( startGame() ) );
     connect( cancelBtn, SIGNAL( clicked() ), this, SLOT( reject() ) );
     connect( neutralPlanets, SIGNAL( valueChanged(int) ), this, SLOT( changeNeutralPlanets(int)) );
     connect( turnCount, SIGNAL( valueChanged(int) ), this, SLOT( changeTurnCount(int)) );
     connect( addPlayer, SIGNAL( clicked() ), this, SLOT( addNewPlayer() ) );
+    connect( addAiPlayer, SIGNAL( clicked() ), this, SLOT( addNewAiPlayer() ) );
     connect( newPlayer, SIGNAL( returnPressed() ), this, SLOT( addNewPlayer() ) );
     connect( deletePlayer, SIGNAL( clicked() ), this, SLOT( removePlayer() ) );
     connect( clearList, SIGNAL( clicked() ), this, SLOT( clearPlayerList() ) );
@@ -202,6 +210,38 @@ NewGameDlg::addNewPlayer()
     updateMiniMap();
 }
 
+void NewGameDlg::addNewAiPlayer() {
+
+    // Is there room for a new player
+    if( playerList->count() >= MAX_PLAYERS )
+        return;
+
+    // Does the name already exist in the list
+    for( unsigned int x = 0; x < playerList->count(); x++ ) {
+        if( newPlayer->text() == playerList->text(x) )
+            return;
+    }
+
+    // Insert the player
+    QString name;
+    int aiNumber = 0;
+
+    for( unsigned int plrNum = 0; plrNum < playerList->count(); plrNum++ ) {
+        QString plrName( playerList->text( plrNum ) );
+        if (plrName.startsWith("Comp"))
+        	aiNumber++;
+    }
+
+    name = i18n("Generated AI player name", "Comp%1").arg(aiNumber+1);
+    playerList->insertItem( name );
+
+    if( playerList->count() > 1)
+       okBtn->setEnabled(true);
+
+    // update the map and game objects
+    updateMiniMap();
+}
+
 void
 NewGameDlg::removePlayer()
 {
@@ -277,7 +317,10 @@ NewGameDlg::updateMiniMap( void )
     // Make player list
     for( unsigned int plrNum = 0; plrNum < playerList->count(); plrNum++ ) {
         QString plrName( playerList->text( plrNum ) );
-        plrList->append( Player::createPlayer( plrName, PlayerColors[plrNum], plrNum ));
+        bool ai = false;
+        if (plrName.startsWith("Comp"))
+        	ai = true;
+        plrList->append( Player::createPlayer( plrName, PlayerColors[plrNum], plrNum, ai ));
     }
 
     // make the planets
