@@ -6,6 +6,8 @@
 #include "gamecore.h"
 #include "minimap.h"
 
+class KPushButton;
+
 /*************************************************************************
  New Game Dialog
  ************************************************************************/
@@ -19,16 +21,17 @@ public:
                 Player *neutralPlayer, PlanetList *planetList );
 
     int turns( void );
-    
+
 public slots:
     void changeNeutralPlanets( int );
     void changeTurnCount( int );
     void addNewPlayer();
+    void addNewAiPlayer();
     void removePlayer();
     void clearPlayerList();
     void startGame();
     void rejectMap();
-    
+
 private:
     void updateMiniMap( void );
 
@@ -41,15 +44,17 @@ private:
     QPushButton *okBtn;
     QPushButton *cancelBtn;
     QLineEdit *newPlayer;
+    QPushButton *addAiPlayer;
     QPushButton *addPlayer;
     QPushButton *deletePlayer;
-    QPushButton *clearList;
+    KPushButton *clearList;
     QSlider *neutralPlanets;
     QSlider *turnCount;
     QLabel *neutralPlanetLbl;
     QLabel *turnCountLbl;
     MiniMap *miniMap;
     QPushButton *rejectMapBtn;
+    int AiPlayers;
 
 };
 
