@@ -1,18 +1,16 @@
 #include "dealer.h"
 #include <kstaticdeleter.h>
-#include <qpainter.h>
 #include <kdebug.h>
-#include <deck.h>
+#include "deck.h"
 #include <assert.h>
-#include "pile.h"
 #include "kmainwindow.h"
 #include <kapplication.h>
 #include <kpixmapeffect.h>
 #include <qtimer.h>
 #include <kaction.h>
 #include <klocale.h>
-#include <cardmaps.h>
-#include <speeds.h>
+#include "cardmaps.h"
+#include "speeds.h"
 
 DealerInfoList *DealerInfoList::_self = 0;
 static KStaticDeleter<DealerInfoList> dl;
@@ -20,7 +18,7 @@ static KStaticDeleter<DealerInfoList> dl;
 DealerInfoList *DealerInfoList::self()
 {
     if (!_self)
-        _self = dl.setObject(new DealerInfoList());
+        _self = dl.setObject(_self, new DealerInfoList());
     return _self;
 }
 
@@ -552,6 +550,12 @@ bool Dealer::cardDblClicked(Card *c)
 
 void Dealer::startNew()
 {
+    if ( ahint )
+        ahint->setEnabled( true );
+    if ( ademo )
+        ademo->setEnabled( true );
+    if ( aredeal )
+        aredeal->setEnabled( true );
     minsize = QSize(0,0);
     _won = false;
     _waiting = 0;
@@ -756,6 +760,12 @@ void Dealer::takeState()
         }
         else if (isGameLost()) {
             QTimer::singleShot(400, this, SIGNAL(gameLost()));
+            if ( ahint )
+                ahint->setEnabled( false );
+            if ( ademo )
+                ademo->setEnabled( false );
+            if ( aredeal )
+                aredeal->setEnabled( false );
             return;
         }
     }
@@ -1007,7 +1017,8 @@ long Dealer::gameNumber() const
 
 void Dealer::setGameNumber(long gmn)
 {
-    gamenumber = ((gmn + 31998) % 31999) + 1;
+    // Deal in the range of 1 to INT_MAX.
+    gamenumber = ((gmn < 1) ? 1 : ((gmn > 0x7FFFFFFF) ? 0x7FFFFFFF : gmn));
 }
 
 void Dealer::addPile(Pile *p)
@@ -1053,31 +1064,48 @@ void Dealer::toggleDemo()
         demo();
 }
 
+class CardPtr
+{
+ public:
+    Card *ptr;
+};
+
+bool operator <(const CardPtr &p1, const CardPtr &p2)
+{
+    return ( p1.ptr->z() < p2.ptr->z() );
+}
+
 void Dealer::won()
 {
     if (_won)
         return;
     _won = true;
-    QCanvasItemList list = canvas()->allItems();
-    for (QCanvasItemList::ConstIterator it = list.begin(); it != list.end(); ++it)
-    {
-        if ((*it)->rtti() == Card::RTTI)
-        {
-            Card *c = dynamic_cast<Card*>(*it);
-            assert(c);
-            c->turn(true);
-            QRect p(0, 0, c->width(), c->height());
-            QRect can(0, 0, canvas()->width(), canvas()->height());
-            int x, y;
 
-            do {
-                // disperse the cards everywhere
-                x = 3*canvas()->width()/2 - kapp->random() % (canvas()->width() * 2);
-                y = 3*canvas()->height()/2 - (kapp->random() % (canvas()->height() * 2));
-                p.moveTopLeft(QPoint(x, y));
-            } while (can.intersects(p));
-	    c->animatedMove( x, y, 0, STEPS_WON);
-       }
+    // sort cards by increasing z
+    QCanvasItemList list = canvas()->allItems();
+    QValueList<CardPtr> cards;
+    for (QCanvasItemList::ConstIterator it=list.begin(); it!=list.end(); ++it)
+        if ((*it)->rtti() == Card::RTTI) {
+            CardPtr p;
+            p.ptr = dynamic_cast<Card*>(*it);
+            assert(p.ptr);
+            cards.push_back(p);
+        }
+    qHeapSort(cards);
+
+    // disperse the cards everywhere
+    QRect can(0, 0, canvas()->width(), canvas()->height());
+    QValueList<CardPtr>::ConstIterator it = cards.begin();
+    for (; it != cards.end(); ++it) {
+        (*it).ptr->turn(true);
+        QRect p(0, 0, (*it).ptr->width(), (*it).ptr->height());
+        int x, y;
+        do {
+            x = 3*canvas()->width()/2 - kapp->random() % (canvas()->width() * 2);
+            y = 3*canvas()->height()/2 - (kapp->random() % (canvas()->height() * 2));
+            p.moveTopLeft(QPoint(x, y));
+        } while (can.intersects(p));
+	    (*it).ptr->animatedMove( x, y, 0, STEPS_WON);
     }
     bool demo = demoActive();
     stopDemo();
