@@ -12,21 +12,23 @@
 #include "move.h"
 #include "state.h"
 
-
-
-#define FCS_MOVE_STACK_GROW_BY 16
-
-#ifndef max
-#define max(a,b) (((a)>(b))?(a):(b))
+#ifdef DMALLOC
+#include "dmalloc.h"
 #endif
 
-int msc_counter=0;
+#include "inline.h"
 
+#if 0
+/* This variable was used for debugging. */
+int msc_counter=0;
+#endif
+
+#if 0
 /* This function allocates an empty move stack */
 fcs_move_stack_t * fcs_move_stack_create(void)
 {
     fcs_move_stack_t * ret;
-    
+
     /* Allocate the data structure itself */
     ret = (fcs_move_stack_t *)malloc(sizeof(fcs_move_stack_t));
 
@@ -34,15 +36,17 @@ fcs_move_stack_t * fcs_move_stack_create(void)
     ret->num_moves = 0;
     /* Allocate some space for the moves */
     ret->moves = (fcs_move_t *)malloc(sizeof(fcs_move_t)*ret->max_num_moves);
-    
+
     return ret;
 }
+#endif
 
+#if 0
 int fcs_move_stack_push(fcs_move_stack_t * stack, fcs_move_t move)
 {
     /* If all the moves inside the stack are taken then
        resize the move vector */
-       
+
     if (stack->num_moves == stack->max_num_moves)
     {
         int a, b;
@@ -50,7 +54,7 @@ int fcs_move_stack_push(fcs_move_stack_t * stack, fcs_move_t move)
         b = FCS_MOVE_STACK_GROW_BY;
         stack->max_num_moves += max(a,b);
         stack->moves = realloc(
-            stack->moves, 
+            stack->moves,
             stack->max_num_moves * sizeof(fcs_move_t)
             );
     }
@@ -58,8 +62,9 @@ int fcs_move_stack_push(fcs_move_stack_t * stack, fcs_move_t move)
 
     return 0;
 }
+#endif
 
-int fcs_move_stack_pop(fcs_move_stack_t * stack, fcs_move_t * move)
+int freecell_solver_move_stack_pop(fcs_move_stack_t * stack, fcs_move_t * move)
 {
     if (stack->num_moves > 0)
     {
@@ -72,14 +77,16 @@ int fcs_move_stack_pop(fcs_move_stack_t * stack, fcs_move_t * move)
     }
 }
 
+#if 0
 void fcs_move_stack_destroy(fcs_move_stack_t * stack)
 {
     free(stack->moves);
-    free(stack);   
+    free(stack);
 }
+#endif
 
-void fcs_move_stack_swallow_stack(
-    fcs_move_stack_t * stack, 
+void freecell_solver_move_stack_swallow_stack(
+    fcs_move_stack_t * stack,
     fcs_move_stack_t * src_stack
     )
 {
@@ -91,20 +98,23 @@ void fcs_move_stack_swallow_stack(
     fcs_move_stack_destroy(src_stack);
 }
 
+#if 0
 void fcs_move_stack_reset(
     fcs_move_stack_t * stack
     )
 {
     stack->num_moves = 0;
 }
+#endif
 
-int fcs_move_stack_get_num_moves(
+int freecell_solver_move_stack_get_num_moves(
     fcs_move_stack_t * stack
     )
 {
     return stack->num_moves;
 }
 
+#if 0
 /*
     This function duplicates a move stack
 */
@@ -115,7 +125,7 @@ fcs_move_stack_t * fcs_move_stack_duplicate(
     fcs_move_stack_t * ret;
 
     ret = (fcs_move_stack_t *)malloc(sizeof(fcs_move_stack_t));
-    
+
     ret->max_num_moves = stack->max_num_moves;
     ret->num_moves = stack->num_moves;
     ret->moves = (fcs_move_t *)malloc(sizeof(fcs_move_t) * ret->max_num_moves);
@@ -123,12 +133,31 @@ fcs_move_stack_t * fcs_move_stack_duplicate(
 
     return ret;
 }
+#endif
 
+#if 0
+extern void fcs_derived_states_list_add_state(
+    fcs_derived_states_list_t * list,
+    fcs_state_with_locations_t * state,
+    fcs_move_stack_t * move_stack
+    )
+{
+    if (list->num_states == list->max_num_states)
+    {
+        list->max_num_states += 16;
+        list->states = realloc(list->states, sizeof(list->states[0]) * list->max_num_states);
+        list->move_stacks = realloc(list->move_stacks, sizeof(list->move_stacks[0]) * list->max_num_states);
+    }
+    list->states[list->num_states] = state;
+    list->move_stacks[list->num_states] = move_stack;
+    list->num_states++;
+}
+#endif
 /*
-    This function performs a given move on a state 
+    This function performs a given move on a state
 
   */
-void fcs_apply_move(fcs_state_with_locations_t * state_with_locations, fcs_move_t move, int freecells_num, int stacks_num, int decks_num)
+void freecell_solver_apply_move(fcs_state_with_locations_t * state_with_locations, fcs_move_t move, int freecells_num, int stacks_num, int decks_num)
 {
     fcs_state_t * state;
     fcs_card_t temp_card;
@@ -153,11 +182,11 @@ void fcs_apply_move(fcs_state_with_locations_t * state_with_locations, fcs_move_
             for(a=0 ; a<fcs_move_get_num_cards_in_seq(move) ; a++)
             {
                 fcs_push_stack_card_into_stack(
-                    *state, 
+                    *state,
                     dest_stack,
                     src_stack,
                     src_stack_len - fcs_move_get_num_cards_in_seq(move)+a
-                    );            
+                    );
             }
             for(a=0 ; a<fcs_move_get_num_cards_in_seq(move) ; a++)
             {
@@ -166,7 +195,7 @@ void fcs_apply_move(fcs_state_with_locations_t * state_with_locations, fcs_move_
                     src_stack,
                     temp_card
                     );
-            }        
+            }
         }
         break;
         case FCS_MOVE_TYPE_FREECELL_TO_STACK:
@@ -198,14 +227,31 @@ void fcs_apply_move(fcs_state_with_locations_t * state_with_locations, fcs_move_
         case FCS_MOVE_TYPE_FREECELL_TO_FOUNDATION:
         {
             fcs_empty_freecell(*state, src_freecell);
-            fcs_increment_foundation(*state, fcs_move_get_foundation(move));        
+            fcs_increment_foundation(*state, fcs_move_get_foundation(move));
         }
         break;
+        case FCS_MOVE_TYPE_SEQ_TO_FOUNDATION:
+        {
+            for(a=0;a<13;a++)
+            {
+                fcs_pop_stack_card(*state, src_stack, temp_card);
+                fcs_increment_foundation(*state, fcs_move_get_foundation(move));
+            }
+        }
+        break;
+
+        case FCS_MOVE_TYPE_FLIP_CARD:
+        {
+            fcs_flip_stack_card(*state, src_stack, fcs_stack_len(*state, src_stack)-1);
+        }
+        break;
+
         case FCS_MOVE_TYPE_CANONIZE:
         {
             fcs_canonize_state(state_with_locations, freecells_num, stacks_num);
         }
         break;
+
     }
 }
 
@@ -214,7 +260,8 @@ void fcs_apply_move(fcs_state_with_locations_t * state_with_locations, fcs_move_
     the canonized positions of the stacks and freecells to their
     user positions.
 */
-void fcs_move_stack_normalize(
+
+void freecell_solver_move_stack_normalize(
     fcs_move_stack_t * moves,
     fcs_state_with_locations_t * init_state,
     int freecells_num,
@@ -225,10 +272,21 @@ void fcs_move_stack_normalize(
     fcs_move_stack_t * temp_moves;
     fcs_move_t in_move, out_move;
     fcs_state_with_locations_t dynamic_state;
+#ifdef INDIRECT_STACK_STATES
+    char buffer[MAX_NUM_STACKS << 7];
+    int a;
+#endif
+    
 
-    temp_moves = fcs_move_stack_create();
+    fcs_move_stack_alloc_into_var(temp_moves);
 
     fcs_duplicate_state(dynamic_state, *init_state);
+#ifdef INDIRECT_STACK_STATES
+    for(a=0;a<stacks_num;a++)
+    {
+        fcs_copy_stack(dynamic_state, a, buffer);
+    }
+#endif
 
     while (
         fcs_move_stack_pop(
@@ -236,7 +294,7 @@ void fcs_move_stack_normalize(
             &in_move
             ) == 0)
     {
-        fcs_apply_move(
+        freecell_solver_apply_move(
             &dynamic_state,
             in_move,
             freecells_num,
@@ -252,11 +310,13 @@ void fcs_move_stack_normalize(
             fcs_move_set_type(out_move, fcs_move_get_type(in_move));
             if ((fcs_move_get_type(in_move) == FCS_MOVE_TYPE_STACK_TO_STACK) ||
                 (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_STACK_TO_FREECELL) ||
-                (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_STACK_TO_FOUNDATION))
+                (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_STACK_TO_FOUNDATION) ||
+                (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_SEQ_TO_FOUNDATION)
+                )
             {
                 fcs_move_set_src_stack(out_move,dynamic_state.stack_locs[(int)fcs_move_get_src_stack(in_move)]);
             }
-            
+
             if (
                 (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_FREECELL_TO_STACK) ||
                 (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_FREECELL_TO_FREECELL) ||
@@ -282,7 +342,10 @@ void fcs_move_stack_normalize(
             }
 
             if ((fcs_move_get_type(in_move) == FCS_MOVE_TYPE_STACK_TO_FOUNDATION) ||
-                (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_FREECELL_TO_FOUNDATION))
+                (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_FREECELL_TO_FOUNDATION) ||
+                (fcs_move_get_type(in_move) == FCS_MOVE_TYPE_SEQ_TO_FOUNDATION)
+
+               )
             {
                 fcs_move_set_foundation(out_move,fcs_move_get_foundation(in_move));
             }
@@ -299,76 +362,170 @@ void fcs_move_stack_normalize(
     /*
      * temp_moves contain the needed moves in reverse order. So let's use
      * swallow_stack to put them in the original in the correct order.
-     * 
+     *
      * */
     fcs_move_stack_reset(moves);
 
-    fcs_move_stack_swallow_stack(moves, temp_moves);
-
-    fcs_clean_state(&dynamic_state);
+    freecell_solver_move_stack_swallow_stack(moves, temp_moves);
 }
 
-/* 
-    This function creates a string that represents a move.
-*/
-char * fcs_move_to_string(fcs_move_t move)
+GCC_INLINE int convert_freecell_num(int fcn)
+{
+    if (fcn >= 7)
+        return (fcn+3);
+    else
+        return fcn;
+}
+
+char * freecell_solver_move_to_string(fcs_move_t move, int standard_notation)
+{
+    return 
+        freecell_solver_move_to_string_w_state(
+            NULL, 4, 8, 1, 
+            move, 
+            (standard_notation == 2)?1:standard_notation
+            );
+}
+
+char * freecell_solver_move_to_string_w_state(fcs_state_with_locations_t * state, int freecells_num, int stacks_num, int decks_num, fcs_move_t move, int standard_notation)
 {
     char string[256];
     switch(fcs_move_get_type(move))
     {
         case FCS_MOVE_TYPE_STACK_TO_STACK:
-            sprintf(string, "Move %i cards from stack %i to stack %i",
-                fcs_move_get_num_cards_in_seq(move),
-                fcs_move_get_src_stack(move),
-                fcs_move_get_dest_stack(move)
+            if ((standard_notation == 2) && 
+                /* More than one card was moved */
+                (fcs_move_get_num_cards_in_seq(move) > 1) && 
+                /* It was a move to an empty stack */
+                (fcs_stack_len(state->s, fcs_move_get_dest_stack(move)) == 
+                 fcs_move_get_num_cards_in_seq(move))
+               )
+            {
+                sprintf(string, "%i%iv%x", 
+                    1+fcs_move_get_src_stack(move),
+                    1+fcs_move_get_dest_stack(move),
+                    fcs_move_get_num_cards_in_seq(move)
+                   );
+            }
+            else if (standard_notation)
+            {
+                sprintf(string, "%i%i",
+                    1+fcs_move_get_src_stack(move),
+                    1+fcs_move_get_dest_stack(move)
+                    );
+            }
+            else
+            {
+                sprintf(string, "Move %i cards from stack %i to stack %i",
+                    fcs_move_get_num_cards_in_seq(move),
+                    fcs_move_get_src_stack(move),
+                    fcs_move_get_dest_stack(move)
                 );
-            
+            }
         break;
 
         case FCS_MOVE_TYPE_FREECELL_TO_STACK:
-            sprintf(string, "Move a card from freecell %i to stack %i",
-                fcs_move_get_src_freecell(move),
-                fcs_move_get_dest_stack(move)
-                );
-            
+            if (standard_notation)
+            {
+                sprintf(string, "%c%i",
+                    ('a'+convert_freecell_num(fcs_move_get_src_freecell(move))),
+                    1+fcs_move_get_dest_stack(move)
+                    );
+            }
+            else
+            {
+                sprintf(string, "Move a card from freecell %i to stack %i",
+                    fcs_move_get_src_freecell(move),
+                    fcs_move_get_dest_stack(move)
+                    );
+            }
+
         break;
 
         case FCS_MOVE_TYPE_FREECELL_TO_FREECELL:
-            sprintf(string, "Move a card from freecell %i to freecell %i",
-                fcs_move_get_src_freecell(move),
-                fcs_move_get_dest_freecell(move)
-                );
+            if (standard_notation)
+            {
+                sprintf(string, "%c%c",
+                    ('a'+convert_freecell_num(fcs_move_get_src_freecell(move))),
+                    ('a'+convert_freecell_num(fcs_move_get_dest_freecell(move)))
+                    );
+            }
+            else
+            {
+                sprintf(string, "Move a card from freecell %i to freecell %i",
+                    fcs_move_get_src_freecell(move),
+                    fcs_move_get_dest_freecell(move)
+                    );
+            }
 
         break;
 
         case FCS_MOVE_TYPE_STACK_TO_FREECELL:
-            sprintf(string, "Move a card from stack %i to freecell %i",
-                fcs_move_get_src_stack(move),
-                fcs_move_get_dest_freecell(move)
-                );
+            if (standard_notation)
+            {
+                sprintf(string, "%i%c",
+                    1+fcs_move_get_src_stack(move),
+                    ('a'+convert_freecell_num(fcs_move_get_dest_freecell(move)))
+                    );
+            }
+            else
+            {
+                sprintf(string, "Move a card from stack %i to freecell %i",
+                    fcs_move_get_src_stack(move),
+                    fcs_move_get_dest_freecell(move)
+                    );
+            }
 
         break;
 
         case FCS_MOVE_TYPE_STACK_TO_FOUNDATION:
-            sprintf(string, "Move a card from stack %i to the foundations",
-                fcs_move_get_src_stack(move)
-                );
+            if (standard_notation)
+            {
+                sprintf(string, "%ih", 1+fcs_move_get_src_stack(move));
+            }
+            else
+            {
+                sprintf(string, "Move a card from stack %i to the foundations",
+                    fcs_move_get_src_stack(move)
+                    );
+            }
 
         break;
-        
+
 
         case FCS_MOVE_TYPE_FREECELL_TO_FOUNDATION:
-            sprintf(string, "Move a card from freecell %i to the foundations",
-                fcs_move_get_src_freecell(move)
-                );
+            if (standard_notation)
+            {
+                sprintf(string, "%ch", ('a'+convert_freecell_num(fcs_move_get_src_freecell(move))));
+            }
+            else
+            {
+                sprintf(string,
+                    "Move a card from freecell %i to the foundations",
+                    fcs_move_get_src_freecell(move)
+                    );
+            }
 
         break;
 
+        case FCS_MOVE_TYPE_SEQ_TO_FOUNDATION:
+            if (standard_notation)
+            {
+                sprintf(string, "%ih", fcs_move_get_src_stack(move));
+            }
+            else
+            {
+                sprintf(string,
+                    "Move the sequence on top of Stack %i to the foundations",
+                    fcs_move_get_src_stack(move)
+                    );
+            }
+        break;
+
         default:
             string[0] = '\0';
         break;
     }
 
     return strdup(string);
-    
 }
