@@ -20,7 +20,6 @@
 
 #include "grandf.h"
 #include <klocale.h>
-#include "pile.h"
 #include "deck.h"
 #include <kaction.h>
 #include <assert.h>
@@ -171,7 +170,7 @@ bool Grandf::isGameLost() const
                 CardList p = store[j]->cards();
                 for (CardList::ConstIterator it = p.begin(); it != p.end(); ++it){
                     Card *c= *it;
-                    if( it != p.begin() && c->isFaceUp() && c->value() == Card::King)
+                    if( it != p.begin() && c->realFace() && c->value() == Card::King)
                         return false;
                 }
             }
