@@ -27,7 +27,6 @@
 #ifndef P_KLONDIKE
 #define P_KLONDIKE
 
-#include <qcombobox.h>
 #include "dealer.h"
 
 class KlondikePile;
@@ -62,7 +61,8 @@ private:
 
     KlondikePile *pile;
     Deck* deck;
-    Card::Values lowest_card[2];
+    Card::Values target_tops[4];
+    bool noLongerNeeded(Card::Values v, Card::Suits s );
 };
 
 #endif
