@@ -17,20 +17,18 @@
  */
 
 #include <kapplication.h>
-#include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
 #include "version.h"
 #include "pwidget.h"
-#include "deck.h"
 
 static const char *description = I18N_NOOP("KDE Patience Game");
 
 static KCmdLineOptions options[] =
 {
     { "+file",          I18N_NOOP("File to load"), 0 },
-    { 0,0,0 }
+    KCmdLineLastOption
 };
 
 int main( int argc, char **argv )
@@ -50,6 +48,9 @@ int main( int argc, char **argv )
     aboutData.addAuthor("Shlomi Fish", I18N_NOOP("Freecell Solver"), "shlomif@vipe.technion.ac.il");
     aboutData.addAuthor("Stephan Kulow", I18N_NOOP("Rewrite and current maintainer"),
                         "coolo@kde.org");
+    aboutData.addAuthor("Erik Sigra", I18N_NOOP("Improved Klondike"), "sigra@home.se");
+    aboutData.addAuthor("Josh Metzler", I18N_NOOP("Spider Implementation"), "joshdeb@metzlers.org");
+    aboutData.addAuthor("Maren Pakura", I18N_NOOP("Documentation"), "maren@kde.org");
 
     KCmdLineArgs::init( argc, argv, &aboutData );
     KCmdLineArgs::addCmdLineOptions (options);
@@ -62,7 +63,7 @@ int main( int argc, char **argv )
         RESTORE(pWidget)
     else {
         pWidget *w = new pWidget;
-    if (args->count())
+        if (args->count())
             w->openGame(args->url(0));
         a.setMainWidget(w);
         w->show();
