@@ -27,9 +27,8 @@
 #include <klocale.h>
 #include "pwidget.h"
 #include "version.h"
-#include <kstdaction.h>
 #include <kaction.h>
-#include <dealer.h>
+#include "dealer.h"
 #include <kdebug.h>
 #include "cardmaps.h"
 #include <kcarddialog.h>
@@ -38,10 +37,13 @@
 #include <kfiledialog.h>
 #include <ktempfile.h>
 #include <kio/netaccess.h>
-#include "speeds.h"
 #include <kmessagebox.h>
 #include <qimage.h>
 #include <kstatusbar.h>
+#include "speeds.h"
+#include <kmessagebox.h>
+#include <kaccelmanager.h>
+#include <kmenubar.h>
 
 static pWidget *current_pwidget = 0;
 
@@ -127,7 +129,7 @@ pWidget::pWidget()
     KConfig *config = kapp->config();
     KConfigGroupSaver cs(config, settings_group );
 
-    QString bgpath = config->readEntry("Background");
+    QString bgpath = config->readPathEntry("Background");
     kdDebug() << "bgpath '" << bgpath << "'" << endl;
     if (bgpath.isEmpty())
         bgpath = locate("wallpaper", "No-Ones-Laughing-3.jpg");
@@ -145,6 +147,7 @@ pWidget::pWidget()
     games->setCurrentItem(game);
 
     createGUI(QString::null, false);
+    KAcceleratorManager::manage(menuBar());
 
     newGameType();
 }
@@ -212,8 +215,10 @@ void pWidget::changeWallpaper()
     if (bgpath.isEmpty())
         return;
     background = QPixmap(bgpath);
-    if (background.isNull())
+    if (background.isNull()) {
+        KMessageBox::sorry(this, i18n("<qt>Couldn't load wallpaper<br/>%1</qt>").arg(bgpath));
         return;
+    }
 
     QImage bg = background.convertToImage().convertDepth(8, 0);
     if (bg.isNull() || !bg.numColors())
@@ -241,7 +246,7 @@ void pWidget::changeWallpaper()
         QString dummy = config->readEntry("Cards", KCardDialog::getDefaultCardDir());
         setBackSide(deck, dummy);
 
-	config->writeEntry("Background", bgpath);
+	config->writePathEntry("Background", bgpath);
         dill->setBackgroundPixmap(background, midcolor);
         dill->canvas()->setAllChanged();
         dill->canvas()->update();
@@ -372,7 +377,7 @@ void pWidget::setBackSide(const QString &deck, const QString &cards)
 
 void pWidget::chooseGame()
 {
-    KLineEditDlg dlg(i18n("Enter a game number (1 to 32000 are the same as in the FreeCell FAQ):"), QString::number(dill->gameNumber()), this);
+    KLineEditDlg dlg(i18n("Enter a game number (FreeCell deals are the same as in the FreeCell FAQ):"), QString::number(dill->gameNumber()), this);
     dlg.setCaption(i18n("Game Number"));
 
     bool ok;
@@ -406,14 +411,14 @@ void pWidget::gameLost()
     if (KMessageBox::questionYesNo(this, i18n("You couldn't win this game, "
                                               "but there is always a second try.\nStart a new game?"),
                                    i18n("Couldn't Win!"),
-                                   i18n("New Game"), i18n("Continue")) == KMessageBox::Yes)
+                                   i18n("New Game"), KStdGuiItem::cont()) == KMessageBox::Yes)
         QTimer::singleShot(0, this, SLOT(newGame()));
  }
 
 void pWidget::openGame(const KURL &url)
 {
     QString tmpFile;
-    if( KIO::NetAccess::download( url, tmpFile ) )
+    if( KIO::NetAccess::download( url, tmpFile, this ) )
     {
         QFile of(tmpFile);
         of.open(IO_ReadOnly);
@@ -457,7 +462,7 @@ void pWidget::saveGame()
     QTextStream *stream = file.textStream();
     *stream << doc.toString();
     file.close();
-    KIO::NetAccess::upload(file.name(), url);
+    KIO::NetAccess::upload(file.name(), url, this);
     recent->addURL(url);
     recent->saveEntries(KGlobal::config());
 }
