@@ -11,7 +11,7 @@
  *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <stdio.h>
@@ -42,9 +42,7 @@
 #include "newgamedlg.h"
 #include "player.h"
 #include "playerbox.h"
-
 #include "version.h"
-
 #include "kpoker.h"
 #include "defines.h"
 
@@ -56,6 +54,8 @@ kpok::kpok(QWidget *parent, const char *name) : QWidget(parent, name)
 {
 	QString version;
 
+	lastHandText = "";
+
         version = kapp->caption() + " " + KPOKER_VERSION;
 	setCaption( version );
 
@@ -94,20 +94,20 @@ kpok::~kpok()
  delete[] playerBox;// necessary?
  delete[] allPlayers;
  delete[] done;
- if (mOptions != 0)
-	delete mOptions;
- if (newGameDlg != 0)
-	delete newGameDlg;
+ delete mOptions;
+ delete newGameDlg;
  player.clear();
  removedPlayers.clear();
 }
 
 void kpok::newGame()
 {
+ lastHandText = "";
  newGameDlg = new NewGameDlg(this);
  newGameDlg->hideReadingFromConfig();
  if (newGameDlg->exec()) {
 	stopBlinking();
+	stopDrawing();
 	stopWave();
 	int players = DEFAULT_PLAYERS;
 	//delete the old values
@@ -131,6 +131,8 @@ void kpok::newGame()
 	paintCash();
 	delete newGameDlg;
 	newGameDlg = 0;
+	drawButton->setText(i18n("&Draw"));
+	drawButton->setEnabled(true);
  }
  else {
 	delete newGameDlg;
@@ -231,6 +233,7 @@ void kpok::bet()
 				playerBet = player.at(i)->raise(currentMustBet);
 			if (playerBet < currentMustBet) { // playerBet == 0
 				removePlayerFromRound(player.at(i));
+				if (getStatus() == statBet) pot += minBet;
 				i--;
 			}
 			else {
@@ -310,7 +313,7 @@ else if (getStatus() == statContinueBet || getStatus() == statContinueRaise) {
 // TODO: port to players > 2
 // this is ONLY working for players <= 2
  if (removedPlayers.count() >= 1 && player.count() == 1)
-	displayWinner_Computer(player.at(0));
+	displayWinner_Computer(player.at(0), true);
 }
 
 void kpok::out()
@@ -352,8 +355,6 @@ return ;
 void kpok::initPoker(int players, Player* ownAllPlayers)
 {
  allPlayersNr = players; //currently anly used for deleting
- QFont myFixedFont;
- myFixedFont.setPointSize(12);
 
 // read some defaults
  kapp->config()->setGroup("General");
@@ -419,13 +420,13 @@ void kpok::initPoker(int players, Player* ownAllPlayers)
  wonLabel->hide();
  emit showClickToHold(false);
  if (player.count() > 1) {
-	emit changeLastHand(i18n("Nobody"), false);
+	setHand(i18n("Nobody"), false);
  	betBox->show();
 	betBox->setEnabled(false);
 	potLabel->show();
  }
  else {
-	emit changeLastHand(i18n("Nothing"));
+	setHand(i18n("Nothing"));
  	betBox->hide();
 	potLabel->hide();
 	playerBox[0]->onePlayerGame(cashPerRound);
@@ -445,7 +446,7 @@ void kpok::initPoker(int players, Player* ownAllPlayers)
  paintCash();
  playerBox[0]->setHeldEnabled(false);
 
- 
+
 // setFixedSize(sizeHint());
 }
 
@@ -460,15 +461,18 @@ void kpok::paintCash()
 
 void kpok::updateLHLabel()
 {
-if (getPlayers() > 1)
-	emit changeLastHand(i18n("Nobody"), false);
-else
-	emit changeLastHand(i18n("Nothing"));
+	if (lastHandText != "")
+		setHand(lastHandText);
+	else if (getPlayers() > 1)
+		setHand(i18n("Nobody"), false);
+	else
+		setHand(i18n("Nothing"));
 }
 
 void kpok::setHand(const QString& newHand, bool lastHand)
 {
  emit changeLastHand(newHand, lastHand);
+ lastHandText = newHand;
 }
 
 void kpok::toggleHeld()
@@ -541,10 +545,8 @@ void kpok::drawClick()
 	if (getStatus() == statSee)
 		drawClick();
  }
- else if (getStatus() == statSee) {
+ else if (getStatus() == statSee)
 	winner();
- 	drawButton->setText(i18n("&Draw"));
- }
 }
 
 void kpok::drawCards(Player* p, bool skip[], bool done[])
@@ -576,7 +578,7 @@ p->takeCard(4, 27);
 } */
 }
 
-void kpok::displayWinner_Computer(Player* winner)
+void kpok::displayWinner_Computer(Player* winner, bool othersPassed)
 {
 // which box?
  for (int unsigned i = 0; i < player.count() + removedPlayers.count(); i++) {
@@ -585,28 +587,38 @@ void kpok::displayWinner_Computer(Player* winner)
  }
 
  winner->setCash(winner->getCash() + pot);
+ QString label;
+ if (winner->getHuman())
+   label = i18n("You won %1").arg(KGlobal::locale()->formatMoney(pot));
+ else
+   label = i18n("%1 won %2").arg(winner->getName()).arg(KGlobal::locale()->formatMoney(pot));
+ wonLabel->setText(label);
+ QFont waveFont;
+ waveFont.setBold(true);
+ waveFont.setPointSize(16);
+ QFontMetrics tmp(waveFont);
+ mWonWidget->setMinimumWidth(tmp.width(label) + 20);
  if (winner->getHuman()) {
   	playSound("win.wav");
-   	wonLabel->setText(i18n("You won %1").arg(KGlobal::locale()->formatMoney(pot)));
- 	wonLabel->show();
  	wonLabel->hide();
 	startWave();
  }
  else {
   	playSound("lose.wav");
-   	wonLabel->setText(i18n("%1 won %2").arg(winner->getName()).arg(KGlobal::locale()->formatMoney(pot)));
 	wonLabel->show();
  }
 
  pot = 0;
  setStatus(statDraw);
  drawButton->setEnabled(true);
- emit changeLastHand(winner->getName(), false);
+ setHand(winner->getName(), false);
  paintCash();
 
 //only start blinking if player 1 is not out
- if (player.contains(&allPlayers[0]))
+ if (player.contains(&allPlayers[0]) && !othersPassed)
  	startBlinking();
+
+ drawButton->setText(i18n("&Draw"));
 }
 
 void kpok::showComputerCards()
@@ -735,6 +747,11 @@ void kpok::stopWave()
    waveActive = false;
 }
 
+void kpok::stopDrawing()
+{
+    drawTimer->stop();
+}
+
 void kpok::waveTimerEvent()
 {
    fCount = (fCount + 1) & 15;
@@ -758,7 +775,7 @@ void kpok::displayWin(const QString& hand, int cashWon)
 {
  QString buf;
 
- emit changeLastHand(hand);
+ setHand(hand);
  player.at(0)->setCash(player.at(0)->getCash() + cashWon);
  paintCash();
 
@@ -882,7 +899,7 @@ void kpok::switchToOnePlayerRules()
  betBox->hide();
  potLabel->hide();
  playerBox[0]->onePlayerGame(cashPerRound);
- emit changeLastHand(i18n("Nothing"));
+ setHand(i18n("Nothing"));
 // drawButton->move(this->width() /2 - drawButton->width() /2, drawButton->y()+20);
 // setFixedSize(PLAYERBOX_WIDTH, player.count() * PLAYERBOX_HEIGHT + 10 + 20 + drawButton->height()); // or the rest of the window will only be empty :-(
 }
@@ -990,10 +1007,11 @@ void kpok::saveGame()
 
 void kpok::saveGame(KConfig* conf)
 {
- kdWarning() << "save game" << endl;
+// kdWarning() << "save game" << endl;
  int players = allPlayersNr;
 
  conf->writeEntry("players", players);
+ conf->writeEntry("lastHandText", lastHandText);
 
  for (int i = 0; i < players; i++) {
 	conf->writeEntry(QString("Name_%1").arg(i), allPlayers[i].getName());
@@ -1024,7 +1042,8 @@ void kpok::toggleAdjust() { setAdjust(!adjust); }
 
 void kpok::slotPreferences()
 {
- mOptions = new OptionsDlg(this, 0, player.count() + removedPlayers.count());
+ if ( mOptions==0 )
+        mOptions = new OptionsDlg(this, 0, player.count() + removedPlayers.count());
  if (player.count() + removedPlayers.count() > 1)
 	mOptions->init(drawDelay, maxBet, minBet);
  else
@@ -1038,7 +1057,7 @@ void kpok::slotPreferences()
 void kpok::setAdjust(bool ad)
 {
  adjust = ad;
- 
+
 //update guessed money statusbar if we currently are in need of adjust
  if (getStatus() == statContinueBet || getStatus() == statContinueRaise) {
 	if (adjust)
@@ -1094,8 +1113,9 @@ bool kpok::loadGame(KConfig* conf)
 
  bool oldGame = false;
 
-// conf->setGroup("Save");
+ // conf->setGroup("Save");
  players = conf->readNumEntry("players", -1);
+
  if (players > 0) {
  	newPlayers = new Player[players];
  	newPlayers[0].initCardHelp();
@@ -1114,6 +1134,9 @@ bool kpok::loadGame(KConfig* conf)
 	}
 	oldGame = true;
 	initPoker(players, newPlayers);
+	// after initPoker because initPoker does a default initialization of lastHandText
+	conf->setGroup("Save");
+	lastHandText = conf->readEntry("lastHandText", "");
 	return true;
  }
  else
@@ -1135,17 +1158,17 @@ void kpok::exchangeCard5()
 void kpok::slotCardDeck()
 {
  kapp->config()->setGroup("General");
- QString deckPath = kapp->config()->readEntry("DeckPath", 0);
- QString cardPath = kapp->config()->readEntry("CardPath", 0);
+ QString deckPath = kapp->config()->readPathEntry("DeckPath", 0);
+ QString cardPath = kapp->config()->readPathEntry("CardPath", 0);
  bool randomDeck, randomCardDir;
- 
- if (KCardDialog::getCardDeck(deckPath, cardPath, this, KCardDialog::Both, 
+
+ if (KCardDialog::getCardDeck(deckPath, cardPath, this, KCardDialog::Both,
 		&randomDeck, &randomCardDir) == QDialog::Accepted) { // TODO make selecting of cards possible
 	loadDeck(deckPath);
 	loadCards(cardPath);
-	kapp->config()->writeEntry("DeckPath", deckPath);
+	kapp->config()->writePathEntry("DeckPath", deckPath);
 	kapp->config()->writeEntry("RandomDeck", randomDeck);
-	kapp->config()->writeEntry("CardPath", cardPath);
+	kapp->config()->writePathEntry("CardPath", cardPath);
 	kapp->config()->writeEntry("RandomCardDir", randomCardDir);
 
  }
