@@ -11,7 +11,7 @@
  *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KPOKER_H
@@ -116,13 +116,20 @@ protected:
 	void setLastWinner(const QString& lastWinner);
 	void startBlinking();
 	void stopBlinking();
+	void stopDrawing();
 	void result();
 	void winner();
 	
 	void bet();
 
 	void displayWin(const QString& hand, int cashWon);
-	void displayWinner_Computer(Player* winner);
+
+	/**
+	  * Displays the winner, adds the pot to his money
+	  *
+	  * othersPassed = true means all the other players didn't bet
+	 **/
+	void displayWinner_Computer(Player* winner, bool othersPassed);
 	
 	void removePlayerFromRound(Player* removePlayer);
 	void switchToOnePlayerRules();
@@ -258,6 +265,8 @@ private:
 	bool          waveActive;
 	int           fCount;
 
+	QString lastHandText;
+
 	Status status;
 
 	int minBet; // the money the player will bet if he wants or not
