@@ -11,9 +11,9 @@
  *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-    
+
 #include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
@@ -26,29 +26,26 @@ static const char *description = I18N_NOOP("KDE Poker Game");
 
 int main( int argc, char *argv[] )
 {
-	KAboutData aboutData("kpoker", I18N_NOOP("KPoker"), 
-		KPOKER_VERSION, description, KAboutData::License_GPL, 
-		"(c) 1997-2000 Jochen Tuchbreiter, Andreas Beckermann", 
+	KAboutData aboutData("kpoker", I18N_NOOP("KPoker"),
+		KPOKER_VERSION, description, KAboutData::License_GPL,
+		"(c) 1997-2000 Jochen Tuchbreiter, Andreas Beckermann",
 		I18N_NOOP("For a full list of credits see helpfile\nAny suggestions, bug reports etc. are welcome"));
 
-	aboutData.addAuthor("Andreas Beckermann", 
+	aboutData.addAuthor("Andreas Beckermann",
 			I18N_NOOP("Current maintainer"), "b_mann@gmx.de");
-	aboutData.addAuthor("Jochen Tuchbreiter", 
+	aboutData.addAuthor("Jochen Tuchbreiter",
 			I18N_NOOP("Original author"), "whynot@mabi.de");
 	KCmdLineArgs::init( argc, argv, &aboutData );
 
 	KApplication myApp;
 	KGlobal::locale()->insertCatalogue("libkdegames");
-	 
-	
-	if (myApp.isRestored()) {
+
+	if (myApp.isRestored())
 		RESTORE(PokerWindow)
-	}
 	else {
 		PokerWindow *MainScreen = new PokerWindow;
 		myApp.setMainWidget( MainScreen );
 		MainScreen->show();
 	}
-
 	return myApp.exec();
 }
