@@ -11,7 +11,7 @@
  * 
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <stdio.h>
@@ -40,6 +40,7 @@ Player::~Player()
  delete[] card;
  delete[] foundCards;
  delete[] cardHelp;
+ cardHelp = 0; //this is NECESSARY don't delete this line
 }
 
 void Player::giveCardsBack()
@@ -62,8 +63,7 @@ void Player::exchangeCards(bool skip[])
 
 void Player::newRound()
 {
- for (int i = 0; i < CARDS; i++)
- 	giveCardBack(i);
+ giveCardsBack();
  currentBet = 0;
  isOut = false;
 }
