@@ -11,8 +11,8 @@
  *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */  
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ */
 
 // QT includes
 #include <qkeycode.h>
@@ -36,25 +36,23 @@
 #include "top.h"
 #include "kpoker.h"
 #include "defines.h"
-
 #include "version.h"
 
-PokerWindow::PokerWindow() : KMainWindow(0)
+PokerWindow::PokerWindow()
 {
-        setCaption("");
 	_kpok = new kpok(this, 0);
 	setCentralWidget( _kpok );
 	_kpok->show();
-	
+
 	clickToHoldIsShown = false;
 
 	LHLabel = new QLabel(statusBar());
 	LHLabel->adjustSize();
-	connect(_kpok, SIGNAL(changeLastHand(QString, bool)), this, 
+	connect(_kpok, SIGNAL(changeLastHand(QString, bool)), this,
 			SLOT(setHand(QString, bool)));
-	connect(_kpok, SIGNAL(showClickToHold(bool)), this, 
+	connect(_kpok, SIGNAL(showClickToHold(bool)), this,
 			SLOT(showClickToHold(bool)));
-	connect(_kpok, SIGNAL(statusBarMessage(QString)), this, 
+	connect(_kpok, SIGNAL(statusBarMessage(QString)), this,
 			SLOT(statusBarMessage(QString)));
 	statusBar()->addWidget(LHLabel, 0, true);
 	_kpok->updateLHLabel();
@@ -76,41 +74,46 @@ void PokerWindow::initKAction()
  KStdGameAction::quit(this, SLOT(close()), actionCollection());
 
 //Settings
- KStdAction::showMenubar(this, SLOT(toggleMenubar()), actionCollection());
- KStdAction::showStatusbar(this, SLOT(toggleStatusbar()), actionCollection());
+ createStandardStatusBarAction();
+ setStandardToolBarMenuEnabled(true);
+ 
+ showMenubarAction =
+     KStdAction::showMenubar(this, SLOT(toggleMenubar()), actionCollection());
  KStdAction::keyBindings(this, SLOT(slotKeyBindings()), actionCollection());
- KToggleAction* sound = new KToggleAction(i18n("Soun&d"), 0, _kpok, 
-		SLOT(toggleSound()), actionCollection(), "options_sound");
- if (sound->isChecked() != _kpok->getSound())
+ soundAction = new KToggleAction(i18n("Soun&d"), 0, _kpok,
+                    SLOT(toggleSound()), actionCollection(), "options_sound");
+ if (_kpok->getSound())
 	_kpok->toggleSound();
- KToggleAction* blinking = new KToggleAction(i18n("&Blinking Cards"), 0, _kpok, 
+ blinkingAction = new KToggleAction(i18n("&Blinking Cards"), 0, _kpok,
 		SLOT(toggleBlinking()), actionCollection(), "options_blinking");
- if (blinking->isChecked() != _kpok->getBlinking())
+ if (_kpok->getBlinking())
 	_kpok->toggleBlinking();
- KToggleAction* adjust = new KToggleAction(i18n("&Adjust Bet is Default"), 0,
-		_kpok, SLOT(toggleAdjust()), actionCollection(), 
-		"options_adjust");
- if (adjust->isChecked() != _kpok->getAdjust())
+ adjustAction = new KToggleAction(i18n("&Adjust Bet is Default"), 0,
+		_kpok, SLOT(toggleAdjust()), actionCollection(), "options_adjust");
+ if (_kpok->getAdjust())
 	_kpok->toggleAdjust();
 
+ showStatusbarAction =
+     KStdAction::showStatusbar(this, SLOT(toggleStatusbar()), actionCollection());
+
  KStdAction::saveOptions(this, SLOT(saveOptions()), actionCollection());
  KStdGameAction::carddecks(_kpok, SLOT(slotCardDeck()), actionCollection());
  KStdAction::preferences(_kpok, SLOT(slotPreferences()), actionCollection());
 
- (void)new KAction(i18n("Draw"), KShortcut(Qt::Key_Return), _kpok, 
+ (void)new KAction(i18n("Draw"), KShortcut(Qt::Key_Return), _kpok,
 		SLOT(drawClick()), actionCollection(), "draw");
- (void)new KAction(i18n("Exchange Card 1"), KShortcut(Qt::Key_1), _kpok, 
+ (void)new KAction(i18n("Exchange Card 1"), KShortcut(Qt::Key_1), _kpok,
 		SLOT(exchangeCard1()), actionCollection(), "exchange_card_1");
- (void)new KAction(i18n("Exchange Card 2"), KShortcut(Qt::Key_2), _kpok, 
+ (void)new KAction(i18n("Exchange Card 2"), KShortcut(Qt::Key_2), _kpok,
 		SLOT(exchangeCard2()), actionCollection(), "exchange_card_2");
- (void)new KAction(i18n("Exchange Card 3"), KShortcut(Qt::Key_3), _kpok, 
+ (void)new KAction(i18n("Exchange Card 3"), KShortcut(Qt::Key_3), _kpok,
 		SLOT(exchangeCard3()), actionCollection(), "exchange_card_3");
- (void)new KAction(i18n("Exchange Card 4"), KShortcut(Qt::Key_4), _kpok, 
+ (void)new KAction(i18n("Exchange Card 4"), KShortcut(Qt::Key_4), _kpok,
 		SLOT(exchangeCard4()), actionCollection(), "exchange_card_4");
- (void)new KAction(i18n("Exchange Card 5"), KShortcut(Qt::Key_5), _kpok, 
+ (void)new KAction(i18n("Exchange Card 5"), KShortcut(Qt::Key_5), _kpok,
 		SLOT(exchangeCard5()), actionCollection(), "exchange_card_5");
 
- createGUI("kpokerui.rc");
+ createGUI();
 }
 
 void PokerWindow::readOptions()
@@ -119,29 +122,24 @@ void PokerWindow::readOptions()
  conf->setGroup("General");
 
  if (_kpok->getSound() != conf->readBoolEntry("Sound", true))
-	(actionCollection()->action("options_sound"))->activate();
+	soundAction->activate();
  if (_kpok->getBlinking() != conf->readBoolEntry("Blinking", true))
-	(actionCollection()->action("options_blinking"))->activate();
+	blinkingAction->activate();
  if (_kpok->getAdjust() != conf->readBoolEntry("Adjust", true))
-	(actionCollection()->action("options_adjust"))->activate();
-
- if ( ((KToggleAction*)actionCollection()->action(
-		KStdAction::stdName(KStdAction::ShowMenubar)))->isChecked() !=
-		conf->readBoolEntry("ShowMenuBar", true))
-	(actionCollection()->action(KStdAction::stdName(
-			KStdAction::ShowMenubar)))->activate();
- if ( ((KToggleAction*)actionCollection()->action(
-		KStdAction::stdName(KStdAction::ShowStatusbar)))->isChecked() !=
-		conf->readBoolEntry("ShowStatusbar", true))
-	(actionCollection()->action(KStdAction::stdName(
-			KStdAction::ShowStatusbar)))->activate();
+	adjustAction->activate();
+ if ( showMenubarAction->isChecked() !=
+      conf->readBoolEntry("ShowMenubar", true))
+     showMenubarAction->activate();
+ if ( showStatusbarAction->isChecked() !=
+      conf->readBoolEntry("ShowStatusbar", true))
+	showStatusbarAction->activate();
 }
 
 void PokerWindow::toggleMenubar()
 {
  if (!menuBar()->isHidden())
 	menuBar()->hide();
- else 
+ else
 	menuBar()->show();
 }
 
@@ -153,39 +151,36 @@ void PokerWindow::toggleStatusbar()
 	statusBar()->show();
 }
 
-void PokerWindow::saveProperties(KConfig* conf)
+
+/*void PokerWindow::saveProperties(KConfig* conf)
 {
 // conf->writeEntry("Sound", optionsPopup->isItemChecked(ID_SOUND));
 // conf->writeEntry("Blinking", optionsPopup->isItemChecked(ID_BLINKING));
 // conf->writeEntry("Adjust", optionsPopup->isItemChecked(ID_ADJUST));
- conf->writeEntry("Sound", ((KToggleAction*)actionCollection()->action(
-		"options_sound"))->isChecked());
- conf->writeEntry("Blinking", ((KToggleAction*)actionCollection()->action(
-		"options_blinking"))->isChecked());
- conf->writeEntry("Adjust", ((KToggleAction*)actionCollection()->action(
-		"options_adjust"))->isChecked());
+ conf->writeEntry("Sound", soundAction->isChecked());
+ conf->writeEntry("Blinking", blinkingAction->isChecked());
+ conf->writeEntry("Adjust", adjustAction->isChecked());
 // and further? - save the game?
  _kpok->saveGame(conf);
-}
+}*/
 
-void PokerWindow::readProperties(KConfig* conf)
+/*void PokerWindow::readProperties(KConfig* conf)
 {
  bool i;
  i = conf->readBoolEntry("Sound", SOUND_DEFAULT);
  _kpok->setSound(i);
- ((KToggleAction*)actionCollection()->action("options_sound"))->setChecked(i);
+ soundAction->setChecked(i);
 
  i = conf->readBoolEntry("Blinking", BLINKING_DEFAULT);
  _kpok->setBlinking(i);
- ((KToggleAction*)actionCollection()->action("options_blinking"))->
-		setChecked(i);
-		
+ blinkingAction->setChecked(i);
+
  i = conf->readBoolEntry("Adjust", ADJUST_DEFAULT);
  _kpok->setAdjust(i);
- ((KToggleAction*)actionCollection()->action("options_adjust"))->setChecked(i);
+ adjustAction->setChecked(i);
 
  _kpok->loadGame(conf);
-}
+}*/
 
 bool PokerWindow::queryClose()
 {
@@ -202,7 +197,7 @@ bool PokerWindow::queryClose()
 
 void PokerWindow::setHand(QString newHand, bool lastHand)
 {
- if (lastHand) 
+ if (lastHand)
 	LHLabel->setText(i18n("Last hand: ") + newHand);
  else
 	LHLabel->setText(i18n("Last winner: ") + newHand);
@@ -239,16 +234,11 @@ void PokerWindow::saveOptions()
  KConfig* conf = kapp->config();
  conf->setGroup("General");
 
- conf->writeEntry("Sound", ((KToggleAction*)actionCollection()->action(
-		"options_sound"))->isChecked());
- conf->writeEntry("Blinking", ((KToggleAction*)actionCollection()->action(
-		"options_blinking"))->isChecked());
- conf->writeEntry("Adjust", ((KToggleAction*)actionCollection()->action(
-		"options_adjust"))->isChecked());
- conf->writeEntry("ShowMenubar", ((KToggleAction*)actionCollection()->action(
-		KStdAction::stdName(KStdAction::ShowMenubar)))->isChecked());
- conf->writeEntry("ShowStatusbar", ((KToggleAction*)actionCollection()->action(
-		KStdAction::stdName(KStdAction::ShowStatusbar)))->isChecked());
+ conf->writeEntry("Sound", soundAction->isChecked());
+ conf->writeEntry("Blinking", blinkingAction->isChecked());
+ conf->writeEntry("Adjust", adjustAction->isChecked());
+ conf->writeEntry("ShowMenubar", showMenubarAction->isChecked());
+ conf->writeEntry("ShowStatusbar", showStatusbarAction->isChecked());
 }
 
 bool PokerWindow::eventFilter(QObject*, QEvent* e)
@@ -272,4 +262,5 @@ void PokerWindow::slotKeyBindings()
 {
  KKeyDialog::configure(actionCollection(), this);
 }
+
 #include "top.moc"
