@@ -11,7 +11,7 @@
  *
  *     You should have received a copy of the GNU General Public License
  *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef __PokerWindow__
@@ -20,10 +20,7 @@
 #include <kmainwindow.h>
 
 class QLabel;
-
-class KMenuBar;
-class KToolBar;
-class KStatusBar;
+class KToggleAction;
 class kpok;
 
 class PokerWindow : public KMainWindow
@@ -31,13 +28,14 @@ class PokerWindow : public KMainWindow
 	Q_OBJECT
 private:
 	kpok            *_kpok;
+    KToggleAction *soundAction, *blinkingAction, *adjustAction, *showMenubarAction, *showStatusbarAction;
 
 	// statusbar elements:
 	QLabel		*LHLabel;
-	
+
 protected slots:
-        void saveProperties(KConfig*);
-        void readProperties(KConfig*);
+//     void saveProperties(KConfig*);
+//     void readProperties(KConfig*);
 	void setHand(QString newHand, bool lastHand = true);
 	void showClickToHold(bool show);
 	void statusBarMessage(QString);
@@ -46,7 +44,7 @@ protected slots:
 	void toggleMenubar();
 	void toggleStatusbar();
 	void slotKeyBindings();
-	
+
 public:
 	PokerWindow();
 	~PokerWindow();
