@@ -15,7 +15,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -42,6 +42,7 @@
 #include <kstdaction.h>
 #include <kaction.h>
 #include <kdebug.h>
+#include <kkeydialog.h>
 
 #include "KSameWidget.h"
 #include "StoneWidget.h"
@@ -62,7 +63,7 @@ KSameWidget::KSameWidget() : KMainWindow(0)
 	new KAction(i18n("S&how Highscore"), CTRL+Key_H, this,
 				SLOT(m_showhs()), actionCollection(), "game_highscores");
 	KStdAction::quit(this, SLOT(m_quit()), actionCollection(), "game_quit");
-
+        KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
 	undo = KStdAction::undo(this, SLOT(m_undo()),
 							actionCollection(), "edit_undo");
 
@@ -103,6 +104,11 @@ KSameWidget::KSameWidget() : KMainWindow(0)
 KSameWidget::~KSameWidget() {
 }
 
+void KSameWidget::slotConfigureKeys()
+{
+  KKeyDialog::configure( actionCollection(), this );
+}
+
 void KSameWidget::readProperties(KConfig *conf) {
   Q_ASSERT(conf);
   stone->readProperties(conf);
@@ -137,16 +143,16 @@ void KSameWidget::m_new() {
 		if (confirmAbort())
 			newGame(kapp->random(),default_colors);
 	} else {
-		KDialogBase dlg(this, "boardchooser", true, 
-		                i18n("Select Board"), 
-		                KDialogBase::Ok | KDialogBase::Cancel, 
+		KDialogBase dlg(this, "boardchooser", true,
+		                i18n("Select Board"),
+		                KDialogBase::Ok | KDialogBase::Cancel,
 		                KDialogBase::Ok);
-		
+
 		QVBox *page = dlg.makeVBoxMainWidget();
-		
+
 		KIntNumInput bno(0, page);
 		bno.setRange(0, 1000000, 1);
-		bno.setLabel(i18n("Select a board"));
+		bno.setLabel(i18n("Select a board:"));
 		bno.setFocus();
 		bno.setFixedSize(bno.sizeHint());
 		bno.setValue(stone->board());
@@ -207,7 +213,7 @@ void KSameWidget::setMarked(int m) {
 }
 
 void KSameWidget::stonesRemoved(int,int) {
-	KNotifyClient::event("stones removed",
+	KNotifyClient::event(winId(), "stones removed",
 	   i18n("%1 stones removed.").arg(stone->marked()));
 }
 
@@ -220,11 +226,11 @@ void KSameWidget::setScore(int score) {
 void KSameWidget::gameover() {
   kdDebug() << "GameOver" << endl;
   if (stone->hasBonus()) {
-	  KNotifyClient::event("game won",
+	  KNotifyClient::event(winId(), "game won",
 		  i18n("You even removed the last stone, great job! "
 			   "This gave you a score of %1 in total.").arg(stone->score()));
   } else {
-	  KNotifyClient::event("game over",
+	  KNotifyClient::event(winId(), "game over",
 		  i18n("There are no more removeable stones. "
 			   "You got a score of %1 in total.").arg(stone->score()));
   }
@@ -234,7 +240,7 @@ void KSameWidget::gameover() {
 
   KScoreDialog::FieldInfo scoreInfo;
   scoreInfo[Board].setNum(stone->board());
-  
+
   if (d.addScore(stone->score(), scoreInfo))
     d.exec();
 }
