@@ -15,7 +15,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -48,9 +48,9 @@ protected:
 
      virtual void saveProperties(KConfig *conf);
      virtual void readProperties(KConfig *conf);
-	
+
      bool confirmAbort();
-	
+
   public slots:
      void sizeChanged();
 
@@ -72,6 +72,8 @@ protected:
      void setScore(int score);
      void setMarked(int m);
      void stonesRemoved(int,int);
+    void slotConfigureKeys();
+
 };
 
 
