@@ -38,8 +38,6 @@
 
 #include <kapplication.h>
 #include <kconfig.h>
-#include <klocale.h>
-#include <kglobal.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 
@@ -51,21 +49,21 @@ static const char *description = I18N_NOOP("KDE Game");
 
 int main(int argc, char **argv)
 {
-  KAboutData aboutData( "kshisen", I18N_NOOP("Shisen-Sho"), 
-    KSHISEN_VERSION, description, KAboutData::License_GPL, 
-    "(c) 1997, Mario Weilguni");
-  aboutData.addAuthor("Dave Corrie", 0, "kde@davecorrie.com");
-  aboutData.addAuthor("Mario Weilguni",0, "mweilguni@sime.com");
-  aboutData.addCredit("Jason Lane", 0, "jglane@btopenworld.com");
-  KCmdLineArgs::init( argc, argv, &aboutData );
+	KAboutData aboutData( "kshisen", I18N_NOOP("Shisen-Sho"),
+		KSHISEN_VERSION, description, KAboutData::License_GPL,
+		"(c) 1997, Mario Weilguni");
+	aboutData.addAuthor("Dave Corrie", I18N_NOOP("Current Maintainer"), "kde@davecorrie.com");
+	aboutData.addAuthor("Mario Weilguni", I18N_NOOP("Original Author"), "mweilguni@sime.com");
+	aboutData.addCredit("Jason Lane", I18N_NOOP("Added 'tiles removed' counter\nTile smooth-scaling and window resizing"), "jglane@btopenworld.com");
+	aboutData.addCredit(0, I18N_NOOP("Thanks also to everyone who should be listed here but isn't!"), 0);
+	KCmdLineArgs::init( argc, argv, &aboutData );
 
-  KApplication a;
-  KGlobal::locale()->insertCatalogue("libkdegames");
+	KApplication a;
+	KGlobal::locale()->insertCatalogue("libkdegames");
 
-  App *app = new App();
-  app->resize(800, 500);
-  app->show();
-  a.setMainWidget(app);
-  a.config()->sync();
-  return a.exec();
+	App *app = new App();
+	app->show();
+	a.setMainWidget(app);
+	a.config()->sync();
+	return a.exec();
 }
