@@ -3,22 +3,21 @@
 
 #include <klocale.h>
 #include <kapplication.h>
+#include <khighscore.h>
 
 #include "common/inter.h"
 #include "common/highscores.h"
-#include "board.h"
+#include "prefs.h"
 #include "piece.h"
-#include "ai.h"
-#include "field.h"
 
 
 //-----------------------------------------------------------------------------
 const MPGameInfo MP_GAME_INFO = {
-        "005", // multiplayer id (increase when incompatible changes are made
-        4,     // max nb local games
-        500,   // interval
-        TRUE,  // IA allowed
-        0, 0   // no setting slots
+    "006", // multiplayer id (increase when incompatible changes are made)
+    4,     // max nb local games
+    500,   // interval
+    true,  // IA allowed
+    0, 0   // no setting slots
 };
 
 const MainData MAIN_DATA = {
@@ -27,8 +26,8 @@ const MainData MAIN_DATA = {
     I18N_NOOP("KSirtet is an adaptation of the well-known Tetris game."),
     "http://ksirtet.sourceforge.net/",
     I18N_NOOP("Removed lines"),
-    "2.1.6b",
-    "2.1.6b (18 December 2002)"
+    "2.1.8",
+    "2.1.8 (10 March 2004)"
 };
 
 const uint HISTOGRAM_SIZE = 8;
@@ -49,17 +48,19 @@ const BaseBoardInfo BASE_BOARD_INFO = {
     KSBoard::Nb_Stages, // nb arcade stages
 
     HISTOGRAM, HISTOGRAM_SIZE, false, // score is not bound
+
+    4, 100, 15 // min, max and default block size
 };
 
 const CommonBoardInfo COMMON_BOARD_INFO = {
     1000, // base time
-    10,   // drop down time
+    20,   // drop down time
     10,   // before glue time
     10,   // after glue time
     10,   // after gift time
     3,    // nb bump stages
     10,   // nb removed to level
-    3, 3, 800, 2000,  // nb leds, nb max to send, shower timeout, pool timeout
+    3, 3, 800, 2000 // nb leds, nb max to send, shower timeout, pool timeout
 };
 
 KSFactory::KSFactory()
@@ -68,44 +69,26 @@ KSFactory::KSFactory()
 
 BaseInterface *KSFactory::createInterface(QWidget *parent)
 {
-    Interface *inter = new Interface(MP_GAME_INFO, parent);
-    return inter;
+    return new Interface(MP_GAME_INFO, parent);
 }
 
-BaseField *KSFactory::createField(QWidget *parent)
-{
-    Field *field = new KSField(parent);
-    field->settingsChanged();
-    QObject::connect(parent->parent(), SIGNAL(settingsChanged()),
-                     field, SLOT(settingsChanged()));
-    return field;
-}
-
-BaseBoard *KSFactory::createBoard(bool graphic, QWidget *parent)
-{
-	return new KSBoard(graphic, parent);
-}
-
-AI *KSFactory::createAI()
-{
-	return new KSAI(0, 200); // times need tuning ?
-}
-
-
 //-----------------------------------------------------------------------------
 int main(int argc, char **argv)
 {
+    KHighscore::init(MAIN_DATA.name);
     KSFactory ksf;
     ksf.init(argc, argv);
 
     KSPieceInfo pieceInfo;
     CommonHighscores highscores;
 
+    (void) Prefs::self(); // Create preferences
+
     if ( kapp->isRestored() ) RESTORE(KSMainWindow)
     else {
         KSMainWindow *mw = new KSMainWindow;
         kapp->setMainWidget(mw);
         mw->show();
     }
-	return kapp->exec();
+    return kapp->exec();
 }
