@@ -28,11 +28,7 @@ this software.
 #include <kconfig.h>
 #include <kmenubar.h>
 #include <kstatusbar.h>
-#include <qaccel.h>
-#include <qfile.h>
-#include <qpopupmenu.h>
-#include <qpushbutton.h>
-#include <qtextstream.h>
+#include <kkeydialog.h>
 
 #include "ksmiletris.h"
 #include "gamewindow.h"
@@ -50,7 +46,7 @@ const int default_height = 460;
 GameWindow::GameWindow(QWidget *, const char *name)
         : KMainWindow(0, name)
 {
-	setCaption(i18n("Smiletris"));
+	setCaption(i18n("KSmileTris"));
 
 
 
@@ -69,22 +65,21 @@ GameWindow::GameWindow(QWidget *, const char *name)
                                   SLOT(menu_endGame()),
                                   actionCollection());
 
-
         //Highscores
         (void)KStdGameAction::highscores(this,
                                     SLOT(menu_highScores()),
                                     actionCollection());
 
-
+        //Configure Shortcuts
+        (void)KStdAction::keyBindings(this,
+                                    SLOT(menu_keyBindings()),
+                                    actionCollection());
 
         //Quit
-
         (void)KStdGameAction::quit(this,
                                SLOT(close()),
                                actionCollection());
 
-
-
         QStringList list;
         KSelectAction* piecesAct =
           new KSelectAction(i18n("&Pieces"), 0, this, SLOT(menu_pieces()),
@@ -116,6 +111,13 @@ GameWindow::GameWindow(QWidget *, const char *name)
 		this, SLOT(updateStats(int, int)));
 	connect(game, SIGNAL(gameOver()), this, SLOT(gameOver()));
 
+        //keys
+        (void)new KAction(i18n("Move Left"), Key_Left, game, SLOT(keyLeft()), actionCollection(), "left");
+        (void)new KAction(i18n("Move Right"), Key_Right, game, SLOT(keyRight()), actionCollection(), "right");
+        (void)new KAction(i18n("Rotate Left"), Key_Up, game, SLOT(keyUp()), actionCollection(), "up");
+        (void)new KAction(i18n("Rotate Right"), Key_Down, game, SLOT(keyDown()), actionCollection(), "down");
+        (void)new KAction(i18n("Drop Down"), Key_Space, game, SLOT(keySpace()), actionCollection(), "space");
+
 
         //Original
         //resize(default_width, default_height + menu->height() + status->height());
@@ -192,13 +194,18 @@ void GameWindow::menu_sounds()
 	config->writeEntry("Sounds", game->do_sounds);
 }
 
+void GameWindow::menu_keyBindings()
+{
+	KKeyDialog::configure(actionCollection(), this);
+}
+
 void GameWindow::updateStats(int level, int points)
 {
 	QString l, p;
 	l.setNum(level);
 	p.setNum(points);
-	status->changeItem(QString("Level: ") + l, 1);
-	status->changeItem(QString("Score: ") + p, 2);
+	status->changeItem(i18n("Level: %1").arg(l), 1);
+	status->changeItem(i18n("Score: %1").arg(p), 2);
 }
 
 void GameWindow::gameOver()
@@ -206,12 +213,12 @@ void GameWindow::gameOver()
     KScoreDialog d(KScoreDialog::Name | KScoreDialog::Level | KScoreDialog::Score, this);
 
     KScoreDialog::FieldInfo scoreInfo;
-    
+
     scoreInfo[KScoreDialog::Level].setNum(game->num_level);
 
     if (!d.addScore(game->num_points, scoreInfo))
        return;
-    
+
     // Show highscore & ask for name.
     d.exec();
 }
