@@ -7,8 +7,8 @@
 class Ball {
 public:
     Ball(Board *b, PixServer *p);
-	virtual ~Ball() {};
-	virtual void nextMove();
+    virtual ~Ball(){};
+    virtual void nextMove();
     void repaint();
     void zero();
 protected:
@@ -22,15 +22,17 @@ protected:
 class KillerBall : public Ball {
 public:
 	KillerBall(Board *b, PixServer *p) : Ball(b, p) {};
-	virtual ~KillerBall() {};
-	virtual void nextMove();
+    	virtual ~KillerBall(){};
+	void nextMove();
+protected:
+	virtual int getNextSquare();
 };
 
-class DumbKillerBall : public Ball {
+class DumbKillerBall : public KillerBall {
 public:
-	DumbKillerBall(Board *b, PixServer *p) : Ball(b, p) {};
-	virtual ~DumbKillerBall() {};
-	virtual void nextMove();
+	DumbKillerBall(Board *b, PixServer *p) : KillerBall(b, p) {};
+protected:
+	int getNextSquare();
 };
 
 #endif // BALL_H
