@@ -38,7 +38,7 @@
 #include "version.h"
 #include <kaction.h>
 #include <kstdaction.h>
-
+#include <kkeydialog.h>
 
 static const char *description = I18N_NOOP("KDE Snake Race Game");
 
@@ -71,10 +71,21 @@ Game::Game() :  KMainWindow(0)
     setCentralWidget(view);
 }
 
+Game::~Game()
+{
+    delete score;
+    delete levels;
+}
 
 
+void Game::slotConfigureKeys()
+{
+  KKeyDialog::configure( actionCollection(), this );
+}
+
 void Game::menu()
 {
+    KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
     KStdGameAction::gameNew(this, SLOT(newGame()), actionCollection());
     pause = KStdGameAction::pause(this, SLOT(pauseGame()), actionCollection());
     KStdGameAction::highscores(this, SLOT(showHighScores()), actionCollection());
@@ -111,7 +122,7 @@ void Game::menu()
     snakes = new KSelectAction(i18n("&Snakes"), 0, this, SLOT(snakesChecked()),
 			       actionCollection(), "opt_snakes");
     snakes->setItems(list);
-    
+
     snakesAI = new KSelectAction(i18n("Snakes AI"), 0, this, SLOT(snakesAIChecked()),
 				 actionCollection(), "opt_snakesai");
     QStringList sai;
@@ -119,7 +130,7 @@ void Game::menu()
     sai.append(i18n("Eater"));
     sai.append(i18n("Killer"));
     snakesAI->setItems(sai);
-    
+
     new KAction(i18n("Change Keys..."),0, this, SLOT(confKeys()),
 		actionCollection(), "opt_change_keys");
     new KAction(i18n("Starting Room..."), 0, this, SLOT(startingRoom()),
@@ -193,7 +204,7 @@ void Game::pixChecked()
 {
     int x = pix->currentItem();
     conf->writeEntry("Background", 2);
-    conf->writeEntry("BackgroundPixmap",
+    conf->writePathEntry("BackgroundPixmap",
 		     *backgroundPixmaps.at(x));
 
     rattler->reloadRoomPixmap();
@@ -213,7 +224,7 @@ void Game::checkMenuItems()
 
     pix->setCurrentItem(0);
 
-    QString path = conf->readEntry("BackgroundPixmap");
+    QString path = conf->readPathEntry("BackgroundPixmap");
     for ( unsigned int x = 0; x < backgroundPixmaps.count(); x++) {
 	if (path == *backgroundPixmaps.at(x)) {
 	    pix->setCurrentItem( x );
@@ -274,7 +285,7 @@ void Game::confKeys()
 
 void Game::confKeys2()
 {
-	Keys *keys = new Keys(0, 0, 2);
+    Keys *keys = new Keys(0, 0, 2);
     if (keys->exec() == QDialog::Accepted)
 	rattler->initKeys();
     delete keys;
