@@ -19,7 +19,7 @@ class Game : public KMainWindow
     Q_OBJECT
 public:
     Game();
-    ~Game() {}
+      ~Game();
 private slots:
     void ballsChecked();
 	void ballsAIChecked();
@@ -39,6 +39,7 @@ private slots:
 
     void showHighScores();
     void startingRoom();
+      void slotConfigureKeys();
 
 private:
 
