@@ -1,11 +1,11 @@
 #ifndef KEYS_H
 #define KEYS_H
 
-#include <qdialog.h>
+#include <kdialogbase.h>
 #include <qlabel.h>
 #include <qstring.h>
 
-class Keys : public QDialog
+class Keys : public KDialogBase
 {
     Q_OBJECT
 public:
