@@ -21,7 +21,7 @@ class PixServer
 {
 public:
     PixServer (Board *, QWidget *parent=0);
-    QPixmap levelPix() { return cachePix; }
+    QPixmap levelPix() const { return cachePix; }
 
     void initRoomPixmap();
     void initBrickPixmap();
@@ -42,7 +42,7 @@ private:
     QPixmap ballPix[4];
     QPixmap applePix[2];
 
-    QPixmap roomPix; 
+    QPixmap roomPix;
     QPixmap cachePix;
     QPixmap offPix;
     QPixmap backPix;
