@@ -1,7 +1,7 @@
 #include "progress.h"
 
 Progress::Progress(QWidget *parent, const char *name)
-	: KProgress(0, 300, 300, KProgress::Horizontal, parent, name)
+	: KGameProgress(0, 300, 300, KGameProgress::Horizontal, parent, name)
 {
   setBackgroundColor("lightgray");
   setBarColor("green1");
@@ -18,13 +18,13 @@ void Progress::advance()
   else if (value() == 80)
     setBarColor("red1");
 
-  KProgress::advance(-1);
+  KGameProgress::advance(-1);
 }
 
 void Progress::rewind()
 {
   setBarColor("green1");
-  KProgress::setValue(300);
+  KGameProgress::setValue(300);
 }
 
 #include "progress.moc"
