@@ -72,6 +72,17 @@ Rattler::Rattler( QWidget *parent, const char *name )
 
 }
 
+Rattler::~Rattler()
+{
+	delete level;
+	delete balls;
+	delete computerSnakes;
+	delete basket;
+	delete samy;
+	delete pix;
+	delete board;
+}
+
 void Rattler::paintEvent( QPaintEvent *e)
 {
     QRect rect = e->rect();
