@@ -3,15 +3,19 @@
 #include <qobject.h>
 #include <qdatastream.h>
 #include <qstring.h>
-#include <qpushbutton.h>
 #include <qframe.h>
 #include <qlabel.h>
+#include <qlayout.h>
 #include <qgroupbox.h>
 #include <qdatetime.h>
-#include <qlineedit.h>
 
+#include <kdialog.h>
+#include <klineedit.h>
 #include <kglobal.h>
+#include <kglobalsettings.h>
 #include <kstandarddirs.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "score.h"
 #include <klocale.h>
@@ -27,22 +31,22 @@ Score::Score( QWidget *parent, const char *name )
 
 void Score::display(int newHall, int newToday)
 {
-    QDialog *dlg = new QDialog(0, "Hall Of Fame", TRUE);
-    dlg->setCaption(i18n("Snake Race High Scores"));
+    KDialog *dlg = new KDialog(0, "Hall Of Fame", true);
+    dlg->setPlainCaption(i18n("Snake Race High Scores"));
+    QVBoxLayout *lay = new QVBoxLayout(dlg, KDialog::marginHint(), KDialog::spacingHint());
 
     ScoreBox *sb1 = new ScoreBox(dlg, 0, newHall);
-    sb1->setGeometry(10, 5, 400, 225);
     sb1->setTitle(i18n("Hall of Fame"));
+    lay->addWidget(sb1);
 
     ScoreBox *sb2 = new ScoreBox(dlg, 0, newToday);
-    sb2->setGeometry(10, 240, 400, 225);
     sb2->setTitle(i18n("Today's High Scores"));
+    lay->addWidget(sb2);
 
-    QPushButton *b = new QPushButton( dlg);
-    b->setText(i18n("OK"));
-    b->setAutoDefault(TRUE);
+    QPushButton *b = new KPushButton(KStdGuiItem::ok(), dlg);
+    b->setAutoDefault(true);
     b->setFocus();
-    b->move(300, 480);
+    lay->addWidget(b, 0, Qt::AlignHCenter);
     connect( b, SIGNAL(clicked()),dlg, SLOT(accept()) );
 
     for ( int x = 0; x < 5; x++) {
@@ -56,33 +60,34 @@ void Score::display(int newHall, int newToday)
 }
 
 QString Score::getPlayerName() {
-    QDialog *dlg = new QDialog(0, "Hall Of Fame", TRUE);
-    dlg->resize(300, 175);
-    dlg->setCaption(i18n("Snake Race High Scores"));
+    KDialog *dlg = new KDialog(0, "Hall Of Fame", true);
+    dlg->setPlainCaption(i18n("Snake Race High Scores"));
+    QVBoxLayout *lay = new QVBoxLayout(dlg, KDialog::marginHint(), KDialog::spacingHint());
     QLabel *label  = new QLabel(i18n("You have achieved a high score!\nPlease enter your name"),
 				dlg);
     label->setAlignment(AlignCenter);
-    label->setFont( QFont( "Times", 14, QFont::Bold ) );
+    QFont f = KGlobalSettings::generalFont();
+    f.setWeight(QFont::Bold);
+    f.setPointSize(14);
+    label->setFont(f);
+    lay->addWidget(label);
 
-    QLineEdit *le = new QLineEdit(dlg);
-    le->setFocus();
+    KLineEdit *le = new KLineEdit(dlg);
     le->setText(playerName);
     le->selectAll();
+    lay->addWidget(le);
 
-    QFrame *sep = new QFrame( dlg);
+    QFrame *sep = new QFrame(dlg);
     sep->setFrameStyle( QFrame::HLine | QFrame::Sunken );
+    lay->addWidget(sep);
 
-    QPushButton *b = new QPushButton(i18n("OK"), dlg);
-    b->setDefault(TRUE);
-    b->setAutoDefault(TRUE);
+    QPushButton *b = new KPushButton(KStdGuiItem::ok(), dlg);
+    b->setDefault(true);
+    b->setAutoDefault(true);
+    lay->addWidget(b, 0, Qt::AlignHCenter);
     connect(b, SIGNAL(released()), dlg, SLOT(accept()));
     connect(le, SIGNAL(returnPressed()), dlg, SLOT(accept()));
 
-    label->setGeometry(0, 0, 300, 50 );
-    le->setGeometry(50, 65, 200, 25 );
-    sep->setGeometry(0, 100, 400, 25 );
-    b->setGeometry(110, 125, 80, 32 );
-
     dlg->exec();
 
     QString s = le->text();
@@ -94,23 +99,23 @@ void Score::setScore(int s)
 {
     read();
 
-    bool checkHall = FALSE;
-    bool checkToday = FALSE;
+    bool checkHall = false;
+    bool checkToday = false;
     int x, xx;
 
     for ( x = 0; x < 5; x++)
 	if ( s > hall[x].points) {
-	    checkHall = TRUE;
+	    checkHall = true;
 	    break;
 	}
 
     for ( xx = 0; xx < 5; xx++)
 	if ( s > today[xx].points) {
-	    checkToday = TRUE;
+	    checkToday = true;
 	    break;
 	}
 
-    if (checkHall == TRUE || checkToday == TRUE) {
+    if (checkHall || checkToday) {
 
 	playerName  = getPlayerName();
 
@@ -185,32 +190,48 @@ void Score::write()
 ScoreBox::ScoreBox( QWidget *parent, const char *name , int current)
     : QWidget( parent, name )
 {
-    box = new QGroupBox(this);
+    QVBoxLayout *lay = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
 
     label = new QLabel(this);
     label->setFrameStyle( QFrame::Panel   | QFrame::Raised );
-    label->setFont( QFont( "times", 14, QFont::Bold ) );
+    QFont f = KGlobalSettings::generalFont();
+    f.setWeight(QFont::Bold);
+    f.setPointSize(14);
+    label->setFont(f);
     label->setAlignment( AlignCenter );
+    label->setMargin( KDialog::marginHint() );
+    lay->addWidget(label, 0, Qt::AlignHCenter);
+
+    box = new QGroupBox(this);
+    lay->addWidget(box);
+    QGridLayout *lay2 = new QGridLayout(box, 5, 3, KDialog::marginHint(), KDialog::spacingHint());
 
     for ( int x = 0; x < 5; x++) {
 
-	QLabel *l = new QLabel(this);
+	QLabel *l = new QLabel(box);
 	Q_CHECK_PTR(l);
-	l->setFont( QFont( "times", 10) );
+	QFont f1 = KGlobalSettings::generalFont();
+	f1.setPointSize(10);
+	l->setFont(f1);
 	l->setAlignment( AlignRight );
 	date[x] = l;
+	lay2->addWidget(l, x, 0);
 
-	QLabel *l1 = new QLabel(this);
+	QLabel *l1 = new QLabel(box);
 	Q_CHECK_PTR(l1);
-	l1->setFont( QFont( "times", 14) );
+	QFont f2 = KGlobalSettings::generalFont();
+	f2.setPointSize(14);
+	l1->setFont(f2);
 	l1->setAlignment( AlignRight );
 	points[x] = l1;
+	lay2->addWidget(l1, x, 1);
 
-	QLabel *l2 = new QLabel(this);
+	QLabel *l2 = new QLabel(box);
 	Q_CHECK_PTR(l2);
-	l2->setFont( QFont( "times", 14) );
+	l2->setFont(f2);
 	l2->setAlignment( AlignLeft );
 	player[x] = l2;
+	lay2->addWidget(l2, x, 2);
     }
 
     if (current >= 0) {
@@ -245,20 +266,4 @@ void ScoreBox::setScore( int x, int p, const QString &pl, const QString &dt)
     }
 }
 
-void ScoreBox::resizeEvent( QResizeEvent * )
-{
-    box->resize( width(), height() - 40 );
-    box->setGeometry(0, 40, width(), height()-40 );
-
-    label->setGeometry(100, 10, 200, 30 );
-
-    int p = 65;
-    for ( int x = 0; x < 5; x++) {
-	date[x]->setGeometry(10, p, 95, 25);
-	points[x]->setGeometry(105, p, 70, 25);
-	player[x]->setGeometry(195, p, 170, 25);
-	p+= 30;
-    }
-}
-
 #include "score.moc"
