@@ -1,7 +1,6 @@
 #ifndef SCORE_H
 #define SCORE_H
 
-#include <qdialog.h>
 #include <qdatetime.h>
 #include <qwidget.h>
 #include <qlabel.h>
@@ -18,9 +17,6 @@ public:
     void setTitle(const QString &);
     void setScore(int, int, const QString &, const QString&);
 
-protected:
-    void resizeEvent( QResizeEvent * );
-
 private:
     QGroupBox   *box;
     QLabel      *label;
