@@ -40,14 +40,14 @@ protected:
     };
 
     QPtrList<Samy> list;
-    
+
     KRandomSequence random;
 
     void reset(int index, int border);
     void appendSamy();
     void updateSamy();
-    int  tail()        { return (list.count() -1 ); }
-    bool growing()     { return (grow > 0 ? TRUE : FALSE); }
+    int  tail() const       { return (list.count() -1 ); }
+    bool growing() const    { return (grow > 0 ? TRUE : FALSE); }
 
     int   hold;
     int   grow;
