@@ -1,6 +1,5 @@
 #include <stdlib.h>
 
-#include <qpushbutton.h>
 #include <qlabel.h>
 #include <qframe.h>
 #include <qpixmap.h>
@@ -8,10 +7,13 @@
 #include <qdatastream.h>
 #include <qfile.h>
 #include <qstring.h>
+#include "lcdrange.h"
 
 #include "levels.h"
 #include "startroom.h"
 #include <klocale.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 
 StartRoom::StartRoom( int init, int *newRoom, QWidget *parent, const char *name)
@@ -22,14 +24,12 @@ StartRoom::StartRoom( int init, int *newRoom, QWidget *parent, const char *name)
 
     nr = newRoom;
 
-    QPushButton *okButton  = new QPushButton(this);
-    okButton->setText(i18n("OK"));
+    QPushButton *okButton  = new KPushButton(KStdGuiItem::ok(), this);
     okButton->setFixedSize(okButton->size());
     okButton->setGeometry(60,170, 100, 100);
     connect( okButton, SIGNAL(clicked()), SLOT(ok()) );
 
-    QPushButton *cancelButton  = new QPushButton(this);
-    cancelButton->setText(i18n("Cancel"));
+    QPushButton *cancelButton  = new KPushButton( KStdGuiItem::cancel(), this);
     connect( cancelButton, SIGNAL(clicked()), SLOT(accept()) );
     cancelButton->setFixedSize(cancelButton->size());
     cancelButton->setGeometry(180,170, 100, 100);
