@@ -2,6 +2,7 @@
 #include <qstring.h>
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <kstandarddirs.h>
 
 #include "trys.h"
 
@@ -9,7 +10,7 @@
 Trys::Trys( QWidget *parent, const char *name )
         : QWidget( parent, name )
 {
-  pixmap = BarIcon("samy");
+  pixmap = QPixmap(locate("appdata", "pics/samy.png"));
   snakes = 2;
   repaint();
 }
