@@ -1,27 +1,27 @@
 #include "mainview.h"
-#include "topwidget.h"
-#include <qpixmap.h>
-#include <qpoint.h>
+
 #include <math.h>
-#include <qcolor.h>
 #include <qbitmap.h>
+#include <qfile.h>
+#include <qvbox.h>
 
 #include <kapplication.h>
-#include <kaccel.h>
 #include <kaction.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
-#include <kglobal.h>
+#include <kglobalsettings.h>
 #include <kconfig.h>
-#include <qfile.h>
+#include <kiconloader.h>
 
-#include "defines.h"
 #include "ai.h"
+#include "options.h"
 
-MyMainView::MyMainView(QWidget *parent, const char *name)
-      :QWidget(parent,name),
-       field(DEF_WIDTH,DEF_HEIGHT),
-       view(&field,this)
+KToggleAction *MyMainView::pauseAction = 0;
+
+MyMainView::MyMainView(QWidget *parent)
+    :QWidget(parent),
+    field(DEF_WIDTH,DEF_HEIGHT),
+    view(&field,this)
 {
    int i,p;
 
@@ -32,7 +32,7 @@ MyMainView::MyMainView(QWidget *parent, const char *name)
    view.setResizePolicy(QScrollView::AutoOne);
    view.setHScrollBarMode(QScrollView::AlwaysOff);
    view.setVScrollBarMode(QScrollView::AlwaysOff);
-   
+
    for(p=0;p<2;p++)
    {
       for(i=0;i<PlayerKeyNum;i++)
@@ -77,7 +77,7 @@ MyMainView::MyMainView(QWidget *parent, const char *name)
       = loadOldPixmapSequence( tmp + MV_POWERSHIELD_PPM, tmp + MV_POWERSHIELD_PBM );
    powerupsequence[PowerupSprite::PowerupEnergy]
       = loadOldPixmapSequence( tmp + MV_POWERENERGY_PPM, tmp + MV_POWERENERGY_PBM );
-   
+
    for(i=0;i<2;i++)
    {
       // ship[i]->setBoundsAction(QwRealMobileSprite::Wrap);
@@ -88,39 +88,35 @@ MyMainView::MyMainView(QWidget *parent, const char *name)
       mines[i]->setAutoDelete(true);
 
    }
-      
+
    explosions.setAutoDelete(true);
    powerups.setAutoDelete(true);
 
    waitForStart=false;
    textSprite=0;
+   readConfig();
 }
 
 MyMainView::~MyMainView()
 {
    killTimers();
+   writeConfig();
 }
 
-void MyMainView::readConfig(KConfig *cfg)
+void MyMainView::setActionCollection(KActionCollection *a)
 {
+   actionCollection = a;
+}
+
+void MyMainView::readConfig()
+{
+   KConfig *cfg = kapp->config();
    int i;
-   
+
    cfg->setGroup("Game");
-   options.refreshTime=cfg->readUnsignedNumEntry("refreshTime",33);
-   options.lastConfig=cfg->readUnsignedNumEntry("lastConfig",0);
-   
    customConfig.gamespeed=cfg->readDoubleNumEntry("gamespeed",
                                                   predefinedConfig[0].gamespeed);
 
-   options.isAi[0]=cfg->readBoolEntry("player1IsAi",false);
-   options.isAi[1]=cfg->readBoolEntry("player2IsAi",false);
-   options.aiDifficulty[0]=
-      (Difficulty)cfg->readUnsignedNumEntry("ai1Difficulty",(unsigned)DNORMAL);
-   options.aiDifficulty[1]=
-      (Difficulty)cfg->readUnsignedNumEntry("ai2Difficulty",(unsigned)DNORMAL);
-
-   options.timeAfterKill=
-      cfg->readDoubleNumEntry("timeAfterKill",1.3*33);
    customConfig.gravity=
       cfg->readDoubleNumEntry("gravity",predefinedConfig[0].gravity);
    customConfig.acc=
@@ -178,28 +174,13 @@ void MyMainView::readConfig(KConfig *cfg)
       cfg->readDoubleNumEntry("powerupEnergyAmount",
                               predefinedConfig[0].powerupEnergyAmount);
 
-   cfg->setGroup("Player2");
-   options.playerKey[1][PlayerKeyLeft]=KAccel::stringToKey(cfg->readEntry("KeyLeft","Left"));
-   options.playerKey[1][PlayerKeyRight]=KAccel::stringToKey(cfg->readEntry("KeyRight","Right"));
-   options.playerKey[1][PlayerKeyAcc]=KAccel::stringToKey(cfg->readEntry("KeyAcc","Up"));
-   options.playerKey[1][PlayerKeyShot]=KAccel::stringToKey(cfg->readEntry("KeyShot","Down"));
-   options.playerKey[1][PlayerKeyMine]=KAccel::stringToKey(cfg->readEntry("KeyMine","Insert"));
-   options.startHitPoints[1]=cfg->readUnsignedNumEntry("startHitPoints",99);
-   cfg->setGroup("Player1");
-   options.playerKey[0][PlayerKeyLeft]=KAccel::stringToKey(cfg->readEntry("KeyLeft","S"));
-   options.playerKey[0][PlayerKeyRight]=KAccel::stringToKey(cfg->readEntry("KeyRight","F"));
-   options.playerKey[0][PlayerKeyAcc]=KAccel::stringToKey(cfg->readEntry("KeyAcc","E"));
-   options.playerKey[0][PlayerKeyShot]=KAccel::stringToKey(cfg->readEntry("KeyShot","D"));
-   options.playerKey[0][PlayerKeyMine]=KAccel::stringToKey(cfg->readEntry("KeyMine","A"));
-   options.startHitPoints[0]=cfg->readUnsignedNumEntry("startHitPoints",99);
-   
-   if(options.lastConfig<predefinedConfigNum)
-      config=modifyConfig(predefinedConfig[options.lastConfig]);
+   if(Options::lastConfig() < predefinedConfigNum)
+      config=modifyConfig(predefinedConfig[Options::lastConfig()]);
    else
       config=modifyConfig(customConfig);
 
    for(i=0;i<2;i++)
-      ai[i]=new Ai(i,ship,bullets,mines,&config,&options);
+      ai[i]=new Ai(i,ship,bullets,mines,&config);
 }
 
 void MyMainView::writeConfig()
@@ -207,11 +188,7 @@ void MyMainView::writeConfig()
    KConfig *cfg;
    cfg=KApplication::kApplication()->config();
    cfg->setGroup("Game");
-   cfg->writeEntry("refreshTime",options.refreshTime);
-   cfg->writeEntry("lastConfig",options.lastConfig);
-   cfg->writeEntry("gamespeed",customConfig.gamespeed);
-   cfg->writeEntry("timeAfterKill",options.timeAfterKill);
-      
+
    cfg->writeEntry("gravity",customConfig.gravity);
    cfg->writeEntry("acceleration",customConfig.acc);
    cfg->writeEntry("bulletDamage",customConfig.bulletDamage);
@@ -231,7 +208,7 @@ void MyMainView::writeConfig()
    cfg->writeEntry("mineFuel",customConfig.mineFuel);
    cfg->writeEntry("shotEnergyNeed",customConfig.shotEnergyNeed);
    cfg->writeEntry("mineEnergyNeed",customConfig.mineEnergyNeed);
-      
+
    cfg->writeEntry("startPosX",customConfig.startPosX);
    cfg->writeEntry("startPosY",customConfig.startPosY);
    cfg->writeEntry("startVelX",customConfig.startVelX);
@@ -241,36 +218,12 @@ void MyMainView::writeConfig()
    cfg->writeEntry("powerupRefreshTime",customConfig.powerupRefreshTime);
    cfg->writeEntry("powerupShieldAmount",customConfig.powerupShieldAmount);
    cfg->writeEntry("powerupEnergyAmount",customConfig.powerupEnergyAmount);
-      
-   cfg->setGroup("Player2");
-   cfg->writeEntry("startHitPoints",options.startHitPoints[1]);
-   cfg->setGroup("Player1");
-   cfg->writeEntry("startHitPoints",options.startHitPoints[0]);
-
-   cfg->setGroup("Player2");
-   cfg->writeEntry("KeyLeft",KKey(options.playerKey[1][PlayerKeyLeft]).toStringInternal());
-   cfg->writeEntry("KeyRight",KKey(options.playerKey[1][PlayerKeyRight]).toStringInternal());
-   cfg->writeEntry("KeyAcc",KKey(options.playerKey[1][PlayerKeyAcc]).toStringInternal());
-   cfg->writeEntry("KeyShot",KKey(options.playerKey[1][PlayerKeyShot]).toStringInternal());
-   cfg->writeEntry("KeyMine",KKey(options.playerKey[1][PlayerKeyMine]).toStringInternal());
-   cfg->setGroup("Player1");
-   cfg->writeEntry("KeyLeft",KKey(options.playerKey[0][PlayerKeyLeft]).toStringInternal());
-   cfg->writeEntry("KeyRight",KKey(options.playerKey[0][PlayerKeyRight]).toStringInternal());
-   cfg->writeEntry("KeyAcc",KKey(options.playerKey[0][PlayerKeyAcc]).toStringInternal());
-   cfg->writeEntry("KeyShot",KKey(options.playerKey[0][PlayerKeyShot]).toStringInternal());
-   cfg->writeEntry("KeyMine",KKey(options.playerKey[0][PlayerKeyMine]).toStringInternal());
-   cfg->setGroup("Game");
-
-   cfg->writeEntry("player1IsAi",options.isAi[0]);
-   cfg->writeEntry("player2IsAi",options.isAi[1]);
-   cfg->writeEntry("ai1Difficulty",(unsigned)options.aiDifficulty[0]);
-   cfg->writeEntry("ai2Difficulty",(unsigned)options.aiDifficulty[1]);
 }
 
 SConfig MyMainView::modifyConfig(SConfig conf)
 {
    SConfig newConfig=conf;
-   newConfig.gamespeed*=options.refreshTime/33.0;
+   newConfig.gamespeed*=Options::refreshTime()/33.0;
    newConfig.acc*=newConfig.gamespeed;
    newConfig.rotationSpeed*=newConfig.gamespeed*M_PI/ROTNUM*4;
    newConfig.energyNeed*=newConfig.gamespeed;
@@ -282,10 +235,6 @@ SConfig MyMainView::modifyConfig(SConfig conf)
 
 void MyMainView::keyPressEvent(QKeyEvent *ev)
 {
-   int key=ev->key();
-   int i,p;
-   bool accept=false;
-
    if((gameEnd<=0.0)&&(gameEnd>-2.0))
    {
       /*
@@ -306,6 +255,35 @@ void MyMainView::keyPressEvent(QKeyEvent *ev)
    }
    else
    {
+      KKey key(ev);
+      bool accept=true;
+
+      if(actionCollection->action("P1KeyLeft")->shortcut().contains(key))
+            playerKeyPressed[0][PlayerKeyLeft]=true;
+      else if(actionCollection->action("P2KeyLeft")->shortcut().contains(key))
+            playerKeyPressed[1][PlayerKeyLeft]=true;
+      
+      else if(actionCollection->action("P1KeyRight")->shortcut().contains(key))
+            playerKeyPressed[0][PlayerKeyRight]=true;
+      else if(actionCollection->action("P2KeyRight")->shortcut().contains(key))
+            playerKeyPressed[1][PlayerKeyRight]=true;
+      
+      else if(actionCollection->action("P1KeyAcc")->shortcut().contains(key))
+            playerKeyPressed[0][PlayerKeyAcc]=true;
+      else if(actionCollection->action("P2KeyAcc")->shortcut().contains(key))
+            playerKeyPressed[1][PlayerKeyAcc]=true;
+      
+      else if(actionCollection->action("P1Shot")->shortcut().contains(key))
+            playerKeyPressed[0][PlayerKeyShot]=true;
+      else if(actionCollection->action("P2Shot")->shortcut().contains(key))
+            playerKeyPressed[1][PlayerKeyShot]=true;
+      
+      else if(actionCollection->action("P1Mine")->shortcut().contains(key))
+            playerKeyPressed[0][PlayerKeyMine]=true;
+      else if(actionCollection->action("P2Mine")->shortcut().contains(key))
+            playerKeyPressed[1][PlayerKeyMine]=true;
+      else
+        accept = false;
       /*
       if((key==options.functionKey[FunctionKeyStart])
          && (!functionKeyPressed[FunctionKeyStart]))
@@ -314,42 +292,51 @@ void MyMainView::keyPressEvent(QKeyEvent *ev)
          pause();
       }
       */
-      for(p=0;p<2;p++)
-         for(i=0;i<PlayerKeyNum;i++)
-            if(key==options.playerKey[p][i])
-            {
-               playerKeyPressed[p][i]=true;
-               accept=true;
-            }
       if(!accept)
-         ev->ignore();
+	ev->ignore();
    }
-
 }
 
 void MyMainView::keyReleaseEvent(QKeyEvent *ev)
 {
-   int i,p,key=ev->key();
-   bool accept=false;
+   KKey key(ev);
+   bool accept=true;
+
+   if(actionCollection->action("P1KeyLeft")->shortcut().contains(key))
+      playerKeyPressed[0][PlayerKeyLeft]=false;
+   else if(actionCollection->action("P2KeyLeft")->shortcut().contains(key))
+      playerKeyPressed[1][PlayerKeyLeft]=false;
+      
+   else if(actionCollection->action("P1KeyRight")->shortcut().contains(key))
+      playerKeyPressed[0][PlayerKeyRight]=false;
+   else if(actionCollection->action("P2KeyRight")->shortcut().contains(key))
+      playerKeyPressed[1][PlayerKeyRight]=false;
+      
+   else if(actionCollection->action("P1KeyAcc")->shortcut().contains(key))
+      playerKeyPressed[0][PlayerKeyAcc]=false;
+   else if(actionCollection->action("P2KeyAcc")->shortcut().contains(key))
+      playerKeyPressed[1][PlayerKeyAcc]=false;
+      
+   else if(actionCollection->action("P1Shot")->shortcut().contains(key))
+      playerKeyPressed[0][PlayerKeyShot]=false;
+   else if(actionCollection->action("P2Shot")->shortcut().contains(key))
+      playerKeyPressed[1][PlayerKeyShot]=false;
+      
+   else if(actionCollection->action("P1Mine")->shortcut().contains(key))
+      playerKeyPressed[0][PlayerKeyMine]=false;
+   else if(actionCollection->action("P2Mine")->shortcut().contains(key))
+      playerKeyPressed[1][PlayerKeyMine]=false;
+   else
+      accept = false;
 
-   for(p=0;p<2;p++)
-      for(i=0;i<PlayerKeyNum;i++)
-         if(key==options.playerKey[p][i])
-         {
-            playerKeyPressed[p][i]=false;
-            accept=true;
-         }
    if(!accept)
-      ev->ignore();
+     ev->ignore();
 }
 
 void MyMainView::pause()
 {
    if( !waitForStart )
    {
-      KToggleAction* pauseAction = ( KToggleAction* )
-         ( (KMainWindow* )parent( )->parent( ) )
-         ->actionCollection( )->action( "pause" );
       pauseAction->setChecked( true );
 
       waitForStart=true;
@@ -361,17 +348,13 @@ void MyMainView::pause()
 void MyMainView::resume()
 {
    waitForStart=false;
-   timerID=startTimer(options.refreshTime);
+   timerID=startTimer(Options::refreshTime());
    emit(setStatusText("",IDS_PAUSE));
    emit(setStatusText("",IDS_MAIN));
 }
 
 void MyMainView::start( )
 {
-   KActionCollection* collection = ( ( KMainWindow* )parent( )->parent( ) )
-      ->actionCollection( );
-   KToggleAction* pauseAction;
-
    if( ( gameEnd <= 0.0 ) && ( gameEnd > -2.0 ) )
    {
       newRound( );
@@ -379,10 +362,9 @@ void MyMainView::start( )
    else if( waitForStart )
    {
       waitForStart = false;
-      timerID=startTimer(options.refreshTime);
+      timerID=startTimer(Options::refreshTime());
       emit(setStatusText("",IDS_PAUSE));
       emit(setStatusText("",IDS_MAIN));
-      pauseAction = ( KToggleAction* )collection->action( "pause" );
       pauseAction->setEnabled( true );
       pauseAction->setChecked( false );
    }
@@ -390,9 +372,6 @@ void MyMainView::start( )
 
 void MyMainView::stop()
 {
-   KToggleAction* pauseAction = ( KToggleAction* )
-      ( (KMainWindow* )parent( )->parent( ) )
-      ->actionCollection( )->action( "pause" );
    pauseAction->setEnabled( false );
    pauseAction->setChecked( false );
 
@@ -482,7 +461,7 @@ void MyMainView::newRound()
    {
       ship[i]->show();
       ship[i]->setEnergy(99.9);
-      ship[i]->setHitPoints(options.startHitPoints[i]);
+      ship[i]->setHitPoints(Options::startHitPoints(i));
       ship[i]->stop(false);
       ship[i]->setExplosion(-1);
       emit(energy(i,(int)ship[i]->getEnergy()));
@@ -513,9 +492,7 @@ void MyMainView::newRound()
    field.update();
 
    QString str = i18n("Press %1 to start")
-      .arg( ( (KMainWindow*)(parent()->parent()) )
-                                ->actionCollection()->action("game_start")
-                                ->shortcut().toString() );
+                 .arg(KShortcut(GAME_START_SHORTCUT).toString());
    emit(setStatusText(str,IDS_MAIN));
    emit( setStatusText( "", IDS_PAUSE ) );
    stop( );
@@ -558,7 +535,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
             textSprite->move(width()/2,height()/2-90);
             textSprite->setTextFlags(AlignCenter);
             textSprite->setColor(qRgb(255,160,0));
-            textSprite->setFont(QFont("Helvetica",14));
+            textSprite->setFont(QFont(KGlobalSettings::generalFont().family(),14));
             textSprite->show( );
             if(ship[0]->getHitPoints()==0)
             {
@@ -580,9 +557,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
                emit(wins(0,w));
             }
             QString str = i18n("Press %1 for new round")
-               .arg(( ( KMainWindow* )( parent( )->parent( ) ) )
-                                         ->actionCollection( )->action( "game_start" )
-                                         ->shortcut( ).toString() );
+                          .arg(KShortcut(GAME_START_SHORTCUT).toString());
             emit(setStatusText(str,IDS_MAIN));
             stop( );
          }
@@ -591,7 +566,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
       if( !stopped )
       {
          for(i=0;i<2;i++)
-            if(options.isAi[i]&&(ship[i]->getHitPoints()>0))
+            if(Options::playerIsAi(i)&&(ship[i]->getHitPoints()>0))
                ai[i]->think();
 
          moveMines();
@@ -600,7 +575,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
          moveShips();
          calculatePowerups();
          collisions();
-         timerID=startTimer(options.refreshTime);
+         timerID=startTimer(Options::refreshTime());
       }
       field.update();
    }
@@ -616,6 +591,7 @@ void MyMainView::moveShips()
 
    for(i=0;i<2;i++)
    {
+      bool playerIsAi = Options::playerIsAi(i);
       olde=(int)ship[i]->getEnergy();
       if(ship[i]->getHitPoints()==0)
       {
@@ -629,13 +605,13 @@ void MyMainView::moveShips()
                                          config.gamespeed);
 
 
-         if(!options.isAi[i]&&playerKeyPressed[i][PlayerKeyRight]
-            || options.isAi[i]&&ai[i]->rotateRight())
+         if(!playerIsAi&&playerKeyPressed[i][PlayerKeyRight]
+            || playerIsAi&&ai[i]->rotateRight())
             ship[i]->rotateRight(config.rotationEnergyNeed,
                                  config.rotationSpeed);
 
-         if(!options.isAi[i]&&playerKeyPressed[i][PlayerKeyLeft]
-            || options.isAi[i]&&ai[i]->rotateLeft())
+         if(!playerIsAi&&playerKeyPressed[i][PlayerKeyLeft]
+            || playerIsAi&&ai[i]->rotateLeft())
             ship[i]->rotateLeft(config.rotationEnergyNeed,
                                 config.rotationSpeed);
 
@@ -646,8 +622,8 @@ void MyMainView::moveShips()
          nf=ship[i]->frame();
          nx=cos(nr);
          ny=sin(nr);
-         if((!options.isAi[i]&&playerKeyPressed[i][PlayerKeyAcc]
-             || options.isAi[i]&&ai[i]->accelerate())
+         if((!playerIsAi&&playerKeyPressed[i][PlayerKeyAcc]
+             || playerIsAi&&ai[i]->accelerate())
             &&(en>config.energyNeed))
          {
             en-=config.energyNeed;
@@ -659,8 +635,8 @@ void MyMainView::moveShips()
 
          ship[i]->forward(config.gamespeed);
              //Bullets and Mines
-         if(!options.isAi[i]&&playerKeyPressed[i][PlayerKeyShot]
-            ||options.isAi[i]&&ai[i]->shootBullet())
+         if(!playerIsAi&&playerKeyPressed[i][PlayerKeyShot]
+            ||playerIsAi&&ai[i]->shootBullet())
          {
             if((en>config.shotEnergyNeed) && (!ship[i]->reloadsBullet()))
             {
@@ -682,8 +658,8 @@ void MyMainView::moveShips()
                }
             }
          }
-         if(!options.isAi[i]&&playerKeyPressed[i][PlayerKeyMine]
-            || options.isAi[i]&&ai[i]->layMine())
+         if(!Options::playerIsAi(i)&&playerKeyPressed[i][PlayerKeyMine]
+            || Options::playerIsAi(i)&&ai[i]->layMine())
          {
             if((en>config.mineEnergyNeed) && (!ship[i]->reloadsMine()))
             {
@@ -1000,59 +976,32 @@ void MyMainView::collisions()
          expl=new ExplosionSprite(explosionsequence,&field,ship[pl]);
          expl->show();
          explosions.append(expl);
-         gameEnd=options.timeAfterKill/config.gamespeed;
+         gameEnd=Options::timeAfterKill()/config.gamespeed;
       }
    }
 }
 
 void MyMainView::gameSetup()
 {
-   if(!waitForStart)
-      pause();
-   ConfigSetup dialog(&customConfig,&options,this);
-   dialog.exec();
-   if(options.lastConfig<predefinedConfigNum)
-      config=modifyConfig(predefinedConfig[options.lastConfig]);
-   else
-      config=modifyConfig(customConfig);
+  if(!waitForStart)
+    pause();
+   
+  if (KConfigDialog::showDialog("settings"))
+    return;
+
+  SettingsDialog *settings=new SettingsDialog(&customConfig,this,"settings");
+  connect(settings, SIGNAL(settingsUpdated()),this,SLOT(closeSettings()));
+  settings->show();
 }
 
-void MyMainView::keySetup()
-{
-   if(!waitForStart)
-      pause();
-   KeySetup dialog(&options,this);
-   dialog.exec();
-//   QString str = i18n("Press %1 to start/resume")
-//           .arg(KKey::keyToString(options.functionKey[FunctionKeyStart]));
-//   emit(setStatusText(str,IDS_MAIN));
+void MyMainView::closeSettings(){
+  if(Options::lastConfig()<predefinedConfigNum)
+    config=modifyConfig(predefinedConfig[Options::lastConfig()]);
+  else
+    config=modifyConfig(customConfig);
 }
 
-void MyMainView::aiSetup()
-{
-   if(!waitForStart)
-      pause();
-   AiSetup dialog(&options,this);
-   dialog.exec();
-}
-
-void MyMainView::hitpointSetup()
-{
-   if(!waitForStart)
-      pause();
-   HitpointSetup dialog(&options,this);
-   dialog.exec();
-}
-
-void MyMainView::graphicSetup()
-{
-   if(!waitForStart)
-      pause();
-   GraphicSetup dialog(&options,this);
-   dialog.exec();
-}
-
-QCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const QString& datapattern, 
+QCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const QString& datapattern,
                             const QString& maskpattern, int framecount)
 {
    int image;
@@ -1063,7 +1012,7 @@ QCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const QString& datapattern
    QBitmap *bitmap;
    int hotx=0, hoty=0;
    QPoint *point;
-      
+
    for( image=0; image < framecount; image++ )
    {
       // #### Why is this a QString??
@@ -1076,7 +1025,7 @@ QCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const QString& datapattern
          char line[128];
          file.readLine( line, 128 ); // Skip "P6"/"P3" line
          file.readLine( line, 128 );
-         
+
          while ( line[0] == '#' )
          {
             // Comment line - see if it has additional parameters
