@@ -1,4 +1,4 @@
-/* ********************************************************************************
+/******************************************************************************
    This file is part of the game 'KTron'
 
   Copyright (C) 1998-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
@@ -15,14 +15,11 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-  ***************************************************************************** */  
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+  ****************************************************************************/  
 #include <kapplication.h>
 #include <kimageio.h>
-#include <klocale.h>
-#include <kglobal.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
@@ -39,32 +36,24 @@ int main(int argc, char* argv[])
 {
   KAboutData aboutData( "ktron", I18N_NOOP("KTron"), 
     KTRON_VERSION, description, KAboutData::License_GPL, notice);
-  aboutData.addAuthor("Matthias Kiefer",0, "matthias.kiefer@gmx.de");
+  aboutData.addAuthor("Matthias Kiefer",I18N_NOOP("Original author"), "matthias.kiefer@gmx.de");
+  aboutData.addAuthor("Benjamin Meyer",I18N_NOOP("Various improvements"), "ben+ktron@meyerhome.net");
   KCmdLineArgs::init( argc, argv, &aboutData );
 
-  
   KApplication a;
   KGlobal::locale()->insertCatalogue("libkdegames");
-
+  
   // used for loading background pixmaps
   KImageIO::registerFormats();
 
-  if(a.isRestored())
-  {
+  if(a.isRestored()){
      RESTORE(KTron)
   }
-  else
-  {
-     KTron* ktron = new KTron;
+  else {
+     KTron *ktron = new KTron();
      a.setMainWidget(ktron);
      ktron->show();
   }
   return a.exec();
 }
 
-
-
-
-
-
-
