@@ -15,7 +15,7 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
   *******************************************************************************/  
 
@@ -26,8 +26,8 @@ player::player()
   computer=false;
   score=0;
   reset();
-  dir=Up;
-  last_dir=None;
+  dir=Directions::Up;
+  last_dir=Directions::None;
 }
 
 
@@ -55,5 +55,3 @@ void player::setComputer(bool computer)
   else keyPressed=false;
 }
 
-
-
