@@ -1,4 +1,4 @@
-/* ********************************************************************************
+/****************************************************************************
   This file is part of the game 'KTron'
 
   Copyright (C) 1998-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
@@ -15,55 +15,96 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  ***************************************************************************** */
+  ***************************************************************************/
+// Background
+#include <kio/netaccess.h>
+#include <kmessagebox.h>
 
+// Normal class
 #include <qtimer.h>
 
 #include <kdebug.h>
 #include <klocale.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kcolordialog.h>
 #include <kaction.h>
 
+#include "settings.h"
 #include "tron.h"
 
 #define TRON_FRAMESIZE 2
 
-/* *************************************************************** **
-**                    init-functions										 **
-** *************************************************************** */
+/**
+ * init-functions
+ **/
 
 Tron::Tron(QWidget *parent,const char *name)
   : QWidget(parent,name)
 {
   pixmap=0;
   playfield=0;
-  changeWinnerColor=false;
-  blockAccelerator=false;
   beginHint=false;
   lookForward=15;
 
   random.setSeed(0);
 
-  timer=new QTimer(this,"timer");
-  connect(timer,SIGNAL(timeout()),SLOT(doMove()));
-
-  colors[0]=QColor("black");
-  colors[1]=QColor("red");
-  colors[2]=QColor("blue");
-  setPalette(colors[0]);
-
   setFocusPolicy(QWidget::StrongFocus);
   setBackgroundMode(NoBackground);
 
   gameBlocked=false;
-  style=OLine;
-  rectSize=7;
-  _skill=Medium;
+  rectSize=10;
 
-  QTimer::singleShot(15000,this,SLOT(showBeginHint()));
+  timer = new QTimer(this,"timer");
+  loadSettings();
+  connect(timer, SIGNAL(timeout()), SLOT(doMove()));
+  QTimer::singleShot(15000, this,SLOT(showBeginHint()));
+}
+
+void Tron::loadSettings(){
+  setPalette(Settings::color_Background());
+
+  // Size
+  int newSize = Settings::rectSize();
+  if(newSize!=rectSize){
+    rectSize=newSize;
+    createNewPlayfield();
+  }
+
+  reset();
+
+  // Velocity
+  setVelocity( Settings::velocity() );
+
+  // Style
+  if(pixmap){
+    updatePixmap();
+    repaint();
+  }
+
+  // Backgroundimage
+  setBackgroundPix(NULL);
+  if(Settings::backgroundImageChoice()){
+    KURL url = Settings::backgroundImage();
+    if(!url.isEmpty()){
+      QString tmpFile;
+      KIO::NetAccess::download(url, tmpFile, this);
+      QPixmap pix(tmpFile);
+      if(!pix.isNull()){
+        setBackgroundPix(pix);
+      } else {
+  	QString msg=i18n("Wasn't able to load wallpaper\n%1");
+	msg=msg.arg(tmpFile);
+	KMessageBox::sorry(this, msg);
+      }
+      KIO::NetAccess::removeTempFile(tmpFile);
+    }
+    else setBackgroundPix(NULL);
+  }
+  setComputerplayer(One, Settings::computerplayer1());
+  setComputerplayer(Two, Settings::computerplayer2());
 }
 
 Tron::~Tron()
@@ -81,15 +122,12 @@ Tron::~Tron()
 void Tron::createNewPlayfield()
 {
   if(playfield)
-    {
-      delete [] playfield;
-    }
+    delete [] playfield;
 
   if(pixmap)
     delete pixmap;
 
   // field size
-
   fieldWidth=(width()-2*TRON_FRAMESIZE)/rectSize;
   fieldHeight=(height()-2*TRON_FRAMESIZE)/rectSize;
 
@@ -99,11 +137,10 @@ void Tron::createNewPlayfield()
     playfield[i].resize(fieldHeight);
 
   pixmap=new QPixmap(size());
-     pixmap->fill(colors[0]);
+  pixmap->fill(Settings::color_Background());
 
   //int min=(fieldWidth<fieldHeight) ? fieldWidth : fieldHeight;
   //lookForward=min/4;
-
 }
 
 void Tron::newGame()
@@ -175,8 +212,8 @@ void Tron::stopGame()
 {
    timer->stop();
    gameEnded=true;
-   players[0].last_dir = None;
-   players[1].last_dir = None;
+   players[0].last_dir = Directions::None;
+   players[1].last_dir = Directions::None;
 }
 
 void Tron::togglePause() // pause or continue game
@@ -202,19 +239,19 @@ void Tron::showWinner(Player player)
 {
    int i,j;
 
-   if(player != Both && changeWinnerColor)
+   if(player != Both && Settings::changeWinnerColor())
    {
       int winner;
-      int looser;
+      int loser;
       if(player==One)
       {
          winner=PLAYER1;
-         looser=PLAYER2;
+         loser=PLAYER2;
       }
       else
       {
          winner=PLAYER2;
-         looser=PLAYER1;
+         loser=PLAYER1;
       }
 
       for(i=0;i<fieldWidth;i++)
@@ -224,7 +261,7 @@ void Tron::showWinner(Player player)
             {
                // change player
                playfield[i][j] |= winner;
-               playfield[i][j] &= ~looser;
+               playfield[i][j] &= ~loser;
             }
          }
 
@@ -259,7 +296,7 @@ void Tron::updatePixmap()
   }
   else
   {
-    pixmap->fill(colors[0]);
+    pixmap->fill(Settings::color_Background());
   }
 
   QPainter p;
@@ -317,12 +354,12 @@ void Tron::drawRect(QPainter & p, int x, int y)
    int player;
    if(type&PLAYER1) // check player bit
    {
-      toDraw=colors[1];
+      toDraw=Settings::color_Player1();
       player=0;
    }
    else if(type&PLAYER2)
    {
-      toDraw=colors[2];
+      toDraw=Settings::color_Player2();
       player=1;
    }
    else
@@ -331,14 +368,14 @@ void Tron::drawRect(QPainter & p, int x, int y)
       return;
    }
 
-   switch(style)
+   switch(Settings::style())
    {
-      case Line:
+      case Settings::EnumStyle::Line:
          p.setBrush(toDraw);
          p.setPen(toDraw);
          p.drawRect(xOffset,yOffset,rectSize,rectSize);
          break;
-      case OLine:
+      case Settings::EnumStyle::OLine:
       {
          p.setBrush(toDraw);
          p.setPen(toDraw);
@@ -364,12 +401,12 @@ void Tron::drawRect(QPainter & p, int x, int y)
 
          break;
       }
-      case Circle:
+      case Settings::EnumStyle::Circle:
          p.setBrush(toDraw);
          p.setPen(toDraw);
          p.drawEllipse(xOffset ,yOffset ,rectSize,rectSize);
          break;
-      case ORect:
+      case Settings::EnumStyle::ORect:
          p.setBrush(toDraw);
          p.setPen(toDraw.light());
          p.drawRect(xOffset,yOffset,rectSize,rectSize);
@@ -394,60 +431,11 @@ void Tron::setBackgroundPix(QPixmap pix)
 {
     bgPix=pix;
 
-    if(pixmap!=0)
+    if(pixmap!=0){
        updatePixmap();
-
-    // most pictures have colors, that you can read white text
-    setPalette(QColor("black"));
-}
-
-// configure colors
-bool Tron::changeColor(int id)
-{
-   QColor color;
-   int result=KColorDialog::getColor(color);
-
-   bool flag=false;
-
-   if(result)  // if button 'ok' pressed
-   {
-      // backgroundcolor changed
-      if(id==0)
-      {
-         colors[0]=color;
-         setPalette(color);
-         bgPix.resize(0,0);
-      }
-      else  // set other color
-      {
-         colors[id]=color;
-      }
-      updatePixmap();
-      repaint();
-
-      flag=true;
-   }
-
-   return flag;
-}
-
-void Tron::saveColors(KConfig* config) const
-{
-   config->writeEntry("Color_Background",colors[0]);
-   config->writeEntry("Color_Player1",colors[1]);
-   config->writeEntry("Color_Player2",colors[2]);
-}
-
-void Tron::restoreColors(KConfig *config)
-{
-   QColor bg("black");
-   QColor pl1("red");
-   QColor pl2("blue");
-   colors[0]=config->readColorEntry("Color_Background",&bg);
-   colors[1]=config->readColorEntry("Color_Player1",&pl1);
-   colors[2]=config->readColorEntry("Color_Player2",&pl2);
-
-   setPalette(colors[0]);
+      // most pictures have colors, that you can read white text
+      setPalette(QColor("black"));
+    }
 }
 
 void Tron::setVelocity(int newVel)            // set new velocity
@@ -456,123 +444,31 @@ void Tron::setVelocity(int newVel)            // set new velocity
 
   if(!gameEnded && !gamePaused)
     timer->changeInterval(velocity);
-
 }
 
-int Tron::getVelocity() const
-{
-  return 10-velocity/15;
-}
-
-void Tron::setStyle(TronStyle newStyle)
-{
-   style=newStyle;
-
-   if(pixmap)
-   {
-      updatePixmap();
-      repaint();
-   }
-}
-
-TronStyle Tron::getStyle() const
-{
-   return style;
-}
-
-void Tron::setRectSize(int newSize)
-{
-   if(newSize!=rectSize)
-   {
-      rectSize=newSize;
-      createNewPlayfield();
-      reset();
-   }
-}
-
-int Tron::getRectSize() const
-{
-   return rectSize;
-}
-
-void Tron::setAcceleratorBlocked(bool flag)
-{
-   blockAccelerator=flag;
-}
-
-bool Tron::acceleratorBlocked() const
-{
-   return blockAccelerator;
-}
-
-void Tron::enableWinnerColor(bool flag)
-{
-   changeWinnerColor=flag;
-}
-
-bool Tron::winnerColor() const
-{
-   return changeWinnerColor;
-}
-
-void Tron::setOppositeDirCrashes(bool flag)
-{
-   crashOnOppositeDir=flag;
-}
-
-bool Tron::oppositeDirCrashes() const
-{
-   return crashOnOppositeDir;
-}
-
-void Tron::setComputerplayer(Player player, bool flag)
-{
+void Tron::setComputerplayer(Player player, bool flag) {
   if(player==One)
-  {
-     players[0].setComputer(flag);
-  }
+    players[0].setComputer(flag);
   else if(player==Two)
-  {
-     players[1].setComputer(flag);
-  }
+    players[1].setComputer(flag);
 
   if(isComputer(Both))
-  {
-     QTimer::singleShot(1000,this,SLOT(computerStart()));
-  }
-
+      QTimer::singleShot(1000,this,SLOT(computerStart()));
 }
 
 bool Tron::isComputer(Player player)
 {
-   bool flag=false;
    if(player==One)
-   {
-       flag=players[0].computer;
-   }
+     return players[0].computer;
    else if(player==Two)
-   {
-      flag=players[1].computer;
-   }
+     return players[1].computer;
    else if(player==Both)
    {
       if(players[0].computer && players[1].computer)
-         flag=true;
-      else
-         flag=false;
+        return true;
    }
 
-   return flag;
-}
-
-void Tron::setSkill(Skill newSkill)
-{
-   _skill=newSkill;
-}
-
-Skill Tron::skill() const
-{
-   return _skill;
+   return false;
 }
 
 /* *************************************************************** **
@@ -594,7 +490,7 @@ bool Tron::crashed(int playerNr,int xInc, int yInc) const
   return flag;
 }
 
-void Tron::switchDir(int playerNr,Direction newDirection)
+void Tron::switchDir(int playerNr,Directions::Direction newDirection)
 {
   if(playerNr!=0 && playerNr != 1)
   {
@@ -602,15 +498,15 @@ void Tron::switchDir(int playerNr,Direction newDirection)
      return;
   }
 
-  if (oppositeDirCrashes()==false)
+  if (Settings::oppositeDirCrashes()==false)
   {
-    if (newDirection==::Up && players[playerNr].last_dir==::Down)
+    if (newDirection==Directions::Up && players[playerNr].last_dir==Directions::Down)
       return;
-    if (newDirection==::Down && players[playerNr].last_dir==::Up)
+    if (newDirection==Directions::Down && players[playerNr].last_dir==Directions::Up)
       return;
-    if (newDirection==::Left && players[playerNr].last_dir==::Right)
+    if (newDirection==Directions::Left && players[playerNr].last_dir==Directions::Right)
       return;
-    if (newDirection==::Right && players[playerNr].last_dir==::Left)
+    if (newDirection==Directions::Right && players[playerNr].last_dir==Directions::Left)
       return;
   }
 
@@ -628,20 +524,22 @@ void Tron::updateDirections(int playerNr)
       switch(players[0].dir)
       {
          // unset drawing flags in the moving direction
-         case ::Up:
+         case Directions::Up:
          {
-  	    playfield[x][y] &= (~TOP);
-  	    break;
-       	 }
-         case ::Down:
+            playfield[x][y] &= (~TOP);
+            break;
+         }
+         case Directions::Down:
             playfield[x][y] &= (~BOTTOM);
             break;
-         case ::Right:
+         case Directions::Right:
             playfield[x][y] &= (~RIGHT);
             break;
-         case ::Left:
+         case Directions::Left:
             playfield[x][y] &= (~LEFT);
             break;
+         default:
+            break;
       }
       players[0].last_dir = players[0].dir;
 
@@ -655,20 +553,22 @@ void Tron::updateDirections(int playerNr)
       switch(players[1].dir)
       {
           // unset drawing flags in the moving direction
-     	  case ::Up:
+     	  case Directions::Up:
      	  {
              playfield[x][y] &= (~TOP);
              break;
        	  }
-          case ::Down:
+          case Directions::Down:
              playfield[x][y] &= (~BOTTOM);
              break;
-          case ::Right:
+          case Directions::Right:
              playfield[x][y] &= (~RIGHT);
              break;
-          case ::Left:
+          case Directions::Left:
              playfield[x][y] &= (~LEFT);
              break;
+         default:
+            break;
       }
       players[1].last_dir = players[1].dir;
 
@@ -701,33 +601,17 @@ void Tron::paintEvent(QPaintEvent *e)
       QString message=i18n("Crash!");
       QPainter p(this);
       int w=p.fontMetrics().width(message);
+      int h=p.fontMetrics().height();
       for(int i=0;i<2;i++)
       {
          if(!players[i].alive)
      	 {
-            int x=players[i].xCoordinate*rectSize+(width()%rectSize)/2-w/2;
-            int y=players[i].yCoordinate*rectSize+(height()%rectSize)/2;
-            if(players[i].dir==::Right)
-            {
-               x+=rectSize;
-               y+=rectSize/2;
-            }
-            if(players[i].dir==::Left)
-            {
-               y+=rectSize/2;
-            }
-            if(players[i].dir==::Down)
-            {
-               y+=rectSize;
-               x+=rectSize/2;
-            }
-            if(players[i].dir==::Up)
-            {
-               x+=rectSize/2;
-               y+=rectSize/3;
-            }
-
-
+            int x=players[i].xCoordinate*rectSize;
+            int y=players[i].yCoordinate*rectSize;
+            while(x<0) x+=rectSize;
+            while(x+w>width()) x-=rectSize;
+            while(y-h<0) y+=rectSize;
+            while(y>height()) y-=rectSize;
             p.drawText(x,y,message);
          }
       }
@@ -758,27 +642,27 @@ void Tron::keyPressEvent(QKeyEvent *e)
   {
       if(actionCollection->action("Pl2Up")->shortcut().contains(key))
 		{
-	  		switchDir(1,::Up);
+	  		switchDir(1,Directions::Up);
 	  		players[1].keyPressed=true;
 		}
       else if(actionCollection->action("Pl2Left")->shortcut().contains(key))
 	   {
-	  		switchDir(1,::Left);
+	  		switchDir(1,Directions::Left);
 	  		players[1].keyPressed=true;
 		}
       else if(actionCollection->action("Pl2Right")->shortcut().contains(key))
 		{
-	  		switchDir(1,::Right);
+	  		switchDir(1,Directions::Right);
 	  		players[1].keyPressed=true;
 		}
       else if(actionCollection->action("Pl2Down")->shortcut().contains(key))
 		{
-	  		switchDir(1,::Down);
+	  		switchDir(1,Directions::Down);
 	  		players[1].keyPressed=true;
 		}
       else if(actionCollection->action("Pl2Ac")->shortcut().contains(key))
 		{
-		   if(!blockAccelerator)
+		   if(!Settings::acceleratorBlocked())
 	  			players[1].accelerated=true;
 
 		}
@@ -788,27 +672,27 @@ void Tron::keyPressEvent(QKeyEvent *e)
   {
       if(actionCollection->action("Pl1Left")->shortcut().contains(key))
 		{
-	  		switchDir(0,::Left);
+	  		switchDir(0,Directions::Left);
 	  		players[0].keyPressed=true;
 		}
       else if(actionCollection->action("Pl1Right")->shortcut().contains(key))
 		{
-	  		switchDir(0,::Right);
+	  		switchDir(0,Directions::Right);
 	  		players[0].keyPressed=true;
 		}
       else if(actionCollection->action("Pl1Up")->shortcut().contains(key))
 		{
-	  		switchDir(0,::Up);
+	  		switchDir(0,Directions::Up);
 	  		players[0].keyPressed=true;
 		}
       else if(actionCollection->action("Pl1Down")->shortcut().contains(key))
 		{
-	 		switchDir(0,::Down);
+	 		switchDir(0,Directions::Down);
 	  		players[0].keyPressed=true;
 		}
       else if(actionCollection->action("Pl1Ac")->shortcut().contains(key))
 		{
-		   if(!blockAccelerator)
+		   if(!Settings::acceleratorBlocked())
 	  			players[0].accelerated=true;
 		}
   }
@@ -900,7 +784,7 @@ void Tron::keyReleaseEvent(QKeyEvent * e)
 
 }
 
-// if playingfield looses keyboard focus, pause game
+// if playingfield loses keyboard focus, pause game
 void Tron::focusOutEvent(QFocusEvent *)
 {
    if(!gameEnded && !gamePaused)
@@ -935,241 +819,245 @@ void Tron::showBeginHint()
 void Tron::doMove()
 {
    int i;
-  	for(i=0;i<2;i++)
-  	{
-  		// berprfen, ob Acceleratortaste gedrckt wurde...
+   for(i=0;i<2;i++)
+   {
+      // berprfen, ob Acceleratortaste gedrckt wurde...
       if(players[i].accelerated)
-		{
+      {
+         updateDirections(i);
 
-		   updateDirections(i);
+         int newType; // determine type of rect to set
+         if(i==0)
+         {
+            newType=PLAYER1;
+         }
+         else
+         {
+            newType=PLAYER2;
+         }
+         switch(players[i].dir)
+         {
+            case Directions::Up:
+               if(crashed(i,0,-1))
+                  players[i].alive=false;
+               else
+               {
+                  players[i].yCoordinate--;
+                  newType|=(TOP | LEFT | RIGHT);
+               }
+            break;
+            case Directions::Down:
+               if(crashed(i,0,1))
+                  players[i].alive=false;
+               else
+               {
+                  players[i].yCoordinate++;
+                  newType |= (BOTTOM | LEFT | RIGHT);
+               }
+            break;
+            case Directions::Left:
+               if(crashed(i,-1,0))
+                  players[i].alive=false;
+               else
+               {
+                  players[i].xCoordinate--;
+                  newType |= (LEFT | TOP | BOTTOM);
+               }
+            break;
+            case Directions::Right:
+               if(crashed(i,1,0))
+                  players[i].alive=false;
+               else
+               {
+                  players[i].xCoordinate++;
+                  newType |= (RIGHT | TOP | BOTTOM);
+               }
+            break;
+            default:
+               break;
+         }
+         if(players[i].alive)
+            playfield[players[i].xCoordinate][players[i].yCoordinate]=newType;
+      }
+   }
 
-		   int newType; // determine type of rect to set
-		   if(i==0)
-		   {
-		      newType=PLAYER1;
-		   }
-		   else
-		   {
-		      newType=PLAYER2;
-		   }
-	  		switch(players[i].dir)
-	    	{
-	    		case ::Up:
-	      		if(crashed(i,0,-1))
-		 				players[i].alive=false;
-	      		else
-	      		{
-	      			players[i].yCoordinate--;
-	      			newType|=(TOP | LEFT | RIGHT);
-	      		}
-	      		break;
-	    		case ::Down:
-	    			if(crashed(i,0,1))
-	       			players[i].alive=false;
-	    			else
-	    			{
-	    			   players[i].yCoordinate++;
-	    			   newType |= (BOTTOM | LEFT | RIGHT);
-	    			}
-
-	      		break;
-	    		case ::Left:
-	       		if(crashed(i,-1,0))
-		 				players[i].alive=false;
-	       		else
-	       		{
-	       		   players[i].xCoordinate--;
-	       		   newType |= (LEFT | TOP | BOTTOM);
-	       		}
-	      		break;
-	    		case ::Right:
-	      	if(crashed(i,1,0))
-					players[i].alive=false;
-	      	else
-	      	{
-	      	   players[i].xCoordinate++;
-	      	   newType |= (RIGHT | TOP | BOTTOM);
-	      	}
-	      	break;
-	    	}
-
-	      if(players[i].alive)
-      		playfield[players[i].xCoordinate][players[i].yCoordinate]=newType;
-		}
-
-  	}
-
-	if(players[0].accelerated || players[1].accelerated)
- 	{
-       /* player collision check */
+   if(players[0].accelerated || players[1].accelerated)
+   {
+      /* player collision check */
       if(!players[1].alive)
-		{
-	  		int xInc=0,yInc=0;
-	  		switch(players[1].dir)
-	    	{
-	    		case ::Left:
-	      		xInc = -1;
-	      		break;
-	    		case ::Right:
-	      		xInc = 1;
-	      		break;
-	    		case ::Up:
-	      		yInc = -1;
-	      		break;
-	    		case ::Down:
-	      		yInc = 1;
-	      		break;
-	    	}
-	  		if ((players[1].xCoordinate+xInc) == players[0].xCoordinate)
-	    		if ((players[1].yCoordinate+yInc) == players[0].yCoordinate)
-	      	{
-					players[0].alive=false;
-	      	}
-		}
+      {
+         int xInc=0,yInc=0;
+         switch(players[1].dir)
+         {
+            case Directions::Left:
+              xInc = -1;
+            break;
+            case Directions::Right:
+               xInc = 1;
+            break;
+            case Directions::Up:
+               yInc = -1;
+            break;
+            case Directions::Down:
+               yInc = 1;
+            break;
+            default:
+            break;
+         }
+         if ((players[1].xCoordinate+xInc) == players[0].xCoordinate)
+         if ((players[1].yCoordinate+yInc) == players[0].yCoordinate)
+         {
+            players[0].alive=false;
+         }
+      }
 
       paintPlayers();
 
       // crashtest
       if(!players[0].alive && !players[1].alive)
-		{
-		   stopGame();
-	  		players[0].score++;
-	  		players[1].score++;
-	  		showWinner(Both);
-		}
+      {
+         stopGame();
+         players[0].score++;
+         players[1].score++;
+         showWinner(Both);
+      }
       else
       {
-			for(i=0;i<2;i++)
-	  		{
-	    		if(!players[i].alive)
-	      	{
-	      	   stopGame();
-					showWinner((i==0)? Two:One);
-					players[i].score++;
-	      	}
-	  		}
-	  	}
+         for(i=0;i<2;i++)
+         {
+            if(!players[i].alive)
+            {
+               stopGame();
+               showWinner((i==0)? Two:One);
+               players[i].score++;
+            }
+         }
+      }
 
 
       if(gameEnded)
-		{
-	  		//this is for waiting 0,5s before starting next game
-	  		gameBlocked=true;
-	  		QTimer::singleShot(1000,this,SLOT(unblockGame()));
-		}
-  	}
+      {
+         //this is for waiting 0,5s before starting next game
+         gameBlocked=true;
+         QTimer::singleShot(1000,this,SLOT(unblockGame()));
+	 return;
+      }
+   }
 
-  	// neue Spielerstandorte festlegen
-  	for(i=0;i<2;i++)
+   // neue Spielerstandorte festlegen
+   for(i=0;i<2;i++)
    {
       if(players[i].computer)
-			think(i);
+         think(i);
    }
 
    updateDirections();
 
    for(i=0;i<2;i++)
    {
-		int newType;
-		if(i==0)
-			newType=PLAYER1;
-		else
-			newType=PLAYER2;
+      int newType;
+      if(i==0)
+         newType=PLAYER1;
+      else
+         newType=PLAYER2;
 
       switch(players[i].dir)
-		{
-			case ::Up:
-	      	if(crashed(i,0,-1))
-					players[i].alive=false;
-	      	else
-	      	{
-	      	   players[i].yCoordinate--;
-	      	   newType |= (TOP | RIGHT | LEFT);
-	      	}
-	  			break;
-			case ::Down:
-	      	if(crashed(i,0,1))
-					players[i].alive=false;
-	      	else
-	      	{
-	      	    players[i].yCoordinate++;
-	      	    newType |= (BOTTOM | RIGHT | LEFT);
-	      	}
-	  			break;
-			case ::Left:
-	      	if(crashed(i,-1,0))
-					players[i].alive=false;
-	      	else
-	      	{
-	      	   players[i].xCoordinate--;
-	      	   newType |= (LEFT | TOP | BOTTOM);
-	      	}
-	  			break;
-			case ::Right:
-	      	if(crashed(i,1,0))
-					players[i].alive=false;
-	      	else
-	      	{
-	      	   players[i].xCoordinate++;
-	      	   newType |= (RIGHT | TOP | BOTTOM);
-	      	}
-	  			break;
-		}
-		if(players[i].alive)
-			playfield[players[i].xCoordinate][players[i].yCoordinate]=newType;
+      {
+         case Directions::Up:
+            if(crashed(i,0,-1))
+               players[i].alive=false;
+            else
+            {
+               players[i].yCoordinate--;
+               newType |= (TOP | RIGHT | LEFT);
+            }
+         break;
+         case Directions::Down:
+            if(crashed(i,0,1))
+               players[i].alive=false;
+            else
+            {
+               players[i].yCoordinate++;
+               newType |= (BOTTOM | RIGHT | LEFT);
+            }
+         break;
+         case Directions::Left:
+            if(crashed(i,-1,0))
+               players[i].alive=false;
+            else
+            {
+               players[i].xCoordinate--;
+               newType |= (LEFT | TOP | BOTTOM);
+            }
+         break;
+         case Directions::Right:
+            if(crashed(i,1,0))
+               players[i].alive=false;
+            else
+            {
+               players[i].xCoordinate++;
+               newType |= (RIGHT | TOP | BOTTOM);
+            }
+         break;
+         default:
+         break;
 
- 	}
+      }
+      if(players[i].alive)
+         playfield[players[i].xCoordinate][players[i].yCoordinate]=newType;
+   }
 
-  	/* player collision check */
-  	if(!players[1].alive)
+   /* player collision check */
+   if(!players[1].alive)
    {
       int xInc=0,yInc=0;
       switch(players[1].dir)
-		{
-			case ::Left:
-	  			xInc = -1; break;
-			case ::Right:
-	  			xInc = 1; break;
-			case ::Up:
-	  			yInc = -1; break;
-			case ::Down:
-	  			yInc = 1; break;
-		}
+      {
+         case Directions::Left:
+            xInc = -1; break;
+         case Directions::Right:
+            xInc = 1; break;
+         case Directions::Up:
+            yInc = -1; break;
+         case Directions::Down:
+            yInc = 1; break;
+         default:
+            break;
+      }
       if ((players[1].xCoordinate+xInc) == players[0].xCoordinate)
-			if ((players[1].yCoordinate+yInc) == players[0].yCoordinate)
-	  		{
-	    		players[0].alive=false;
-	  		}
+         if ((players[1].yCoordinate+yInc) == players[0].yCoordinate)
+         {
+            players[0].alive=false;
+         }
    }
 
-  paintPlayers();
+   paintPlayers();
 
-  if(!players[0].alive && !players[1].alive)
-  {
+   if(!players[0].alive && !players[1].alive)
+   {
       stopGame();
       players[0].score++;
       players[1].score++;
       showWinner(Both);
-  }
-	else
-		for(i=0;i<2;i++)
-    	{
-			// crashtests
-			if(!players[i].alive)
-	  		{
-	  		   stopGame();
-	    		showWinner((i==0)? Two:One);
-	    		players[i].score++;
-	  		}
+   }
+   else
+      for(i=0;i<2;i++)
+      {
+         // crashtests
+         if(!players[i].alive)
+         {
+            stopGame();
+            showWinner((i==0)? Two:One);
+            players[i].score++;
+         }
       }
 
-
-  	if(gameEnded)
-  	{
-   	//this is for waiting 1s before starting next game
+   if(gameEnded)
+   {
+      //this is for waiting 1s before starting next game
       gameBlocked=true;
       QTimer::singleShot(1000,this,SLOT(unblockGame()));
-  	}
+   }
 
 }
 
@@ -1181,12 +1069,12 @@ void Tron::doMove()
 // xtron-1.1 by Rhett D. Jacobs <rhett@hotel.canberra.edu.au>
 void Tron::think(int playerNr)
 {
-if(_skill != Easy)
+if(Settings::skill() != Settings::EnumSkill::Easy)
 {
   int opponent=(playerNr==1)? 0 : 1;
 
   // determines left and right side
-  Direction sides[2];
+  Directions::Direction sides[2];
   // increments for moving to the different sides
   int flags[6]={0,0,0,0,0,0};
   int index[2];
@@ -1198,7 +1086,7 @@ if(_skill != Easy)
 
   	switch (players[playerNr].dir)
    	{
-  			case ::Left:
+  			case Directions::Left:
     			//forward flags
     			flags[0] = -1;
     			flags[1] = 0;
@@ -1212,39 +1100,42 @@ if(_skill != Easy)
     			flags[5] = -1;
 
     			//turns to either side
-    			sides[0] = ::Down;
-    			sides[1] = ::Up;
+    			sides[0] = Directions::Down;
+    			sides[1] = Directions::Up;
     			break;
-  			case ::Right:
+  			case Directions::Right:
     			flags[0] = 1;
     			flags[1] = 0;
     			flags[2] = 0;
 			   flags[3] = -1;
     			flags[4] = 0;
     			flags[5] = 1;
-    			sides[0] = ::Up;
-    			sides[1] = ::Down;
+    			sides[0] = Directions::Up;
+    			sides[1] = Directions::Down;
     			break;
-  			case ::Up:
+  			case Directions::Up:
     			flags[0] = 0;
     			flags[1] = -1;
     			flags[2] = -1;
     			flags[3] = 0;
     			flags[4] = 1;
     			flags[5] = 0;
-    			sides[0] = ::Left;
-    			sides[1] = ::Right;
+    			sides[0] = Directions::Left;
+    			sides[1] = Directions::Right;
     			break;
-  			case ::Down:
+  			case Directions::Down:
     			flags[0] = 0;
     			flags[1] = 1;
     			flags[2] = 1;
     			flags[3] = 0;
     			flags[4] = -1;
     			flags[5] = 0;
-    			sides[0] = ::Right;
-    			sides[1] = ::Left;
+    			sides[0] = Directions::Right;
+    			sides[1] = Directions::Left;
     			break;
+			default:
+			break;
+
   		}
 
   		// check forward
@@ -1296,61 +1187,74 @@ if(_skill != Easy)
 
   	switch(players[playerNr].dir)
   	{
-  	   case ::Up:
+  	   case Directions::Up:
   	      opForwardDis=vert_dis;
   	      opSideDis=-hor_dis;
-  	      if(players[opponent].dir==::Down)
+  	      if(players[opponent].dir==Directions::Down)
   	         opMovesOppositeDir=true;
-  	      else if(players[opponent].dir==::Up)
+  	      else if(players[opponent].dir==Directions::Up)
   	         opMovesSameDir=true;
-  	      else if(players[opponent].dir==::Left)
+  	      else if(players[opponent].dir==Directions::Left)
   	         opMovesLeft=true;
-  	      else if(players[opponent].dir==::Right)
+  	      else if(players[opponent].dir==Directions::Right)
   	         opMovesRight=true;
   	      break;
-  	   case ::Down:
+  	   case Directions::Down:
   	      opForwardDis=-vert_dis;
   	      opSideDis=hor_dis;
-  	      if(players[opponent].dir==::Up)
+  	      if(players[opponent].dir==Directions::Up)
   	         opMovesOppositeDir=true;
-  	      else if(players[opponent].dir==::Down)
+  	      else if(players[opponent].dir==Directions::Down)
   	         opMovesSameDir=true;
-  	      else if(players[opponent].dir==::Left)
+  	      else if(players[opponent].dir==Directions::Left)
   	         opMovesRight=true;
-  	      else if(players[opponent].dir==::Right)
+  	      else if(players[opponent].dir==Directions::Right)
   	         opMovesLeft=true;
   	      break;
-  	   case ::Left:
+  	   case Directions::Left:
   	      opForwardDis=hor_dis;
   	      opSideDis=vert_dis;
-  	      if(players[opponent].dir==::Right)
+  	      if(players[opponent].dir==Directions::Right)
   	         opMovesOppositeDir=true;
-  	      else if(players[opponent].dir==::Left)
+  	      else if(players[opponent].dir==Directions::Left)
   	         opMovesSameDir=true;
-  	      else if(players[opponent].dir==::Down)
+  	      else if(players[opponent].dir==Directions::Down)
   	         opMovesLeft=true;
-  	      else if(players[opponent].dir==::Up)
+  	      else if(players[opponent].dir==Directions::Up)
   	         opMovesRight=true;
   	      break;
-  	   case ::Right:
+  	   case Directions::Right:
   	      opForwardDis=-hor_dis;
   	      opSideDis=-vert_dis;
-  	      if(players[opponent].dir==::Left)
+  	      if(players[opponent].dir==Directions::Left)
   	         opMovesOppositeDir=true;
-  	      else if(players[opponent].dir==::Right)
+  	      else if(players[opponent].dir==Directions::Right)
   	         opMovesSameDir=true;
-  	      else if(players[opponent].dir==::Up)
+  	      else if(players[opponent].dir==Directions::Up)
   	         opMovesLeft=true;
-  	      else if(players[opponent].dir==::Down)
+  	      else if(players[opponent].dir==Directions::Down)
   	         opMovesRight=true;
   	      break;
+  	    default:
+  	      break;
+
   	}
 
-  	int doPercentage=100;
-  	if(_skill==Medium)
+  	int doPercentage = 100;
+  	switch(Settings::skill())
+  	{
+  	  case Settings::EnumSkill::Easy:
+  	        // Never reached
+  		break;
+
+  	  case Settings::EnumSkill::Medium:
   		doPercentage=5;
-  	else if(_skill==Hard)
+  		break;
+  		
+  	  case Settings::EnumSkill::Hard:
   		doPercentage=90;
+  		break;
+  	}
 
   	// if opponent moves the opposite direction as we
    if(opMovesOppositeDir)
@@ -1567,11 +1471,11 @@ if(_skill != Easy)
    } // end if(opMovesLeft)
 
 }
-// This part is completly ported from
+// This part is completely ported from
 // xtron-1.1 by Rhett D. Jacobs <rhett@hotel.canberra.edu.au>
-else //_skill==Easy
+else // Settings::skill() == Settings::EnumSkill::Easy
 {
-  Direction sides[2];
+  Directions::Direction sides[2];
   int flags[6] = {0,0,0,0,0,0};
   int index[2];
   int dis_forward,  dis_left, dis_right;
@@ -1579,7 +1483,7 @@ else //_skill==Easy
   dis_forward = dis_left = dis_right = 1;
 
   switch (players[playerNr].dir) {
-  case ::Left:
+  case Directions::Left:
 
     //forward flags
     flags[0] = -1;
@@ -1594,38 +1498,40 @@ else //_skill==Easy
     flags[5] = -1;
 
     //turns to either side
-    sides[0] = ::Down;
-    sides[1] = ::Up;
+    sides[0] = Directions::Down;
+    sides[1] = Directions::Up;
     break;
-  case ::Right:
+  case Directions::Right:
     flags[0] = 1;
     flags[1] = 0;
     flags[2] = 0;
     flags[3] = -1;
     flags[4] = 0;
     flags[5] = 1;
-    sides[0] = ::Up;
-    sides[1] = ::Down;
+    sides[0] = Directions::Up;
+    sides[1] = Directions::Down;
     break;
-  case ::Up:
+  case Directions::Up:
     flags[0] = 0;
     flags[1] = -1;
     flags[2] = -1;
     flags[3] = 0;
     flags[4] = 1;
     flags[5] = 0;
-    sides[0] = ::Left;
-    sides[1] = ::Right;
+    sides[0] = Directions::Left;
+    sides[1] = Directions::Right;
     break;
-  case ::Down:
+  case Directions::Down:
     flags[0] = 0;
     flags[1] = 1;
     flags[2] = 1;
     flags[3] = 0;
     flags[4] = -1;
     flags[5] = 0;
-    sides[0] = ::Right;
-    sides[1] = ::Left;
+    sides[0] = Directions::Right;
+    sides[1] = Directions::Left;
+    break;
+  default:
     break;
   }
 
@@ -1694,27 +1600,30 @@ else //_skill==Easy
 
 void Tron::changeDirection(int playerNr,int dis_right,int dis_left)
 {
-   Direction currentDir=players[playerNr].dir;
-   Direction sides[2];
+   Directions::Direction currentDir=players[playerNr].dir;
+   Directions::Direction sides[2];
    switch (currentDir)
    {
-  		case ::Left:
+  		case Directions::Left:
     		//turns to either side
-    		sides[0] = ::Down;
-    		sides[1] = ::Up;
+    		sides[0] = Directions::Down;
+    		sides[1] = Directions::Up;
     		break;
-  		case ::Right:
-    		sides[0] = ::Up;
-    		sides[1] = ::Down;
+  		case Directions::Right:
+    		sides[0] = Directions::Up;
+    		sides[1] = Directions::Down;
     		break;
-  		case ::Up:
-    		sides[0] = ::Left;
-    		sides[1] = ::Right;
+  		case Directions::Up:
+    		sides[0] = Directions::Left;
+    		sides[1] = Directions::Right;
     		break;
-  		case ::Down:
-    		sides[0] = ::Right;
-    		sides[1] = ::Left;
+  		case Directions::Down:
+    		sides[0] = Directions::Right;
+    		sides[1] = Directions::Left;
     		break;
+		default:
+		break;
+
   	}
 
    if(!(dis_left == 1 && dis_right == 1))
@@ -1742,3 +1651,4 @@ void Tron::changeDirection(int playerNr,int dis_right,int dis_left)
 }
 
 #include "tron.moc"
+
