@@ -15,6 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
+
 // include files for QT
 #include <qstring.h>
 #include <qlayout.h>
@@ -150,7 +151,7 @@ Kwin4App::Kwin4App() : KMainWindow(0)
    // Allow overriding of the grafix directory
    // This is a cheap and dirty way for theming
    config->setGroup("Themes");
-   mGrafix = config->readEntry("grafixdir", mGrafix);
+   mGrafix = config->readPathEntry("grafixdir", mGrafix);
    kdDebug() << "Localised mGrafix " << mGrafix << endl;
 
 
@@ -276,8 +277,8 @@ void Kwin4App::checkMenus(int menu)
 
   if (!menu || (menu&CheckViewMenu))
   {
-    if (statusBar()->isHidden()) ((KToggleAction*)ACTION("show_statusbar"))->setChecked(false);
-    else ((KToggleAction*)ACTION("show_statusbar"))->setChecked(true);
+    if (statusBar()->isHidden()) ((KToggleAction*)ACTION("options_show_statusbar"))->setChecked(false);
+    else ((KToggleAction*)ACTION("options_show_statusbar"))->setChecked(true);
   }
 
   if (!menu || (menu&CheckOptionsMenu))
@@ -375,7 +376,7 @@ void Kwin4App::initGUI()
   (void)new KAction(i18n("&Network Configuration..."),0, this, SLOT(slotInitNetwork()),
                        actionCollection(), "file_network");
 
-  (void)new KAction(i18n("Chat Widget"),0, this, SLOT(slotChat()),
+  (void)new KAction(i18n("Chat Widget..."),0, this, SLOT(slotChat()),
                        actionCollection(), "file_chat");
 
   if (global_debug>0)                     
@@ -406,10 +407,7 @@ void Kwin4App::initGUI()
   ACTION("edit_redo")->setStatusText(i18n("Redo last move."));
   ACTION("edit_redo")->setWhatsThis(i18n("Redo last move."));
 
-  (void)new KToggleAction(i18n("&View Statusbar"),0,this,SLOT(slotViewStatusBar()),
-                      actionCollection(), "show_statusbar");
-  ACTION("show_statusbar")->setStatusText(i18n("Toggle the statusbar..."));
-  ACTION("show_statusbar")->setWhatsThis(i18n("Toggle the statusbar..."));
+  (void)KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());
 
   (void)new KSelectAction(i18n("Starting Player"),0,this,SLOT(slotStartplayer()),
                       actionCollection(), "startplayer");
@@ -587,7 +585,7 @@ void Kwin4App::saveOptions()
   config->writeEntry("ToolBarPos", (int) toolBar()->barPos());
 #endif
   config->writeEntry("Show Statusbar",statusBar()->isVisible());
-//  config->writeEntry("Recent Files", recentFiles);
+//  config->writePathEntry("Recent Files", recentFiles);
 
   doc->WriteConfig(config);
 
@@ -646,7 +644,7 @@ void Kwin4App::saveProperties(KConfig *_cfg)
   else
   {
     QString filename=doc->getAbsFilePath();
-    _cfg->writeEntry("filename", filename);
+    _cfg->writePathEntry("filename", filename);
 
     QString tempname = kapp->tempSaveName(filename);
     doc->saveDocument(tempname);
@@ -658,7 +656,7 @@ void Kwin4App::saveProperties(KConfig *_cfg)
  **/
 void Kwin4App::readProperties(KConfig* _cfg)
 {
-  QString filename = _cfg->readEntry("filename", "");
+  QString filename = _cfg->readPathEntry("filename");
   bool modified = _cfg->readBoolEntry("modified", false);
   if(modified)
   {
