@@ -202,7 +202,6 @@ const QString &Kwin4Doc::getTitle() const
 
 bool Kwin4Doc::newDocument(KConfig * /*config*/,QString path)
 {
-  int res;
   absFilePath=QDir::homeDirPath();
   if (global_debug>1) kdDebug() << "path=" << path << endl;
   return true;
@@ -235,7 +234,7 @@ void Kwin4Doc::SetColour(int x,int y,FARBE c){
     kdDebug() << "ERROR: SetColour auf falsche Poition " << x << " " << y << endl;
     return ;
   }
-  //kdDebug() << "mField["<<x+y*geom.field_mx<<"="<<c<<endl;
+  //kdDebug() << "SetColor::mField["<<x+y*geom.field_mx<<"="<<c<<endl;
   mField.setAt(x+y*geom.field_mx,c);
 }
 
@@ -342,7 +341,7 @@ void Kwin4Doc::moveDone(QCanvasItem *item,int )
 //  kdDebug() << "kwin4doc::moveDone::signalNextPlayer emitted" << endl;
 }
 
-KPlayer * Kwin4Doc::nextPlayer(KPlayer *last,bool exclusive)
+KPlayer * Kwin4Doc::nextPlayer(KPlayer *last,bool /*exclusive*/)
 {
   if (global_debug>1) kdDebug() << k_funcinfo << "nextPlayer last="<<last->id() << " admin="<<isAdmin()<<endl;
   // Should be enough if the admin sets the turn
@@ -354,7 +353,7 @@ KPlayer * Kwin4Doc::nextPlayer(KPlayer *last,bool exclusive)
     getPlayer(QueryCurrentPlayer())->setTurn(true,true);
   }
   emit signalMoveDone(0,0);
-
+  return getPlayer(QueryCurrentPlayer());
 }
 
 /** Make a game move */
@@ -421,8 +420,8 @@ MOVESTATUS Kwin4Doc::MakeMove(int x,int mode){
 /** Undo a move */
 bool Kwin4Doc::UndoMove(){
   int x,y;
-  kdDebug() <<" undo: current player="<<QueryCurrentPlayer() << endl;
-  kdDebug() <<" undo: history="<<QueryHistoryCnt() << endl;
+  //kdDebug() <<" undo: current player="<<QueryCurrentPlayer() << endl;
+  //kdDebug() <<" undo: history="<<QueryHistoryCnt() << endl;
   if (QueryHistoryCnt()<1) return false;
   if (mLastHint>=0)
   {
@@ -432,15 +431,16 @@ bool Kwin4Doc::UndoMove(){
     SetColour(mLastHint,hy,Niemand);
     mLastHint=-1;
   }
-  //kdDebug() << "Undo no="<<mHistoryCnt.value() << endl;
+  // kdDebug() << "Undo no="<<mHistoryCnt.value() << endl;
   mHistoryCnt=mHistoryCnt.value()-1;
   x=mHistory.at(QueryHistoryCnt());
   mFieldFilled.setAt(x,mFieldFilled.at(x)-1);
-  //field_filled[x]--;
-  //y=field_filled[x];
   y=mFieldFilled.at(x);
-  //kdDebug() << "Undo x="<<x << " y=" <<y << endl;
+  // kdDebug() << "Undo x="<<x << " y=" <<y << endl;
   SetColour(x,y,Niemand);
+  // We have to remove the piece as well...
+  pView->setPiece(x,y,Niemand,mCurrentMove-1,false);
+
   mLastColour=QueryCurrentPlayer();
   if (QueryCurrentPlayer()==Gelb) SetCurrentPlayer(Rot);
   else SetCurrentPlayer(Gelb);
@@ -628,7 +628,7 @@ int Kwin4Doc::CheckGameOver(int x, FARBE col){
       {
         //y=field_filled[x]-1-i;
         y=mFieldFilled.at(x)-1-i;
-        if (y>=geom.field_my) break;
+        if (y<0) break;
         if (QueryColour(xx,y)!=winc) break;
         pView->drawStar(xx,y,star++);
         cnt++;
@@ -642,7 +642,7 @@ int Kwin4Doc::CheckGameOver(int x, FARBE col){
       {
         //y=field_filled[x]-1-i;
         y=mFieldFilled.at(x)-1-i;
-        if (y<0) break;
+        if (y>=geom.field_my) break;
         if (QueryColour(xx,y)!=winc) break;
         pView->drawStar(xx,y,star++);
         cnt++;
@@ -742,7 +742,7 @@ long Kwin4Doc::QueryScore(){
 int Kwin4Doc::QueryHeight(int x){
   if (x<0 || x>=geom.field_mx)
   {
-    kdDebug() << "ERROR: Query Height for wrong x " << x << endl;
+    kdError() << "ERROR: Query Height for wrong x " << x << endl;
     return 0;
   }
   //return field_filled[x];
@@ -920,7 +920,7 @@ void Kwin4Doc::SetHost(QString host)
   mHost=host;
 }
 
-void Kwin4Doc::slotMessageUpdate(int id,Q_UINT32 sender,Q_UINT32 recv)
+void Kwin4Doc::slotMessageUpdate(int /*id*/,Q_UINT32 /*sender*/,Q_UINT32 /*recv*/)
 {
 //  kdDebug() << "MSG: id=" << id << " sender=" << sender << " receiver="<<recv<< endl;
 }
@@ -948,7 +948,7 @@ KPlayer *Kwin4Doc::createPlayer(int rtti,int io,bool isvirtual)
  */
 bool Kwin4Doc::playerInput(QDataStream &msg,KPlayer *player)
 {
-  Kwin4Player *p=(Kwin4Player *)player;
+  // Kwin4Player *p=(Kwin4Player *)player;
   Q_INT32 move,pl;
   msg >> pl >> move;
   if (global_debug>1)  kdDebug()  << "!!!!! Player " << pl << " id="<<player->id() 
@@ -1128,7 +1128,7 @@ void Kwin4Doc::prepareGameMessage(QDataStream &stream, Q_INT32 pl)
   stream << (Q_INT32)421256;
 }
 
-void Kwin4Doc::slotProcessQuery(QDataStream &in,KGameProcessIO *me)
+void Kwin4Doc::slotProcessQuery(QDataStream &in,KGameProcessIO * /*me*/)
 {
   Q_INT8 cid;
   in >> cid;
@@ -1249,7 +1249,7 @@ void Kwin4Doc::calcHint()
  * The compute rprocess sent a hint which we show in the
  * game board
  **/
-void Kwin4Doc::slotProcessHint(QDataStream &in,KGameProcessIO *me)
+void Kwin4Doc::slotProcessHint(QDataStream &in,KGameProcessIO * /*me*/)
 {
   Q_INT8 cid;
   in >> cid;
@@ -1404,7 +1404,7 @@ bool Kwin4Doc::loadgame(QDataStream &stream,bool network,bool reset)
  * what is local
  * This function is only called in the Admin.
  */
-void Kwin4Doc::newPlayersJoin(KGamePlayerList *oldList,KGamePlayerList *newList,QValueList<int> &inactivate)
+void Kwin4Doc::newPlayersJoin(KGamePlayerList * /*oldList*/,KGamePlayerList *newList,QValueList<int> &inactivate)
 {
   if (global_debug>1) kdDebug() << "newPlayersJoin: ================================= START =="<<endl;
   Kwin4Player *yellow=getPlayer(Gelb);
@@ -1417,7 +1417,7 @@ void Kwin4Doc::newPlayersJoin(KGamePlayerList *oldList,KGamePlayerList *newList,
     // Deactivate the lower one 
     inactivate.append(red->id());
     if (global_debug>1) kdDebug() << "ADMIN keeps yellow and kicks red= " << red->id()<<" userId/col="<<red->userId()<<endl;
-    // loop all client players and deactive the one which have the color
+    // loop all client players and deactivate the one which have the color
     // yellow
     for ( player=newList->first(); player != 0; player=newList->next() ) 
     {
@@ -1433,7 +1433,7 @@ void Kwin4Doc::newPlayersJoin(KGamePlayerList *oldList,KGamePlayerList *newList,
     // Deactivate the lower one 
     inactivate.append(yellow->id());
     if (global_debug>1) kdDebug() << "ADMIN keeps red and kicks yellow= " << yellow->id()<<" userId/col="<<yellow->userId()<<endl;
-    // loop all client players and deactive the one which have the color
+    // loop all client players and deactivate the one which have the color
     // red
     for ( player=newList->first(); player != 0; player=newList->next() ) 
     {
