@@ -74,7 +74,7 @@ ScoreWidget::ScoreWidget( QWidget* parent,  const char* name, WFlags fl )
 
 
     TextLabel2 = new KWLabel( this, "Move" );
-    TextLabel2->setText( i18n( "Move" ) );
+    TextLabel2->setText( i18n("number of MOVE in game", "Move" ) );
     TextLabel2->setBackgroundColor( COL_STATUSFIELD );
     LayoutB->addWidget( TextLabel2, row, 0 );
 
