@@ -17,7 +17,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kcarddialog.cpp,v 1.23.2.2 2003/08/31 17:49:21 mlaurent Exp $
+    $Id: kcarddialog.cpp,v 1.28 2003/08/31 17:48:30 mlaurent Exp $
 */
 
 #include <stdio.h>
@@ -93,7 +93,7 @@ public:
     QCheckBox* randomCardDir;
     QCheckBox* globalDeck;
     QCheckBox* globalCardDir;
-    
+
     QSlider* scaleSlider;
     QPixmap cPreviewPix;
     QLabel* cPreview;
@@ -110,7 +110,7 @@ public:
 };
 
 int KCardDialog::getCardDeck(QString &pDeck, QString &pCardDir, QWidget *pParent,
-                             CardFlags pFlags, bool* pRandomDeck, bool* pRandomCardDir, 
+                             CardFlags pFlags, bool* pRandomDeck, bool* pRandomCardDir,
 			     double* pScale, KConfig* pConf)
 {
     KCardDialog dlg(pParent, "dlg", pFlags);
@@ -140,12 +140,12 @@ int KCardDialog::getCardDeck(QString &pDeck, QString &pCardDir, QWidget *pParent
         {
             *pRandomCardDir = dlg.isRandomCardDir();
         }
-	if (pScale) 
+	if (pScale)
 	{
             *pScale = dlg.cardScale();
 	}
 
-        if (dlg.isGlobalDeck()) 
+        if (dlg.isGlobalDeck())
 	{
 	    kdDebug(11000) << "use global deck" << endl;
 	    bool random;
@@ -158,7 +158,7 @@ int KCardDialog::getCardDeck(QString &pDeck, QString &pCardDir, QWidget *pParent
 	        kdDebug(11000) << "use random deck" << endl;
 	    }
 	}
-        if (dlg.isGlobalCardDir()) 
+        if (dlg.isGlobalCardDir())
 	{
 	    kdDebug(11000) << "use global carddir" << endl;
 	    bool random;
@@ -193,21 +193,21 @@ void KCardDialog::getConfigCardDeck(KConfig* conf, QString &pDeck, QString &pCar
  if (conf->readBoolEntry(CONF_RANDOMCARDDIR) || !conf->hasKey(CONF_CARDDIR)) {
 	pCardDir = getRandomCardDir();
  } else {
-	pCardDir = conf->readEntry(CONF_CARDDIR);
+	pCardDir = conf->readPathEntry(CONF_CARDDIR);
  }
  pScale = conf->readDoubleNumEntry(CONF_SCALE, 1.0);
 
  if (conf->readBoolEntry(CONF_USEGLOBALDECK, false)) {
 	bool random;
 	getGlobalDeck(pCardDir, random);
-	if (random || pDeck == QString::null) {
+	if (random || pDeck.isNull() ) {
 		pDeck = getRandomDeck();
 	}
  }
  if (conf->readBoolEntry(CONF_USEGLOBALCARDDIR, false)) {
 	bool random;
 	getGlobalCardDir(pCardDir, random);
-	if (random || pCardDir == QString::null) {
+	if (random || pCardDir.isNull() ) {
 		pCardDir = getRandomCardDir();
 	}
  }
@@ -458,7 +458,7 @@ void KCardDialog::insertCardIcons()
         return;
 
     // We shrink the icons a little
-    // 
+    //
     QWMatrix m;
     m.scale(0.8,0.8);
 
@@ -669,7 +669,7 @@ void KCardDialog::loadConfig(KConfig* conf)
  }
  if (! (flags() & NoCards)) {
 	if (conf->hasKey(CONF_CARDDIR)) {
-		setCardDir(conf->readEntry(CONF_CARDDIR));
+		setCardDir(conf->readPathEntry(CONF_CARDDIR));
 	}
 
 	bool random = conf->readBoolEntry(CONF_RANDOMCARDDIR, false);
@@ -700,7 +700,7 @@ void KCardDialog::slotCardResized(int s)
 
  s *= -1;
  s += (SLIDER_MIN + SLIDER_MAX);
- 
+
  QWMatrix m;
  double scale = (double)1000/s;
  m.scale(scale, scale);
@@ -731,7 +731,7 @@ void KCardDialog::saveConfig(KConfig* conf)
 	conf->writeEntry(CONF_USEGLOBALDECK, d->globalDeck->isChecked());
  }
  if (! (flags() & NoCards)) {
-	conf->writeEntry(CONF_CARDDIR, cardDir());
+	conf->writePathEntry(CONF_CARDDIR, cardDir());
 	conf->writeEntry(CONF_RANDOMCARDDIR, isRandomCardDir());
 	conf->writeEntry(CONF_USEGLOBALCARDDIR, d->globalCardDir->isChecked());
  }
@@ -755,8 +755,8 @@ void KCardDialog::slotSetGlobalCardDir()
 {
  KSimpleConfig* conf = new KSimpleConfig(QString::fromLatin1("kdeglobals"), false);
  conf->setGroup(CONF_GLOBAL_GROUP);
- 
- conf->writeEntry(CONF_GLOBAL_CARDDIR, cardDir());
+
+ conf->writePathEntry(CONF_GLOBAL_CARDDIR, cardDir());
  conf->writeEntry(CONF_GLOBAL_RANDOMCARDDIR, isRandomCardDir());
 
  delete conf;
@@ -766,7 +766,7 @@ void KCardDialog::getGlobalDeck(QString& deck, bool& random)
 {
  KSimpleConfig* conf = new KSimpleConfig(QString::fromLatin1("kdeglobals"), true);
  conf->setGroup(CONF_GLOBAL_GROUP);
- 
+
  if (!conf->hasKey(CONF_GLOBAL_DECK) || conf->readBoolEntry(CONF_GLOBAL_RANDOMDECK, false)) {
 	deck = getRandomDeck();
 	random = true;
@@ -782,12 +782,12 @@ void KCardDialog::getGlobalCardDir(QString& dir, bool& random)
 {
  KSimpleConfig* conf = new KSimpleConfig(QString::fromLatin1("kdeglobals"), true);
  conf->setGroup(CONF_GLOBAL_GROUP);
- 
+
  if (!conf->hasKey(CONF_GLOBAL_CARDDIR) || conf->readBoolEntry(CONF_GLOBAL_RANDOMCARDDIR, false)) {
 	dir = getRandomCardDir();
 	random = true;
  } else {
-	dir = conf->readEntry(CONF_GLOBAL_CARDDIR);
+	dir = conf->readPathEntry(CONF_GLOBAL_CARDDIR);
 	random = conf->readBoolEntry(CONF_GLOBAL_RANDOMCARDDIR, false);
  }
 
@@ -800,6 +800,7 @@ void KCardDialog::init()
     if (_inited)
         return;
     KGlobal::dirs()->addResourceType("cards", KStandardDirs::kde_default("data") + QString::fromLatin1("carddecks/"));
+
     KGlobal::locale()->insertCatalogue("libkdegames");
     _inited = true;
 }
