@@ -18,15 +18,17 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgame.cpp,v 1.81 2002/07/14 20:03:26 heni Exp $
+    $Id: kgame.cpp,v 1.89 2003/07/01 00:31:38 mueller Exp $
 */
 
+#include "kgame.h"
+#include "kgame.moc"
 #include "kgamepropertyhandler.h"
 #include "kgameproperty.h"
 #include "kplayer.h"
-#include "kgame.h"
 #include "kgameio.h"
 #include "kgameerror.h"
+#include "kgamesequence.h"
 
 #include "kgamemessage.h"
 
@@ -53,15 +55,15 @@ public:
     KGamePrivate()
     {
         mUniquePlayerNumber = 0;
-        mCurrentPlayer = 0 ; // use this only for the singleShot otherwise load problems
         mPolicy=KGame::PolicyLocal;
+        mGameSequence = 0;
     }
 
     int mUniquePlayerNumber;
-    KPlayer *mCurrentPlayer;
     QPtrQueue<KPlayer> mAddPlayerList;// this is a list of to-be-added players. See addPlayer() docu
     KRandomSequence* mRandom;
     KGame::GamePolicy mPolicy;
+    KGameSequence* mGameSequence;
 
 
     KGamePropertyHandler* mProperties;
@@ -85,14 +87,14 @@ KGame::KGame(int cookie,QObject* parent) : KGameNetwork(cookie,parent)
  d = new KGamePrivate;
 
  d->mProperties = new KGamePropertyHandler(this);
-  
+
  d->mProperties->registerHandler(KGameMessage::IdGameProperty,
                                 this,SLOT(sendProperty(int, QDataStream&, bool* )),
                                      SLOT(emitSignal(KGamePropertyBase *)));
  d->mMaxPlayer.registerData(KGamePropertyBase::IdMaxPlayer, this, i18n("MaxPlayers"));
  d->mMaxPlayer.setLocal(-1);  // Infinite
  d->mMinPlayer.registerData(KGamePropertyBase::IdMinPlayer, this, i18n("MinPlayers"));
- d->mMinPlayer.setLocal(0);   // Always ok     
+ d->mMinPlayer.setLocal(0);   // Always ok
  d->mGameStatus.registerData(KGamePropertyBase::IdGameStatus, this, i18n("GameStatus"));
  d->mGameStatus.setLocal(Init);
  // d->mUniquePlayerNumber = 0;
@@ -100,12 +102,13 @@ KGame::KGame(int cookie,QObject* parent) : KGameNetwork(cookie,parent)
  d->mRandom->setSeed(0);
 
  connect(this, SIGNAL(signalClientConnected(Q_UINT32)),
- 	this, SLOT(slotClientConnected(Q_UINT32)));
+                this, SLOT(slotClientConnected(Q_UINT32)));
  connect(this, SIGNAL(signalClientDisconnected(Q_UINT32,bool)),
- 	this, SLOT(slotClientDisconnected(Q_UINT32,bool)));
- connect(this, SIGNAL(signalConnectionBroken()), 
-		this, SLOT(slotServerDisconnected()));
+                this, SLOT(slotClientDisconnected(Q_UINT32,bool)));
+ connect(this, SIGNAL(signalConnectionBroken()),
+                this, SLOT(slotServerDisconnected()));
 
+ setGameSequence(new KGameSequence());
 
  // BL: FIXME This signal does no longer exist. When we are merging
  // MH: super....and how do I find out about the lost conenction now?
@@ -119,6 +122,7 @@ KGame::~KGame()
  kdDebug(11001) << k_funcinfo << endl;
 // Debug();
  reset();
+ delete d->mGameSequence;
  delete d->mRandom;
  delete d;
  kdDebug(11001) << k_funcinfo << " done" << endl;
@@ -136,7 +140,7 @@ void KGame::deletePlayers()
 // kdDebug(11001) << k_funcinfo << endl;
  KGamePlayerList tmp = d->mPlayerList; // in case of PolicyClean player=d->mPlayerList.first() is infinite
  KPlayer *player;
- while((player=tmp.first())) 
+ while((player=tmp.first()))
  {
    delete player; // delete and removes the player
    tmp.removeFirst();
@@ -147,7 +151,7 @@ void KGame::deletePlayers()
 void KGame::deleteInactivePlayers()
 {
  KPlayer *player;
- while((player=d->mInactivePlayerList.first())) 
+ while((player=d->mInactivePlayerList.first()))
  {
    //player->setGame(0); // prevent call backs
    d->mInactivePlayerList.remove(player);
@@ -157,12 +161,12 @@ void KGame::deleteInactivePlayers()
 
 bool KGame::load(QString filename,bool reset)
 {
-  if (filename.isNull()) 
+  if (filename.isNull())
   {
     return false;
   }
   QFile f(filename);
-  if (!f.open(IO_ReadOnly)) 
+  if (!f.open(IO_ReadOnly))
   {
     return false;
   }
@@ -191,14 +195,17 @@ bool KGame::loadgame(QDataStream &stream, bool network,bool resetgame)
    return result;
  }
  if (resetgame) reset();
- 
+
  uint i;
  stream >> i;
 // setPolicy((GamePolicy)i);
 
  stream >> d->mUniquePlayerNumber;
 
- d->mCurrentPlayer=0;  // TODO !!!
+ if (gameSequence())
+ {
+   gameSequence()->setCurrentPlayer(0);  // TODO !!!
+ }
  int newseed;
  stream >> newseed;
  d->mRandom->setSeed(newseed);
@@ -259,12 +266,12 @@ bool KGame::loadgame(QDataStream &stream, bool network,bool resetgame)
 
 bool KGame::save(QString filename,bool saveplayers)
 {
- if (filename.isNull()) 
+ if (filename.isNull())
  {
    return false;
  }
  QFile f(filename);
- if (!f.open(IO_WriteOnly)) 
+ if (!f.open(IO_WriteOnly))
  {
    return false;
  }
@@ -294,7 +301,7 @@ bool KGame::savegame(QDataStream &stream,bool /*network*/,bool saveplayers)
 
  // Properties
  dataHandler()->save(stream);
- 
+
  // Save all data that need to be saved *before* the players are saved
  emit signalSavePrePlayers(stream);
 
@@ -322,13 +329,13 @@ void KGame::savePlayer(QDataStream &stream,KPlayer* p)
  p->save(stream);
 }
 
-void KGame::savePlayers(QDataStream &stream, KGamePlayerList *list) 
+void KGame::savePlayers(QDataStream &stream, KGamePlayerList *list)
 {
- if (!list) 
+ if (!list)
  {
    list=playerList();
  }
- 
+
  Q_INT32 cnt=list->count();
  kdDebug(11001) << "Saving KGame " << cnt << " KPlayer objects " << endl;
  stream << cnt;
@@ -351,7 +358,7 @@ KPlayer *KGame::loadPlayer(QDataStream& stream,bool isvirtual)
   KPlayer *newplayer=findPlayer(id);
   if (!newplayer)
   {
-    kdDebug(11001) << k_funcinfo << ":   Player "<< id << "not found...asking user to create one " << endl;
+    kdDebug(11001) << k_funcinfo << "Player "<< id << " not found...asking user to create one " << endl;
     newplayer=createPlayer(rtti,iovalue,isvirtual);
     //emit signalCreatePlayer(newplayer,rtti,iovalue,isvirtual,this);
   }
@@ -378,16 +385,16 @@ KPlayer *KGame::loadPlayer(QDataStream& stream,bool isvirtual)
 
 KPlayer * KGame::findPlayer(Q_UINT32 id) const
 {
- for (QPtrListIterator<KPlayer> it(d->mPlayerList); it.current(); ++it) 
+ for (QPtrListIterator<KPlayer> it(d->mPlayerList); it.current(); ++it)
  {
-   if (it.current()->id() == id) 
+   if (it.current()->id() == id)
    {
      return it.current();
    }
  }
- for (QPtrListIterator<KPlayer> it(d->mInactivePlayerList); it.current(); ++it) 
+ for (QPtrListIterator<KPlayer> it(d->mInactivePlayerList); it.current(); ++it)
  {
-   if (it.current()->id() == id) 
+   if (it.current()->id() == id)
    {
      return it.current();
    }
@@ -410,7 +417,7 @@ void KGame::addPlayer(KPlayer* newplayer)
   kdFatal(11001) << "trying to add NULL player in KGame::addPlayer()" << endl;
   return ;
  }
-  
+
  if (maxPlayers() >= 0 && (int)playerCount() >= maxPlayers())
  {
    kdWarning(11001) << "cannot add more than " << maxPlayers() << " players - deleting..." << endl;
@@ -418,6 +425,19 @@ void KGame::addPlayer(KPlayer* newplayer)
    return;
  }
 
+ if (newplayer->id() == 0)
+ {
+   d->mUniquePlayerNumber++;
+   newplayer->setId(KGameMessage::createPlayerId(d->mUniquePlayerNumber, gameId()));
+   kdDebug(11001) << k_funcinfo << "NEW!!! player " << newplayer << " now has id " << newplayer->id() << endl;
+ }
+ else
+ {
+   // this could happen in games which use their own ID management by certain
+   // reasons. that is NOT recommended
+   kdDebug(11001) << k_funcinfo << "player " << newplayer << " already has an id: " << newplayer->id() << endl;
+ }
+
  QByteArray buffer;
  QDataStream stream(buffer,IO_WriteOnly);
  // We distinguis here what policy we have
@@ -429,39 +449,40 @@ void KGame::addPlayer(KPlayer* newplayer)
  {
    savePlayer(stream,newplayer);
    // Store the player for delayed clean adding
-   if (policy()==PolicyClean) d->mAddPlayerList.enqueue(newplayer);
+   if (policy()==PolicyClean)
+   {
+     d->mAddPlayerList.enqueue(newplayer);
+   }
    sendSystemMessage(stream,(int)KGameMessage::IdAddPlayer, 0);
  }
 }
 
 void KGame::systemAddPlayer(KPlayer* newplayer)
 {
- if (!newplayer) 
+ if (!newplayer)
  {
    kdFatal(11001) << "trying to add NULL player in KGame::systemAddPlayer()" << endl;
    return ;
  }
- if (newplayer->id() == 0) 
+ if (newplayer->id() == 0)
  {
-   d->mUniquePlayerNumber++;
-   newplayer->setId(KGameMessage::createPlayerId(d->mUniquePlayerNumber,gameId()));
-   kdDebug(11001) << k_funcinfo << ": NEW!!! player " << newplayer << " now has id " << newplayer->id() << endl;
+   kdWarning(11001) << k_funcinfo << "player " << newplayer << " has no ID" << endl;
  }
 
- if (findPlayer(newplayer->id())) 
+ if (findPlayer(newplayer->id()))
  {
    kdError(11001) << "ERROR: Double adding player !!!!! NOT GOOD !!!!!! " << newplayer->id() << "...I delete it again" << endl;
    delete newplayer;
- } 
- else 
+ }
+ else
  {
    kdDebug(11001) << "Trying to add player " << newplayer <<" maxPlayers="<<maxPlayers()<<" playerCount="<<playerCount() << endl;
    // Add the player to the game
-   d->mPlayerList.append(newplayer); 
+   d->mPlayerList.append(newplayer);
    newplayer->setGame(this);
    kdDebug(11001) << "Player: isVirtual=" << newplayer->isVirtual() << endl;
    kdDebug(11001) << "        id=" << newplayer->id() << "  #Players="
-                  << d->mPlayerList.count() << " added " << newplayer 
+                  << d->mPlayerList.count() << " added " << newplayer
                   << "  (virtual=" << newplayer->isVirtual() << ")" << endl;
    emit signalPlayerJoinedGame(newplayer);
  }
@@ -510,17 +531,18 @@ bool KGame::removePlayer(KPlayer * player, Q_UINT32 receiver)
 
 void KGame::systemRemovePlayer(KPlayer* player,bool deleteit)
 {
- if (!player) 
+ kdDebug(11001) << k_funcinfo << endl;
+ if (!player)
  {
    kdWarning(11001) << "cannot remove NULL player" << endl;
    return;
  }
- if (!systemRemove(player,deleteit)) 
+ if (!systemRemove(player,deleteit))
  {
    kdWarning(11001) << "player " << player << "(" << player->id() << ") Could not be found!" << endl;
  }
 
- if (gameStatus()==(int)Run && playerCount()<minPlayers()) 
+ if (gameStatus()==(int)Run && playerCount()<minPlayers())
  {
    kdWarning(11001) << k_funcinfo ": not enough players, PAUSING game\n" << endl;
    setGameStatus(Pause);
@@ -529,7 +551,7 @@ void KGame::systemRemovePlayer(KPlayer* player,bool deleteit)
 
 bool KGame::systemRemove(KPlayer* p,bool deleteit)
 {
- if (!p) 
+ if (!p)
  {
    kdWarning(11001) << "cannot remove NULL player" << endl;
    return false;
@@ -537,11 +559,11 @@ bool KGame::systemRemove(KPlayer* p,bool deleteit)
  bool result;
  kdDebug(11001) << k_funcinfo << ": Player (" << p->id() << ") to be removed " << p << endl;
 
- if (d->mPlayerList.count() == 0) 
+ if (d->mPlayerList.count() == 0)
  {
    result = false;
  }
- else 
+ else
  {
    result = d->mPlayerList.remove(p);
  }
@@ -549,7 +571,7 @@ bool KGame::systemRemove(KPlayer* p,bool deleteit)
  emit signalPlayerLeftGame(p);
 
  p->setGame(0);
- if (deleteit) 
+ if (deleteit)
  {
    delete p;
  }
@@ -579,7 +601,7 @@ bool KGame::inactivatePlayer(KPlayer* player)
 
 bool KGame::systemInactivatePlayer(KPlayer* player)
 {
- if (!player || !player->isActive()) 
+ if (!player || !player->isActive())
  {
    return false;
  }
@@ -587,16 +609,16 @@ bool KGame::systemInactivatePlayer(KPlayer* player)
 
  int pid=player->id();
  // Virtual players cannot be deactivated. They will be removed
- if (player->isVirtual()) 
+ if (player->isVirtual())
  {
    systemRemovePlayer(player,true);
  }
- else 
+ else
  {
    d->mPlayerList.remove(player);
    d->mInactivePlayerList.prepend(player);
    player->setActive(false);
- } 
+ }
  emit signalPlayerLeftGame(player);
  if (isAdmin())
  {
@@ -625,7 +647,7 @@ bool KGame::activatePlayer(KPlayer * player)
 
 bool KGame::systemActivatePlayer(KPlayer* player)
 {
- if (!player || player->isActive()) 
+ if (!player || player->isActive())
  {
    return false;
  }
@@ -686,12 +708,12 @@ KRandomSequence* KGame::random() const
 
 bool KGame::sendPlayerInput(QDataStream &msg, KPlayer *player, Q_UINT32 sender)
 {
- if (!player) 
+ if (!player)
  {
    kdError(11001) << k_funcinfo << ": NULL player" << endl;
    return false;
  }
- if (!isRunning()) 
+ if (!isRunning())
  {
    kdError(11001) << k_funcinfo << ": game not running" << endl;
    return false;
@@ -704,12 +726,12 @@ bool KGame::sendPlayerInput(QDataStream &msg, KPlayer *player, Q_UINT32 sender)
 
 bool KGame::systemPlayerInput(QDataStream &msg, KPlayer *player, Q_UINT32 sender)
 {
- if (!player) 
+ if (!player)
  {
    kdError(11001) << k_funcinfo << ": NULL player" << endl;
    return false;
  }
- if (!isRunning()) 
+ if (!isRunning())
  {
    kdError(11001) << k_funcinfo << ": game not running" << endl;
    return false;
@@ -722,7 +744,9 @@ bool KGame::systemPlayerInput(QDataStream &msg, KPlayer *player, Q_UINT32 sender
  else
  {
    kdDebug(11001) << k_funcinfo<<": switching off player input"<<endl;
-   if (!player->asyncInput()) 
+   // TODO: (MH 03-2003): We need an return option from playerInput so that
+   // the player's is not automatically disabled here 
+   if (!player->asyncInput())
    {
      player->setTurn(false); // in turn based games we have to switch off input now
    }
@@ -730,97 +754,79 @@ bool KGame::systemPlayerInput(QDataStream &msg, KPlayer *player, Q_UINT32 sender
  return true;
 }
 
-  
+
 KPlayer * KGame::playerInputFinished(KPlayer *player)
 {
  kdDebug(11001) << k_funcinfo<<"player input finished for "<<player->id()<<endl;
  // Check for game over and if not allow the next player to move
- d->mCurrentPlayer=player;
- int gameOver=checkGameOver(player);
- if (gameOver!=0) 
+ int gameOver = 0;
+ if (gameSequence())
  {
-   if (player) player->setTurn(false);
+   gameSequence()->setCurrentPlayer(player);
+ }
+ // do not call gameSequence()->checkGameOver() to keep backward compatibility!
+ gameOver = checkGameOver(player);
+ if (gameOver!=0)
+ {
+   if (player)
+   {
+     player->setTurn(false);
+   }
    setGameStatus(End);
    emit signalGameOver(gameOver,player,this);
  }
- else if (!player->asyncInput()) 
+ else if (!player->asyncInput())
  {
    player->setTurn(false); // in turn based games we have to switch off input now
-   QTimer::singleShot(0,this,SLOT(prepareNext()));
+   if (gameSequence())
+   {
+     QTimer::singleShot(0,this,SLOT(prepareNext()));
+   }
  }
  return player;
 }
 
 // Per default we do not do anything
-int KGame::checkGameOver(KPlayer *)
+int KGame::checkGameOver(KPlayer *player)
 {
+ if (gameSequence())
+ {
+   return gameSequence()->checkGameOver(player);
+ }
  return 0;
 }
 
+void KGame::setGameSequence(KGameSequence* sequence)
+{
+ delete d->mGameSequence;
+ d->mGameSequence = sequence;
+ if (d->mGameSequence)
+ {
+   d->mGameSequence->setGame(this);
+ }
+}
+
+KGameSequence* KGame::gameSequence() const
+{
+  return d->mGameSequence;
+}
+
 void KGame::prepareNext()
 {
- nextPlayer(d->mCurrentPlayer);
+ if (gameSequence())
+ {
+   // we don't call gameSequence->nextPlayer() to keep old code working
+   nextPlayer(gameSequence()->currentPlayer());
+ }
 }
 
 KPlayer *KGame::nextPlayer(KPlayer *last,bool exclusive)
 {
- kdDebug(11001) << "=================== NEXT PLAYER =========================="<<endl;
- unsigned int minId,nextId,lastId;
- KPlayer *nextplayer, *minplayer;
- if (last) 
+ if (gameSequence())
  {
-   lastId = last->id();
+   return gameSequence()->nextPlayer(last, exclusive);
  }
- else 
- {
-   lastId = 0;
- }
-
- kdDebug(11001) << "nextPlayer: lastId="<<lastId<<endl;
- 
- // remove when this has been checked
- minId = 0x7fff;  // we just need a very large number...properly MAX_UINT or so would be ok...
- nextId = minId;
- nextplayer = 0;
- minplayer = 0;
-
- KPlayer *player;
- for ( player=d->mPlayerList.first(); player != 0; player=d->mPlayerList.next() ) 
- {
-   // Find the first player for a cycle
-   if (player->id() < minId) 
-   {
-     minId=player->id();
-     minplayer=player;
-   }
-   if (player==last) 
-   {
-     continue;
-   }
-   // Find the next player which is bigger than the current one
-   if (player->id() > lastId && player->id() < nextId) 
-   {
-     nextId=player->id();
-     nextplayer=player;
-   }
- }
-
- // Cycle to the beginning
- if (!nextplayer) 
- {
-   nextplayer=minplayer;
- }
-
- kdDebug(11001) << k_funcinfo << " ##### lastId=" << lastId << " exclusive=" << exclusive << "  minId=" << minId << " nextid=" << nextId << " count=" <<d->mPlayerList.count()  << endl;
- if (nextplayer) 
- {
-   nextplayer->setTurn(true,exclusive);
- }
- else 
- {
-   return 0;
- }
- return nextplayer;
+ return 0;
 }
 
 void KGame::setGameStatus(int status)
@@ -848,18 +854,18 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
  emit signalMessageUpdate(msgid, receiver, sender);
  if (KGameMessage::isPlayer(receiver))
  {
-   //kdDebug(11001) << "message id " << msgid << " seems to be for a player ("<<active=p->isActive()<<" recv="<< recevier << endl;
+   //kdDebug(11001) << "message id " << msgid << " seems to be for a player ("<<active=p->isActive()<<" recv="<< receiver << endl;
    KPlayer *p=findPlayer(receiver);
    if (p && p->isActive())
    {
      p->networkTransmission(stream,msgid,sender);
      return;
    }
-   if (p) 
+   if (p)
    {
       kdDebug(11001) << "player is here but not active" << endl;
    }
-   else 
+   else
    {
       kdDebug(11001) << "no player found" << endl;
    }
@@ -874,7 +880,7 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
    return ;
  }
 
- switch(msgid) 
+ switch(msgid)
  {
    case KGameMessage::IdSetupGame:  // Client: First step in setup game
    {
@@ -884,18 +890,18 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
      kdDebug(11001) << " ===================> (Client) " << k_funcinfo << ": Got IdSetupGame ================== " << endl;
      kdDebug(11001) << "our game id is " << gameId() << " Lib version=" << v << " App Cookie=" << c << endl; 
      // Verify identity of the network partners
-     if (c!=cookie()) 
+     if (c!=cookie())
      {
        kdError(11001) << "IdGameSetup: Negotiate Game: cookie mismatch I'am="<<cookie()<<" master="<<c<<endl;
        sendError(KGameError::Cookie, KGameError::errCookie(cookie(), c));
        disconnect(); // disconnect from master
      }
-     else if (v!=KGameMessage::version()) 
+     else if (v!=KGameMessage::version())
      {
        sendError(KGameError::Version, KGameError::errVersion(v));
        disconnect(); // disconnect from master
      }
-     else 
+     else
      {
        setupGame(sender);
      }
@@ -942,7 +948,10 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
           kdDebug(11001) << "dequeue previously added player" << endl;
           newplayer = d->mAddPlayerList.dequeue();
        }
-       else newplayer=loadPlayer(stream,true);
+       else
+       {
+         newplayer=loadPlayer(stream,true);
+       }
        systemAddPlayer(newplayer);// the final, local, adding
        //systemAddPlayer(stream);
      }
@@ -962,6 +971,10 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
          systemRemovePlayer(p,true);
        }
      }
+     else
+     {
+       kdWarning(11001) << k_funcinfo << "Cannot find player " << id << endl;
+     }
    }
    break;
    case KGameMessage::IdGameLoad:
@@ -976,7 +989,7 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
      stream >> cid;
      kdDebug(11001) << "====> (CLIENT) " << k_funcinfo << ": Got IdGameSetupDone for client "
              << cid << " we are =" << gameId() << endl;
-     sendSystemMessage(gameId(), KGameMessage::IdGameConnected);
+     sendSystemMessage(gameId(), KGameMessage::IdGameConnected, 0);
    }
    break;
    case KGameMessage::IdGameConnected:
@@ -987,7 +1000,7 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
      emit signalClientJoinedGame(cid,this);
    }
    break;
-     
+
    case KGameMessage::IdSyncRandom:  // Master forces a new random seed on us
    {
      int newseed;
@@ -1000,10 +1013,10 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
    {
    // if we disconnect we *always* start a local game. 
    // this could lead into problems if we just change the message server
-     if (sender != gameId()) 
+     if (sender != gameId())
      {
          kdDebug(11001) << "client " << sender << " leaves game" << endl;
-	 return;
+         return;
      }
      kdDebug(11001) << "leaving the game" << endl;
      // start a new local game
@@ -1014,7 +1027,7 @@ void KGame::networkTransmission(QDataStream &stream, int msgid, Q_UINT32 receive
    break;
    default:
     {
-     if (msgid < KGameMessage::IdUser) 
+     if (msgid < KGameMessage::IdUser)
      {
        kdError(11001) << "incorrect message id " << msgid << " - emit anyway"
                       << endl;
@@ -1070,9 +1083,9 @@ void KGame::setupGameContinue(QDataStream& stream, Q_UINT32 sender)
   kdDebug(11001) << " havePlayers " << cnt+playerCount()-inactivateIds.count() << endl;
   while (maxPlayers() > 0 && maxPlayers() < (int)(cnt+playerCount() - inactivateIds.count()))
   {
-    kdDebug(11001) << "  Still to deacticvate " 
+    kdDebug(11001) << "  Still to deacticvate "
             << (int)(cnt+playerCount()-inactivateIds.count())-(int)maxPlayers() 
-	    << endl;
+            << endl;
     KPlayer *currentPlayer=0;
     int currentPriority=0x7fff; // MAX_UINT (16bit?) to get the maximum of the list
     // find lowest network priority which is not yet in the newPlayerList
@@ -1113,7 +1126,7 @@ void KGame::setupGameContinue(QDataStream& stream, Q_UINT32 sender)
       kdDebug(11001) << "Marking player " << currentPlayer->id() << " for inactivation" << endl;
       inactivateIds.append(currentPlayer->id());
     }
-    else 
+    else
     {
       kdError(11001) << "Couldn't find a player to dectivate..That is not so good..." << endl;
       break;
@@ -1134,7 +1147,7 @@ void KGame::setupGameContinue(QDataStream& stream, Q_UINT32 sender)
   for ( it = inactivateIds.begin(); it != inactivateIds.end(); ++it )
   {
     int pid=*it;
-    if (KGameMessage::rawGameId(pid) == sender) 
+    if (KGameMessage::rawGameId(pid) == sender)
     {
       continue; // client's player
     }
@@ -1156,16 +1169,16 @@ void KGame::setupGameContinue(QDataStream& stream, Q_UINT32 sender)
   }
 
   // Now send out the player list which the client can activate
-  for ( player=newPlayerList.first(); player != 0; player=newPlayerList.next() ) 
+  for ( player=newPlayerList.first(); player != 0; player=newPlayerList.next() )
   {
     kdDebug(11001) << " newplayerlist contains " << player->id() << endl;
     // Only activate what is not in the list
-    if (inactivateIds.find(player->id())!=inactivateIds.end()) 
+    if (inactivateIds.find(player->id())!=inactivateIds.end())
     {
       continue;
     }
     kdDebug(11001) << " -> the client can ******** reactivate ********  " << player->id() << endl;
-    sendSystemMessage(player->id(), KGameMessage::IdActivatePlayer,sender);
+    sendSystemMessage(player->id(), KGameMessage::IdActivatePlayer, sender);
   }
 
   // Save the game over the network
@@ -1174,7 +1187,7 @@ void KGame::setupGameContinue(QDataStream& stream, Q_UINT32 sender)
   // Save game over netowrk and save players
   savegame(streamS,true,true);
   sendSystemMessage(streamS,KGameMessage::IdGameLoad,sender);
- 
+
 
   // Only to the client first , as the client will add players
   sendSystemMessage(sender, KGameMessage::IdGameSetupDone, sender);
@@ -1182,7 +1195,7 @@ void KGame::setupGameContinue(QDataStream& stream, Q_UINT32 sender)
 
 // called by the IdSetupGame Message - CLIENT SIDE
 // Client needs to prepare for network transfer
-void KGame::setupGame(Q_UINT32 sender)  
+void KGame::setupGame(Q_UINT32 sender)
 {
   QByteArray bufferS;
   QDataStream streamS(bufferS,IO_WriteOnly);
@@ -1196,7 +1209,7 @@ void KGame::setupGame(Q_UINT32 sender)
 
   QPtrListIterator<KPlayer> it(mTmpList);
   KPlayer *player;
-  while (it.current()) 
+  while (it.current())
   {
     player=it.current();
     systemInactivatePlayer(player);
@@ -1240,7 +1253,7 @@ void KGame::Debug()
 
 void KGame::slotClientConnected(Q_UINT32 clientID)
 {
- if (isAdmin()) 
+ if (isAdmin())
  {
    negotiateNetworkGame(clientID);
  }
@@ -1312,7 +1325,7 @@ void KGame::slotClientDisconnected(Q_UINT32 clientID,bool /*broken*/) // server
  KPlayer *player;
  KGamePlayerList removeList;
  kdDebug(11001) << "Playerlist of client=" << d->mPlayerList.count() << " count" << endl;
- for ( player=d->mPlayerList.first(); player != 0; player=d->mPlayerList.next() ) 
+ for ( player=d->mPlayerList.first(); player != 0; player=d->mPlayerList.next() )
  {
    if (KGameMessage::rawGameId(player->id())==clientID)
    {
@@ -1357,7 +1370,7 @@ void KGame::slotClientDisconnected(Q_UINT32 clientID,bool /*broken*/) // server
 void KGame::negotiateNetworkGame(Q_UINT32 clientID)
 {
  kdDebug(11001) << "===========================" << k_funcinfo << ": clientID=" << clientID << " =========================== "<< endl;
- if (!isAdmin()) 
+ if (!isAdmin())
  {
    kdError(11001) << k_funcinfo << ": Serious WARNING..only gameAdmin should call this" << endl;
    return ;
@@ -1382,9 +1395,9 @@ bool KGame::sendGroupMessage(const QByteArray &msg, int msgid, Q_UINT32 sender,
 // AB: group must not be i18n'ed!! we should better use an id for group and use
 // a groupName() for the name // FIXME
  KPlayer *player;
- for ( player=d->mPlayerList.first(); player != 0; player=d->mPlayerList.next() ) 
+ for ( player=d->mPlayerList.first(); player != 0; player=d->mPlayerList.next() )
  {
-   if (player && player->group()==group) 
+   if (player && player->group()==group)
    {
      sendMessage(msg,msgid,player->id(), sender);
    }
@@ -1403,7 +1416,6 @@ bool KGame::sendGroupMessage(const QString& msg, int msgid, Q_UINT32 sender, con
  return sendGroupMessage(stream, msgid, sender, group);
 }
 
-
 bool KGame::addProperty(KGamePropertyBase* data)
 { return dataHandler()->addProperty(data); }
 
@@ -1413,7 +1425,7 @@ bool KGame::sendPlayerProperty(int msgid, QDataStream& s, Q_UINT32 playerId)
 void KGame::sendProperty(int msgid, QDataStream& stream, bool* sent)
 {
   bool s = sendSystemMessage(stream, msgid);
-  if (s) 
+  if (s)
   {
     *sent = true;
   }
@@ -1437,20 +1449,21 @@ void KGame::setPolicy(GamePolicy p,bool recursive)
  d->mPolicy=p;
  if (recursive)
  {
-   // Set all KGame property policy 
+   // Set all KGame property policy
    dataHandler()->setPolicy((KGamePropertyBase::PropertyPolicy)p,false);
 
    // Set all KPLayer (active or inactive) property policy
-   for (QPtrListIterator<KPlayer> it(d->mPlayerList); it.current(); ++it) 
+   for (QPtrListIterator<KPlayer> it(d->mPlayerList); it.current(); ++it)
    {
      it.current()->dataHandler()->setPolicy((KGamePropertyBase::PropertyPolicy)p,false);
    }
-   for (QPtrListIterator<KPlayer> it(d->mInactivePlayerList); it.current(); ++it) 
+   for (QPtrListIterator<KPlayer> it(d->mInactivePlayerList); it.current(); ++it)
    {
      it.current()->dataHandler()->setPolicy((KGamePropertyBase::PropertyPolicy)p,false);
    }
  }
 }
 
-
-#include "kgame.moc"
+/*
+ * vim: et sw=2
+ */
