@@ -19,7 +19,7 @@ BaseFactory::BaseFactory(const MainData &md, const BaseBoardInfo &bi)
     _aboutData =
         new KAboutData(md.name, md.trName, md.longVersion, md.description,
                        KAboutData::License_GPL,
-                       "(c) 1995, Eirik End\n(c) 1996-2002, Nicolas Hadacek",
+                       "(c) 1995, Eirik Eng\n(c) 1996-2002, Nicolas Hadacek",
                        0, md.homepage);
     _aboutData->addAuthor("Nicolas Hadacek", 0, "hadacek@kde.org");
     _aboutData->addCredit("Eirik Eng", I18N_NOOP("Core engine"));
@@ -28,9 +28,8 @@ BaseFactory::BaseFactory(const MainData &md, const BaseBoardInfo &bi)
 void BaseFactory::init(int argc, char **argv)
 {
     KCmdLineArgs::init(argc, argv, _aboutData);
-	(void)new KApplication;
+    (void)new KApplication;
     KGlobal::locale()->insertCatalogue("libkdegames");
-    KGlobal::locale()->insertCatalogue("libkdehighscores");
     KGlobal::locale()->insertCatalogue("libksirtet");
 }
 
@@ -42,7 +41,12 @@ BaseFactory::~BaseFactory()
     _self = 0;
 }
 
-KConfigWidget *BaseFactory::createAppearanceConfig()
+QWidget *BaseFactory::createAppearanceConfig()
 {
-    return new AppearanceConfig;
+    return new BaseAppearanceConfig;
+}
+
+QWidget *BaseFactory::createColorConfig()
+{
+    return new ColorConfig;
 }
