@@ -21,12 +21,14 @@ struct BaseBoardInfo {
     const uint *histogram;
     uint histogramSize;
     bool scoreBound;
+
+    // settings defaults
+    uint minBlockSize, maxBlockSize, defaultBlockSize;
 };
 
 class BaseBoard;
 class BaseInterface;
 class QWidget;
-class KConfigWidget;
 class KAboutData;
 
 #define bfactory BaseFactory::self()
@@ -46,8 +48,9 @@ class BaseFactory
     virtual BaseBoard *createBoard(bool graphic, QWidget *parent) = 0;
     virtual BaseInterface *createInterface(QWidget *parent) = 0;
 
-    virtual KConfigWidget *createAppearanceConfig();
-    virtual KConfigWidget *createGameConfig() = 0;
+    virtual QWidget *createAppearanceConfig();
+    virtual QWidget *createColorConfig();
+    virtual QWidget *createGameConfig() { return 0; }
 
  private:
     static BaseFactory *_self;
