@@ -5,42 +5,42 @@
 
 
 class BaseInterface;
-class KConfigCollection;
-class KConfigDialog;
 class KToggleAction;
 class KKeyDialog;
+class KConfigDialog;
 
 class BaseMainWindow : public KMainWindow
 {
- Q_OBJECT
- public:
+    Q_OBJECT
+public:
     BaseMainWindow();
-	virtual ~BaseMainWindow();
+    virtual ~BaseMainWindow();
 
- signals:
+signals:
     void settingsChanged();
 
- private slots:
-	void toggleMenubar();
+private slots:
+    void toggleMenubar();
     void start();
     void pause();
     void showHighscores();
     void configureSettings();
     void configureKeys();
+    void configureHighscores();
+    void configureNotifications();
 
- protected:
+protected:
     BaseInterface     *_inter;
-    KConfigCollection *_configCollection;
 
-	bool eventFilter(QObject *, QEvent *);
+    bool eventFilter(QObject *, QEvent *);
     bool queryExit();
     void readSettings();
     void buildGUI(QWidget *);
-    virtual void addConfigWidgets(KConfigDialog &);
+    virtual void addConfig(KConfigDialog *) {}
     virtual void addKeys(KKeyDialog &) {}
     virtual void saveKeys() {}
 
- private:
+private:
     KToggleAction *_menu, *_pause;
 };
 
