@@ -5,17 +5,16 @@
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kkeydialog.h>
+#include <kconfigdialog.h>
 
-#include "settings.h"
 #include "inter.h"
 #include "factory.h"
 
 
-void MainWindow::addConfigWidgets(KConfigDialog &d)
+void MainWindow::addConfig(KConfigDialog *dialog)
 {
-    BaseMainWindow::addConfigWidgets(d);
-    KConfigWidget *cw = cfactory->createAIConfig();
-    if (cw) d.append(cw);
+    QWidget *w = cfactory->createAIConfig();
+    if (w) dialog->addPage(w, i18n("A.I."), "ai");
 }
 
 void MainWindow::init()
@@ -23,7 +22,7 @@ void MainWindow::init()
     Interface *inter = static_cast<Interface *>(_inter);
     inter->normalGame();
 
-	// Modes
+    // Modes
     bool ama = ( bfactory->bbi.nbArcadeStages!=0 );
     QString s = (ama ? i18n("&Single Human (Normal)") : i18n("&Single Human"));
     (void)new KAction(s, 0, inter, SLOT(normalGame()),
@@ -31,15 +30,17 @@ void MainWindow::init()
     if (ama) (void)new KAction(i18n("&Single Human (Arcade)"), 0,
                                inter, SLOT(arcadeGame()),
                                actionCollection(), "mp_arcade");
-	(void)new KAction(i18n("Human vs &Human"), 0, inter, SLOT(humanVsHuman()),
-					  actionCollection(), "mp_human_vs_human");
-	(void)new KAction(i18n("Human vs &Computer"), 0,
-					  inter, SLOT(humanVsComputer()),
-					  actionCollection(), "mp_human_vs_computer");
-	(void)new KAction(i18n("&More..."), 0, inter, SLOT(dialog()),
-					  actionCollection(), "mp_more");
+    (void)new KAction(i18n("Human vs &Human"), 0, inter, SLOT(humanVsHuman()),
+                      actionCollection(), "mp_human_vs_human");
+    (void)new KAction(i18n("Human vs &Computer"), 0,
+                      inter, SLOT(humanVsComputer()),
+                      actionCollection(), "mp_human_vs_computer");
+    (void)new KAction(i18n("&More..."), 0, inter, SLOT(dialog()),
+                      actionCollection(), "mp_more");
 
     buildGUI(inter);
+    connect(this, SIGNAL(settingsChanged()),
+            inter, SLOT(settingsChangedSlot()));
 }
 
 void MainWindow::addKeys(KKeyDialog &d)
