@@ -21,10 +21,10 @@ class MPSimpleInterface : public MPInterface
 	void addKeys(KKeyDialog &);
 
  protected:
-	virtual void _init(bool server) = 0;
+	virtual void _init() = 0;
 	virtual void _readGameOverData(QDataStream &s) = 0;
 	virtual void _sendGameOverData(QDataStream &s) = 0;
-	virtual void _showGameOverData(bool server) = 0;
+	virtual void _showGameOverData() = 0;
 	virtual void _firstInit() = 0;
 	virtual void _treatInit() = 0;
 	virtual bool _readPlayData() = 0;
@@ -40,8 +40,8 @@ class MPSimpleInterface : public MPInterface
 	void treatPause(bool pause);
 	void treatStop();
 
-	void init(bool server);
-	void stop(bool server);
+	void init();
+	void stop();
 	void dataFromServer(QDataStream &);
 };
 
