@@ -1,5 +1,5 @@
 /***************************************************************************
-                          Msgdlg  -  Send message to remote 
+                          Msgdlg  -  Send message to remote
                              -------------------
     begin                : Thu Mar 30 2000
     copyright            : (C) |1995-2000 by Martin Heni
@@ -17,20 +17,21 @@
 /*
     Msgdlg.cpp
 
-    $Id: msgdlg.cpp,v 1.8 2002/07/09 08:43:42 binner Exp $
-    
+    $Id: msgdlg.cpp,v 1.8.4.1 2004/04/14 16:24:51 binner Exp $
+
     Msg dialog for player names
-    
+
     (c) Martin Heni, martin@heni-online.de
 	      June 1999
-    
+
     License: GPL
 
 */
 
 #include <qgroupbox.h>
-#include <qpushbutton.h>
 #include <klocale.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 #include "msgdlg.h"
 
 
@@ -41,7 +42,7 @@ MsgDlg::MsgDlg( QWidget *parent, const char *name,const char * /*sufi */ )
 {
   setCaption(i18n("Send Message to Remote Player"));
   setMinimumSize(400,160);
-  setMaximumSize(600,360);                                                        
+  setMaximumSize(600,360);
   resize( 400, 160 );
 
   QGroupBox* grp;
@@ -54,16 +55,14 @@ MsgDlg::MsgDlg( QWidget *parent, const char *name,const char * /*sufi */ )
   MultiLine->setText(QCString("") );
 
   QPushButton *PushButton;
-  PushButton = new QPushButton( this, "PushButton_1" );
+  PushButton = new QPushButton( i18n("Send" ), this, "PushButton_1" );
   PushButton->setGeometry( 20, 120, 65, 30 );
   connect( PushButton, SIGNAL(clicked()), SLOT(accept()) );
-  PushButton->setText( i18n("Send" ));
   PushButton->setAutoRepeat( FALSE );
 
-  PushButton = new QPushButton( this, "PushButton_2" );
+  PushButton = new KPushButton( KStdGuiItem::cancel(), this, "PushButton_2" );
   PushButton->setGeometry( 305, 120, 65, 30 );
   connect( PushButton, SIGNAL(clicked()), SLOT(reject()) );
-  PushButton->setText( i18n("Cancel" ));
   PushButton->setAutoRepeat( FALSE );
 }
 
